/****************************************************************************
** Meta object code from reading C++ file 'alias_config.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/config/alias_config.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'alias_config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Alias_Config_t {
    QByteArrayData data[12];
    char stringdata0[130];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Alias_Config_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Alias_Config_t qt_meta_stringdata_Alias_Config = {
    {
QT_MOC_LITERAL(0, 0, 12), // "Alias_Config"
QT_MOC_LITERAL(1, 13, 8), // "modified"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 13), // "entrySelected"
QT_MOC_LITERAL(4, 37, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(5, 54, 10), // "aliasEntry"
QT_MOC_LITERAL(6, 65, 11), // "nameChanged"
QT_MOC_LITERAL(7, 77, 7), // "newName"
QT_MOC_LITERAL(8, 85, 13), // "actionChanged"
QT_MOC_LITERAL(9, 99, 9), // "newAction"
QT_MOC_LITERAL(10, 109, 8), // "addEntry"
QT_MOC_LITERAL(11, 118, 11) // "removeEntry"

    },
    "Alias_Config\0modified\0\0entrySelected\0"
    "QTreeWidgetItem*\0aliasEntry\0nameChanged\0"
    "newName\0actionChanged\0newAction\0"
    "addEntry\0removeEntry"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Alias_Config[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   45,    2, 0x09 /* Protected */,
       6,    1,   48,    2, 0x09 /* Protected */,
       8,    1,   51,    2, 0x09 /* Protected */,
      10,    0,   54,    2, 0x09 /* Protected */,
      11,    0,   55,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Alias_Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Alias_Config *_t = static_cast<Alias_Config *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modified(); break;
        case 1: _t->entrySelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->nameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->actionChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->addEntry(); break;
        case 5: _t->removeEntry(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Alias_Config::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Alias_Config::modified)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Alias_Config::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Alias_Config.data,
      qt_meta_data_Alias_Config,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Alias_Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Alias_Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Alias_Config.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KonviSettingsPage"))
        return static_cast< KonviSettingsPage*>(this);
    return QWidget::qt_metacast(_clname);
}

int Alias_Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Alias_Config::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
