#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'identitydialog.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IDENTITYDIALOG_H
#define UI_IDENTITYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "kpluralhandlingspinbox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_IdentityDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *identityBarHLayout;
    QLabel *label;
    KComboBox *m_identityCBox;
    QHBoxLayout *identityButtonsHLayout;
    QPushButton *newBtn;
    QPushButton *copyBtn;
    QPushButton *m_editBtn;
    QPushButton *m_delBtn;
    QTabWidget *tabWidget;
    QWidget *generalWidget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *realNameHLayout;
    QLabel *realNameLabel;
    KLineEdit *m_realNameEdit;
    QGroupBox *autoIdentifyGroup;
    QFormLayout *autoIdentifyLayout;
    QLabel *authTypeLabel;
    KComboBox *m_authTypeCombo;
    QLabel *nickservNicknameLabel;
    KLineEdit *m_nickservNicknameEdit;
    QLabel *nickservCommandLabel;
    KLineEdit *m_nickservCommandEdit;
    QLabel *saslAccountLabel;
    KLineEdit *m_saslAccountEdit;
    QLabel *authPasswordLabel;
    KLineEdit *m_authPasswordEdit;
    QLabel *pemClientCertFileLabel;
    KUrlRequester *m_pemClientCertFile;
    QWidget *awayWidget;
    QFormLayout *formLayout_3;
    QCheckBox *m_insertRememberLineOnAwayChBox;
    QLabel *awayMessageLabel;
    KLineEdit *m_awayMessageEdit;
    QLabel *awayNicknameLabel;
    KLineEdit *m_awayNickEdit;
    QGroupBox *automaticAwayGroup;
    QGridLayout *gridLayout_3;
    QLabel *setAwayAfterLabel;
    KPluralHandlingSpinBox *m_awayInactivitySpin;
    QLabel *timeOfUserInactivityLabel;
    QCheckBox *m_automaticUnawayChBox;
    QGroupBox *awayCommandsGroup;
    QFormLayout *formLayout_2;
    QLabel *awayLabel;
    KLineEdit *m_awayEdit;
    QLabel *unAwayLabel;
    KLineEdit *m_unAwayEdit;
    QSpacerItem *awayWidgetVSpacer;
    QWidget *advancedWidget;
    QFormLayout *formLayout;
    QLabel *sCommandLabel;
    KLineEdit *m_sCommandEdit;
    QLabel *codecLabel;
    KComboBox *m_codecCBox;
    QLabel *loginLabel;
    KLineEdit *m_loginEdit;
    QLabel *quitLabel;
    KLineEdit *m_quitEdit;
    QLabel *partLabel;
    KLineEdit *m_partEdit;
    QLabel *kickLabel;
    KLineEdit *m_kickEdit;

    void setupUi(QWidget *IdentityDialog)
    {
        if (IdentityDialog->objectName().isEmpty())
            IdentityDialog->setObjectName(QStringLiteral("IdentityDialog"));
        IdentityDialog->resize(331, 344);
        verticalLayout_2 = new QVBoxLayout(IdentityDialog);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        identityBarHLayout = new QHBoxLayout();
        identityBarHLayout->setObjectName(QStringLiteral("identityBarHLayout"));
        label = new QLabel(IdentityDialog);
        label->setObjectName(QStringLiteral("label"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        identityBarHLayout->addWidget(label);

        m_identityCBox = new KComboBox(IdentityDialog);
        m_identityCBox->setObjectName(QStringLiteral("m_identityCBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_identityCBox->sizePolicy().hasHeightForWidth());
        m_identityCBox->setSizePolicy(sizePolicy1);

        identityBarHLayout->addWidget(m_identityCBox);

        identityButtonsHLayout = new QHBoxLayout();
        identityButtonsHLayout->setObjectName(QStringLiteral("identityButtonsHLayout"));
        newBtn = new QPushButton(IdentityDialog);
        newBtn->setObjectName(QStringLiteral("newBtn"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(newBtn->sizePolicy().hasHeightForWidth());
        newBtn->setSizePolicy(sizePolicy2);
        newBtn->setMinimumSize(QSize(28, 28));
        newBtn->setMaximumSize(QSize(28, 28));
        newBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(newBtn);

        copyBtn = new QPushButton(IdentityDialog);
        copyBtn->setObjectName(QStringLiteral("copyBtn"));
        sizePolicy2.setHeightForWidth(copyBtn->sizePolicy().hasHeightForWidth());
        copyBtn->setSizePolicy(sizePolicy2);
        copyBtn->setMinimumSize(QSize(28, 28));
        copyBtn->setMaximumSize(QSize(28, 28));
        copyBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(copyBtn);

        m_editBtn = new QPushButton(IdentityDialog);
        m_editBtn->setObjectName(QStringLiteral("m_editBtn"));
        sizePolicy2.setHeightForWidth(m_editBtn->sizePolicy().hasHeightForWidth());
        m_editBtn->setSizePolicy(sizePolicy2);
        m_editBtn->setMinimumSize(QSize(28, 28));
        m_editBtn->setMaximumSize(QSize(28, 28));
        m_editBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(m_editBtn);

        m_delBtn = new QPushButton(IdentityDialog);
        m_delBtn->setObjectName(QStringLiteral("m_delBtn"));
        sizePolicy2.setHeightForWidth(m_delBtn->sizePolicy().hasHeightForWidth());
        m_delBtn->setSizePolicy(sizePolicy2);
        m_delBtn->setMinimumSize(QSize(28, 28));
        m_delBtn->setMaximumSize(QSize(28, 28));
        m_delBtn->setIconSize(QSize(16, 16));

        identityButtonsHLayout->addWidget(m_delBtn);


        identityBarHLayout->addLayout(identityButtonsHLayout);


        verticalLayout_2->addLayout(identityBarHLayout);

        tabWidget = new QTabWidget(IdentityDialog);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        generalWidget = new QWidget();
        generalWidget->setObjectName(QStringLiteral("generalWidget"));
        verticalLayout = new QVBoxLayout(generalWidget);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        realNameHLayout = new QHBoxLayout();
        realNameHLayout->setObjectName(QStringLiteral("realNameHLayout"));
        realNameLabel = new QLabel(generalWidget);
        realNameLabel->setObjectName(QStringLiteral("realNameLabel"));

        realNameHLayout->addWidget(realNameLabel);

        m_realNameEdit = new KLineEdit(generalWidget);
        m_realNameEdit->setObjectName(QStringLiteral("m_realNameEdit"));

        realNameHLayout->addWidget(m_realNameEdit);


        verticalLayout->addLayout(realNameHLayout);

        autoIdentifyGroup = new QGroupBox(generalWidget);
        autoIdentifyGroup->setObjectName(QStringLiteral("autoIdentifyGroup"));
        autoIdentifyLayout = new QFormLayout(autoIdentifyGroup);
        autoIdentifyLayout->setObjectName(QStringLiteral("autoIdentifyLayout"));
        autoIdentifyLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        authTypeLabel = new QLabel(autoIdentifyGroup);
        authTypeLabel->setObjectName(QStringLiteral("authTypeLabel"));

        autoIdentifyLayout->setWidget(0, QFormLayout::LabelRole, authTypeLabel);

        m_authTypeCombo = new KComboBox(autoIdentifyGroup);
        m_authTypeCombo->setObjectName(QStringLiteral("m_authTypeCombo"));

        autoIdentifyLayout->setWidget(0, QFormLayout::FieldRole, m_authTypeCombo);

        nickservNicknameLabel = new QLabel(autoIdentifyGroup);
        nickservNicknameLabel->setObjectName(QStringLiteral("nickservNicknameLabel"));

        autoIdentifyLayout->setWidget(2, QFormLayout::LabelRole, nickservNicknameLabel);

        m_nickservNicknameEdit = new KLineEdit(autoIdentifyGroup);
        m_nickservNicknameEdit->setObjectName(QStringLiteral("m_nickservNicknameEdit"));

        autoIdentifyLayout->setWidget(2, QFormLayout::FieldRole, m_nickservNicknameEdit);

        nickservCommandLabel = new QLabel(autoIdentifyGroup);
        nickservCommandLabel->setObjectName(QStringLiteral("nickservCommandLabel"));

        autoIdentifyLayout->setWidget(3, QFormLayout::LabelRole, nickservCommandLabel);

        m_nickservCommandEdit = new KLineEdit(autoIdentifyGroup);
        m_nickservCommandEdit->setObjectName(QStringLiteral("m_nickservCommandEdit"));

        autoIdentifyLayout->setWidget(3, QFormLayout::FieldRole, m_nickservCommandEdit);

        saslAccountLabel = new QLabel(autoIdentifyGroup);
        saslAccountLabel->setObjectName(QStringLiteral("saslAccountLabel"));

        autoIdentifyLayout->setWidget(4, QFormLayout::LabelRole, saslAccountLabel);

        m_saslAccountEdit = new KLineEdit(autoIdentifyGroup);
        m_saslAccountEdit->setObjectName(QStringLiteral("m_saslAccountEdit"));

        autoIdentifyLayout->setWidget(4, QFormLayout::FieldRole, m_saslAccountEdit);

        authPasswordLabel = new QLabel(autoIdentifyGroup);
        authPasswordLabel->setObjectName(QStringLiteral("authPasswordLabel"));

        autoIdentifyLayout->setWidget(5, QFormLayout::LabelRole, authPasswordLabel);

        m_authPasswordEdit = new KLineEdit(autoIdentifyGroup);
        m_authPasswordEdit->setObjectName(QStringLiteral("m_authPasswordEdit"));
        m_authPasswordEdit->setPasswordMode(true);

        autoIdentifyLayout->setWidget(5, QFormLayout::FieldRole, m_authPasswordEdit);

        pemClientCertFileLabel = new QLabel(autoIdentifyGroup);
        pemClientCertFileLabel->setObjectName(QStringLiteral("pemClientCertFileLabel"));

        autoIdentifyLayout->setWidget(6, QFormLayout::LabelRole, pemClientCertFileLabel);

        m_pemClientCertFile = new KUrlRequester(autoIdentifyGroup);
        m_pemClientCertFile->setObjectName(QStringLiteral("m_pemClientCertFile"));

        autoIdentifyLayout->setWidget(6, QFormLayout::FieldRole, m_pemClientCertFile);


        verticalLayout->addWidget(autoIdentifyGroup);

        tabWidget->addTab(generalWidget, QString());
        awayWidget = new QWidget();
        awayWidget->setObjectName(QStringLiteral("awayWidget"));
        formLayout_3 = new QFormLayout(awayWidget);
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        m_insertRememberLineOnAwayChBox = new QCheckBox(awayWidget);
        m_insertRememberLineOnAwayChBox->setObjectName(QStringLiteral("m_insertRememberLineOnAwayChBox"));

        formLayout_3->setWidget(0, QFormLayout::SpanningRole, m_insertRememberLineOnAwayChBox);

        awayMessageLabel = new QLabel(awayWidget);
        awayMessageLabel->setObjectName(QStringLiteral("awayMessageLabel"));

        formLayout_3->setWidget(1, QFormLayout::LabelRole, awayMessageLabel);

        m_awayMessageEdit = new KLineEdit(awayWidget);
        m_awayMessageEdit->setObjectName(QStringLiteral("m_awayMessageEdit"));

        formLayout_3->setWidget(1, QFormLayout::FieldRole, m_awayMessageEdit);

        awayNicknameLabel = new QLabel(awayWidget);
        awayNicknameLabel->setObjectName(QStringLiteral("awayNicknameLabel"));

        formLayout_3->setWidget(2, QFormLayout::LabelRole, awayNicknameLabel);

        m_awayNickEdit = new KLineEdit(awayWidget);
        m_awayNickEdit->setObjectName(QStringLiteral("m_awayNickEdit"));

        formLayout_3->setWidget(2, QFormLayout::FieldRole, m_awayNickEdit);

        automaticAwayGroup = new QGroupBox(awayWidget);
        automaticAwayGroup->setObjectName(QStringLiteral("automaticAwayGroup"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(automaticAwayGroup->sizePolicy().hasHeightForWidth());
        automaticAwayGroup->setSizePolicy(sizePolicy3);
        automaticAwayGroup->setCheckable(true);
        automaticAwayGroup->setChecked(false);
        gridLayout_3 = new QGridLayout(automaticAwayGroup);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        setAwayAfterLabel = new QLabel(automaticAwayGroup);
        setAwayAfterLabel->setObjectName(QStringLiteral("setAwayAfterLabel"));
        sizePolicy2.setHeightForWidth(setAwayAfterLabel->sizePolicy().hasHeightForWidth());
        setAwayAfterLabel->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(setAwayAfterLabel, 0, 0, 1, 1);

        m_awayInactivitySpin = new KPluralHandlingSpinBox(automaticAwayGroup);
        m_awayInactivitySpin->setObjectName(QStringLiteral("m_awayInactivitySpin"));
        sizePolicy2.setHeightForWidth(m_awayInactivitySpin->sizePolicy().hasHeightForWidth());
        m_awayInactivitySpin->setSizePolicy(sizePolicy2);
        m_awayInactivitySpin->setMinimum(1);

        gridLayout_3->addWidget(m_awayInactivitySpin, 0, 1, 1, 1);

        timeOfUserInactivityLabel = new QLabel(automaticAwayGroup);
        timeOfUserInactivityLabel->setObjectName(QStringLiteral("timeOfUserInactivityLabel"));
        sizePolicy3.setHeightForWidth(timeOfUserInactivityLabel->sizePolicy().hasHeightForWidth());
        timeOfUserInactivityLabel->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(timeOfUserInactivityLabel, 0, 2, 1, 1);

        m_automaticUnawayChBox = new QCheckBox(automaticAwayGroup);
        m_automaticUnawayChBox->setObjectName(QStringLiteral("m_automaticUnawayChBox"));

        gridLayout_3->addWidget(m_automaticUnawayChBox, 1, 0, 1, 3);


        formLayout_3->setWidget(3, QFormLayout::SpanningRole, automaticAwayGroup);

        awayCommandsGroup = new QGroupBox(awayWidget);
        awayCommandsGroup->setObjectName(QStringLiteral("awayCommandsGroup"));
        sizePolicy1.setHeightForWidth(awayCommandsGroup->sizePolicy().hasHeightForWidth());
        awayCommandsGroup->setSizePolicy(sizePolicy1);
        awayCommandsGroup->setCheckable(true);
        awayCommandsGroup->setChecked(false);
        formLayout_2 = new QFormLayout(awayCommandsGroup);
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        awayLabel = new QLabel(awayCommandsGroup);
        awayLabel->setObjectName(QStringLiteral("awayLabel"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, awayLabel);

        m_awayEdit = new KLineEdit(awayCommandsGroup);
        m_awayEdit->setObjectName(QStringLiteral("m_awayEdit"));

        formLayout_2->setWidget(0, QFormLayout::FieldRole, m_awayEdit);

        unAwayLabel = new QLabel(awayCommandsGroup);
        unAwayLabel->setObjectName(QStringLiteral("unAwayLabel"));

        formLayout_2->setWidget(1, QFormLayout::LabelRole, unAwayLabel);

        m_unAwayEdit = new KLineEdit(awayCommandsGroup);
        m_unAwayEdit->setObjectName(QStringLiteral("m_unAwayEdit"));

        formLayout_2->setWidget(1, QFormLayout::FieldRole, m_unAwayEdit);


        formLayout_3->setWidget(4, QFormLayout::SpanningRole, awayCommandsGroup);

        awayWidgetVSpacer = new QSpacerItem(20, 45, QSizePolicy::Minimum, QSizePolicy::Expanding);

        formLayout_3->setItem(5, QFormLayout::LabelRole, awayWidgetVSpacer);

        tabWidget->addTab(awayWidget, QString());
        advancedWidget = new QWidget();
        advancedWidget->setObjectName(QStringLiteral("advancedWidget"));
        formLayout = new QFormLayout(advancedWidget);
        formLayout->setObjectName(QStringLiteral("formLayout"));
        sCommandLabel = new QLabel(advancedWidget);
        sCommandLabel->setObjectName(QStringLiteral("sCommandLabel"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(sCommandLabel->sizePolicy().hasHeightForWidth());
        sCommandLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(0, QFormLayout::LabelRole, sCommandLabel);

        m_sCommandEdit = new KLineEdit(advancedWidget);
        m_sCommandEdit->setObjectName(QStringLiteral("m_sCommandEdit"));

        formLayout->setWidget(0, QFormLayout::FieldRole, m_sCommandEdit);

        codecLabel = new QLabel(advancedWidget);
        codecLabel->setObjectName(QStringLiteral("codecLabel"));
        QSizePolicy sizePolicy5(QSizePolicy::Fixed, QSizePolicy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(codecLabel->sizePolicy().hasHeightForWidth());
        codecLabel->setSizePolicy(sizePolicy5);

        formLayout->setWidget(1, QFormLayout::LabelRole, codecLabel);

        m_codecCBox = new KComboBox(advancedWidget);
        m_codecCBox->setObjectName(QStringLiteral("m_codecCBox"));

        formLayout->setWidget(1, QFormLayout::FieldRole, m_codecCBox);

        loginLabel = new QLabel(advancedWidget);
        loginLabel->setObjectName(QStringLiteral("loginLabel"));
        sizePolicy4.setHeightForWidth(loginLabel->sizePolicy().hasHeightForWidth());
        loginLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(2, QFormLayout::LabelRole, loginLabel);

        m_loginEdit = new KLineEdit(advancedWidget);
        m_loginEdit->setObjectName(QStringLiteral("m_loginEdit"));

        formLayout->setWidget(2, QFormLayout::FieldRole, m_loginEdit);

        quitLabel = new QLabel(advancedWidget);
        quitLabel->setObjectName(QStringLiteral("quitLabel"));
        sizePolicy4.setHeightForWidth(quitLabel->sizePolicy().hasHeightForWidth());
        quitLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(3, QFormLayout::LabelRole, quitLabel);

        m_quitEdit = new KLineEdit(advancedWidget);
        m_quitEdit->setObjectName(QStringLiteral("m_quitEdit"));

        formLayout->setWidget(3, QFormLayout::FieldRole, m_quitEdit);

        partLabel = new QLabel(advancedWidget);
        partLabel->setObjectName(QStringLiteral("partLabel"));
        sizePolicy4.setHeightForWidth(partLabel->sizePolicy().hasHeightForWidth());
        partLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(4, QFormLayout::LabelRole, partLabel);

        m_partEdit = new KLineEdit(advancedWidget);
        m_partEdit->setObjectName(QStringLiteral("m_partEdit"));

        formLayout->setWidget(4, QFormLayout::FieldRole, m_partEdit);

        kickLabel = new QLabel(advancedWidget);
        kickLabel->setObjectName(QStringLiteral("kickLabel"));
        sizePolicy4.setHeightForWidth(kickLabel->sizePolicy().hasHeightForWidth());
        kickLabel->setSizePolicy(sizePolicy4);

        formLayout->setWidget(5, QFormLayout::LabelRole, kickLabel);

        m_kickEdit = new KLineEdit(advancedWidget);
        m_kickEdit->setObjectName(QStringLiteral("m_kickEdit"));

        formLayout->setWidget(5, QFormLayout::FieldRole, m_kickEdit);

        tabWidget->addTab(advancedWidget, QString());

        verticalLayout_2->addWidget(tabWidget);

#ifndef UI_QT_NO_SHORTCUT
        label->setBuddy(m_identityCBox);
        realNameLabel->setBuddy(m_realNameEdit);
        authTypeLabel->setBuddy(m_authTypeCombo);
        nickservNicknameLabel->setBuddy(m_nickservNicknameEdit);
        nickservCommandLabel->setBuddy(m_nickservCommandEdit);
        saslAccountLabel->setBuddy(m_saslAccountEdit);
        authPasswordLabel->setBuddy(m_authPasswordEdit);
        awayMessageLabel->setBuddy(m_awayMessageEdit);
        awayNicknameLabel->setBuddy(m_awayNickEdit);
        awayLabel->setBuddy(m_awayEdit);
        unAwayLabel->setBuddy(m_unAwayEdit);
        sCommandLabel->setBuddy(m_sCommandEdit);
        codecLabel->setBuddy(m_codecCBox);
        loginLabel->setBuddy(m_loginEdit);
        quitLabel->setBuddy(m_quitEdit);
        partLabel->setBuddy(m_partEdit);
        kickLabel->setBuddy(m_kickEdit);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(m_identityCBox, newBtn);
        QWidget::setTabOrder(newBtn, copyBtn);
        QWidget::setTabOrder(copyBtn, m_editBtn);
        QWidget::setTabOrder(m_editBtn, m_delBtn);
        QWidget::setTabOrder(m_delBtn, tabWidget);
        QWidget::setTabOrder(tabWidget, m_realNameEdit);
        QWidget::setTabOrder(m_realNameEdit, m_authTypeCombo);
        QWidget::setTabOrder(m_authTypeCombo, m_nickservNicknameEdit);
        QWidget::setTabOrder(m_nickservNicknameEdit, m_nickservCommandEdit);
        QWidget::setTabOrder(m_nickservCommandEdit, m_saslAccountEdit);
        QWidget::setTabOrder(m_saslAccountEdit, m_authPasswordEdit);
        QWidget::setTabOrder(m_authPasswordEdit, m_pemClientCertFile);
        QWidget::setTabOrder(m_pemClientCertFile, m_insertRememberLineOnAwayChBox);
        QWidget::setTabOrder(m_insertRememberLineOnAwayChBox, m_awayMessageEdit);
        QWidget::setTabOrder(m_awayMessageEdit, m_awayNickEdit);
        QWidget::setTabOrder(m_awayNickEdit, automaticAwayGroup);
        QWidget::setTabOrder(automaticAwayGroup, m_awayInactivitySpin);
        QWidget::setTabOrder(m_awayInactivitySpin, m_automaticUnawayChBox);
        QWidget::setTabOrder(m_automaticUnawayChBox, awayCommandsGroup);
        QWidget::setTabOrder(awayCommandsGroup, m_awayEdit);
        QWidget::setTabOrder(m_awayEdit, m_unAwayEdit);
        QWidget::setTabOrder(m_unAwayEdit, m_sCommandEdit);
        QWidget::setTabOrder(m_sCommandEdit, m_codecCBox);
        QWidget::setTabOrder(m_codecCBox, m_loginEdit);
        QWidget::setTabOrder(m_loginEdit, m_quitEdit);
        QWidget::setTabOrder(m_quitEdit, m_partEdit);
        QWidget::setTabOrder(m_partEdit, m_kickEdit);

        retranslateUi(IdentityDialog);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(IdentityDialog);
    } // setupUi

    void retranslateUi(QWidget *IdentityDialog)
    {
        label->setText(tr2i18n("&Identity:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        newBtn->setToolTip(tr2i18n("Add", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_TOOLTIP
        copyBtn->setToolTip(tr2i18n("Duplicate", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_TOOLTIP
        m_editBtn->setToolTip(tr2i18n("Rename", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_TOOLTIP
        m_delBtn->setToolTip(tr2i18n("Remove", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        realNameLabel->setText(tr2i18n("&Real name:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_realNameEdit->setWhatsThis(tr2i18n("Enter your real name here. IRC is not intended to keep you hidden from your friends or enemies. Keep this in mind if you are tempted to behave maliciously. A fake \"real name\" can be a good way to mask your gender from all the nerds out there, but the PC you use can always be traced so you will never be truly anonymous.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        autoIdentifyGroup->setTitle(tr2i18n("Auto Identify", Q_NULLPTR));
        authTypeLabel->setText(tr2i18n("Type:", Q_NULLPTR));
        nickservNicknameLabel->setText(tr2i18n("Ser&vice:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_nickservNicknameEdit->setWhatsThis(tr2i18n("Service name can be <b><i>nickserv</i></b> or a network-dependent name such as <b><i>nickserv@services.dal.net</i></b>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nickservCommandLabel->setText(tr2i18n("Command:", Q_NULLPTR));
        saslAccountLabel->setText(tr2i18n("Account:", Q_NULLPTR));
        authPasswordLabel->setText(tr2i18n("Pa&ssword:", Q_NULLPTR));
        pemClientCertFileLabel->setText(tr2i18n("PEM file:", Q_NULLPTR));
        m_pemClientCertFile->setFilter(tr2i18n("*.pem", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(generalWidget), tr2i18n("General", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_insertRememberLineOnAwayChBox->setWhatsThis(tr2i18n("If you check this box, whenever you perform an <b>/away</b> command, a horizontal line will appear in the channel, marking the point where you went away. Other IRC users do not see this horizontal line.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_insertRememberLineOnAwayChBox->setText(tr2i18n("Mark the last position in chat windows when going away", Q_NULLPTR));
        awayMessageLabel->setText(tr2i18n("Default away message:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_awayMessageEdit->setWhatsThis(tr2i18n("The text you enter here is used as the away message when no message is entered as an argument to the <b>/away</b> or <b>/aaway</b> commands, and also when Global Away is toggled from the menu or via the keyboard shortcut.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        awayNicknameLabel->setText(tr2i18n("Away nickname:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_awayNickEdit->setWhatsThis(tr2i18n("Enter a nickname that indicates you are away. Whenever you perform an <b>/away msg</b> command in any channel joined with this Identity, Konversation will automatically change your nickname to the Away nickname. Other users will be able to tell you are away from your computer. Whenever you perform an <b>/away</b> command in any channel in which you are away, Konversation will automatically change your nickname back to the original. If you do not wish to automatically change your nickname when going away, leave blank.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        automaticAwayGroup->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically set all connections using this Identity away when the screensaver starts or after a period of user inactivity configured below.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        automaticAwayGroup->setTitle(tr2i18n("Automatic Away", Q_NULLPTR));
        setAwayAfterLabel->setText(tr2i18n("Set away after", Q_NULLPTR));
        timeOfUserInactivityLabel->setText(tr2i18n("of user inactivity", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_automaticUnawayChBox->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically cancel away for all connections using this Identity when the screensaver stops or new user activity is detected.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_automaticUnawayChBox->setText(tr2i18n("Automatically return on activity", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        awayCommandsGroup->setWhatsThis(tr2i18n("If you check this box, Konversation will automatically run the away command in all channel tabs using this Identity. <b>%s</b> in the away command is replaced with the away message. When you return, it will run the return command. <b>%t</b> in the return command is replaced with the length of time you were away.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        awayCommandsGroup->setTitle(tr2i18n("Away Commands", Q_NULLPTR));
        awayLabel->setText(tr2i18n("Away command:", Q_NULLPTR));
        unAwayLabel->setText(tr2i18n("Return command:", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(awayWidget), tr2i18n("Away", "@title:tab"));
        sCommandLabel->setText(tr2i18n("&Pre-shell command:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_sCommandEdit->setWhatsThis(tr2i18n("Here you can enter a command to be executed before connection to server starts<br>If you have multiple servers in this identity this command will be executed for each server", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        codecLabel->setText(tr2i18n("&Encoding:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_codecCBox->setWhatsThis(tr2i18n("This setting affects how characters you type are encoded for sending to the server. It also affects how messages are displayed. When you first open Konversation, it automatically retrieves this setting from the operating system. If you seem to be having trouble seeing other user's messages correctly, try changing this setting.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        loginLabel->setText(tr2i18n("I&dent:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_loginEdit->setWhatsThis(tr2i18n("When you connect, many servers query your computer for an IDENT response. If you computer is not running an IDENT server, this response is sent by Konversation. No spaces are allowed.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        quitLabel->setText(tr2i18n("&Quit reason:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_quitEdit->setWhatsThis(tr2i18n("Whenever you leave a server, this message is shown to others.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_quitEdit->setText(tr2i18n("Konversation terminated.", Q_NULLPTR));
        partLabel->setText(tr2i18n("&Part reason:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_partEdit->setWhatsThis(tr2i18n("Whenever you leave a channel, this message is sent to the channel.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_partEdit->setText(tr2i18n("Konversation terminated.", Q_NULLPTR));
        kickLabel->setText(tr2i18n("&Kick reason:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_kickEdit->setWhatsThis(tr2i18n("Whenever you are kicked from a channel (usually by an IRC operator), this message is sent to the channel.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_kickEdit->setText(tr2i18n("User terminated.", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(advancedWidget), tr2i18n("Advanced", Q_NULLPTR));
        Q_UNUSED(IdentityDialog);
    } // retranslateUi

};

namespace Ui {
    class IdentityDialog: public Ui_IdentityDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IDENTITYDIALOG_H

