/****************************************************************************
** Meta object code from reading C++ file 'whiteboardpaintarea.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/whiteboardpaintarea.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardpaintarea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea_t {
    QByteArrayData data[64];
    char stringdata0[703];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea_t qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea = {
    {
QT_MOC_LITERAL(0, 0, 38), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(1, 39, 12), // "drawedPencil"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 9), // "lineWidth"
QT_MOC_LITERAL(4, 63, 8), // "penColor"
QT_MOC_LITERAL(5, 72, 10), // "brushColor"
QT_MOC_LITERAL(6, 83, 5), // "xFrom"
QT_MOC_LITERAL(7, 89, 5), // "yFrom"
QT_MOC_LITERAL(8, 95, 3), // "xTo"
QT_MOC_LITERAL(9, 99, 3), // "yTo"
QT_MOC_LITERAL(10, 103, 10), // "drawedLine"
QT_MOC_LITERAL(11, 114, 15), // "drawedRectangle"
QT_MOC_LITERAL(12, 130, 21), // "drawedFilledRectangle"
QT_MOC_LITERAL(13, 152, 13), // "drawedEllipse"
QT_MOC_LITERAL(14, 166, 19), // "drawedFilledEllipse"
QT_MOC_LITERAL(15, 186, 11), // "drawedArrow"
QT_MOC_LITERAL(16, 198, 10), // "usedEraser"
QT_MOC_LITERAL(17, 209, 13), // "usedFloodFill"
QT_MOC_LITERAL(18, 223, 1), // "x"
QT_MOC_LITERAL(19, 225, 1), // "y"
QT_MOC_LITERAL(20, 227, 5), // "color"
QT_MOC_LITERAL(21, 233, 8), // "usedText"
QT_MOC_LITERAL(22, 242, 4), // "text"
QT_MOC_LITERAL(23, 247, 16), // "usedTextExtended"
QT_MOC_LITERAL(24, 264, 4), // "font"
QT_MOC_LITERAL(25, 269, 9), // "textColor"
QT_MOC_LITERAL(26, 279, 10), // "background"
QT_MOC_LITERAL(27, 290, 11), // "colorPicked"
QT_MOC_LITERAL(28, 302, 7), // "setTool"
QT_MOC_LITERAL(29, 310, 52), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(30, 363, 4), // "tool"
QT_MOC_LITERAL(31, 368, 18), // "setForegroundColor"
QT_MOC_LITERAL(32, 387, 18), // "setBackgroundColor"
QT_MOC_LITERAL(33, 406, 10), // "swapColors"
QT_MOC_LITERAL(34, 417, 13), // "newForeground"
QT_MOC_LITERAL(35, 431, 13), // "newBackground"
QT_MOC_LITERAL(36, 445, 11), // "setPenWidth"
QT_MOC_LITERAL(37, 457, 5), // "width"
QT_MOC_LITERAL(38, 463, 7), // "setFont"
QT_MOC_LITERAL(39, 471, 5), // "clear"
QT_MOC_LITERAL(40, 477, 8), // "drawLine"
QT_MOC_LITERAL(41, 486, 13), // "drawRectangle"
QT_MOC_LITERAL(42, 500, 19), // "drawFilledRectangle"
QT_MOC_LITERAL(43, 520, 11), // "drawEllipse"
QT_MOC_LITERAL(44, 532, 17), // "drawFilledEllipse"
QT_MOC_LITERAL(45, 550, 9), // "drawArrow"
QT_MOC_LITERAL(46, 560, 9), // "useEraser"
QT_MOC_LITERAL(47, 570, 12), // "useFloodFill"
QT_MOC_LITERAL(48, 583, 6), // "useBlt"
QT_MOC_LITERAL(49, 590, 5), // "x1src"
QT_MOC_LITERAL(50, 596, 5), // "y1src"
QT_MOC_LITERAL(51, 602, 5), // "x2src"
QT_MOC_LITERAL(52, 608, 5), // "y2src"
QT_MOC_LITERAL(53, 614, 5), // "xdest"
QT_MOC_LITERAL(54, 620, 5), // "ydest"
QT_MOC_LITERAL(55, 626, 7), // "useText"
QT_MOC_LITERAL(56, 634, 2), // "x1"
QT_MOC_LITERAL(57, 637, 2), // "y1"
QT_MOC_LITERAL(58, 640, 10), // "textString"
QT_MOC_LITERAL(59, 651, 15), // "useTextExtended"
QT_MOC_LITERAL(60, 667, 10), // "foreGround"
QT_MOC_LITERAL(61, 678, 10), // "backGround"
QT_MOC_LITERAL(62, 689, 4), // "save"
QT_MOC_LITERAL(63, 694, 8) // "fileName"

    },
    "Konversation::DCC::WhiteBoardPaintArea\0"
    "drawedPencil\0\0lineWidth\0penColor\0"
    "brushColor\0xFrom\0yFrom\0xTo\0yTo\0"
    "drawedLine\0drawedRectangle\0"
    "drawedFilledRectangle\0drawedEllipse\0"
    "drawedFilledEllipse\0drawedArrow\0"
    "usedEraser\0usedFloodFill\0x\0y\0color\0"
    "usedText\0text\0usedTextExtended\0font\0"
    "textColor\0background\0colorPicked\0"
    "setTool\0Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool\0"
    "tool\0setForegroundColor\0setBackgroundColor\0"
    "swapColors\0newForeground\0newBackground\0"
    "setPenWidth\0width\0setFont\0clear\0"
    "drawLine\0drawRectangle\0drawFilledRectangle\0"
    "drawEllipse\0drawFilledEllipse\0drawArrow\0"
    "useEraser\0useFloodFill\0useBlt\0x1src\0"
    "y1src\0x2src\0y2src\0xdest\0ydest\0useText\0"
    "x1\0y1\0textString\0useTextExtended\0"
    "foreGround\0backGround\0save\0fileName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__WhiteBoardPaintArea[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      31,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    7,  169,    2, 0x06 /* Public */,
      10,    7,  184,    2, 0x06 /* Public */,
      11,    6,  199,    2, 0x06 /* Public */,
      12,    7,  212,    2, 0x06 /* Public */,
      13,    6,  227,    2, 0x06 /* Public */,
      14,    7,  240,    2, 0x06 /* Public */,
      15,    6,  255,    2, 0x06 /* Public */,
      16,    5,  268,    2, 0x06 /* Public */,
      17,    3,  279,    2, 0x06 /* Public */,
      21,    3,  286,    2, 0x06 /* Public */,
      23,    6,  293,    2, 0x06 /* Public */,
      27,    1,  306,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      28,    1,  309,    2, 0x0a /* Public */,
      31,    1,  312,    2, 0x0a /* Public */,
      32,    1,  315,    2, 0x0a /* Public */,
      33,    2,  318,    2, 0x0a /* Public */,
      36,    1,  323,    2, 0x0a /* Public */,
      38,    1,  326,    2, 0x0a /* Public */,
      39,    0,  329,    2, 0x0a /* Public */,
      40,    7,  330,    2, 0x0a /* Public */,
      41,    6,  345,    2, 0x0a /* Public */,
      42,    7,  358,    2, 0x0a /* Public */,
      43,    6,  373,    2, 0x0a /* Public */,
      44,    7,  386,    2, 0x0a /* Public */,
      45,    6,  401,    2, 0x0a /* Public */,
      46,    5,  414,    2, 0x0a /* Public */,
      47,    3,  425,    2, 0x0a /* Public */,
      48,    6,  432,    2, 0x0a /* Public */,
      55,    3,  445,    2, 0x0a /* Public */,
      59,    6,  452,    2, 0x0a /* Public */,
      62,    1,  465,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QColor,   18,   19,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   18,   19,   22,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QFont, QMetaType::QColor, QMetaType::QColor, QMetaType::QString,   18,   19,   24,   25,   26,   22,
    QMetaType::Void, QMetaType::QColor,   20,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, QMetaType::QColor,   20,
    QMetaType::Void, QMetaType::QColor,   20,
    QMetaType::Void, QMetaType::QColor, QMetaType::QColor,   34,   35,
    QMetaType::Void, QMetaType::Int,   37,
    QMetaType::Void, QMetaType::QFont,   24,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    4,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    3,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QColor,   18,   19,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   49,   50,   51,   52,   53,   54,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   56,   57,   58,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QFont, QMetaType::QColor, QMetaType::QColor, QMetaType::QString,   56,   57,   24,   60,   61,   58,
    QMetaType::Void, QMetaType::QString,   63,

       0        // eod
};

void Konversation::DCC::WhiteBoardPaintArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhiteBoardPaintArea *_t = static_cast<WhiteBoardPaintArea *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->drawedPencil((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 1: _t->drawedLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 2: _t->drawedRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 3: _t->drawedFilledRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 4: _t->drawedEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 5: _t->drawedFilledEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 6: _t->drawedArrow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 7: _t->usedEraser((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 8: _t->usedFloodFill((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3]))); break;
        case 9: _t->usedText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 10: _t->usedTextExtended((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QFont(*)>(_a[3])),(*reinterpret_cast< const QColor(*)>(_a[4])),(*reinterpret_cast< const QColor(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 11: _t->colorPicked((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 12: _t->setTool((*reinterpret_cast< Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool(*)>(_a[1]))); break;
        case 13: _t->setForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 14: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 15: _t->swapColors((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 16: _t->setPenWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->setFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 18: _t->clear(); break;
        case 19: _t->drawLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 20: _t->drawRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 21: _t->drawFilledRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 22: _t->drawEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 23: _t->drawFilledEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 24: _t->drawArrow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 25: _t->useEraser((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 26: _t->useFloodFill((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3]))); break;
        case 27: _t->useBlt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 28: _t->useText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 29: _t->useTextExtended((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QFont(*)>(_a[3])),(*reinterpret_cast< const QColor(*)>(_a[4])),(*reinterpret_cast< const QColor(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 30: _t->save((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedPencil)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedLine)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedRectangle)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedFilledRectangle)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedEllipse)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedFilledEllipse)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , const QColor & , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::drawedArrow)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::usedEraser)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , int , const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::usedFloodFill)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::usedText)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(int , int , const QFont & , const QColor & , const QColor & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::usedTextExtended)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (WhiteBoardPaintArea::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardPaintArea::colorPicked)) {
                *result = 11;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::WhiteBoardPaintArea::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea.data,
      qt_meta_data_Konversation__DCC__WhiteBoardPaintArea,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::WhiteBoardPaintArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardPaintArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__WhiteBoardPaintArea.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardPaintArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 31;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardPaintArea::drawedPencil(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::WhiteBoardPaintArea::drawedLine(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::WhiteBoardPaintArea::drawedRectangle(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Konversation::DCC::WhiteBoardPaintArea::drawedFilledRectangle(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Konversation::DCC::WhiteBoardPaintArea::drawedEllipse(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Konversation::DCC::WhiteBoardPaintArea::drawedFilledEllipse(int _t1, const QColor & _t2, const QColor & _t3, int _t4, int _t5, int _t6, int _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Konversation::DCC::WhiteBoardPaintArea::drawedArrow(int _t1, const QColor & _t2, int _t3, int _t4, int _t5, int _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Konversation::DCC::WhiteBoardPaintArea::usedEraser(int _t1, int _t2, int _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Konversation::DCC::WhiteBoardPaintArea::usedFloodFill(int _t1, int _t2, const QColor & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Konversation::DCC::WhiteBoardPaintArea::usedText(int _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Konversation::DCC::WhiteBoardPaintArea::usedTextExtended(int _t1, int _t2, const QFont & _t3, const QColor & _t4, const QColor & _t5, const QString & _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Konversation::DCC::WhiteBoardPaintArea::colorPicked(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
