/****************************************************************************
** Meta object code from reading C++ file 'transfer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transfer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__Transfer_t {
    QByteArrayData data[15];
    char stringdata0[164];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__Transfer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__Transfer_t qt_meta_stringdata_Konversation__DCC__Transfer = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Konversation::DCC::Transfer"
QT_MOC_LITERAL(1, 28, 15), // "transferStarted"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(4, 74, 4), // "item"
QT_MOC_LITERAL(5, 79, 4), // "done"
QT_MOC_LITERAL(6, 84, 13), // "statusChanged"
QT_MOC_LITERAL(7, 98, 9), // "newStatus"
QT_MOC_LITERAL(8, 108, 9), // "oldStatus"
QT_MOC_LITERAL(9, 118, 7), // "removed"
QT_MOC_LITERAL(10, 126, 5), // "queue"
QT_MOC_LITERAL(11, 132, 5), // "start"
QT_MOC_LITERAL(12, 138, 5), // "abort"
QT_MOC_LITERAL(13, 144, 7), // "runFile"
QT_MOC_LITERAL(14, 152, 11) // "logTransfer"

    },
    "Konversation::DCC::Transfer\0transferStarted\0"
    "\0Konversation::DCC::Transfer*\0item\0"
    "done\0statusChanged\0newStatus\0oldStatus\0"
    "removed\0queue\0start\0abort\0runFile\0"
    "logTransfer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__Transfer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       5,    1,   62,    2, 0x06 /* Public */,
       6,    3,   65,    2, 0x06 /* Public */,
       9,    1,   72,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   75,    2, 0x0a /* Public */,
      11,    0,   76,    2, 0x0a /* Public */,
      12,    0,   77,    2, 0x0a /* Public */,
      13,    0,   78,    2, 0x0a /* Public */,
      14,    0,   79,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    4,    7,    8,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Konversation::DCC::Transfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Transfer *_t = static_cast<Transfer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->transferStarted((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 1: _t->done((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 2: _t->statusChanged((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->removed((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 4: { bool _r = _t->queue();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->start(); break;
        case 6: _t->abort(); break;
        case 7: _t->runFile(); break;
        case 8: _t->logTransfer(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Transfer::*_t)(Konversation::DCC::Transfer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::transferStarted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Transfer::*_t)(Konversation::DCC::Transfer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::done)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Transfer::*_t)(Konversation::DCC::Transfer * , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::statusChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Transfer::*_t)(Konversation::DCC::Transfer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::removed)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::Transfer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__DCC__Transfer.data,
      qt_meta_data_Konversation__DCC__Transfer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::Transfer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::Transfer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__Transfer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DCC::Transfer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::Transfer::transferStarted(Konversation::DCC::Transfer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::Transfer::done(Konversation::DCC::Transfer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::Transfer::statusChanged(Konversation::DCC::Transfer * _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Konversation::DCC::Transfer::removed(Konversation::DCC::Transfer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
