#include <klocalizedstring.h>

/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'log_config.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOG_CONFIG_H
#define UI_LOG_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Log_Config
{
public:
    QGridLayout *gridLayout;
    QGroupBox *kcfg_Log;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_PrivateOnly;
    QCheckBox *kcfg_LowerLog;
    QCheckBox *kcfg_AddHostnameToLog;
    QLabel *textLabel1;
    KUrlRequester *kcfg_LogfilePath;
    QCheckBox *kcfg_UseExternalLogViewer;
    QSpacerItem *spacer1;

    void setupUi(QWidget *Log_Config)
    {
        if (Log_Config->objectName().isEmpty())
            Log_Config->setObjectName(QStringLiteral("Log_Config"));
        Log_Config->resize(410, 164);
        gridLayout = new QGridLayout(Log_Config);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kcfg_Log = new QGroupBox(Log_Config);
        kcfg_Log->setObjectName(QStringLiteral("kcfg_Log"));
        kcfg_Log->setCheckable(true);
        gridLayout1 = new QGridLayout(kcfg_Log);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        kcfg_PrivateOnly = new QCheckBox(kcfg_Log);
        kcfg_PrivateOnly->setObjectName(QStringLiteral("kcfg_PrivateOnly"));

        gridLayout1->addWidget(kcfg_PrivateOnly, 0, 0, 1, 1);

        kcfg_LowerLog = new QCheckBox(kcfg_Log);
        kcfg_LowerLog->setObjectName(QStringLiteral("kcfg_LowerLog"));

        gridLayout1->addWidget(kcfg_LowerLog, 1, 0, 1, 2);

        kcfg_AddHostnameToLog = new QCheckBox(kcfg_Log);
        kcfg_AddHostnameToLog->setObjectName(QStringLiteral("kcfg_AddHostnameToLog"));

        gridLayout1->addWidget(kcfg_AddHostnameToLog, 2, 0, 1, 2);

        textLabel1 = new QLabel(kcfg_Log);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        gridLayout1->addWidget(textLabel1, 4, 0, 1, 1);

        kcfg_LogfilePath = new KUrlRequester(kcfg_Log);
        kcfg_LogfilePath->setObjectName(QStringLiteral("kcfg_LogfilePath"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_LogfilePath->sizePolicy().hasHeightForWidth());
        kcfg_LogfilePath->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(kcfg_LogfilePath, 4, 1, 1, 1);

        kcfg_UseExternalLogViewer = new QCheckBox(kcfg_Log);
        kcfg_UseExternalLogViewer->setObjectName(QStringLiteral("kcfg_UseExternalLogViewer"));

        gridLayout1->addWidget(kcfg_UseExternalLogViewer, 5, 0, 1, 1);


        gridLayout->addWidget(kcfg_Log, 0, 0, 1, 1);

        spacer1 = new QSpacerItem(21, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacer1, 1, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        textLabel1->setBuddy(kcfg_LogfilePath);
#endif // QT_NO_SHORTCUT

        retranslateUi(Log_Config);

        QMetaObject::connectSlotsByName(Log_Config);
    } // setupUi

    void retranslateUi(QWidget *Log_Config)
    {
        kcfg_Log->setTitle(tr2i18n("&Enable Logging", Q_NULLPTR));
        kcfg_PrivateOnly->setText(tr2i18n("Only log private conversations (queries, DCC chats)", Q_NULLPTR));
        kcfg_LowerLog->setText(tr2i18n("Enable &lower case logfile names", Q_NULLPTR));
        kcfg_AddHostnameToLog->setText(tr2i18n("&Append hostname to logfile names", Q_NULLPTR));
        textLabel1->setText(tr2i18n("Logfile &path:", Q_NULLPTR));
        kcfg_UseExternalLogViewer->setText(tr2i18n("Use system text editor to open logs", Q_NULLPTR));
        Q_UNUSED(Log_Config);
    } // retranslateUi

};

namespace Ui {
    class Log_Config: public Ui_Log_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOG_CONFIG_H

