/****************************************************************************
** Meta object code from reading C++ file 'transferdetailedinfopanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transferdetailedinfopanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferdetailedinfopanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel_t {
    QByteArrayData data[11];
    char stringdata0[186];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel_t qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel = {
    {
QT_MOC_LITERAL(0, 0, 44), // "Konversation::DCC::TransferDe..."
QT_MOC_LITERAL(1, 45, 10), // "updateView"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 20), // "updateChangeableView"
QT_MOC_LITERAL(4, 78, 25), // "slotTransferStatusChanged"
QT_MOC_LITERAL(5, 104, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(6, 133, 8), // "transfer"
QT_MOC_LITERAL(7, 142, 9), // "newStatus"
QT_MOC_LITERAL(8, 152, 9), // "oldStatus"
QT_MOC_LITERAL(9, 162, 19), // "slotLocationChanged"
QT_MOC_LITERAL(10, 182, 3) // "url"

    },
    "Konversation::DCC::TransferDetailedInfoPanel\0"
    "updateView\0\0updateChangeableView\0"
    "slotTransferStatusChanged\0"
    "Konversation::DCC::Transfer*\0transfer\0"
    "newStatus\0oldStatus\0slotLocationChanged\0"
    "url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferDetailedInfoPanel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x08 /* Private */,
       3,    0,   35,    2, 0x08 /* Private */,
       4,    3,   36,    2, 0x08 /* Private */,
       9,    1,   43,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, QMetaType::QString,   10,

       0        // eod
};

void Konversation::DCC::TransferDetailedInfoPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferDetailedInfoPanel *_t = static_cast<TransferDetailedInfoPanel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateView(); break;
        case 1: _t->updateChangeableView(); break;
        case 2: _t->slotTransferStatusChanged((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->slotLocationChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::DCC::TransferDetailedInfoPanel::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel.data,
      qt_meta_data_Konversation__DCC__TransferDetailedInfoPanel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferDetailedInfoPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferDetailedInfoPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferDetailedInfoPanel.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int Konversation::DCC::TransferDetailedInfoPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
