/****************************************************************************
** Meta object code from reading C++ file 'notificationhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/notificationhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__NotificationHandler_t {
    QByteArrayData data[34];
    char stringdata0[335];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__NotificationHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__NotificationHandler_t qt_meta_stringdata_Konversation__NotificationHandler = {
    {
QT_MOC_LITERAL(0, 0, 33), // "Konversation::NotificationHan..."
QT_MOC_LITERAL(1, 34, 7), // "message"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 11), // "ChatWindow*"
QT_MOC_LITERAL(4, 55, 7), // "chatWin"
QT_MOC_LITERAL(5, 63, 8), // "fromNick"
QT_MOC_LITERAL(6, 72, 4), // "nick"
QT_MOC_LITERAL(7, 77, 4), // "join"
QT_MOC_LITERAL(8, 82, 4), // "part"
QT_MOC_LITERAL(9, 87, 4), // "quit"
QT_MOC_LITERAL(10, 92, 10), // "nickChange"
QT_MOC_LITERAL(11, 103, 7), // "oldNick"
QT_MOC_LITERAL(12, 111, 7), // "newNick"
QT_MOC_LITERAL(13, 119, 11), // "dccIncoming"
QT_MOC_LITERAL(14, 131, 8), // "dccError"
QT_MOC_LITERAL(15, 140, 5), // "error"
QT_MOC_LITERAL(16, 146, 15), // "dccTransferDone"
QT_MOC_LITERAL(17, 162, 4), // "file"
QT_MOC_LITERAL(18, 167, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(19, 196, 8), // "transfer"
QT_MOC_LITERAL(20, 205, 4), // "mode"
QT_MOC_LITERAL(21, 210, 7), // "subject"
QT_MOC_LITERAL(22, 218, 6), // "change"
QT_MOC_LITERAL(23, 225, 5), // "query"
QT_MOC_LITERAL(24, 231, 12), // "queryMessage"
QT_MOC_LITERAL(25, 244, 10), // "nickOnline"
QT_MOC_LITERAL(26, 255, 11), // "nickOffline"
QT_MOC_LITERAL(27, 267, 4), // "kick"
QT_MOC_LITERAL(28, 272, 7), // "channel"
QT_MOC_LITERAL(29, 280, 7), // "dccChat"
QT_MOC_LITERAL(30, 288, 9), // "highlight"
QT_MOC_LITERAL(31, 298, 17), // "connectionFailure"
QT_MOC_LITERAL(32, 316, 6), // "server"
QT_MOC_LITERAL(33, 323, 11) // "channelJoin"

    },
    "Konversation::NotificationHandler\0"
    "message\0\0ChatWindow*\0chatWin\0fromNick\0"
    "nick\0join\0part\0quit\0nickChange\0oldNick\0"
    "newNick\0dccIncoming\0dccError\0error\0"
    "dccTransferDone\0file\0Konversation::DCC::Transfer*\0"
    "transfer\0mode\0subject\0change\0query\0"
    "queryMessage\0nickOnline\0nickOffline\0"
    "kick\0channel\0dccChat\0highlight\0"
    "connectionFailure\0server\0channelJoin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__NotificationHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,  109,    2, 0x0a /* Public */,
       6,    3,  116,    2, 0x0a /* Public */,
       7,    2,  123,    2, 0x0a /* Public */,
       8,    2,  128,    2, 0x0a /* Public */,
       9,    2,  133,    2, 0x0a /* Public */,
      10,    3,  138,    2, 0x0a /* Public */,
      13,    2,  145,    2, 0x0a /* Public */,
      14,    2,  150,    2, 0x0a /* Public */,
      16,    3,  155,    2, 0x0a /* Public */,
      20,    4,  162,    2, 0x0a /* Public */,
      23,    2,  171,    2, 0x0a /* Public */,
      24,    3,  176,    2, 0x0a /* Public */,
      25,    2,  183,    2, 0x0a /* Public */,
      26,    2,  188,    2, 0x0a /* Public */,
      27,    3,  193,    2, 0x0a /* Public */,
      29,    2,  200,    2, 0x0a /* Public */,
      30,    3,  205,    2, 0x0a /* Public */,
      31,    2,  212,    2, 0x0a /* Public */,
      33,    2,  217,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,    5,    1,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,    5,    1,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,   11,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   15,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, 0x80000000 | 18,    4,   17,   19,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,    6,   21,   22,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,    5,    1,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,   28,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString,    4,    5,    1,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   32,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   28,

       0        // eod
};

void Konversation::NotificationHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotificationHandler *_t = static_cast<NotificationHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->message((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->nick((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->join((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->part((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->quit((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->nickChange((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 6: _t->dccIncoming((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->dccError((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->dccTransferDone((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[3]))); break;
        case 9: _t->mode((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 10: _t->query((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->queryMessage((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 12: _t->nickOnline((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->nickOffline((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 14: _t->kick((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 15: _t->dccChat((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->highlight((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->connectionFailure((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 18: _t->channelJoin((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::NotificationHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__NotificationHandler.data,
      qt_meta_data_Konversation__NotificationHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::NotificationHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::NotificationHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__NotificationHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::NotificationHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
