/****************************************************************************
** Meta object code from reading C++ file 'application.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/application.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'application.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Application_t {
    QByteArrayData data[34];
    char stringdata0[442];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Application_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Application_t qt_meta_stringdata_Application = {
    {
QT_MOC_LITERAL(0, 0, 11), // "Application"
QT_MOC_LITERAL(1, 12, 19), // "serverGroupsChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 36), // "Konversation::ServerGroupSett..."
QT_MOC_LITERAL(4, 70, 11), // "serverGroup"
QT_MOC_LITERAL(5, 82, 17), // "appearanceChanged"
QT_MOC_LITERAL(6, 100, 7), // "restart"
QT_MOC_LITERAL(7, 108, 11), // "readOptions"
QT_MOC_LITERAL(8, 120, 11), // "saveOptions"
QT_MOC_LITERAL(9, 132, 9), // "updateGUI"
QT_MOC_LITERAL(10, 142, 15), // "fetchQueueRates"
QT_MOC_LITERAL(11, 158, 15), // "stashQueueRates"
QT_MOC_LITERAL(12, 174, 15), // "resetQueueRates"
QT_MOC_LITERAL(13, 190, 13), // "countOfQueues"
QT_MOC_LITERAL(14, 204, 15), // "prepareShutdown"
QT_MOC_LITERAL(15, 220, 8), // "storeUrl"
QT_MOC_LITERAL(16, 229, 6), // "origin"
QT_MOC_LITERAL(17, 236, 6), // "newUrl"
QT_MOC_LITERAL(18, 243, 8), // "dateTime"
QT_MOC_LITERAL(19, 252, 14), // "handleActivate"
QT_MOC_LITERAL(20, 267, 9), // "arguments"
QT_MOC_LITERAL(21, 277, 22), // "openQuickConnectDialog"
QT_MOC_LITERAL(22, 300, 18), // "dbusMultiServerRaw"
QT_MOC_LITERAL(23, 319, 7), // "command"
QT_MOC_LITERAL(24, 327, 7), // "dbusRaw"
QT_MOC_LITERAL(25, 335, 10), // "connection"
QT_MOC_LITERAL(26, 346, 7), // "dbusSay"
QT_MOC_LITERAL(27, 354, 6), // "target"
QT_MOC_LITERAL(28, 361, 8), // "dbusInfo"
QT_MOC_LITERAL(29, 370, 6), // "string"
QT_MOC_LITERAL(30, 377, 22), // "sendMultiServerCommand"
QT_MOC_LITERAL(31, 400, 9), // "parameter"
QT_MOC_LITERAL(32, 410, 19), // "updateProxySettings"
QT_MOC_LITERAL(33, 430, 11) // "closeWallet"

    },
    "Application\0serverGroupsChanged\0\0"
    "Konversation::ServerGroupSettingsPtr\0"
    "serverGroup\0appearanceChanged\0restart\0"
    "readOptions\0saveOptions\0updateGUI\0"
    "fetchQueueRates\0stashQueueRates\0"
    "resetQueueRates\0countOfQueues\0"
    "prepareShutdown\0storeUrl\0origin\0newUrl\0"
    "dateTime\0handleActivate\0arguments\0"
    "openQuickConnectDialog\0dbusMultiServerRaw\0"
    "command\0dbusRaw\0connection\0dbusSay\0"
    "target\0dbusInfo\0string\0sendMultiServerCommand\0"
    "parameter\0updateProxySettings\0closeWallet"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Application[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,
       5,    0,  122,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  123,    2, 0x0a /* Public */,
       7,    0,  124,    2, 0x0a /* Public */,
       8,    1,  125,    2, 0x0a /* Public */,
       8,    0,  128,    2, 0x2a /* Public | MethodCloned */,
      10,    0,  129,    2, 0x0a /* Public */,
      11,    0,  130,    2, 0x0a /* Public */,
      12,    0,  131,    2, 0x0a /* Public */,
      13,    0,  132,    2, 0x0a /* Public */,
      14,    0,  133,    2, 0x0a /* Public */,
      15,    3,  134,    2, 0x0a /* Public */,
      19,    1,  141,    2, 0x0a /* Public */,
      21,    0,  144,    2, 0x09 /* Protected */,
      22,    1,  145,    2, 0x09 /* Protected */,
      24,    2,  148,    2, 0x09 /* Protected */,
      26,    3,  153,    2, 0x09 /* Protected */,
      28,    1,  160,    2, 0x09 /* Protected */,
      30,    2,  163,    2, 0x09 /* Protected */,
      32,    0,  168,    2, 0x09 /* Protected */,
      33,    0,  169,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QDateTime,   16,   17,   18,
    QMetaType::Void, QMetaType::QStringList,   20,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   25,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   25,   27,   23,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   23,   31,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Application *_t = static_cast<Application *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->serverGroupsChanged((*reinterpret_cast< const Konversation::ServerGroupSettingsPtr(*)>(_a[1]))); break;
        case 1: _t->appearanceChanged(); break;
        case 2: _t->restart(); break;
        case 3: _t->readOptions(); break;
        case 4: _t->saveOptions((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->saveOptions(); break;
        case 6: _t->fetchQueueRates(); break;
        case 7: _t->stashQueueRates(); break;
        case 8: _t->resetQueueRates(); break;
        case 9: { int _r = _t->countOfQueues();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->prepareShutdown(); break;
        case 11: _t->storeUrl((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QDateTime(*)>(_a[3]))); break;
        case 12: _t->handleActivate((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 13: _t->openQuickConnectDialog(); break;
        case 14: _t->dbusMultiServerRaw((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->dbusRaw((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->dbusSay((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->dbusInfo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->sendMultiServerCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 19: _t->updateProxySettings(); break;
        case 20: _t->closeWallet(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Application::*_t)(const Konversation::ServerGroupSettingsPtr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::serverGroupsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Application::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Application::appearanceChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Application::staticMetaObject = {
    { &QApplication::staticMetaObject, qt_meta_stringdata_Application.data,
      qt_meta_data_Application,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Application.stringdata0))
        return static_cast<void*>(this);
    return QApplication::qt_metacast(_clname);
}

int Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Application::serverGroupsChanged(const Konversation::ServerGroupSettingsPtr _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Application::appearanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
