#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'tabnotifications_config.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABNOTIFICATIONS_CONFIG_H
#define UI_TABNOTIFICATIONS_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_TabNotifications_Config
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox4;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_TabNotificationsText;
    QCheckBox *kcfg_TabNotificationsLeds;
    QGroupBox *groupBox5;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_TabNotificationsSystem;
    QSpacerItem *spacer45_2;
    KColorButton *kcfg_TabNotificationsSystemColor;
    QCheckBox *kcfg_TabNotificationsMsgs;
    QSpacerItem *spacer42;
    KColorButton *kcfg_TabNotificationsMsgsColor;
    QSpacerItem *spacer42_2;
    QCheckBox *kcfg_TabNotificationsPrivate;
    KColorButton *kcfg_TabNotificationsPrivateColor;
    QCheckBox *kcfg_TabNotificationsNick;
    QSpacerItem *spacer44;
    QSpacerItem *spacer45;
    KColorButton *kcfg_TabNotificationsNickColor;
    KColorButton *kcfg_TabNotificationsHighlightsColor;
    QCheckBox *kcfg_TabNotificationsEvents;
    QCheckBox *kcfg_TabNotificationsHighlights;
    QSpacerItem *spacer43;
    KColorButton *kcfg_TabNotificationsEventsColor;
    QGroupBox *groupBox10;
    QGridLayout *gridLayout2;
    QCheckBox *kcfg_TabNotificationsOverride;
    QSpacerItem *spacer47;

    void setupUi(QWidget *TabNotifications_Config)
    {
        if (TabNotifications_Config->objectName().isEmpty())
            TabNotifications_Config->setObjectName(QStringLiteral("TabNotifications_Config"));
        TabNotifications_Config->resize(349, 407);
        vboxLayout = new QVBoxLayout(TabNotifications_Config);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        groupBox4 = new QGroupBox(TabNotifications_Config);
        groupBox4->setObjectName(QStringLiteral("groupBox4"));
        gridLayout = new QGridLayout(groupBox4);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kcfg_TabNotificationsText = new QCheckBox(groupBox4);
        kcfg_TabNotificationsText->setObjectName(QStringLiteral("kcfg_TabNotificationsText"));
        kcfg_TabNotificationsText->setChecked(true);

        gridLayout->addWidget(kcfg_TabNotificationsText, 0, 0, 1, 1);

        kcfg_TabNotificationsLeds = new QCheckBox(groupBox4);
        kcfg_TabNotificationsLeds->setObjectName(QStringLiteral("kcfg_TabNotificationsLeds"));

        gridLayout->addWidget(kcfg_TabNotificationsLeds, 1, 0, 1, 1);


        vboxLayout->addWidget(groupBox4);

        groupBox5 = new QGroupBox(TabNotifications_Config);
        groupBox5->setObjectName(QStringLiteral("groupBox5"));
        gridLayout1 = new QGridLayout(groupBox5);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        kcfg_TabNotificationsSystem = new QCheckBox(groupBox5);
        kcfg_TabNotificationsSystem->setObjectName(QStringLiteral("kcfg_TabNotificationsSystem"));
        kcfg_TabNotificationsSystem->setChecked(true);

        gridLayout1->addWidget(kcfg_TabNotificationsSystem, 5, 0, 1, 3);

        spacer45_2 = new QSpacerItem(50, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer45_2, 5, 3, 1, 1);

        kcfg_TabNotificationsSystemColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsSystemColor->setObjectName(QStringLiteral("kcfg_TabNotificationsSystemColor"));

        gridLayout1->addWidget(kcfg_TabNotificationsSystemColor, 5, 4, 1, 1);

        kcfg_TabNotificationsMsgs = new QCheckBox(groupBox5);
        kcfg_TabNotificationsMsgs->setObjectName(QStringLiteral("kcfg_TabNotificationsMsgs"));
        kcfg_TabNotificationsMsgs->setChecked(true);

        gridLayout1->addWidget(kcfg_TabNotificationsMsgs, 0, 0, 1, 1);

        spacer42 = new QSpacerItem(50, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer42, 0, 1, 1, 3);

        kcfg_TabNotificationsMsgsColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsMsgsColor->setObjectName(QStringLiteral("kcfg_TabNotificationsMsgsColor"));
        kcfg_TabNotificationsMsgsColor->setDefaultColor(QColor(0, 0, 0));

        gridLayout1->addWidget(kcfg_TabNotificationsMsgsColor, 0, 4, 1, 1);

        spacer42_2 = new QSpacerItem(60, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer42_2, 1, 3, 1, 1);

        kcfg_TabNotificationsPrivate = new QCheckBox(groupBox5);
        kcfg_TabNotificationsPrivate->setObjectName(QStringLiteral("kcfg_TabNotificationsPrivate"));
        kcfg_TabNotificationsPrivate->setChecked(true);

        gridLayout1->addWidget(kcfg_TabNotificationsPrivate, 1, 0, 1, 3);

        kcfg_TabNotificationsPrivateColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsPrivateColor->setObjectName(QStringLiteral("kcfg_TabNotificationsPrivateColor"));
        kcfg_TabNotificationsPrivateColor->setDefaultColor(QColor(0, 0, 0));

        gridLayout1->addWidget(kcfg_TabNotificationsPrivateColor, 1, 4, 1, 1);

        kcfg_TabNotificationsNick = new QCheckBox(groupBox5);
        kcfg_TabNotificationsNick->setObjectName(QStringLiteral("kcfg_TabNotificationsNick"));
        kcfg_TabNotificationsNick->setChecked(true);

        gridLayout1->addWidget(kcfg_TabNotificationsNick, 2, 0, 1, 3);

        spacer44 = new QSpacerItem(50, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer44, 2, 3, 1, 1);

        spacer45 = new QSpacerItem(50, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer45, 3, 1, 1, 3);

        kcfg_TabNotificationsNickColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsNickColor->setObjectName(QStringLiteral("kcfg_TabNotificationsNickColor"));

        gridLayout1->addWidget(kcfg_TabNotificationsNickColor, 2, 4, 1, 1);

        kcfg_TabNotificationsHighlightsColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsHighlightsColor->setObjectName(QStringLiteral("kcfg_TabNotificationsHighlightsColor"));

        gridLayout1->addWidget(kcfg_TabNotificationsHighlightsColor, 3, 4, 1, 1);

        kcfg_TabNotificationsEvents = new QCheckBox(groupBox5);
        kcfg_TabNotificationsEvents->setObjectName(QStringLiteral("kcfg_TabNotificationsEvents"));
        kcfg_TabNotificationsEvents->setChecked(false);

        gridLayout1->addWidget(kcfg_TabNotificationsEvents, 4, 0, 1, 2);

        kcfg_TabNotificationsHighlights = new QCheckBox(groupBox5);
        kcfg_TabNotificationsHighlights->setObjectName(QStringLiteral("kcfg_TabNotificationsHighlights"));
        kcfg_TabNotificationsHighlights->setChecked(true);

        gridLayout1->addWidget(kcfg_TabNotificationsHighlights, 3, 0, 1, 1);

        spacer43 = new QSpacerItem(50, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout1->addItem(spacer43, 4, 2, 1, 2);

        kcfg_TabNotificationsEventsColor = new KColorButton(groupBox5);
        kcfg_TabNotificationsEventsColor->setObjectName(QStringLiteral("kcfg_TabNotificationsEventsColor"));
        kcfg_TabNotificationsEventsColor->setEnabled(false);

        gridLayout1->addWidget(kcfg_TabNotificationsEventsColor, 4, 4, 1, 1);


        vboxLayout->addWidget(groupBox5);

        groupBox10 = new QGroupBox(TabNotifications_Config);
        groupBox10->setObjectName(QStringLiteral("groupBox10"));
        gridLayout2 = new QGridLayout(groupBox10);
        gridLayout2->setSpacing(6);
        gridLayout2->setContentsMargins(11, 11, 11, 11);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        kcfg_TabNotificationsOverride = new QCheckBox(groupBox10);
        kcfg_TabNotificationsOverride->setObjectName(QStringLiteral("kcfg_TabNotificationsOverride"));

        gridLayout2->addWidget(kcfg_TabNotificationsOverride, 0, 0, 1, 1);


        vboxLayout->addWidget(groupBox10);

        spacer47 = new QSpacerItem(21, 60, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacer47);

        QWidget::setTabOrder(kcfg_TabNotificationsText, kcfg_TabNotificationsLeds);
        QWidget::setTabOrder(kcfg_TabNotificationsLeds, kcfg_TabNotificationsMsgs);
        QWidget::setTabOrder(kcfg_TabNotificationsMsgs, kcfg_TabNotificationsMsgsColor);
        QWidget::setTabOrder(kcfg_TabNotificationsMsgsColor, kcfg_TabNotificationsPrivate);
        QWidget::setTabOrder(kcfg_TabNotificationsPrivate, kcfg_TabNotificationsPrivateColor);
        QWidget::setTabOrder(kcfg_TabNotificationsPrivateColor, kcfg_TabNotificationsNick);
        QWidget::setTabOrder(kcfg_TabNotificationsNick, kcfg_TabNotificationsNickColor);
        QWidget::setTabOrder(kcfg_TabNotificationsNickColor, kcfg_TabNotificationsHighlights);
        QWidget::setTabOrder(kcfg_TabNotificationsHighlights, kcfg_TabNotificationsHighlightsColor);
        QWidget::setTabOrder(kcfg_TabNotificationsHighlightsColor, kcfg_TabNotificationsEvents);
        QWidget::setTabOrder(kcfg_TabNotificationsEvents, kcfg_TabNotificationsEventsColor);
        QWidget::setTabOrder(kcfg_TabNotificationsEventsColor, kcfg_TabNotificationsSystem);
        QWidget::setTabOrder(kcfg_TabNotificationsSystem, kcfg_TabNotificationsSystemColor);
        QWidget::setTabOrder(kcfg_TabNotificationsSystemColor, kcfg_TabNotificationsOverride);

        retranslateUi(TabNotifications_Config);
        QObject::connect(kcfg_TabNotificationsMsgs, SIGNAL(toggled(bool)), kcfg_TabNotificationsMsgsColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_TabNotificationsEvents, SIGNAL(toggled(bool)), kcfg_TabNotificationsEventsColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_TabNotificationsNick, SIGNAL(toggled(bool)), kcfg_TabNotificationsNickColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_TabNotificationsHighlights, SIGNAL(toggled(bool)), kcfg_TabNotificationsHighlightsColor, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_TabNotificationsSystem, SIGNAL(toggled(bool)), kcfg_TabNotificationsSystemColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(TabNotifications_Config);
    } // setupUi

    void retranslateUi(QWidget *TabNotifications_Config)
    {
        groupBox4->setTitle(tr2i18n("Look", Q_NULLPTR));
        kcfg_TabNotificationsText->setText(tr2i18n("Use colored text", Q_NULLPTR));
        kcfg_TabNotificationsLeds->setText(tr2i18n("Use colored LEDs", Q_NULLPTR));
        groupBox5->setTitle(tr2i18n("Notifications", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_TabNotificationsSystem->setWhatsThis(tr2i18n("Application events occur in Konsole tabs, the DCC Status tab and other application tabs not used directly for chatting.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_TabNotificationsSystem->setText(tr2i18n("Application event", Q_NULLPTR));
        kcfg_TabNotificationsSystemColor->setText(QString());
        kcfg_TabNotificationsMsgs->setText(tr2i18n("Message", Q_NULLPTR));
        kcfg_TabNotificationsMsgsColor->setText(QString());
        kcfg_TabNotificationsPrivate->setText(tr2i18n("Private message", Q_NULLPTR));
        kcfg_TabNotificationsPrivateColor->setText(QString());
        kcfg_TabNotificationsNick->setText(tr2i18n("Current nick used", Q_NULLPTR));
        kcfg_TabNotificationsNickColor->setText(QString());
        kcfg_TabNotificationsHighlightsColor->setText(QString());
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_TabNotificationsEvents->setWhatsThis(tr2i18n("Channel events are mode changes or users joining/leaving a channel.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_TabNotificationsEvents->setText(tr2i18n("Channel event", Q_NULLPTR));
        kcfg_TabNotificationsHighlights->setText(tr2i18n("Highlight", Q_NULLPTR));
        kcfg_TabNotificationsEventsColor->setText(QString());
        groupBox10->setTitle(tr2i18n("Options", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_TabNotificationsOverride->setWhatsThis(tr2i18n("If you select this, the colors you chose in the Highlights preferences page will override the colors for \"Current nick used\" and \"Highlight\".", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_TabNotificationsOverride->setText(tr2i18n("Give precedence to chat window highlight colors", Q_NULLPTR));
        Q_UNUSED(TabNotifications_Config);
    } // retranslateUi

};

namespace Ui {
    class TabNotifications_Config: public Ui_TabNotifications_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TABNOTIFICATIONS_CONFIG_H

