/****************************************************************************
** Meta object code from reading C++ file 'osd.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/osd.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'osd.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OSDWidget_t {
    QByteArrayData data[20];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OSDWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OSDWidget_t qt_meta_stringdata_OSDWidget = {
    {
QT_MOC_LITERAL(0, 0, 9), // "OSDWidget"
QT_MOC_LITERAL(1, 10, 4), // "show"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 4), // "text"
QT_MOC_LITERAL(4, 21, 10), // "preemptive"
QT_MOC_LITERAL(5, 32, 11), // "setDuration"
QT_MOC_LITERAL(6, 44, 2), // "ms"
QT_MOC_LITERAL(7, 47, 12), // "setTextColor"
QT_MOC_LITERAL(8, 60, 5), // "color"
QT_MOC_LITERAL(9, 66, 9), // "setOffset"
QT_MOC_LITERAL(10, 76, 1), // "y"
QT_MOC_LITERAL(11, 78, 12), // "setAlignment"
QT_MOC_LITERAL(12, 91, 9), // "Alignment"
QT_MOC_LITERAL(13, 101, 9), // "alignment"
QT_MOC_LITERAL(14, 111, 9), // "setScreen"
QT_MOC_LITERAL(15, 121, 6), // "screen"
QT_MOC_LITERAL(16, 128, 7), // "setText"
QT_MOC_LITERAL(17, 136, 14), // "setTranslucent"
QT_MOC_LITERAL(18, 151, 7), // "enabled"
QT_MOC_LITERAL(19, 159, 10) // "minReached"

    },
    "OSDWidget\0show\0\0text\0preemptive\0"
    "setDuration\0ms\0setTextColor\0color\0"
    "setOffset\0y\0setAlignment\0Alignment\0"
    "alignment\0setScreen\0screen\0setText\0"
    "setTranslucent\0enabled\0minReached"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OSDWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   69,    2, 0x0a /* Public */,
       1,    1,   74,    2, 0x2a /* Public | MethodCloned */,
       1,    0,   77,    2, 0x0a /* Public */,
       5,    1,   78,    2, 0x0a /* Public */,
       7,    1,   81,    2, 0x0a /* Public */,
       9,    1,   84,    2, 0x0a /* Public */,
      11,    1,   87,    2, 0x0a /* Public */,
      14,    1,   90,    2, 0x0a /* Public */,
      16,    1,   93,    2, 0x0a /* Public */,
      17,    1,   96,    2, 0x0a /* Public */,
      19,    0,   99,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    3,    4,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::QColor,    8,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,

       0        // eod
};

void OSDWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OSDWidget *_t = static_cast<OSDWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->show((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->show((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->show(); break;
        case 3: _t->setDuration((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setTextColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 5: _t->setOffset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setAlignment((*reinterpret_cast< Alignment(*)>(_a[1]))); break;
        case 7: _t->setScreen((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->setTranslucent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->minReached(); break;
        default: ;
        }
    }
}

const QMetaObject OSDWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_OSDWidget.data,
      qt_meta_data_OSDWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *OSDWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OSDWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OSDWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int OSDWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
struct qt_meta_stringdata_OSDPreviewWidget_t {
    QByteArrayData data[14];
    char stringdata0[132];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OSDPreviewWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OSDPreviewWidget_t qt_meta_stringdata_OSDPreviewWidget = {
    {
QT_MOC_LITERAL(0, 0, 16), // "OSDPreviewWidget"
QT_MOC_LITERAL(1, 17, 15), // "positionChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 12), // "setTextColor"
QT_MOC_LITERAL(4, 47, 5), // "color"
QT_MOC_LITERAL(5, 53, 7), // "setFont"
QT_MOC_LITERAL(6, 61, 4), // "font"
QT_MOC_LITERAL(7, 66, 9), // "setScreen"
QT_MOC_LITERAL(8, 76, 6), // "screen"
QT_MOC_LITERAL(9, 83, 18), // "setUseCustomColors"
QT_MOC_LITERAL(10, 102, 3), // "use"
QT_MOC_LITERAL(11, 106, 2), // "fg"
QT_MOC_LITERAL(12, 109, 14), // "setTranslucent"
QT_MOC_LITERAL(13, 124, 7) // "enabled"

    },
    "OSDPreviewWidget\0positionChanged\0\0"
    "setTextColor\0color\0setFont\0font\0"
    "setScreen\0screen\0setUseCustomColors\0"
    "use\0fg\0setTranslucent\0enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OSDPreviewWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   45,    2, 0x0a /* Public */,
       5,    1,   48,    2, 0x0a /* Public */,
       7,    1,   51,    2, 0x0a /* Public */,
       9,    2,   54,    2, 0x0a /* Public */,
      12,    1,   59,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QColor,    4,
    QMetaType::Void, QMetaType::QFont,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Bool, QMetaType::QColor,   10,   11,
    QMetaType::Void, QMetaType::Bool,   13,

       0        // eod
};

void OSDPreviewWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OSDPreviewWidget *_t = static_cast<OSDPreviewWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->positionChanged(); break;
        case 1: _t->setTextColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 2: _t->setFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 3: _t->setScreen((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setUseCustomColors((*reinterpret_cast< const bool(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 5: _t->setTranslucent((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (OSDPreviewWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OSDPreviewWidget::positionChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject OSDPreviewWidget::staticMetaObject = {
    { &OSDWidget::staticMetaObject, qt_meta_stringdata_OSDPreviewWidget.data,
      qt_meta_data_OSDPreviewWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *OSDPreviewWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OSDPreviewWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OSDPreviewWidget.stringdata0))
        return static_cast<void*>(this);
    return OSDWidget::qt_metacast(_clname);
}

int OSDPreviewWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = OSDWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void OSDPreviewWidget::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
