/****************************************************************************
** Meta object code from reading C++ file 'transfersend.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transfersend.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfersend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferSend_t {
    QByteArrayData data[24];
    char stringdata0[287];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferSend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferSend_t qt_meta_stringdata_Konversation__DCC__TransferSend = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Konversation::DCC::TransferSend"
QT_MOC_LITERAL(1, 32, 5), // "queue"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 5), // "start"
QT_MOC_LITERAL(4, 45, 5), // "abort"
QT_MOC_LITERAL(5, 51, 17), // "connectToReceiver"
QT_MOC_LITERAL(6, 69, 11), // "partnerHost"
QT_MOC_LITERAL(7, 81, 11), // "partnerPort"
QT_MOC_LITERAL(8, 93, 12), // "acceptClient"
QT_MOC_LITERAL(9, 106, 12), // "startSending"
QT_MOC_LITERAL(10, 119, 9), // "writeData"
QT_MOC_LITERAL(11, 129, 12), // "bytesWritten"
QT_MOC_LITERAL(12, 142, 5), // "bytes"
QT_MOC_LITERAL(13, 148, 6), // "getAck"
QT_MOC_LITERAL(14, 155, 18), // "slotGotSocketError"
QT_MOC_LITERAL(15, 174, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(16, 203, 9), // "errorCode"
QT_MOC_LITERAL(17, 213, 21), // "slotConnectionTimeout"
QT_MOC_LITERAL(18, 235, 11), // "sendRequest"
QT_MOC_LITERAL(19, 247, 5), // "error"
QT_MOC_LITERAL(20, 253, 4), // "port"
QT_MOC_LITERAL(21, 258, 18), // "slotLocalCopyReady"
QT_MOC_LITERAL(22, 277, 5), // "KJob*"
QT_MOC_LITERAL(23, 283, 3) // "job"

    },
    "Konversation::DCC::TransferSend\0queue\0"
    "\0start\0abort\0connectToReceiver\0"
    "partnerHost\0partnerPort\0acceptClient\0"
    "startSending\0writeData\0bytesWritten\0"
    "bytes\0getAck\0slotGotSocketError\0"
    "QAbstractSocket::SocketError\0errorCode\0"
    "slotConnectionTimeout\0sendRequest\0"
    "error\0port\0slotLocalCopyReady\0KJob*\0"
    "job"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferSend[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    0,   80,    2, 0x0a /* Public */,
       4,    0,   81,    2, 0x0a /* Public */,
       5,    2,   82,    2, 0x0a /* Public */,
       8,    0,   87,    2, 0x09 /* Protected */,
       9,    0,   88,    2, 0x09 /* Protected */,
      10,    0,   89,    2, 0x09 /* Protected */,
      11,    1,   90,    2, 0x09 /* Protected */,
      13,    0,   93,    2, 0x09 /* Protected */,
      14,    1,   94,    2, 0x09 /* Protected */,
      17,    0,   97,    2, 0x09 /* Protected */,
      18,    2,   98,    2, 0x09 /* Protected */,
      21,    1,  103,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::UShort,    6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   12,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,   19,   20,
    QMetaType::Void, 0x80000000 | 22,   23,

       0        // eod
};

void Konversation::DCC::TransferSend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferSend *_t = static_cast<TransferSend *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->queue();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->start(); break;
        case 2: _t->abort(); break;
        case 3: _t->connectToReceiver((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        case 4: _t->acceptClient(); break;
        case 5: _t->startSending(); break;
        case 6: _t->writeData(); break;
        case 7: _t->bytesWritten((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 8: _t->getAck(); break;
        case 9: _t->slotGotSocketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 10: _t->slotConnectionTimeout(); break;
        case 11: _t->sendRequest((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        case 12: _t->slotLocalCopyReady((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Konversation::DCC::TransferSend::staticMetaObject = {
    { &Transfer::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferSend.data,
      qt_meta_data_Konversation__DCC__TransferSend,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferSend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferSend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferSend.stringdata0))
        return static_cast<void*>(this);
    return Transfer::qt_metacast(_clname);
}

int Konversation::DCC::TransferSend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Transfer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
