/****************************************************************************
** Meta object code from reading C++ file 'whiteboard.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/whiteboard.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__WhiteBoard_t {
    QByteArrayData data[33];
    char stringdata0[354];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__WhiteBoard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__WhiteBoard_t qt_meta_stringdata_Konversation__DCC__WhiteBoard = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Konversation::DCC::WhiteBoard"
QT_MOC_LITERAL(1, 30, 20), // "rawWhiteBoardCommand"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 7), // "command"
QT_MOC_LITERAL(4, 60, 22), // "receivedWhiteBoardLine"
QT_MOC_LITERAL(5, 83, 4), // "line"
QT_MOC_LITERAL(6, 88, 9), // "connected"
QT_MOC_LITERAL(7, 98, 5), // "clear"
QT_MOC_LITERAL(8, 104, 12), // "drawedPencil"
QT_MOC_LITERAL(9, 117, 9), // "lineWidth"
QT_MOC_LITERAL(10, 127, 8), // "penColor"
QT_MOC_LITERAL(11, 136, 10), // "brushColor"
QT_MOC_LITERAL(12, 147, 5), // "xFrom"
QT_MOC_LITERAL(13, 153, 5), // "yFrom"
QT_MOC_LITERAL(14, 159, 3), // "xTo"
QT_MOC_LITERAL(15, 163, 3), // "yTo"
QT_MOC_LITERAL(16, 167, 10), // "drawedLine"
QT_MOC_LITERAL(17, 178, 15), // "drawedRectangle"
QT_MOC_LITERAL(18, 194, 21), // "drawedFilledRectangle"
QT_MOC_LITERAL(19, 216, 13), // "drawedEllipse"
QT_MOC_LITERAL(20, 230, 19), // "drawedFilledEllipse"
QT_MOC_LITERAL(21, 250, 11), // "drawedArrow"
QT_MOC_LITERAL(22, 262, 10), // "usedEraser"
QT_MOC_LITERAL(23, 273, 13), // "usedFloodFill"
QT_MOC_LITERAL(24, 287, 1), // "x"
QT_MOC_LITERAL(25, 289, 1), // "y"
QT_MOC_LITERAL(26, 291, 5), // "color"
QT_MOC_LITERAL(27, 297, 8), // "usedText"
QT_MOC_LITERAL(28, 306, 4), // "text"
QT_MOC_LITERAL(29, 311, 16), // "usedTextExtended"
QT_MOC_LITERAL(30, 328, 4), // "font"
QT_MOC_LITERAL(31, 333, 9), // "textColor"
QT_MOC_LITERAL(32, 343, 10) // "background"

    },
    "Konversation::DCC::WhiteBoard\0"
    "rawWhiteBoardCommand\0\0command\0"
    "receivedWhiteBoardLine\0line\0connected\0"
    "clear\0drawedPencil\0lineWidth\0penColor\0"
    "brushColor\0xFrom\0yFrom\0xTo\0yTo\0"
    "drawedLine\0drawedRectangle\0"
    "drawedFilledRectangle\0drawedEllipse\0"
    "drawedFilledEllipse\0drawedArrow\0"
    "usedEraser\0usedFloodFill\0x\0y\0color\0"
    "usedText\0text\0usedTextExtended\0font\0"
    "textColor\0background"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__WhiteBoard[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   92,    2, 0x0a /* Public */,
       6,    0,   95,    2, 0x0a /* Public */,
       7,    0,   96,    2, 0x0a /* Public */,
       8,    7,   97,    2, 0x0a /* Public */,
      16,    7,  112,    2, 0x0a /* Public */,
      17,    6,  127,    2, 0x0a /* Public */,
      18,    7,  140,    2, 0x0a /* Public */,
      19,    6,  155,    2, 0x0a /* Public */,
      20,    7,  168,    2, 0x0a /* Public */,
      21,    6,  183,    2, 0x0a /* Public */,
      22,    5,  196,    2, 0x0a /* Public */,
      23,    3,  207,    2, 0x0a /* Public */,
      27,    3,  214,    2, 0x0a /* Public */,
      29,    6,  221,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   11,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::QColor, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   10,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    9,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QColor,   24,   25,   26,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   24,   25,   28,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QFont, QMetaType::QColor, QMetaType::QColor, QMetaType::QString,   24,   25,   30,   31,   32,   28,

       0        // eod
};

void Konversation::DCC::WhiteBoard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhiteBoard *_t = static_cast<WhiteBoard *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->rawWhiteBoardCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->receivedWhiteBoardLine((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->connected(); break;
        case 3: _t->clear(); break;
        case 4: _t->drawedPencil((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 5: _t->drawedLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 6: _t->drawedRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 7: _t->drawedFilledRectangle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 8: _t->drawedEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 9: _t->drawedFilledEllipse((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7]))); break;
        case 10: _t->drawedArrow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6]))); break;
        case 11: _t->usedEraser((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 12: _t->usedFloodFill((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QColor(*)>(_a[3]))); break;
        case 13: _t->usedText((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 14: _t->usedTextExtended((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QFont(*)>(_a[3])),(*reinterpret_cast< const QColor(*)>(_a[4])),(*reinterpret_cast< const QColor(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhiteBoard::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoard::rawWhiteBoardCommand)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::WhiteBoard::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Konversation__DCC__WhiteBoard.data,
      qt_meta_data_Konversation__DCC__WhiteBoard,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::WhiteBoard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__WhiteBoard.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoard::rawWhiteBoardCommand(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
