#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'servergroupdialogui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVERGROUPDIALOGUI_H
#define UI_SERVERGROUPDIALOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ServerGroupDialogUI
{
public:
    QGridLayout *gridLayout_3;
    QLabel *m_networkLabel;
    QLabel *m_identityLabel;
    KComboBox *m_identityCBox;
    QPushButton *m_editIdentityButton;
    QLabel *m_commandsLabel;
    KLineEdit *m_commandEdit;
    KLineEdit *m_nameEdit;
    QLabel *label;
    QLabel *label_2;
    QCheckBox *m_autoConnectCBox;
    QWidget *serverWidget;
    QGridLayout *gridLayout;
    QListWidget *m_serverLBox;
    QPushButton *m_addServerButton;
    QPushButton *m_changeServerButton;
    QToolButton *m_removeServerButton;
    QSpacerItem *serverSpacer;
    QToolButton *m_upServerBtn;
    QToolButton *m_downServerBtn;
    QWidget *channelWidget;
    QGridLayout *gridLayout_2;
    QListWidget *m_channelLBox;
    QPushButton *m_addChannelButton;
    QPushButton *m_changeChannelButton;
    QToolButton *m_removeChannelButton;
    QSpacerItem *channelSpacer;
    QToolButton *m_upChannelBtn;
    QToolButton *m_downChannelBtn;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *ServerGroupDialogUI)
    {
        if (ServerGroupDialogUI->objectName().isEmpty())
            ServerGroupDialogUI->setObjectName(QStringLiteral("ServerGroupDialogUI"));
        ServerGroupDialogUI->resize(307, 431);
        gridLayout_3 = new QGridLayout(ServerGroupDialogUI);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        m_networkLabel = new QLabel(ServerGroupDialogUI);
        m_networkLabel->setObjectName(QStringLiteral("m_networkLabel"));
        m_networkLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_networkLabel->setWordWrap(false);

        gridLayout_3->addWidget(m_networkLabel, 0, 0, 1, 1);

        m_identityLabel = new QLabel(ServerGroupDialogUI);
        m_identityLabel->setObjectName(QStringLiteral("m_identityLabel"));
        m_identityLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_identityLabel->setWordWrap(false);

        gridLayout_3->addWidget(m_identityLabel, 2, 0, 1, 1);

        m_identityCBox = new KComboBox(ServerGroupDialogUI);
        m_identityCBox->setObjectName(QStringLiteral("m_identityCBox"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(2);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_identityCBox->sizePolicy().hasHeightForWidth());
        m_identityCBox->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(m_identityCBox, 2, 1, 1, 1);

        m_editIdentityButton = new QPushButton(ServerGroupDialogUI);
        m_editIdentityButton->setObjectName(QStringLiteral("m_editIdentityButton"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_editIdentityButton->sizePolicy().hasHeightForWidth());
        m_editIdentityButton->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(m_editIdentityButton, 2, 2, 1, 1);

        m_commandsLabel = new QLabel(ServerGroupDialogUI);
        m_commandsLabel->setObjectName(QStringLiteral("m_commandsLabel"));
        m_commandsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        m_commandsLabel->setWordWrap(false);

        gridLayout_3->addWidget(m_commandsLabel, 3, 0, 1, 1);

        m_commandEdit = new KLineEdit(ServerGroupDialogUI);
        m_commandEdit->setObjectName(QStringLiteral("m_commandEdit"));

        gridLayout_3->addWidget(m_commandEdit, 3, 1, 1, 2);

        m_nameEdit = new KLineEdit(ServerGroupDialogUI);
        m_nameEdit->setObjectName(QStringLiteral("m_nameEdit"));

        gridLayout_3->addWidget(m_nameEdit, 0, 1, 1, 2);

        label = new QLabel(ServerGroupDialogUI);
        label->setObjectName(QStringLiteral("label"));

        gridLayout_3->addWidget(label, 6, 0, 1, 3);

        label_2 = new QLabel(ServerGroupDialogUI);
        label_2->setObjectName(QStringLiteral("label_2"));

        gridLayout_3->addWidget(label_2, 10, 0, 1, 3);

        m_autoConnectCBox = new QCheckBox(ServerGroupDialogUI);
        m_autoConnectCBox->setObjectName(QStringLiteral("m_autoConnectCBox"));

        gridLayout_3->addWidget(m_autoConnectCBox, 4, 0, 1, 3);

        serverWidget = new QWidget(ServerGroupDialogUI);
        serverWidget->setObjectName(QStringLiteral("serverWidget"));
        gridLayout = new QGridLayout(serverWidget);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        m_serverLBox = new QListWidget(serverWidget);
        m_serverLBox->setObjectName(QStringLiteral("m_serverLBox"));

        gridLayout->addWidget(m_serverLBox, 0, 0, 1, 6);

        m_addServerButton = new QPushButton(serverWidget);
        m_addServerButton->setObjectName(QStringLiteral("m_addServerButton"));

        gridLayout->addWidget(m_addServerButton, 1, 0, 1, 1);

        m_changeServerButton = new QPushButton(serverWidget);
        m_changeServerButton->setObjectName(QStringLiteral("m_changeServerButton"));
        m_changeServerButton->setEnabled(false);

        gridLayout->addWidget(m_changeServerButton, 1, 1, 1, 1);

        m_removeServerButton = new QToolButton(serverWidget);
        m_removeServerButton->setObjectName(QStringLiteral("m_removeServerButton"));
        m_removeServerButton->setEnabled(false);

        gridLayout->addWidget(m_removeServerButton, 1, 2, 1, 1);

        serverSpacer = new QSpacerItem(228, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(serverSpacer, 1, 3, 1, 1);

        m_upServerBtn = new QToolButton(serverWidget);
        m_upServerBtn->setObjectName(QStringLiteral("m_upServerBtn"));
        m_upServerBtn->setEnabled(false);
        m_upServerBtn->setAutoRepeat(true);

        gridLayout->addWidget(m_upServerBtn, 1, 4, 1, 1);

        m_downServerBtn = new QToolButton(serverWidget);
        m_downServerBtn->setObjectName(QStringLiteral("m_downServerBtn"));
        m_downServerBtn->setEnabled(false);
        m_downServerBtn->setAutoRepeat(true);

        gridLayout->addWidget(m_downServerBtn, 1, 5, 1, 1);


        gridLayout_3->addWidget(serverWidget, 8, 0, 1, 3);

        channelWidget = new QWidget(ServerGroupDialogUI);
        channelWidget->setObjectName(QStringLiteral("channelWidget"));
        gridLayout_2 = new QGridLayout(channelWidget);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        m_channelLBox = new QListWidget(channelWidget);
        m_channelLBox->setObjectName(QStringLiteral("m_channelLBox"));

        gridLayout_2->addWidget(m_channelLBox, 0, 0, 1, 6);

        m_addChannelButton = new QPushButton(channelWidget);
        m_addChannelButton->setObjectName(QStringLiteral("m_addChannelButton"));

        gridLayout_2->addWidget(m_addChannelButton, 1, 0, 1, 1);

        m_changeChannelButton = new QPushButton(channelWidget);
        m_changeChannelButton->setObjectName(QStringLiteral("m_changeChannelButton"));
        m_changeChannelButton->setEnabled(false);

        gridLayout_2->addWidget(m_changeChannelButton, 1, 1, 1, 1);

        m_removeChannelButton = new QToolButton(channelWidget);
        m_removeChannelButton->setObjectName(QStringLiteral("m_removeChannelButton"));
        m_removeChannelButton->setEnabled(false);

        gridLayout_2->addWidget(m_removeChannelButton, 1, 2, 1, 1);

        channelSpacer = new QSpacerItem(255, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(channelSpacer, 1, 3, 1, 1);

        m_upChannelBtn = new QToolButton(channelWidget);
        m_upChannelBtn->setObjectName(QStringLiteral("m_upChannelBtn"));
        m_upChannelBtn->setEnabled(false);
        m_upChannelBtn->setAutoRepeat(true);

        gridLayout_2->addWidget(m_upChannelBtn, 1, 4, 1, 1);

        m_downChannelBtn = new QToolButton(channelWidget);
        m_downChannelBtn->setObjectName(QStringLiteral("m_downChannelBtn"));
        m_downChannelBtn->setEnabled(false);
        m_downChannelBtn->setAutoRepeat(true);

        gridLayout_2->addWidget(m_downChannelBtn, 1, 5, 1, 1);


        gridLayout_3->addWidget(channelWidget, 11, 0, 1, 3);

        verticalSpacer = new QSpacerItem(20, 6, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_3->addItem(verticalSpacer, 5, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 6, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout_3->addItem(verticalSpacer_2, 9, 0, 1, 1);

#ifndef UI_QT_NO_SHORTCUT
        m_networkLabel->setBuddy(m_nameEdit);
        m_identityLabel->setBuddy(m_identityCBox);
        m_commandsLabel->setBuddy(m_commandEdit);
        label->setBuddy(m_serverLBox);
        label_2->setBuddy(m_channelLBox);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(m_nameEdit, m_identityCBox);
        QWidget::setTabOrder(m_identityCBox, m_editIdentityButton);
        QWidget::setTabOrder(m_editIdentityButton, m_commandEdit);
        QWidget::setTabOrder(m_commandEdit, m_autoConnectCBox);
        QWidget::setTabOrder(m_autoConnectCBox, m_serverLBox);
        QWidget::setTabOrder(m_serverLBox, m_addServerButton);
        QWidget::setTabOrder(m_addServerButton, m_changeServerButton);
        QWidget::setTabOrder(m_changeServerButton, m_removeServerButton);
        QWidget::setTabOrder(m_removeServerButton, m_upServerBtn);
        QWidget::setTabOrder(m_upServerBtn, m_downServerBtn);
        QWidget::setTabOrder(m_downServerBtn, m_channelLBox);
        QWidget::setTabOrder(m_channelLBox, m_addChannelButton);
        QWidget::setTabOrder(m_addChannelButton, m_changeChannelButton);
        QWidget::setTabOrder(m_changeChannelButton, m_removeChannelButton);
        QWidget::setTabOrder(m_removeChannelButton, m_upChannelBtn);
        QWidget::setTabOrder(m_upChannelBtn, m_downChannelBtn);

        retranslateUi(ServerGroupDialogUI);

        QMetaObject::connectSlotsByName(ServerGroupDialogUI);
    } // setupUi

    void retranslateUi(QWidget *ServerGroupDialogUI)
    {
        m_networkLabel->setText(tr2i18n("Network name:", Q_NULLPTR));
        m_identityLabel->setText(tr2i18n("Identity:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_identityCBox->setWhatsThis(tr2i18n("Choose an existing Identity or click the Edit button to add a new Identity or edit an existing one. The Identity will identify you and determine your nickname when you connect to the network.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_editIdentityButton->setText(tr2i18n("&Edit...", Q_NULLPTR));
        m_commandsLabel->setText(tr2i18n("Commands:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_commandEdit->setWhatsThis(tr2i18n("<qt>Optional. This command will be sent to the server after connecting. Example: <b>/msg NickServ IDENTIFY <i>konvirocks</i></b>. This example is for the freenode network, which requires users to register their nickname with a password and login when connecting. <i>konvirocks</i> is the password for the nickname given in Identity. You may enter more than one command by separating them with semicolons.</qt>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef UI_QT_NO_WHATSTHIS
        m_nameEdit->setWhatsThis(tr2i18n("Enter the name of the Network here. You may create as many entries in the Server List screen with the same Network as you like.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        label->setText(tr2i18n("Servers:", Q_NULLPTR));
        label_2->setText(tr2i18n("Auto Join Channels:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_autoConnectCBox->setWhatsThis(tr2i18n("Check here if you want Konversation to automatically connect to this network whenever you open Konversation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_autoConnectCBox->setText(tr2i18n("Co&nnect on application start up", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        m_serverLBox->setWhatsThis(tr2i18n("This is a list of IRC Servers in the network. When connecting to the network, Konversation will attempt to connect to the top server first. If this fails, it will attempt the second server. If this fails, it will attempt the third, and so on. At least one server must be specified. Click a server to highlight it.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_addServerButton->setText(tr2i18n("&Add...", Q_NULLPTR));
        m_changeServerButton->setText(tr2i18n("E&dit...", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        m_removeServerButton->setToolTip(tr2i18n("Delete", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        m_removeServerButton->setText(QString());
        m_upServerBtn->setText(QString());
        m_downServerBtn->setText(QString());
#ifndef UI_QT_NO_WHATSTHIS
        m_channelLBox->setWhatsThis(tr2i18n("Optional. This is a list of the channels that will be automatically joined once Konversation has connected to a server. You may leave this blank if you wish to not automatically join any channels.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        m_addChannelButton->setText(tr2i18n("Add...", Q_NULLPTR));
        m_changeChannelButton->setText(tr2i18n("Ed&it...", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        m_removeChannelButton->setToolTip(tr2i18n("Delete", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        m_removeChannelButton->setText(QString());
        m_upChannelBtn->setText(QString());
        m_downChannelBtn->setText(QString());
        Q_UNUSED(ServerGroupDialogUI);
    } // retranslateUi

};

namespace Ui {
    class ServerGroupDialogUI: public Ui_ServerGroupDialogUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SERVERGROUPDIALOGUI_H

