/****************************************************************************
** Meta object code from reading C++ file 'channellistpanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/channellistpanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channellistpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChannelListProxyModel_t {
    QByteArrayData data[8];
    char stringdata0[112];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChannelListProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChannelListProxyModel_t qt_meta_stringdata_ChannelListProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 21), // "ChannelListProxyModel"
QT_MOC_LITERAL(1, 22, 21), // "setFilterMinimumUsers"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 5), // "users"
QT_MOC_LITERAL(4, 51, 21), // "setFilterMaximumUsers"
QT_MOC_LITERAL(5, 73, 14), // "setFilterTopic"
QT_MOC_LITERAL(6, 88, 6), // "filter"
QT_MOC_LITERAL(7, 95, 16) // "setFilterChannel"

    },
    "ChannelListProxyModel\0setFilterMinimumUsers\0"
    "\0users\0setFilterMaximumUsers\0"
    "setFilterTopic\0filter\0setFilterChannel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChannelListProxyModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       4,    1,   37,    2, 0x0a /* Public */,
       5,    1,   40,    2, 0x0a /* Public */,
       7,    1,   43,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Bool,    6,

       0        // eod
};

void ChannelListProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChannelListProxyModel *_t = static_cast<ChannelListProxyModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setFilterMinimumUsers((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->setFilterMaximumUsers((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setFilterTopic((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setFilterChannel((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject ChannelListProxyModel::staticMetaObject = {
    { &QSortFilterProxyModel::staticMetaObject, qt_meta_stringdata_ChannelListProxyModel.data,
      qt_meta_data_ChannelListProxyModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ChannelListProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChannelListProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChannelListProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int ChannelListProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_ChannelListModel_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChannelListModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChannelListModel_t qt_meta_stringdata_ChannelListModel = {
    {
QT_MOC_LITERAL(0, 0, 16) // "ChannelListModel"

    },
    "ChannelListModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChannelListModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ChannelListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject ChannelListModel::staticMetaObject = {
    { &QAbstractListModel::staticMetaObject, qt_meta_stringdata_ChannelListModel.data,
      qt_meta_data_ChannelListModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ChannelListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChannelListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChannelListModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ChannelListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ChannelListPanel_t {
    QByteArrayData data[30];
    char stringdata0[353];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChannelListPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChannelListPanel_t qt_meta_stringdata_ChannelListPanel = {
    {
QT_MOC_LITERAL(0, 0, 16), // "ChannelListPanel"
QT_MOC_LITERAL(1, 17, 18), // "refreshChannelList"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 11), // "joinChannel"
QT_MOC_LITERAL(4, 49, 11), // "channelName"
QT_MOC_LITERAL(5, 61, 11), // "refreshList"
QT_MOC_LITERAL(6, 73, 16), // "addToChannelList"
QT_MOC_LITERAL(7, 90, 7), // "channel"
QT_MOC_LITERAL(8, 98, 5), // "users"
QT_MOC_LITERAL(9, 104, 5), // "topic"
QT_MOC_LITERAL(10, 110, 16), // "endOfChannelList"
QT_MOC_LITERAL(11, 127, 18), // "applyFilterClicked"
QT_MOC_LITERAL(12, 146, 15), // "appendInputText"
QT_MOC_LITERAL(13, 162, 10), // "fromCursor"
QT_MOC_LITERAL(14, 173, 9), // "setFilter"
QT_MOC_LITERAL(15, 183, 6), // "filter"
QT_MOC_LITERAL(16, 190, 8), // "saveList"
QT_MOC_LITERAL(17, 199, 13), // "filterChanged"
QT_MOC_LITERAL(18, 213, 12), // "updateFilter"
QT_MOC_LITERAL(19, 226, 19), // "updateUsersChannels"
QT_MOC_LITERAL(20, 246, 14), // "currentChanged"
QT_MOC_LITERAL(21, 261, 7), // "current"
QT_MOC_LITERAL(22, 269, 8), // "previous"
QT_MOC_LITERAL(23, 278, 11), // "setProgress"
QT_MOC_LITERAL(24, 290, 18), // "joinChannelClicked"
QT_MOC_LITERAL(25, 309, 11), // "contextMenu"
QT_MOC_LITERAL(26, 321, 3), // "pos"
QT_MOC_LITERAL(27, 325, 7), // "openURL"
QT_MOC_LITERAL(28, 333, 12), // "serverOnline"
QT_MOC_LITERAL(29, 346, 6) // "online"

    },
    "ChannelListPanel\0refreshChannelList\0"
    "\0joinChannel\0channelName\0refreshList\0"
    "addToChannelList\0channel\0users\0topic\0"
    "endOfChannelList\0applyFilterClicked\0"
    "appendInputText\0fromCursor\0setFilter\0"
    "filter\0saveList\0filterChanged\0"
    "updateFilter\0updateUsersChannels\0"
    "currentChanged\0current\0previous\0"
    "setProgress\0joinChannelClicked\0"
    "contextMenu\0pos\0openURL\0serverOnline\0"
    "online"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChannelListPanel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,
       3,    1,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,  108,    2, 0x0a /* Public */,
       6,    3,  109,    2, 0x0a /* Public */,
      10,    0,  116,    2, 0x0a /* Public */,
      11,    0,  117,    2, 0x0a /* Public */,
      12,    2,  118,    2, 0x0a /* Public */,
      14,    1,  123,    2, 0x0a /* Public */,
      16,    0,  126,    2, 0x09 /* Protected */,
      17,    0,  127,    2, 0x09 /* Protected */,
      18,    0,  128,    2, 0x09 /* Protected */,
      19,    0,  129,    2, 0x09 /* Protected */,
      20,    2,  130,    2, 0x09 /* Protected */,
      23,    0,  135,    2, 0x09 /* Protected */,
      24,    0,  136,    2, 0x09 /* Protected */,
      25,    1,  137,    2, 0x09 /* Protected */,
      27,    0,  140,    2, 0x09 /* Protected */,
      28,    1,  141,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    7,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,   13,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,   21,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   26,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,

       0        // eod
};

void ChannelListPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChannelListPanel *_t = static_cast<ChannelListPanel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->refreshChannelList(); break;
        case 1: _t->joinChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->refreshList(); break;
        case 3: _t->addToChannelList((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 4: _t->endOfChannelList(); break;
        case 5: _t->applyFilterClicked(); break;
        case 6: _t->appendInputText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 7: _t->setFilter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->saveList(); break;
        case 9: _t->filterChanged(); break;
        case 10: _t->updateFilter(); break;
        case 11: _t->updateUsersChannels(); break;
        case 12: _t->currentChanged((*reinterpret_cast< QModelIndex(*)>(_a[1])),(*reinterpret_cast< QModelIndex(*)>(_a[2]))); break;
        case 13: _t->setProgress(); break;
        case 14: _t->joinChannelClicked(); break;
        case 15: _t->contextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 16: _t->openURL(); break;
        case 17: _t->serverOnline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ChannelListPanel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChannelListPanel::refreshChannelList)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ChannelListPanel::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChannelListPanel::joinChannel)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject ChannelListPanel::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_ChannelListPanel.data,
      qt_meta_data_ChannelListPanel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ChannelListPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChannelListPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChannelListPanel.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int ChannelListPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void ChannelListPanel::refreshChannelList()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ChannelListPanel::joinChannel(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
