/****************************************************************************
** Meta object code from reading C++ file 'highlight_config.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/config/highlight_config.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'highlight_config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Highlight_Config_t {
    QByteArrayData data[23];
    char stringdata0[309];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Highlight_Config_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Highlight_Config_t qt_meta_stringdata_Highlight_Config = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Highlight_Config"
QT_MOC_LITERAL(1, 17, 8), // "modified"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 17), // "highlightSelected"
QT_MOC_LITERAL(4, 45, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(5, 62, 4), // "item"
QT_MOC_LITERAL(6, 67, 14), // "patternChanged"
QT_MOC_LITERAL(7, 82, 10), // "newPattern"
QT_MOC_LITERAL(8, 93, 17), // "notifyModeChanged"
QT_MOC_LITERAL(9, 111, 12), // "colorChanged"
QT_MOC_LITERAL(10, 124, 8), // "newColor"
QT_MOC_LITERAL(11, 133, 15), // "soundURLChanged"
QT_MOC_LITERAL(12, 149, 6), // "newURL"
QT_MOC_LITERAL(13, 156, 15), // "autoTextChanged"
QT_MOC_LITERAL(14, 172, 7), // "newText"
QT_MOC_LITERAL(15, 180, 18), // "chatWindowsChanged"
QT_MOC_LITERAL(16, 199, 14), // "newChatWindows"
QT_MOC_LITERAL(17, 214, 12), // "addHighlight"
QT_MOC_LITERAL(18, 227, 15), // "removeHighlight"
QT_MOC_LITERAL(19, 243, 9), // "playSound"
QT_MOC_LITERAL(20, 253, 16), // "getHighlightList"
QT_MOC_LITERAL(21, 270, 17), // "QList<Highlight*>"
QT_MOC_LITERAL(22, 288, 20) // "currentHighlightList"

    },
    "Highlight_Config\0modified\0\0highlightSelected\0"
    "QTreeWidgetItem*\0item\0patternChanged\0"
    "newPattern\0notifyModeChanged\0colorChanged\0"
    "newColor\0soundURLChanged\0newURL\0"
    "autoTextChanged\0newText\0chatWindowsChanged\0"
    "newChatWindows\0addHighlight\0removeHighlight\0"
    "playSound\0getHighlightList\0QList<Highlight*>\0"
    "currentHighlightList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Highlight_Config[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   80,    2, 0x09 /* Protected */,
       6,    1,   83,    2, 0x09 /* Protected */,
       8,    1,   86,    2, 0x09 /* Protected */,
       9,    1,   89,    2, 0x09 /* Protected */,
      11,    1,   92,    2, 0x09 /* Protected */,
      13,    1,   95,    2, 0x09 /* Protected */,
      15,    1,   98,    2, 0x09 /* Protected */,
      17,    0,  101,    2, 0x09 /* Protected */,
      18,    0,  102,    2, 0x09 /* Protected */,
      19,    0,  103,    2, 0x09 /* Protected */,
      20,    0,  104,    2, 0x09 /* Protected */,
      22,    0,  105,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QColor,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 21,
    QMetaType::QStringList,

       0        // eod
};

void Highlight_Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Highlight_Config *_t = static_cast<Highlight_Config *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->modified(); break;
        case 1: _t->highlightSelected((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->patternChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->notifyModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->colorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 5: _t->soundURLChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->autoTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->chatWindowsChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->addHighlight(); break;
        case 9: _t->removeHighlight(); break;
        case 10: _t->playSound(); break;
        case 11: { QList<Highlight*> _r = _t->getHighlightList();
            if (_a[0]) *reinterpret_cast< QList<Highlight*>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QStringList _r = _t->currentHighlightList();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Highlight_Config::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Highlight_Config::modified)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Highlight_Config::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Highlight_Config.data,
      qt_meta_data_Highlight_Config,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Highlight_Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Highlight_Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Highlight_Config.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KonviSettingsPage"))
        return static_cast< KonviSettingsPage*>(this);
    return QWidget::qt_metacast(_clname);
}

int Highlight_Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Highlight_Config::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
