/****************************************************************************
** Meta object code from reading C++ file 'logfilereader.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/logfilereader.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'logfilereader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LogfileReader_t {
    QByteArrayData data[11];
    char stringdata0[92];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LogfileReader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LogfileReader_t qt_meta_stringdata_LogfileReader = {
    {
QT_MOC_LITERAL(0, 0, 13), // "LogfileReader"
QT_MOC_LITERAL(1, 14, 10), // "updateView"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 15), // "storeBufferSize"
QT_MOC_LITERAL(4, 42, 2), // "kb"
QT_MOC_LITERAL(5, 45, 8), // "clearLog"
QT_MOC_LITERAL(6, 54, 7), // "saveLog"
QT_MOC_LITERAL(7, 62, 8), // "closeLog"
QT_MOC_LITERAL(8, 71, 10), // "copyResult"
QT_MOC_LITERAL(9, 82, 5), // "KJob*"
QT_MOC_LITERAL(10, 88, 3) // "job"

    },
    "LogfileReader\0updateView\0\0storeBufferSize\0"
    "kb\0clearLog\0saveLog\0closeLog\0copyResult\0"
    "KJob*\0job"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LogfileReader[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x09 /* Protected */,
       3,    1,   45,    2, 0x09 /* Protected */,
       5,    0,   48,    2, 0x09 /* Protected */,
       6,    0,   49,    2, 0x09 /* Protected */,
       7,    0,   50,    2, 0x09 /* Protected */,
       8,    1,   51,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,

       0        // eod
};

void LogfileReader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        LogfileReader *_t = static_cast<LogfileReader *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateView(); break;
        case 1: _t->storeBufferSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->clearLog(); break;
        case 3: _t->saveLog(); break;
        case 4: _t->closeLog(); break;
        case 5: _t->copyResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject LogfileReader::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_LogfileReader.data,
      qt_meta_data_LogfileReader,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *LogfileReader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LogfileReader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LogfileReader.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int LogfileReader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
