/****************************************************************************
** Meta object code from reading C++ file 'channeloptionsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/channeloptionsdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channeloptionsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__ChannelOptionsDialog_t {
    QByteArrayData data[23];
    char stringdata0[341];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__ChannelOptionsDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__ChannelOptionsDialog_t qt_meta_stringdata_Konversation__ChannelOptionsDialog = {
    {
QT_MOC_LITERAL(0, 0, 34), // "Konversation::ChannelOptionsD..."
QT_MOC_LITERAL(1, 35, 26), // "refreshAllowedChannelModes"
QT_MOC_LITERAL(2, 62, 0), // ""
QT_MOC_LITERAL(3, 63, 12), // "refreshModes"
QT_MOC_LITERAL(4, 76, 18), // "refreshEnableModes"
QT_MOC_LITERAL(5, 95, 11), // "forceUpdate"
QT_MOC_LITERAL(6, 107, 19), // "toggleAdvancedModes"
QT_MOC_LITERAL(7, 127, 14), // "refreshBanList"
QT_MOC_LITERAL(8, 142, 6), // "addBan"
QT_MOC_LITERAL(9, 149, 6), // "newban"
QT_MOC_LITERAL(10, 156, 13), // "addBanClicked"
QT_MOC_LITERAL(11, 170, 16), // "updateBanClicked"
QT_MOC_LITERAL(12, 187, 9), // "removeBan"
QT_MOC_LITERAL(13, 197, 3), // "ban"
QT_MOC_LITERAL(14, 201, 16), // "removeBanClicked"
QT_MOC_LITERAL(15, 218, 19), // "banSelectionChanged"
QT_MOC_LITERAL(16, 238, 15), // "hostmaskChanged"
QT_MOC_LITERAL(17, 254, 13), // "changeOptions"
QT_MOC_LITERAL(18, 268, 23), // "topicHistoryItemClicked"
QT_MOC_LITERAL(19, 292, 14), // "QItemSelection"
QT_MOC_LITERAL(20, 307, 9), // "selection"
QT_MOC_LITERAL(21, 317, 16), // "topicBeingEdited"
QT_MOC_LITERAL(22, 334, 6) // "edited"

    },
    "Konversation::ChannelOptionsDialog\0"
    "refreshAllowedChannelModes\0\0refreshModes\0"
    "refreshEnableModes\0forceUpdate\0"
    "toggleAdvancedModes\0refreshBanList\0"
    "addBan\0newban\0addBanClicked\0"
    "updateBanClicked\0removeBan\0ban\0"
    "removeBanClicked\0banSelectionChanged\0"
    "hostmaskChanged\0changeOptions\0"
    "topicHistoryItemClicked\0QItemSelection\0"
    "selection\0topicBeingEdited\0edited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__ChannelOptionsDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x0a /* Public */,
       3,    0,   95,    2, 0x0a /* Public */,
       4,    1,   96,    2, 0x0a /* Public */,
       4,    0,   99,    2, 0x2a /* Public | MethodCloned */,
       6,    0,  100,    2, 0x0a /* Public */,
       7,    0,  101,    2, 0x0a /* Public */,
       8,    1,  102,    2, 0x0a /* Public */,
      10,    0,  105,    2, 0x0a /* Public */,
      11,    0,  106,    2, 0x0a /* Public */,
      12,    1,  107,    2, 0x0a /* Public */,
      14,    0,  110,    2, 0x0a /* Public */,
      15,    0,  111,    2, 0x0a /* Public */,
      16,    1,  112,    2, 0x0a /* Public */,
      17,    0,  115,    2, 0x0a /* Public */,
      18,    1,  116,    2, 0x09 /* Protected */,
      21,    1,  119,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, QMetaType::Bool,   22,

       0        // eod
};

void Konversation::ChannelOptionsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChannelOptionsDialog *_t = static_cast<ChannelOptionsDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->refreshAllowedChannelModes(); break;
        case 1: _t->refreshModes(); break;
        case 2: _t->refreshEnableModes((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->refreshEnableModes(); break;
        case 4: _t->toggleAdvancedModes(); break;
        case 5: _t->refreshBanList(); break;
        case 6: _t->addBan((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->addBanClicked(); break;
        case 8: _t->updateBanClicked(); break;
        case 9: _t->removeBan((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->removeBanClicked(); break;
        case 11: _t->banSelectionChanged(); break;
        case 12: _t->hostmaskChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->changeOptions(); break;
        case 14: _t->topicHistoryItemClicked((*reinterpret_cast< const QItemSelection(*)>(_a[1]))); break;
        case 15: _t->topicBeingEdited((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::ChannelOptionsDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__ChannelOptionsDialog.data,
      qt_meta_data_Konversation__ChannelOptionsDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::ChannelOptionsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ChannelOptionsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__ChannelOptionsDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ChannelOptionsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
