/****************************************************************************
** Meta object code from reading C++ file 'osd_config.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/config/osd_config.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'osd_config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OSD_Config_t {
    QByteArrayData data[14];
    char stringdata0[201];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OSD_Config_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OSD_Config_t qt_meta_stringdata_OSD_Config = {
    {
QT_MOC_LITERAL(0, 0, 10), // "OSD_Config"
QT_MOC_LITERAL(1, 11, 21), // "slotOSDEnabledChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 2), // "on"
QT_MOC_LITERAL(4, 37, 23), // "slotCustomColorsChanged"
QT_MOC_LITERAL(5, 61, 20), // "slotTextColorChanged"
QT_MOC_LITERAL(6, 82, 5), // "color"
QT_MOC_LITERAL(7, 88, 26), // "slotBackgroundColorChanged"
QT_MOC_LITERAL(8, 115, 17), // "slotScreenChanged"
QT_MOC_LITERAL(9, 133, 5), // "index"
QT_MOC_LITERAL(10, 139, 21), // "slotDrawShadowChanged"
QT_MOC_LITERAL(11, 161, 14), // "slotUpdateFont"
QT_MOC_LITERAL(12, 176, 4), // "font"
QT_MOC_LITERAL(13, 181, 19) // "slotPositionChanged"

    },
    "OSD_Config\0slotOSDEnabledChanged\0\0on\0"
    "slotCustomColorsChanged\0slotTextColorChanged\0"
    "color\0slotBackgroundColorChanged\0"
    "slotScreenChanged\0index\0slotDrawShadowChanged\0"
    "slotUpdateFont\0font\0slotPositionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OSD_Config[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x09 /* Protected */,
       4,    1,   57,    2, 0x09 /* Protected */,
       5,    1,   60,    2, 0x09 /* Protected */,
       7,    1,   63,    2, 0x09 /* Protected */,
       8,    1,   66,    2, 0x09 /* Protected */,
      10,    1,   69,    2, 0x09 /* Protected */,
      11,    1,   72,    2, 0x09 /* Protected */,
      13,    0,   75,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QColor,    6,
    QMetaType::Void, QMetaType::QColor,    6,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QFont,   12,
    QMetaType::Void,

       0        // eod
};

void OSD_Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OSD_Config *_t = static_cast<OSD_Config *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOSDEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->slotCustomColorsChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->slotTextColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 3: _t->slotBackgroundColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 4: _t->slotScreenChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->slotDrawShadowChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->slotUpdateFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 7: _t->slotPositionChanged(); break;
        default: ;
        }
    }
}

const QMetaObject OSD_Config::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_OSD_Config.data,
      qt_meta_data_OSD_Config,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *OSD_Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OSD_Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OSD_Config.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KonviSettingsPage"))
        return static_cast< KonviSettingsPage*>(this);
    return QWidget::qt_metacast(_clname);
}

int OSD_Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
