/****************************************************************************
** Meta object code from reading C++ file 'identitydialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/identitydialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identitydialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__IdentityDialog_t {
    QByteArrayData data[12];
    char stringdata0[170];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__IdentityDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__IdentityDialog_t qt_meta_stringdata_Konversation__IdentityDialog = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Konversation::IdentityDialog"
QT_MOC_LITERAL(1, 29, 17), // "identitiesChanged"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 6), // "accept"
QT_MOC_LITERAL(4, 55, 14), // "updateIdentity"
QT_MOC_LITERAL(5, 70, 5), // "index"
QT_MOC_LITERAL(6, 76, 22), // "refreshCurrentIdentity"
QT_MOC_LITERAL(7, 99, 11), // "newIdentity"
QT_MOC_LITERAL(8, 111, 14), // "renameIdentity"
QT_MOC_LITERAL(9, 126, 14), // "deleteIdentity"
QT_MOC_LITERAL(10, 141, 12), // "copyIdentity"
QT_MOC_LITERAL(11, 154, 15) // "authTypeChanged"

    },
    "Konversation::IdentityDialog\0"
    "identitiesChanged\0\0accept\0updateIdentity\0"
    "index\0refreshCurrentIdentity\0newIdentity\0"
    "renameIdentity\0deleteIdentity\0"
    "copyIdentity\0authTypeChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__IdentityDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   60,    2, 0x0a /* Public */,
       4,    1,   61,    2, 0x09 /* Protected */,
       6,    0,   64,    2, 0x09 /* Protected */,
       7,    0,   65,    2, 0x09 /* Protected */,
       8,    0,   66,    2, 0x09 /* Protected */,
       9,    0,   67,    2, 0x09 /* Protected */,
      10,    0,   68,    2, 0x09 /* Protected */,
      11,    1,   69,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    5,

       0        // eod
};

void Konversation::IdentityDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IdentityDialog *_t = static_cast<IdentityDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->identitiesChanged(); break;
        case 1: _t->accept(); break;
        case 2: _t->updateIdentity((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->refreshCurrentIdentity(); break;
        case 4: _t->newIdentity(); break;
        case 5: _t->renameIdentity(); break;
        case 6: _t->deleteIdentity(); break;
        case 7: _t->copyIdentity(); break;
        case 8: _t->authTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IdentityDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IdentityDialog::identitiesChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Konversation::IdentityDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__IdentityDialog.data,
      qt_meta_data_Konversation__IdentityDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::IdentityDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::IdentityDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__IdentityDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::IdentityDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Konversation::IdentityDialog::identitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
