#include <klocalizedstring.h>

/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'dcc_configui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DCC_CONFIGUI_H
#define UI_DCC_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "kpluralhandlingspinbox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_DCC_ConfigUI
{
public:
    QGridLayout *gridLayout;
    QLabel *dccPathLbl;
    KUrlRequester *kcfg_DccPath;
    QCheckBox *kcfg_DccAddPartner;
    QCheckBox *kcfg_DccCreateFolder;
    QCheckBox *kcfg_DccSpaceToUnderscore;
    QCheckBox *kcfg_DccAutoGet;
    QCheckBox *kcfg_DccAutoResume;
    QCheckBox *kcfg_DccFastSend;
    QCheckBox *kcfg_DccPassiveSend;
    QCheckBox *kcfg_DccIPv4Fallback;
    QLabel *textLabel7;
    KPluralHandlingSpinBox *kcfg_DccSendTimeout;
    QSpacerItem *spacer3;
    QLabel *textLabel6;
    KPluralHandlingSpinBox *kcfg_DccBufferSize;
    QSpacerItem *spacer3_2;
    QGroupBox *groupBox1;
    QGridLayout *gridLayout1;
    QLabel *textLabel4;
    KComboBox *kcfg_DccMethodToGetOwnIp;
    QLabel *ownIP;
    KLineEdit *kcfg_DccSpecificOwnIp;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout2;
    QCheckBox *kcfg_DccSpecificChatPorts;
    QSpacerItem *spacer6;
    QSpinBox *kcfg_DccChatPortsFirst;
    QLabel *textLabel2_2;
    QSpinBox *kcfg_DccChatPortsLast;
    QCheckBox *kcfg_DccSpecificSendPorts;
    QSpacerItem *spacer4;
    QSpinBox *kcfg_DccSendPortsFirst;
    QLabel *textLabel1_2;
    QSpinBox *kcfg_DccSendPortsLast;
    QSpacerItem *spacer4_2;
    QCheckBox *kcfg_DccUPnP;
    QCheckBox *kcfg_DccChatAutoAccept;
    KComboBox *kcfg_DccIPv4FallbackIface;

    void setupUi(QWidget *DCC_ConfigUI)
    {
        if (DCC_ConfigUI->objectName().isEmpty())
            DCC_ConfigUI->setObjectName(QStringLiteral("DCC_ConfigUI"));
        DCC_ConfigUI->resize(502, 575);
        gridLayout = new QGridLayout(DCC_ConfigUI);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        dccPathLbl = new QLabel(DCC_ConfigUI);
        dccPathLbl->setObjectName(QStringLiteral("dccPathLbl"));
        dccPathLbl->setWordWrap(false);

        gridLayout->addWidget(dccPathLbl, 0, 0, 1, 1);

        kcfg_DccPath = new KUrlRequester(DCC_ConfigUI);
        kcfg_DccPath->setObjectName(QStringLiteral("kcfg_DccPath"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_DccPath->sizePolicy().hasHeightForWidth());
        kcfg_DccPath->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_DccPath, 0, 1, 1, 3);

        kcfg_DccAddPartner = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAddPartner->setObjectName(QStringLiteral("kcfg_DccAddPartner"));

        gridLayout->addWidget(kcfg_DccAddPartner, 1, 0, 1, 4);

        kcfg_DccCreateFolder = new QCheckBox(DCC_ConfigUI);
        kcfg_DccCreateFolder->setObjectName(QStringLiteral("kcfg_DccCreateFolder"));

        gridLayout->addWidget(kcfg_DccCreateFolder, 2, 0, 1, 4);

        kcfg_DccSpaceToUnderscore = new QCheckBox(DCC_ConfigUI);
        kcfg_DccSpaceToUnderscore->setObjectName(QStringLiteral("kcfg_DccSpaceToUnderscore"));

        gridLayout->addWidget(kcfg_DccSpaceToUnderscore, 3, 0, 1, 4);

        kcfg_DccAutoGet = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAutoGet->setObjectName(QStringLiteral("kcfg_DccAutoGet"));

        gridLayout->addWidget(kcfg_DccAutoGet, 4, 0, 1, 4);

        kcfg_DccAutoResume = new QCheckBox(DCC_ConfigUI);
        kcfg_DccAutoResume->setObjectName(QStringLiteral("kcfg_DccAutoResume"));

        gridLayout->addWidget(kcfg_DccAutoResume, 5, 0, 1, 4);

        kcfg_DccFastSend = new QCheckBox(DCC_ConfigUI);
        kcfg_DccFastSend->setObjectName(QStringLiteral("kcfg_DccFastSend"));

        gridLayout->addWidget(kcfg_DccFastSend, 6, 0, 1, 4);

        kcfg_DccPassiveSend = new QCheckBox(DCC_ConfigUI);
        kcfg_DccPassiveSend->setObjectName(QStringLiteral("kcfg_DccPassiveSend"));

        gridLayout->addWidget(kcfg_DccPassiveSend, 7, 0, 1, 2);

        kcfg_DccIPv4Fallback = new QCheckBox(DCC_ConfigUI);
        kcfg_DccIPv4Fallback->setObjectName(QStringLiteral("kcfg_DccIPv4Fallback"));

        gridLayout->addWidget(kcfg_DccIPv4Fallback, 10, 0, 1, 2);

        textLabel7 = new QLabel(DCC_ConfigUI);
        textLabel7->setObjectName(QStringLiteral("textLabel7"));
        textLabel7->setWordWrap(false);

        gridLayout->addWidget(textLabel7, 11, 0, 1, 2);

        kcfg_DccSendTimeout = new KPluralHandlingSpinBox(DCC_ConfigUI);
        kcfg_DccSendTimeout->setObjectName(QStringLiteral("kcfg_DccSendTimeout"));
        kcfg_DccSendTimeout->setMinimum(1);
        kcfg_DccSendTimeout->setMaximum(300);

        gridLayout->addWidget(kcfg_DccSendTimeout, 11, 2, 1, 1);

        spacer3 = new QSpacerItem(70, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacer3, 11, 3, 1, 1);

        textLabel6 = new QLabel(DCC_ConfigUI);
        textLabel6->setObjectName(QStringLiteral("textLabel6"));
        textLabel6->setWordWrap(false);

        gridLayout->addWidget(textLabel6, 12, 0, 1, 2);

        kcfg_DccBufferSize = new KPluralHandlingSpinBox(DCC_ConfigUI);
        kcfg_DccBufferSize->setObjectName(QStringLiteral("kcfg_DccBufferSize"));
        kcfg_DccBufferSize->setMinimum(1024);
        kcfg_DccBufferSize->setMaximum(65536);
        kcfg_DccBufferSize->setSingleStep(128);

        gridLayout->addWidget(kcfg_DccBufferSize, 12, 2, 1, 1);

        spacer3_2 = new QSpacerItem(70, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacer3_2, 12, 3, 1, 1);

        groupBox1 = new QGroupBox(DCC_ConfigUI);
        groupBox1->setObjectName(QStringLiteral("groupBox1"));
        gridLayout1 = new QGridLayout(groupBox1);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        textLabel4 = new QLabel(groupBox1);
        textLabel4->setObjectName(QStringLiteral("textLabel4"));
        textLabel4->setWordWrap(false);

        gridLayout1->addWidget(textLabel4, 0, 0, 1, 1);

        kcfg_DccMethodToGetOwnIp = new KComboBox(groupBox1);
        kcfg_DccMethodToGetOwnIp->setObjectName(QStringLiteral("kcfg_DccMethodToGetOwnIp"));

        gridLayout1->addWidget(kcfg_DccMethodToGetOwnIp, 0, 1, 1, 1);

        ownIP = new QLabel(groupBox1);
        ownIP->setObjectName(QStringLiteral("ownIP"));
        ownIP->setWordWrap(false);

        gridLayout1->addWidget(ownIP, 1, 0, 1, 1);

        kcfg_DccSpecificOwnIp = new KLineEdit(groupBox1);
        kcfg_DccSpecificOwnIp->setObjectName(QStringLiteral("kcfg_DccSpecificOwnIp"));

        gridLayout1->addWidget(kcfg_DccSpecificOwnIp, 1, 1, 1, 1);


        gridLayout->addWidget(groupBox1, 13, 0, 1, 4);

        groupBox2 = new QGroupBox(DCC_ConfigUI);
        groupBox2->setObjectName(QStringLiteral("groupBox2"));
        gridLayout2 = new QGridLayout(groupBox2);
        gridLayout2->setSpacing(6);
        gridLayout2->setContentsMargins(11, 11, 11, 11);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        kcfg_DccSpecificChatPorts = new QCheckBox(groupBox2);
        kcfg_DccSpecificChatPorts->setObjectName(QStringLiteral("kcfg_DccSpecificChatPorts"));

        gridLayout2->addWidget(kcfg_DccSpecificChatPorts, 1, 0, 1, 1);

        spacer6 = new QSpacerItem(50, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout2->addItem(spacer6, 1, 1, 1, 1);

        kcfg_DccChatPortsFirst = new QSpinBox(groupBox2);
        kcfg_DccChatPortsFirst->setObjectName(QStringLiteral("kcfg_DccChatPortsFirst"));
        kcfg_DccChatPortsFirst->setEnabled(false);
        kcfg_DccChatPortsFirst->setMinimum(1026);
        kcfg_DccChatPortsFirst->setMaximum(65535);

        gridLayout2->addWidget(kcfg_DccChatPortsFirst, 1, 2, 1, 1);

        textLabel2_2 = new QLabel(groupBox2);
        textLabel2_2->setObjectName(QStringLiteral("textLabel2_2"));
        textLabel2_2->setEnabled(false);
        textLabel2_2->setAlignment(Qt::AlignCenter);
        textLabel2_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel2_2, 1, 3, 1, 1);

        kcfg_DccChatPortsLast = new QSpinBox(groupBox2);
        kcfg_DccChatPortsLast->setObjectName(QStringLiteral("kcfg_DccChatPortsLast"));
        kcfg_DccChatPortsLast->setEnabled(false);
        kcfg_DccChatPortsLast->setMinimum(1027);
        kcfg_DccChatPortsLast->setMaximum(65535);

        gridLayout2->addWidget(kcfg_DccChatPortsLast, 1, 4, 1, 1);

        kcfg_DccSpecificSendPorts = new QCheckBox(groupBox2);
        kcfg_DccSpecificSendPorts->setObjectName(QStringLiteral("kcfg_DccSpecificSendPorts"));

        gridLayout2->addWidget(kcfg_DccSpecificSendPorts, 0, 0, 1, 1);

        spacer4 = new QSpacerItem(50, 21, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout2->addItem(spacer4, 0, 1, 1, 1);

        kcfg_DccSendPortsFirst = new QSpinBox(groupBox2);
        kcfg_DccSendPortsFirst->setObjectName(QStringLiteral("kcfg_DccSendPortsFirst"));
        kcfg_DccSendPortsFirst->setEnabled(false);
        kcfg_DccSendPortsFirst->setMinimum(1026);
        kcfg_DccSendPortsFirst->setMaximum(65535);

        gridLayout2->addWidget(kcfg_DccSendPortsFirst, 0, 2, 1, 1);

        textLabel1_2 = new QLabel(groupBox2);
        textLabel1_2->setObjectName(QStringLiteral("textLabel1_2"));
        textLabel1_2->setEnabled(false);
        textLabel1_2->setAlignment(Qt::AlignCenter);
        textLabel1_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel1_2, 0, 3, 1, 1);

        kcfg_DccSendPortsLast = new QSpinBox(groupBox2);
        kcfg_DccSendPortsLast->setObjectName(QStringLiteral("kcfg_DccSendPortsLast"));
        kcfg_DccSendPortsLast->setEnabled(false);
        kcfg_DccSendPortsLast->setMinimum(1027);
        kcfg_DccSendPortsLast->setMaximum(65535);

        gridLayout2->addWidget(kcfg_DccSendPortsLast, 0, 4, 1, 1);


        gridLayout->addWidget(groupBox2, 14, 0, 1, 4);

        spacer4_2 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacer4_2, 15, 2, 1, 1);

        kcfg_DccUPnP = new QCheckBox(DCC_ConfigUI);
        kcfg_DccUPnP->setObjectName(QStringLiteral("kcfg_DccUPnP"));

        gridLayout->addWidget(kcfg_DccUPnP, 9, 0, 1, 2);

        kcfg_DccChatAutoAccept = new QCheckBox(DCC_ConfigUI);
        kcfg_DccChatAutoAccept->setObjectName(QStringLiteral("kcfg_DccChatAutoAccept"));

        gridLayout->addWidget(kcfg_DccChatAutoAccept, 8, 0, 1, 1);

        kcfg_DccIPv4FallbackIface = new KComboBox(DCC_ConfigUI);
        kcfg_DccIPv4FallbackIface->setObjectName(QStringLiteral("kcfg_DccIPv4FallbackIface"));
        kcfg_DccIPv4FallbackIface->setEnabled(false);

        gridLayout->addWidget(kcfg_DccIPv4FallbackIface, 10, 2, 1, 2);

#ifndef UI_QT_NO_SHORTCUT
        dccPathLbl->setBuddy(kcfg_DccPath);
        textLabel7->setBuddy(kcfg_DccSendTimeout);
        textLabel6->setBuddy(kcfg_DccBufferSize);
        textLabel4->setBuddy(kcfg_DccMethodToGetOwnIp);
        ownIP->setBuddy(kcfg_DccSpecificOwnIp);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_DccPath, kcfg_DccAddPartner);
        QWidget::setTabOrder(kcfg_DccAddPartner, kcfg_DccCreateFolder);
        QWidget::setTabOrder(kcfg_DccCreateFolder, kcfg_DccSpaceToUnderscore);
        QWidget::setTabOrder(kcfg_DccSpaceToUnderscore, kcfg_DccAutoGet);
        QWidget::setTabOrder(kcfg_DccAutoGet, kcfg_DccAutoResume);
        QWidget::setTabOrder(kcfg_DccAutoResume, kcfg_DccFastSend);
        QWidget::setTabOrder(kcfg_DccFastSend, kcfg_DccPassiveSend);
        QWidget::setTabOrder(kcfg_DccPassiveSend, kcfg_DccChatAutoAccept);
        QWidget::setTabOrder(kcfg_DccChatAutoAccept, kcfg_DccUPnP);
        QWidget::setTabOrder(kcfg_DccUPnP, kcfg_DccIPv4Fallback);
        QWidget::setTabOrder(kcfg_DccIPv4Fallback, kcfg_DccIPv4FallbackIface);
        QWidget::setTabOrder(kcfg_DccIPv4FallbackIface, kcfg_DccSendTimeout);
        QWidget::setTabOrder(kcfg_DccSendTimeout, kcfg_DccBufferSize);
        QWidget::setTabOrder(kcfg_DccBufferSize, kcfg_DccMethodToGetOwnIp);
        QWidget::setTabOrder(kcfg_DccMethodToGetOwnIp, kcfg_DccSpecificOwnIp);
        QWidget::setTabOrder(kcfg_DccSpecificOwnIp, kcfg_DccSpecificSendPorts);
        QWidget::setTabOrder(kcfg_DccSpecificSendPorts, kcfg_DccSendPortsFirst);
        QWidget::setTabOrder(kcfg_DccSendPortsFirst, kcfg_DccSendPortsLast);
        QWidget::setTabOrder(kcfg_DccSendPortsLast, kcfg_DccSpecificChatPorts);
        QWidget::setTabOrder(kcfg_DccSpecificChatPorts, kcfg_DccChatPortsFirst);
        QWidget::setTabOrder(kcfg_DccChatPortsFirst, kcfg_DccChatPortsLast);

        retranslateUi(DCC_ConfigUI);
        QObject::connect(kcfg_DccSpecificSendPorts, SIGNAL(toggled(bool)), kcfg_DccSendPortsFirst, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccSpecificSendPorts, SIGNAL(toggled(bool)), textLabel1_2, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccSpecificSendPorts, SIGNAL(toggled(bool)), kcfg_DccSendPortsLast, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccSpecificChatPorts, SIGNAL(toggled(bool)), kcfg_DccChatPortsFirst, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccSpecificChatPorts, SIGNAL(toggled(bool)), textLabel2_2, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccSpecificChatPorts, SIGNAL(toggled(bool)), kcfg_DccChatPortsLast, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_DccIPv4Fallback, SIGNAL(toggled(bool)), kcfg_DccIPv4FallbackIface, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(DCC_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *DCC_ConfigUI)
    {
        DCC_ConfigUI->setWindowTitle(tr2i18n("DCC_Settings", Q_NULLPTR));
        dccPathLbl->setText(tr2i18n("Download &folder:", Q_NULLPTR));
        kcfg_DccAddPartner->setText(tr2i18n("&Add sender to file name", Q_NULLPTR));
        kcfg_DccCreateFolder->setText(tr2i18n("Cr&eate folder for sender", Q_NULLPTR));
        kcfg_DccSpaceToUnderscore->setText(tr2i18n("Convert spaces in file names to underscores before sending", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        kcfg_DccSpaceToUnderscore->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        kcfg_DccAutoGet->setText(tr2i18n("Automaticall&y accept download offer", Q_NULLPTR));
        kcfg_DccAutoResume->setText(tr2i18n("Au&tomatically resume download", Q_NULLPTR));
        kcfg_DccFastSend->setText(tr2i18n("Enable fast DCC send (Might &not work with all clients)", Q_NULLPTR));
        kcfg_DccPassiveSend->setText(tr2i18n("Enable passive DCC send", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        kcfg_DccPassiveSend->setShortcut(QString());
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_DccIPv4Fallback->setWhatsThis(tr2i18n("If this option enabled dcc transfers for IPv6 connections will be done over IPv4 interface set here", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_DccIPv4Fallback->setText(tr2i18n("Fallback to an IPv&4 interface for DCC send:", Q_NULLPTR));
        textLabel7->setText(tr2i18n("DCC send t&imeout:", Q_NULLPTR));
        textLabel6->setText(tr2i18n("Buffer si&ze:", Q_NULLPTR));
        groupBox1->setTitle(tr2i18n("IP", Q_NULLPTR));
        textLabel4->setText(tr2i18n("&Method to get own IP:", Q_NULLPTR));
        ownIP->setText(tr2i18n("O&wn IP:", Q_NULLPTR));
        groupBox2->setTitle(tr2i18n("Ports", Q_NULLPTR));
        kcfg_DccSpecificChatPorts->setText(tr2i18n("Enable specific p&orts for DCC chat:", Q_NULLPTR));
        textLabel2_2->setText(tr2i18n("to", Q_NULLPTR));
        kcfg_DccSpecificSendPorts->setText(tr2i18n("Enable specific &ports for DCC transfer server:", Q_NULLPTR));
        textLabel1_2->setText(tr2i18n("to", Q_NULLPTR));
        kcfg_DccUPnP->setText(tr2i18n("Enable UPnP for NAT traversal", Q_NULLPTR));
        kcfg_DccChatAutoAccept->setText(tr2i18n("Automatically accept DCC chat offer", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DCC_ConfigUI: public Ui_DCC_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DCC_CONFIGUI_H

