#include <klocalizedstring.h>

/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
*/

/********************************************************************************
** Form generated from reading UI file 'chatwindowappearance_config.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATWINDOWAPPEARANCE_CONFIG_H
#define UI_CHATWINDOWAPPEARANCE_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ChatWindowAppearance_Config
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *kcfg_Timestamping;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_ShowDate;
    QLabel *textLabel1;
    KComboBox *kcfg_TimestampFormat;
    QSpacerItem *spacer127;
    QGroupBox *kcfg_ShowBacklog;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1_2;
    QSpinBox *kcfg_BacklogLines;
    QSpacerItem *spacer3;
    QGroupBox *groupBox2;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_ShowTopic;
    QCheckBox *kcfg_ShowModeButtons;
    QCheckBox *kcfg_ShowNickList;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacer9_2;
    QCheckBox *kcfg_AutoUserhost;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *spacer9;
    QCheckBox *kcfg_ShowRealNames;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *spacer10;
    QCheckBox *kcfg_ShowQuickButtons;
    QCheckBox *kcfg_ShowNicknameBox;
    QCheckBox *kcfg_ShowIRCViewScrollBar;
    QGroupBox *kcfg_ShowBackgroundImage;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel4;
    KUrlRequester *kcfg_BackgroundImage;
    QSpacerItem *spacer90;

    void setupUi(QWidget *ChatWindowAppearance_Config)
    {
        if (ChatWindowAppearance_Config->objectName().isEmpty())
            ChatWindowAppearance_Config->setObjectName(QStringLiteral("ChatWindowAppearance_Config"));
        ChatWindowAppearance_Config->resize(401, 502);
        verticalLayout_2 = new QVBoxLayout(ChatWindowAppearance_Config);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        kcfg_Timestamping = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_Timestamping->setObjectName(QStringLiteral("kcfg_Timestamping"));
        kcfg_Timestamping->setCheckable(true);
        gridLayout = new QGridLayout(kcfg_Timestamping);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kcfg_ShowDate = new QCheckBox(kcfg_Timestamping);
        kcfg_ShowDate->setObjectName(QStringLiteral("kcfg_ShowDate"));

        gridLayout->addWidget(kcfg_ShowDate, 1, 0, 1, 3);

        textLabel1 = new QLabel(kcfg_Timestamping);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        gridLayout->addWidget(textLabel1, 0, 0, 1, 1);

        kcfg_TimestampFormat = new KComboBox(kcfg_Timestamping);
        kcfg_TimestampFormat->setObjectName(QStringLiteral("kcfg_TimestampFormat"));
        kcfg_TimestampFormat->setEditable(true);

        gridLayout->addWidget(kcfg_TimestampFormat, 0, 1, 1, 1);

        spacer127 = new QSpacerItem(191, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacer127, 0, 2, 1, 1);


        verticalLayout_2->addWidget(kcfg_Timestamping);

        kcfg_ShowBacklog = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_ShowBacklog->setObjectName(QStringLiteral("kcfg_ShowBacklog"));
        kcfg_ShowBacklog->setCheckable(true);
        hboxLayout = new QHBoxLayout(kcfg_ShowBacklog);
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(11, 11, 11, 11);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        textLabel1_2 = new QLabel(kcfg_ShowBacklog);
        textLabel1_2->setObjectName(QStringLiteral("textLabel1_2"));
        textLabel1_2->setWordWrap(false);

        hboxLayout->addWidget(textLabel1_2);

        kcfg_BacklogLines = new QSpinBox(kcfg_ShowBacklog);
        kcfg_BacklogLines->setObjectName(QStringLiteral("kcfg_BacklogLines"));
        kcfg_BacklogLines->setValue(10);
        kcfg_BacklogLines->setProperty("maxValue", QVariant(100));

        hboxLayout->addWidget(kcfg_BacklogLines);

        spacer3 = new QSpacerItem(251, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacer3);


        verticalLayout_2->addWidget(kcfg_ShowBacklog);

        groupBox2 = new QGroupBox(ChatWindowAppearance_Config);
        groupBox2->setObjectName(QStringLiteral("groupBox2"));
        verticalLayout = new QVBoxLayout(groupBox2);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        kcfg_ShowTopic = new QCheckBox(groupBox2);
        kcfg_ShowTopic->setObjectName(QStringLiteral("kcfg_ShowTopic"));

        verticalLayout->addWidget(kcfg_ShowTopic);

        kcfg_ShowModeButtons = new QCheckBox(groupBox2);
        kcfg_ShowModeButtons->setObjectName(QStringLiteral("kcfg_ShowModeButtons"));

        verticalLayout->addWidget(kcfg_ShowModeButtons);

        kcfg_ShowNickList = new QCheckBox(groupBox2);
        kcfg_ShowNickList->setObjectName(QStringLiteral("kcfg_ShowNickList"));

        verticalLayout->addWidget(kcfg_ShowNickList);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        spacer9_2 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacer9_2);

        kcfg_AutoUserhost = new QCheckBox(groupBox2);
        kcfg_AutoUserhost->setObjectName(QStringLiteral("kcfg_AutoUserhost"));
        kcfg_AutoUserhost->setEnabled(false);

        horizontalLayout->addWidget(kcfg_AutoUserhost);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        spacer9 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(spacer9);

        kcfg_ShowRealNames = new QCheckBox(groupBox2);
        kcfg_ShowRealNames->setObjectName(QStringLiteral("kcfg_ShowRealNames"));
        kcfg_ShowRealNames->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_ShowRealNames);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setSpacing(6);
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        spacer10 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(spacer10);

        kcfg_ShowQuickButtons = new QCheckBox(groupBox2);
        kcfg_ShowQuickButtons->setObjectName(QStringLiteral("kcfg_ShowQuickButtons"));
        kcfg_ShowQuickButtons->setEnabled(false);

        horizontalLayout_3->addWidget(kcfg_ShowQuickButtons);


        verticalLayout->addLayout(horizontalLayout_3);

        kcfg_ShowNicknameBox = new QCheckBox(groupBox2);
        kcfg_ShowNicknameBox->setObjectName(QStringLiteral("kcfg_ShowNicknameBox"));

        verticalLayout->addWidget(kcfg_ShowNicknameBox);

        kcfg_ShowIRCViewScrollBar = new QCheckBox(groupBox2);
        kcfg_ShowIRCViewScrollBar->setObjectName(QStringLiteral("kcfg_ShowIRCViewScrollBar"));

        verticalLayout->addWidget(kcfg_ShowIRCViewScrollBar);


        verticalLayout_2->addWidget(groupBox2);

        kcfg_ShowBackgroundImage = new QGroupBox(ChatWindowAppearance_Config);
        kcfg_ShowBackgroundImage->setObjectName(QStringLiteral("kcfg_ShowBackgroundImage"));
        kcfg_ShowBackgroundImage->setCheckable(true);
        hboxLayout1 = new QHBoxLayout(kcfg_ShowBackgroundImage);
        hboxLayout1->setSpacing(6);
        hboxLayout1->setContentsMargins(11, 11, 11, 11);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        textLabel4 = new QLabel(kcfg_ShowBackgroundImage);
        textLabel4->setObjectName(QStringLiteral("textLabel4"));
        textLabel4->setWordWrap(false);

        hboxLayout1->addWidget(textLabel4);

        kcfg_BackgroundImage = new KUrlRequester(kcfg_ShowBackgroundImage);
        kcfg_BackgroundImage->setObjectName(QStringLiteral("kcfg_BackgroundImage"));

        hboxLayout1->addWidget(kcfg_BackgroundImage);


        verticalLayout_2->addWidget(kcfg_ShowBackgroundImage);

        spacer90 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(spacer90);

#ifndef UI_QT_NO_SHORTCUT
        textLabel1->setBuddy(kcfg_TimestampFormat);
        textLabel1_2->setBuddy(kcfg_BacklogLines);
        textLabel4->setBuddy(kcfg_BackgroundImage);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_Timestamping, kcfg_TimestampFormat);
        QWidget::setTabOrder(kcfg_TimestampFormat, kcfg_ShowDate);
        QWidget::setTabOrder(kcfg_ShowDate, kcfg_ShowBacklog);
        QWidget::setTabOrder(kcfg_ShowBacklog, kcfg_BacklogLines);
        QWidget::setTabOrder(kcfg_BacklogLines, kcfg_ShowTopic);
        QWidget::setTabOrder(kcfg_ShowTopic, kcfg_ShowModeButtons);
        QWidget::setTabOrder(kcfg_ShowModeButtons, kcfg_ShowNickList);
        QWidget::setTabOrder(kcfg_ShowNickList, kcfg_AutoUserhost);
        QWidget::setTabOrder(kcfg_AutoUserhost, kcfg_ShowRealNames);
        QWidget::setTabOrder(kcfg_ShowRealNames, kcfg_ShowQuickButtons);
        QWidget::setTabOrder(kcfg_ShowQuickButtons, kcfg_ShowNicknameBox);
        QWidget::setTabOrder(kcfg_ShowNicknameBox, kcfg_ShowIRCViewScrollBar);
        QWidget::setTabOrder(kcfg_ShowIRCViewScrollBar, kcfg_ShowBackgroundImage);
        QWidget::setTabOrder(kcfg_ShowBackgroundImage, kcfg_BackgroundImage);

        retranslateUi(ChatWindowAppearance_Config);
        QObject::connect(kcfg_ShowNickList, SIGNAL(toggled(bool)), kcfg_AutoUserhost, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_ShowNickList, SIGNAL(toggled(bool)), kcfg_ShowQuickButtons, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_ShowNickList, SIGNAL(toggled(bool)), kcfg_ShowRealNames, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ChatWindowAppearance_Config);
    } // setupUi

    void retranslateUi(QWidget *ChatWindowAppearance_Config)
    {
        kcfg_Timestamping->setTitle(tr2i18n("Enable &Timestamps", Q_NULLPTR));
        kcfg_ShowDate->setText(tr2i18n("Sho&w dates", Q_NULLPTR));
        textLabel1->setText(tr2i18n("&Format:", Q_NULLPTR));
        kcfg_ShowBacklog->setTitle(tr2i18n("Show &Backlog", Q_NULLPTR));
        textLabel1_2->setText(tr2i18n("&Lines: ", Q_NULLPTR));
        groupBox2->setTitle(tr2i18n("&Layout", Q_NULLPTR));
        kcfg_ShowTopic->setText(tr2i18n("&Show channel topic", Q_NULLPTR));
        kcfg_ShowModeButtons->setText(tr2i18n("Show channel &mode buttons", Q_NULLPTR));
        kcfg_ShowNickList->setText(tr2i18n("Show channel &nick list and quick buttons", Q_NULLPTR));
        kcfg_AutoUserhost->setText(tr2i18n("Show hostmas&ks in nickname list", Q_NULLPTR));
        kcfg_ShowRealNames->setText(tr2i18n("Show real names in nickname list", Q_NULLPTR));
        kcfg_ShowQuickButtons->setText(tr2i18n("Show &quick buttons", Q_NULLPTR));
        kcfg_ShowNicknameBox->setText(tr2i18n("Show bo&x to change own nickname", Q_NULLPTR));
        kcfg_ShowIRCViewScrollBar->setText(tr2i18n("Show sc&rollbar", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        kcfg_ShowIRCViewScrollBar->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        kcfg_ShowBackgroundImage->setTitle(tr2i18n("Enable Back&ground Image", Q_NULLPTR));
        textLabel4->setText(tr2i18n("P&ath:", Q_NULLPTR));
        Q_UNUSED(ChatWindowAppearance_Config);
    } // retranslateUi

};

namespace Ui {
    class ChatWindowAppearance_Config: public Ui_ChatWindowAppearance_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHATWINDOWAPPEARANCE_CONFIG_H

