/****************************************************************************
** Meta object code from reading C++ file 'query.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/query.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'query.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Query_t {
    QByteArrayData data[26];
    char stringdata0[321];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Query_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Query_t qt_meta_stringdata_Query = {
    {
QT_MOC_LITERAL(0, 0, 5), // "Query"
QT_MOC_LITERAL(1, 6, 8), // "sendFile"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 9), // "recipient"
QT_MOC_LITERAL(4, 26, 17), // "updateQueryChrome"
QT_MOC_LITERAL(5, 44, 11), // "ChatWindow*"
QT_MOC_LITERAL(6, 56, 8), // "sendText"
QT_MOC_LITERAL(7, 65, 4), // "text"
QT_MOC_LITERAL(8, 70, 12), // "indicateAway"
QT_MOC_LITERAL(9, 83, 4), // "show"
QT_MOC_LITERAL(10, 88, 18), // "setEncryptedOutput"
QT_MOC_LITERAL(11, 107, 22), // "connectionStateChanged"
QT_MOC_LITERAL(12, 130, 7), // "Server*"
QT_MOC_LITERAL(13, 138, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(14, 168, 16), // "queryTextEntered"
QT_MOC_LITERAL(15, 185, 23), // "queryPassthroughCommand"
QT_MOC_LITERAL(16, 209, 12), // "sendFileMenu"
QT_MOC_LITERAL(17, 222, 11), // "urlsDropped"
QT_MOC_LITERAL(18, 234, 11), // "QList<QUrl>"
QT_MOC_LITERAL(19, 246, 4), // "urls"
QT_MOC_LITERAL(20, 251, 10), // "textPasted"
QT_MOC_LITERAL(21, 262, 15), // "nickInfoChanged"
QT_MOC_LITERAL(22, 278, 14), // "updateNickInfo"
QT_MOC_LITERAL(23, 293, 6), // "server"
QT_MOC_LITERAL(24, 300, 11), // "NickInfoPtr"
QT_MOC_LITERAL(25, 312, 8) // "nickInfo"

    },
    "Query\0sendFile\0\0recipient\0updateQueryChrome\0"
    "ChatWindow*\0sendText\0text\0indicateAway\0"
    "show\0setEncryptedOutput\0connectionStateChanged\0"
    "Server*\0Konversation::ConnectionState\0"
    "queryTextEntered\0queryPassthroughCommand\0"
    "sendFileMenu\0urlsDropped\0QList<QUrl>\0"
    "urls\0textPasted\0nickInfoChanged\0"
    "updateNickInfo\0server\0NickInfoPtr\0"
    "nickInfo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Query[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,
       4,    2,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   87,    2, 0x0a /* Public */,
       8,    1,   90,    2, 0x0a /* Public */,
      10,    1,   93,    2, 0x0a /* Public */,
      11,    2,   96,    2, 0x0a /* Public */,
      14,    0,  101,    2, 0x09 /* Protected */,
      15,    0,  102,    2, 0x09 /* Protected */,
      16,    0,  103,    2, 0x09 /* Protected */,
      17,    1,  104,    2, 0x09 /* Protected */,
      20,    1,  107,    2, 0x09 /* Protected */,
      21,    0,  110,    2, 0x09 /* Protected */,
      22,    2,  111,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5, QMetaType::QString,    2,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 13,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 24,   23,   25,

       0        // eod
};

void Query::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Query *_t = static_cast<Query *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sendFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->updateQueryChrome((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->indicateAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->setEncryptedOutput((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->connectionStateChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 6: _t->queryTextEntered(); break;
        case 7: _t->queryPassthroughCommand(); break;
        case 8: _t->sendFileMenu(); break;
        case 9: _t->urlsDropped((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 10: _t->textPasted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->nickInfoChanged(); break;
        case 12: _t->updateNickInfo((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< NickInfoPtr(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Query::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Query::sendFile)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Query::*_t)(ChatWindow * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Query::updateQueryChrome)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Query::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_Query.data,
      qt_meta_data_Query,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Query::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Query::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Query.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Query::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Query::sendFile(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Query::updateQueryChrome(ChatWindow * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
