/****************************************************************************
** Meta object code from reading C++ file 'servergroupdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/servergroupdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'servergroupdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__ServerGroupDialog_t {
    QByteArrayData data[18];
    char stringdata0[243];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__ServerGroupDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__ServerGroupDialog_t qt_meta_stringdata_Konversation__ServerGroupDialog = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Konversation::ServerGroupDialog"
QT_MOC_LITERAL(1, 32, 6), // "accept"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 9), // "addServer"
QT_MOC_LITERAL(4, 50, 10), // "editServer"
QT_MOC_LITERAL(5, 61, 14), // "ServerSettings"
QT_MOC_LITERAL(6, 76, 6), // "server"
QT_MOC_LITERAL(7, 83, 12), // "deleteServer"
QT_MOC_LITERAL(8, 96, 18), // "updateServerArrows"
QT_MOC_LITERAL(9, 115, 12), // "moveServerUp"
QT_MOC_LITERAL(10, 128, 14), // "moveServerDown"
QT_MOC_LITERAL(11, 143, 10), // "addChannel"
QT_MOC_LITERAL(12, 154, 11), // "editChannel"
QT_MOC_LITERAL(13, 166, 13), // "deleteChannel"
QT_MOC_LITERAL(14, 180, 19), // "updateChannelArrows"
QT_MOC_LITERAL(15, 200, 13), // "moveChannelUp"
QT_MOC_LITERAL(16, 214, 15), // "moveChannelDown"
QT_MOC_LITERAL(17, 230, 12) // "editIdentity"

    },
    "Konversation::ServerGroupDialog\0accept\0"
    "\0addServer\0editServer\0ServerSettings\0"
    "server\0deleteServer\0updateServerArrows\0"
    "moveServerUp\0moveServerDown\0addChannel\0"
    "editChannel\0deleteChannel\0updateChannelArrows\0"
    "moveChannelUp\0moveChannelDown\0"
    "editIdentity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__ServerGroupDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x09 /* Protected */,
       4,    0,   91,    2, 0x09 /* Protected */,
       4,    1,   92,    2, 0x09 /* Protected */,
       7,    0,   95,    2, 0x09 /* Protected */,
       8,    0,   96,    2, 0x09 /* Protected */,
       9,    0,   97,    2, 0x09 /* Protected */,
      10,    0,   98,    2, 0x09 /* Protected */,
      11,    0,   99,    2, 0x09 /* Protected */,
      12,    0,  100,    2, 0x09 /* Protected */,
      13,    0,  101,    2, 0x09 /* Protected */,
      14,    0,  102,    2, 0x09 /* Protected */,
      15,    0,  103,    2, 0x09 /* Protected */,
      16,    0,  104,    2, 0x09 /* Protected */,
      17,    0,  105,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Konversation::ServerGroupDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServerGroupDialog *_t = static_cast<ServerGroupDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->accept(); break;
        case 1: _t->addServer(); break;
        case 2: _t->editServer(); break;
        case 3: _t->editServer((*reinterpret_cast< ServerSettings(*)>(_a[1]))); break;
        case 4: _t->deleteServer(); break;
        case 5: _t->updateServerArrows(); break;
        case 6: _t->moveServerUp(); break;
        case 7: _t->moveServerDown(); break;
        case 8: _t->addChannel(); break;
        case 9: _t->editChannel(); break;
        case 10: _t->deleteChannel(); break;
        case 11: _t->updateChannelArrows(); break;
        case 12: _t->moveChannelUp(); break;
        case 13: _t->moveChannelDown(); break;
        case 14: _t->editIdentity(); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::ServerGroupDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__ServerGroupDialog.data,
      qt_meta_data_Konversation__ServerGroupDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::ServerGroupDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ServerGroupDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__ServerGroupDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ServerGroupDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
struct qt_meta_stringdata_Konversation__ServerDialog_t {
    QByteArrayData data[4];
    char stringdata0[57];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__ServerDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__ServerDialog_t qt_meta_stringdata_Konversation__ServerDialog = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Konversation::ServerDialog"
QT_MOC_LITERAL(1, 27, 6), // "slotOk"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 21) // "slotServerNameChanged"

    },
    "Konversation::ServerDialog\0slotOk\0\0"
    "slotServerNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__ServerDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x09 /* Protected */,
       3,    1,   25,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void Konversation::ServerDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServerDialog *_t = static_cast<ServerDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOk(); break;
        case 1: _t->slotServerNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::ServerDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__ServerDialog.data,
      qt_meta_data_Konversation__ServerDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::ServerDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ServerDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__ServerDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ServerDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_Konversation__ChannelDialog_t {
    QByteArrayData data[4];
    char stringdata0[58];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__ChannelDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__ChannelDialog_t qt_meta_stringdata_Konversation__ChannelDialog = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Konversation::ChannelDialog"
QT_MOC_LITERAL(1, 28, 6), // "slotOk"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 21) // "slotServerNameChanged"

    },
    "Konversation::ChannelDialog\0slotOk\0\0"
    "slotServerNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__ChannelDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x09 /* Protected */,
       3,    1,   25,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void Konversation::ChannelDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChannelDialog *_t = static_cast<ChannelDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOk(); break;
        case 1: _t->slotServerNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::ChannelDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__ChannelDialog.data,
      qt_meta_data_Konversation__ChannelDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::ChannelDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ChannelDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__ChannelDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ChannelDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
