/****************************************************************************
** Meta object code from reading C++ file 'statuspanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/statuspanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statuspanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StatusPanel_t {
    QByteArrayData data[19];
    char stringdata0[212];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StatusPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StatusPanel_t qt_meta_stringdata_StatusPanel = {
    {
QT_MOC_LITERAL(0, 0, 11), // "StatusPanel"
QT_MOC_LITERAL(1, 12, 8), // "sendFile"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 11), // "setNickname"
QT_MOC_LITERAL(4, 34, 11), // "newNickname"
QT_MOC_LITERAL(5, 46, 12), // "indicateAway"
QT_MOC_LITERAL(6, 59, 4), // "show"
QT_MOC_LITERAL(7, 64, 16), // "updateAppearance"
QT_MOC_LITERAL(8, 81, 10), // "updateName"
QT_MOC_LITERAL(9, 92, 12), // "sendFileMenu"
QT_MOC_LITERAL(10, 105, 17), // "statusTextEntered"
QT_MOC_LITERAL(11, 123, 8), // "sendText"
QT_MOC_LITERAL(12, 132, 4), // "line"
QT_MOC_LITERAL(13, 137, 10), // "textPasted"
QT_MOC_LITERAL(14, 148, 4), // "text"
QT_MOC_LITERAL(15, 153, 14), // "changeNickname"
QT_MOC_LITERAL(16, 168, 23), // "nicknameComboboxChanged"
QT_MOC_LITERAL(17, 192, 12), // "serverOnline"
QT_MOC_LITERAL(18, 205, 6) // "online"

    },
    "StatusPanel\0sendFile\0\0setNickname\0"
    "newNickname\0indicateAway\0show\0"
    "updateAppearance\0updateName\0sendFileMenu\0"
    "statusTextEntered\0sendText\0line\0"
    "textPasted\0text\0changeNickname\0"
    "nicknameComboboxChanged\0serverOnline\0"
    "online"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StatusPanel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   75,    2, 0x0a /* Public */,
       5,    1,   78,    2, 0x0a /* Public */,
       7,    0,   81,    2, 0x0a /* Public */,
       8,    0,   82,    2, 0x0a /* Public */,
       9,    0,   83,    2, 0x09 /* Protected */,
      10,    0,   84,    2, 0x09 /* Protected */,
      11,    1,   85,    2, 0x09 /* Protected */,
      13,    1,   88,    2, 0x09 /* Protected */,
      15,    1,   91,    2, 0x09 /* Protected */,
      16,    0,   94,    2, 0x09 /* Protected */,
      17,    1,   95,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,

       0        // eod
};

void StatusPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StatusPanel *_t = static_cast<StatusPanel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sendFile(); break;
        case 1: _t->setNickname((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->indicateAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->updateAppearance(); break;
        case 4: _t->updateName(); break;
        case 5: _t->sendFileMenu(); break;
        case 6: _t->statusTextEntered(); break;
        case 7: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->textPasted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->changeNickname((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->nicknameComboboxChanged(); break;
        case 11: _t->serverOnline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (StatusPanel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusPanel::sendFile)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject StatusPanel::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_StatusPanel.data,
      qt_meta_data_StatusPanel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *StatusPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatusPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StatusPanel.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int StatusPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void StatusPanel::sendFile()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
