/****************************************************************************
** Meta object code from reading C++ file 'chat.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/chat.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chat.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__Chat_t {
    QByteArrayData data[32];
    char stringdata0[398];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__Chat_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__Chat_t qt_meta_stringdata_Konversation__DCC__Chat = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Konversation::DCC::Chat"
QT_MOC_LITERAL(1, 24, 13), // "statusChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 24), // "Konversation::DCC::Chat*"
QT_MOC_LITERAL(4, 64, 4), // "chat"
QT_MOC_LITERAL(5, 69, 31), // "Konversation::DCC::Chat::Status"
QT_MOC_LITERAL(6, 101, 9), // "newStatus"
QT_MOC_LITERAL(7, 111, 9), // "oldStatus"
QT_MOC_LITERAL(8, 121, 7), // "removed"
QT_MOC_LITERAL(9, 129, 15), // "receivedRawLine"
QT_MOC_LITERAL(10, 145, 4), // "line"
QT_MOC_LITERAL(11, 150, 12), // "aboutToClose"
QT_MOC_LITERAL(12, 163, 6), // "closed"
QT_MOC_LITERAL(13, 170, 5), // "error"
QT_MOC_LITERAL(14, 176, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(15, 205, 9), // "errorCode"
QT_MOC_LITERAL(16, 215, 12), // "errorMessage"
QT_MOC_LITERAL(17, 228, 9), // "upnpError"
QT_MOC_LITERAL(18, 238, 9), // "connected"
QT_MOC_LITERAL(19, 248, 8), // "sendText"
QT_MOC_LITERAL(20, 257, 4), // "text"
QT_MOC_LITERAL(21, 262, 10), // "sendAction"
QT_MOC_LITERAL(22, 273, 6), // "action"
QT_MOC_LITERAL(23, 280, 11), // "sendRawLine"
QT_MOC_LITERAL(24, 292, 21), // "connectionEstablished"
QT_MOC_LITERAL(25, 314, 16), // "connectionFailed"
QT_MOC_LITERAL(26, 331, 12), // "heardPartner"
QT_MOC_LITERAL(27, 344, 12), // "socketClosed"
QT_MOC_LITERAL(28, 357, 8), // "readData"
QT_MOC_LITERAL(29, 366, 11), // "sendRequest"
QT_MOC_LITERAL(30, 378, 4), // "port"
QT_MOC_LITERAL(31, 383, 14) // "sendReverseAck"

    },
    "Konversation::DCC::Chat\0statusChanged\0"
    "\0Konversation::DCC::Chat*\0chat\0"
    "Konversation::DCC::Chat::Status\0"
    "newStatus\0oldStatus\0removed\0receivedRawLine\0"
    "line\0aboutToClose\0closed\0error\0"
    "QAbstractSocket::SocketError\0errorCode\0"
    "errorMessage\0upnpError\0connected\0"
    "sendText\0text\0sendAction\0action\0"
    "sendRawLine\0connectionEstablished\0"
    "connectionFailed\0heardPartner\0"
    "socketClosed\0readData\0sendRequest\0"
    "port\0sendReverseAck"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__Chat[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,  104,    2, 0x06 /* Public */,
       8,    1,  111,    2, 0x06 /* Public */,
       9,    1,  114,    2, 0x06 /* Public */,
      11,    0,  117,    2, 0x06 /* Public */,
      12,    0,  118,    2, 0x06 /* Public */,
      13,    2,  119,    2, 0x06 /* Public */,
      17,    1,  124,    2, 0x06 /* Public */,
      18,    0,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    1,  128,    2, 0x0a /* Public */,
      21,    1,  131,    2, 0x0a /* Public */,
      23,    1,  134,    2, 0x0a /* Public */,
      24,    0,  137,    2, 0x09 /* Protected */,
      25,    1,  138,    2, 0x09 /* Protected */,
      26,    0,  141,    2, 0x09 /* Protected */,
      27,    0,  142,    2, 0x09 /* Protected */,
      28,    0,  143,    2, 0x09 /* Protected */,
      29,    2,  144,    2, 0x09 /* Protected */,
      31,    2,  149,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5,    4,    6,    7,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString,   15,   16,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,   13,   30,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,   13,   30,

       0        // eod
};

void Konversation::DCC::Chat::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Chat *_t = static_cast<Chat *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1])),(*reinterpret_cast< Konversation::DCC::Chat::Status(*)>(_a[2])),(*reinterpret_cast< Konversation::DCC::Chat::Status(*)>(_a[3]))); break;
        case 1: _t->removed((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1]))); break;
        case 2: _t->receivedRawLine((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->aboutToClose(); break;
        case 4: _t->closed(); break;
        case 5: _t->error((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->upnpError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->connected(); break;
        case 8: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->sendAction((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->sendRawLine((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->connectionEstablished(); break;
        case 12: _t->connectionFailed((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 13: _t->heardPartner(); break;
        case 14: _t->socketClosed(); break;
        case 15: _t->readData(); break;
        case 16: _t->sendRequest((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        case 17: _t->sendReverseAck((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Chat* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Chat* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Chat::*_t)(Konversation::DCC::Chat * , Konversation::DCC::Chat::Status , Konversation::DCC::Chat::Status );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::statusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Chat::*_t)(Konversation::DCC::Chat * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::removed)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Chat::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::receivedRawLine)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Chat::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::aboutToClose)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Chat::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::closed)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Chat::*_t)(QAbstractSocket::SocketError , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::error)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Chat::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::upnpError)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Chat::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Chat::connected)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::Chat::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__DCC__Chat.data,
      qt_meta_data_Konversation__DCC__Chat,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::Chat::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::Chat::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__Chat.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DCC::Chat::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::Chat::statusChanged(Konversation::DCC::Chat * _t1, Konversation::DCC::Chat::Status _t2, Konversation::DCC::Chat::Status _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::Chat::removed(Konversation::DCC::Chat * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::Chat::receivedRawLine(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Konversation::DCC::Chat::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Konversation::DCC::Chat::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Konversation::DCC::Chat::error(QAbstractSocket::SocketError _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Konversation::DCC::Chat::upnpError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Konversation::DCC::Chat::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
