/****************************************************************************
** Meta object code from reading C++ file 'awaymanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/awaymanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'awaymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AwayManager_t {
    QByteArrayData data[18];
    char stringdata0[269];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AwayManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AwayManager_t qt_meta_stringdata_AwayManager = {
    {
QT_MOC_LITERAL(0, 0, 11), // "AwayManager"
QT_MOC_LITERAL(1, 12, 17), // "identitiesChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 14), // "identityOnline"
QT_MOC_LITERAL(4, 46, 10), // "identityId"
QT_MOC_LITERAL(5, 57, 15), // "identityOffline"
QT_MOC_LITERAL(6, 73, 14), // "requestAllAway"
QT_MOC_LITERAL(7, 88, 6), // "reason"
QT_MOC_LITERAL(8, 95, 16), // "requestAllUnaway"
QT_MOC_LITERAL(9, 112, 24), // "setManagedIdentitiesAway"
QT_MOC_LITERAL(10, 137, 26), // "setManagedIdentitiesUnaway"
QT_MOC_LITERAL(11, 164, 20), // "simulateUserActivity"
QT_MOC_LITERAL(12, 185, 13), // "setGlobalAway"
QT_MOC_LITERAL(13, 199, 4), // "away"
QT_MOC_LITERAL(14, 204, 22), // "updateGlobalAwayAction"
QT_MOC_LITERAL(15, 227, 14), // "resumeFromIdle"
QT_MOC_LITERAL(16, 242, 18), // "idleTimeoutReached"
QT_MOC_LITERAL(17, 261, 7) // "timerId"

    },
    "AwayManager\0identitiesChanged\0\0"
    "identityOnline\0identityId\0identityOffline\0"
    "requestAllAway\0reason\0requestAllUnaway\0"
    "setManagedIdentitiesAway\0"
    "setManagedIdentitiesUnaway\0"
    "simulateUserActivity\0setGlobalAway\0"
    "away\0updateGlobalAwayAction\0resumeFromIdle\0"
    "idleTimeoutReached\0timerId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AwayManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    1,   80,    2, 0x0a /* Public */,
       5,    1,   83,    2, 0x0a /* Public */,
       6,    1,   86,    2, 0x0a /* Public */,
       6,    0,   89,    2, 0x2a /* Public | MethodCloned */,
       8,    0,   90,    2, 0x0a /* Public */,
       9,    0,   91,    2, 0x0a /* Public */,
      10,    0,   92,    2, 0x0a /* Public */,
      11,    0,   93,    2, 0x0a /* Public */,
      12,    1,   94,    2, 0x0a /* Public */,
      14,    1,   97,    2, 0x0a /* Public */,
      15,    0,  100,    2, 0x08 /* Private */,
      16,    1,  101,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   17,

       0        // eod
};

void AwayManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AwayManager *_t = static_cast<AwayManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->identitiesChanged(); break;
        case 1: _t->identityOnline((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->identityOffline((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->requestAllAway((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->requestAllAway(); break;
        case 5: _t->requestAllUnaway(); break;
        case 6: _t->setManagedIdentitiesAway(); break;
        case 7: _t->setManagedIdentitiesUnaway(); break;
        case 8: _t->simulateUserActivity(); break;
        case 9: _t->setGlobalAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->updateGlobalAwayAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->resumeFromIdle(); break;
        case 12: _t->idleTimeoutReached((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject AwayManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_AwayManager.data,
      qt_meta_data_AwayManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *AwayManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AwayManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AwayManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AwayManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
