/****************************************************************************
** Meta object code from reading C++ file 'queuetuner.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/queuetuner.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'queuetuner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QueueTuner_t {
    QByteArrayData data[22];
    char stringdata0[266];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QueueTuner_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QueueTuner_t qt_meta_stringdata_QueueTuner = {
    {
QT_MOC_LITERAL(0, 0, 10), // "QueueTuner"
QT_MOC_LITERAL(1, 11, 6), // "hidden"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 9), // "setServer"
QT_MOC_LITERAL(4, 29, 7), // "Server*"
QT_MOC_LITERAL(5, 37, 9), // "newServer"
QT_MOC_LITERAL(6, 47, 8), // "getRates"
QT_MOC_LITERAL(7, 56, 10), // "timerFired"
QT_MOC_LITERAL(8, 67, 4), // "hide"
QT_MOC_LITERAL(9, 72, 4), // "show"
QT_MOC_LITERAL(10, 77, 4), // "open"
QT_MOC_LITERAL(11, 82, 5), // "close"
QT_MOC_LITERAL(12, 88, 15), // "slowRateChanged"
QT_MOC_LITERAL(13, 104, 15), // "slowTypeChanged"
QT_MOC_LITERAL(14, 120, 19), // "slowIntervalChanged"
QT_MOC_LITERAL(15, 140, 17), // "normalRateChanged"
QT_MOC_LITERAL(16, 158, 17), // "normalTypeChanged"
QT_MOC_LITERAL(17, 176, 21), // "normalIntervalChanged"
QT_MOC_LITERAL(18, 198, 15), // "fastRateChanged"
QT_MOC_LITERAL(19, 214, 15), // "fastTypeChanged"
QT_MOC_LITERAL(20, 230, 19), // "fastIntervalChanged"
QT_MOC_LITERAL(21, 250, 15) // "serverDestroyed"

    },
    "QueueTuner\0hidden\0\0setServer\0Server*\0"
    "newServer\0getRates\0timerFired\0hide\0"
    "show\0open\0close\0slowRateChanged\0"
    "slowTypeChanged\0slowIntervalChanged\0"
    "normalRateChanged\0normalTypeChanged\0"
    "normalIntervalChanged\0fastRateChanged\0"
    "fastTypeChanged\0fastIntervalChanged\0"
    "serverDestroyed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QueueTuner[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  105,    2, 0x0a /* Public */,
       6,    0,  108,    2, 0x0a /* Public */,
       7,    0,  109,    2, 0x0a /* Public */,
       8,    0,  110,    2, 0x0a /* Public */,
       9,    0,  111,    2, 0x0a /* Public */,
      10,    0,  112,    2, 0x0a /* Public */,
      11,    0,  113,    2, 0x0a /* Public */,
      12,    1,  114,    2, 0x0a /* Public */,
      13,    1,  117,    2, 0x0a /* Public */,
      14,    1,  120,    2, 0x0a /* Public */,
      15,    1,  123,    2, 0x0a /* Public */,
      16,    1,  126,    2, 0x0a /* Public */,
      17,    1,  129,    2, 0x0a /* Public */,
      18,    1,  132,    2, 0x0a /* Public */,
      19,    1,  135,    2, 0x0a /* Public */,
      20,    1,  138,    2, 0x0a /* Public */,
      21,    1,  141,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QObjectStar,    2,

       0        // eod
};

void QueueTuner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QueueTuner *_t = static_cast<QueueTuner *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hidden(); break;
        case 1: _t->setServer((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 2: _t->getRates(); break;
        case 3: _t->timerFired(); break;
        case 4: _t->hide(); break;
        case 5: _t->show(); break;
        case 6: _t->open(); break;
        case 7: _t->close(); break;
        case 8: _t->slowRateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->slowTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->slowIntervalChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->normalRateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->normalTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->normalIntervalChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->fastRateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->fastTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->fastIntervalChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->serverDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QueueTuner::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QueueTuner::hidden)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject QueueTuner::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_QueueTuner.data,
      qt_meta_data_QueueTuner,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QueueTuner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QueueTuner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QueueTuner.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int QueueTuner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void QueueTuner::hidden()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
