/****************************************************************************
** Meta object code from reading C++ file 'urlcatcher.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/urlcatcher.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'urlcatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_UrlSortFilterProxyModel_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_UrlSortFilterProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_UrlSortFilterProxyModel_t qt_meta_stringdata_UrlSortFilterProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 23) // "UrlSortFilterProxyModel"

    },
    "UrlSortFilterProxyModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_UrlSortFilterProxyModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void UrlSortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject UrlSortFilterProxyModel::staticMetaObject = {
    { &QSortFilterProxyModel::staticMetaObject, qt_meta_stringdata_UrlSortFilterProxyModel.data,
      qt_meta_data_UrlSortFilterProxyModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *UrlSortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UrlSortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_UrlSortFilterProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int UrlSortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_UrlCatcher_t {
    QByteArrayData data[15];
    char stringdata0[208];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_UrlCatcher_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_UrlCatcher_t qt_meta_stringdata_UrlCatcher = {
    {
QT_MOC_LITERAL(0, 0, 10), // "UrlCatcher"
QT_MOC_LITERAL(1, 11, 22), // "updateItemActionStates"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 22), // "updateListActionStates"
QT_MOC_LITERAL(4, 58, 15), // "openContextMenu"
QT_MOC_LITERAL(5, 74, 1), // "p"
QT_MOC_LITERAL(6, 76, 7), // "openUrl"
QT_MOC_LITERAL(7, 84, 5), // "index"
QT_MOC_LITERAL(8, 90, 16), // "openSelectedUrls"
QT_MOC_LITERAL(9, 107, 16), // "saveSelectedUrls"
QT_MOC_LITERAL(10, 124, 20), // "bookmarkSelectedUrls"
QT_MOC_LITERAL(11, 145, 16), // "copySelectedUrls"
QT_MOC_LITERAL(12, 162, 18), // "deleteSelectedUrls"
QT_MOC_LITERAL(13, 181, 12), // "saveUrlModel"
QT_MOC_LITERAL(14, 194, 13) // "clearUrlModel"

    },
    "UrlCatcher\0updateItemActionStates\0\0"
    "updateListActionStates\0openContextMenu\0"
    "p\0openUrl\0index\0openSelectedUrls\0"
    "saveSelectedUrls\0bookmarkSelectedUrls\0"
    "copySelectedUrls\0deleteSelectedUrls\0"
    "saveUrlModel\0clearUrlModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_UrlCatcher[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x08 /* Private */,
       3,    0,   70,    2, 0x08 /* Private */,
       4,    1,   71,    2, 0x08 /* Private */,
       6,    1,   74,    2, 0x08 /* Private */,
       8,    0,   77,    2, 0x08 /* Private */,
       9,    0,   78,    2, 0x08 /* Private */,
      10,    0,   79,    2, 0x08 /* Private */,
      11,    0,   80,    2, 0x08 /* Private */,
      12,    0,   81,    2, 0x08 /* Private */,
      13,    0,   82,    2, 0x08 /* Private */,
      14,    0,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    5,
    QMetaType::Void, QMetaType::QModelIndex,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void UrlCatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UrlCatcher *_t = static_cast<UrlCatcher *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateItemActionStates(); break;
        case 1: _t->updateListActionStates(); break;
        case 2: _t->openContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 3: _t->openUrl((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->openSelectedUrls(); break;
        case 5: _t->saveSelectedUrls(); break;
        case 6: _t->bookmarkSelectedUrls(); break;
        case 7: _t->copySelectedUrls(); break;
        case 8: _t->deleteSelectedUrls(); break;
        case 9: _t->saveUrlModel(); break;
        case 10: _t->clearUrlModel(); break;
        default: ;
        }
    }
}

const QMetaObject UrlCatcher::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_UrlCatcher.data,
      qt_meta_data_UrlCatcher,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *UrlCatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UrlCatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_UrlCatcher.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int UrlCatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
