/****************************************************************************
** Meta object code from reading C++ file 'dbus.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dbus.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DBus_t {
    QByteArrayData data[42];
    char stringdata0[451];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DBus_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DBus_t qt_meta_stringdata_Konversation__DBus = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Konversation::DBus"
QT_MOC_LITERAL(1, 19, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 35, 20), // "org.kde.konversation"
QT_MOC_LITERAL(3, 56, 7), // "dbusSay"
QT_MOC_LITERAL(4, 64, 0), // ""
QT_MOC_LITERAL(5, 65, 6), // "server"
QT_MOC_LITERAL(6, 72, 6), // "target"
QT_MOC_LITERAL(7, 79, 7), // "command"
QT_MOC_LITERAL(8, 87, 8), // "dbusInfo"
QT_MOC_LITERAL(9, 96, 6), // "string"
QT_MOC_LITERAL(10, 103, 20), // "dbusInsertMarkerLine"
QT_MOC_LITERAL(11, 124, 7), // "dbusRaw"
QT_MOC_LITERAL(12, 132, 18), // "dbusMultiServerRaw"
QT_MOC_LITERAL(13, 151, 9), // "connectTo"
QT_MOC_LITERAL(14, 161, 28), // "Konversation::ConnectionFlag"
QT_MOC_LITERAL(15, 190, 4), // "flag"
QT_MOC_LITERAL(16, 195, 8), // "hostName"
QT_MOC_LITERAL(17, 204, 4), // "port"
QT_MOC_LITERAL(18, 209, 8), // "password"
QT_MOC_LITERAL(19, 218, 4), // "nick"
QT_MOC_LITERAL(20, 223, 7), // "channel"
QT_MOC_LITERAL(21, 231, 6), // "useSSL"
QT_MOC_LITERAL(22, 238, 7), // "setAway"
QT_MOC_LITERAL(23, 246, 11), // "awaymessage"
QT_MOC_LITERAL(24, 258, 7), // "setBack"
QT_MOC_LITERAL(25, 266, 8), // "sayToAll"
QT_MOC_LITERAL(26, 275, 7), // "message"
QT_MOC_LITERAL(27, 283, 11), // "actionToAll"
QT_MOC_LITERAL(28, 295, 3), // "raw"
QT_MOC_LITERAL(29, 299, 3), // "say"
QT_MOC_LITERAL(30, 303, 4), // "info"
QT_MOC_LITERAL(31, 308, 5), // "debug"
QT_MOC_LITERAL(32, 314, 5), // "error"
QT_MOC_LITERAL(33, 320, 16), // "insertMarkerLine"
QT_MOC_LITERAL(34, 337, 15), // "connectToServer"
QT_MOC_LITERAL(35, 353, 7), // "address"
QT_MOC_LITERAL(36, 361, 15), // "listConnections"
QT_MOC_LITERAL(37, 377, 11), // "listServers"
QT_MOC_LITERAL(38, 389, 20), // "listConnectedServers"
QT_MOC_LITERAL(39, 410, 18), // "listJoinedChannels"
QT_MOC_LITERAL(40, 429, 16), // "changeAwayStatus"
QT_MOC_LITERAL(41, 446, 4) // "away"

    },
    "Konversation::DBus\0D-Bus Interface\0"
    "org.kde.konversation\0dbusSay\0\0server\0"
    "target\0command\0dbusInfo\0string\0"
    "dbusInsertMarkerLine\0dbusRaw\0"
    "dbusMultiServerRaw\0connectTo\0"
    "Konversation::ConnectionFlag\0flag\0"
    "hostName\0port\0password\0nick\0channel\0"
    "useSSL\0setAway\0awaymessage\0setBack\0"
    "sayToAll\0message\0actionToAll\0raw\0say\0"
    "info\0debug\0error\0insertMarkerLine\0"
    "connectToServer\0address\0listConnections\0"
    "listServers\0listConnectedServers\0"
    "listJoinedChannels\0changeAwayStatus\0"
    "away"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DBus[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      27,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    3,  151,    4, 0x06 /* Public */,
       8,    1,  158,    4, 0x06 /* Public */,
      10,    0,  161,    4, 0x06 /* Public */,
      11,    2,  162,    4, 0x06 /* Public */,
      12,    1,  167,    4, 0x06 /* Public */,
      13,    7,  170,    4, 0x06 /* Public */,
      13,    6,  185,    4, 0x26 /* Public | MethodCloned */,
      13,    5,  198,    4, 0x26 /* Public | MethodCloned */,
      13,    4,  209,    4, 0x26 /* Public | MethodCloned */,
      13,    3,  218,    4, 0x26 /* Public | MethodCloned */,
      13,    2,  225,    4, 0x26 /* Public | MethodCloned */,

 // slots: name, argc, parameters, tag, flags
      22,    1,  230,    4, 0x0a /* Public */,
      24,    0,  233,    4, 0x0a /* Public */,
      25,    1,  234,    4, 0x0a /* Public */,
      27,    1,  237,    4, 0x0a /* Public */,
      28,    2,  240,    4, 0x0a /* Public */,
      29,    3,  245,    4, 0x0a /* Public */,
      30,    1,  252,    4, 0x0a /* Public */,
      31,    1,  255,    4, 0x0a /* Public */,
      32,    1,  258,    4, 0x0a /* Public */,
      33,    0,  261,    4, 0x0a /* Public */,
      34,    4,  262,    4, 0x0a /* Public */,
      36,    0,  271,    4, 0x0a /* Public */,
      37,    0,  272,    4, 0x0a /* Public */,
      38,    0,  273,    4, 0x0a /* Public */,
      39,    1,  274,    4, 0x0a /* Public */,
      40,    1,  277,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   15,   16,   17,   18,   19,   20,   21,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   15,   16,   17,   18,   19,   20,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   15,   16,   17,   18,   19,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString, QMetaType::QString, QMetaType::QString,   15,   16,   17,   18,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString, QMetaType::QString,   15,   16,   17,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QString,   15,   16,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,    6,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString, QMetaType::QString,   35,   17,   20,   18,
    QMetaType::QStringList,
    QMetaType::QStringList,
    QMetaType::QStringList,
    QMetaType::QStringList, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Bool,   41,

       0        // eod
};

void Konversation::DBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DBus *_t = static_cast<DBus *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dbusSay((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 1: _t->dbusInfo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->dbusInsertMarkerLine(); break;
        case 3: _t->dbusRaw((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->dbusMultiServerRaw((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 6: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 7: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 8: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 9: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 10: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->setAway((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->setBack(); break;
        case 13: _t->sayToAll((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->actionToAll((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->raw((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->say((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->info((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->debug((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->error((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->insertMarkerLine(); break;
        case 21: _t->connectToServer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 22: { QStringList _r = _t->listConnections();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 23: { QStringList _r = _t->listServers();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QStringList _r = _t->listConnectedServers();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 25: { QStringList _r = _t->listJoinedChannels((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->changeAwayStatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (DBus::*_t)(const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::dbusSay)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DBus::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::dbusInfo)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (DBus::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::dbusInsertMarkerLine)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (DBus::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::dbusRaw)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (DBus::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::dbusMultiServerRaw)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (DBus::*_t)(Konversation::ConnectionFlag , const QString & , const QString & , const QString & , const QString & , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DBus::connectTo)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DBus::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__DBus.data,
      qt_meta_data_Konversation__DBus,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DBus.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DBus::dbusSay(const QString & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DBus::dbusInfo(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DBus::dbusInsertMarkerLine()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Konversation::DBus::dbusRaw(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Konversation::DBus::dbusMultiServerRaw(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Konversation::DBus::connectTo(Konversation::ConnectionFlag _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, bool _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
struct qt_meta_stringdata_Konversation__IdentDBus_t {
    QByteArrayData data[46];
    char stringdata0[549];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__IdentDBus_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__IdentDBus_t qt_meta_stringdata_Konversation__IdentDBus = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Konversation::IdentDBus"
QT_MOC_LITERAL(1, 24, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 40, 20), // "org.kde.konversation"
QT_MOC_LITERAL(3, 61, 11), // "setrealName"
QT_MOC_LITERAL(4, 73, 0), // ""
QT_MOC_LITERAL(5, 74, 8), // "identity"
QT_MOC_LITERAL(6, 83, 4), // "name"
QT_MOC_LITERAL(7, 88, 11), // "getrealName"
QT_MOC_LITERAL(8, 100, 8), // "setIdent"
QT_MOC_LITERAL(9, 109, 5), // "ident"
QT_MOC_LITERAL(10, 115, 8), // "getIdent"
QT_MOC_LITERAL(11, 124, 11), // "setNickname"
QT_MOC_LITERAL(12, 136, 5), // "index"
QT_MOC_LITERAL(13, 142, 4), // "nick"
QT_MOC_LITERAL(14, 147, 11), // "getNickname"
QT_MOC_LITERAL(15, 159, 6), // "setBot"
QT_MOC_LITERAL(16, 166, 3), // "bot"
QT_MOC_LITERAL(17, 170, 6), // "getBot"
QT_MOC_LITERAL(18, 177, 11), // "setPassword"
QT_MOC_LITERAL(19, 189, 8), // "password"
QT_MOC_LITERAL(20, 198, 11), // "getPassword"
QT_MOC_LITERAL(21, 210, 15), // "setNicknameList"
QT_MOC_LITERAL(22, 226, 7), // "newList"
QT_MOC_LITERAL(23, 234, 15), // "getNicknameList"
QT_MOC_LITERAL(24, 250, 13), // "setQuitReason"
QT_MOC_LITERAL(25, 264, 6), // "reason"
QT_MOC_LITERAL(26, 271, 13), // "getQuitReason"
QT_MOC_LITERAL(27, 285, 13), // "setPartReason"
QT_MOC_LITERAL(28, 299, 13), // "getPartReason"
QT_MOC_LITERAL(29, 313, 13), // "setKickReason"
QT_MOC_LITERAL(30, 327, 13), // "getKickReason"
QT_MOC_LITERAL(31, 341, 18), // "setRunAwayCommands"
QT_MOC_LITERAL(32, 360, 3), // "run"
QT_MOC_LITERAL(33, 364, 18), // "getRunAwayCommands"
QT_MOC_LITERAL(34, 383, 14), // "setAwayCommand"
QT_MOC_LITERAL(35, 398, 7), // "command"
QT_MOC_LITERAL(36, 406, 14), // "getAwayCommand"
QT_MOC_LITERAL(37, 421, 16), // "setReturnCommand"
QT_MOC_LITERAL(38, 438, 16), // "getReturnCommand"
QT_MOC_LITERAL(39, 455, 15), // "setAwayNickname"
QT_MOC_LITERAL(40, 471, 8), // "nickname"
QT_MOC_LITERAL(41, 480, 15), // "getAwayNickname"
QT_MOC_LITERAL(42, 496, 14), // "setAwayMessage"
QT_MOC_LITERAL(43, 511, 7), // "message"
QT_MOC_LITERAL(44, 519, 14), // "getAwayMessage"
QT_MOC_LITERAL(45, 534, 14) // "listIdentities"

    },
    "Konversation::IdentDBus\0D-Bus Interface\0"
    "org.kde.konversation\0setrealName\0\0"
    "identity\0name\0getrealName\0setIdent\0"
    "ident\0getIdent\0setNickname\0index\0nick\0"
    "getNickname\0setBot\0bot\0getBot\0setPassword\0"
    "password\0getPassword\0setNicknameList\0"
    "newList\0getNicknameList\0setQuitReason\0"
    "reason\0getQuitReason\0setPartReason\0"
    "getPartReason\0setKickReason\0getKickReason\0"
    "setRunAwayCommands\0run\0getRunAwayCommands\0"
    "setAwayCommand\0command\0getAwayCommand\0"
    "setReturnCommand\0getReturnCommand\0"
    "setAwayNickname\0nickname\0getAwayNickname\0"
    "setAwayMessage\0message\0getAwayMessage\0"
    "listIdentities"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__IdentDBus[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      29,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    2,  161,    4, 0x0a /* Public */,
       7,    1,  166,    4, 0x0a /* Public */,
       8,    2,  169,    4, 0x0a /* Public */,
      10,    1,  174,    4, 0x0a /* Public */,
      11,    3,  177,    4, 0x0a /* Public */,
      14,    2,  184,    4, 0x0a /* Public */,
      15,    2,  189,    4, 0x0a /* Public */,
      17,    1,  194,    4, 0x0a /* Public */,
      18,    2,  197,    4, 0x0a /* Public */,
      20,    1,  202,    4, 0x0a /* Public */,
      21,    2,  205,    4, 0x0a /* Public */,
      23,    1,  210,    4, 0x0a /* Public */,
      24,    2,  213,    4, 0x0a /* Public */,
      26,    1,  218,    4, 0x0a /* Public */,
      27,    2,  221,    4, 0x0a /* Public */,
      28,    1,  226,    4, 0x0a /* Public */,
      29,    2,  229,    4, 0x0a /* Public */,
      30,    1,  234,    4, 0x0a /* Public */,
      31,    2,  237,    4, 0x0a /* Public */,
      33,    1,  242,    4, 0x0a /* Public */,
      34,    2,  245,    4, 0x0a /* Public */,
      36,    1,  250,    4, 0x0a /* Public */,
      37,    2,  253,    4, 0x0a /* Public */,
      38,    1,  258,    4, 0x0a /* Public */,
      39,    2,  261,    4, 0x0a /* Public */,
      41,    1,  266,    4, 0x0a /* Public */,
      42,    2,  269,    4, 0x0a /* Public */,
      44,    1,  274,    4, 0x0a /* Public */,
      45,    0,  277,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    6,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,    9,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    5,   12,   13,
    QMetaType::QString, QMetaType::QString, QMetaType::Int,    5,   12,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   16,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   19,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    5,   22,
    QMetaType::QStringList, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   25,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   25,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   25,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    5,   32,
    QMetaType::Bool, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   35,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   35,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   40,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   43,
    QMetaType::QString, QMetaType::QString,    5,
    QMetaType::QStringList,

       0        // eod
};

void Konversation::IdentDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IdentDBus *_t = static_cast<IdentDBus *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setrealName((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: { QString _r = _t->getrealName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setIdent((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: { QString _r = _t->getIdent((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setNickname((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 5: { QString _r = _t->getNickname((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setBot((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: { QString _r = _t->getBot((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setPassword((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 9: { QString _r = _t->getPassword((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setNicknameList((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 11: { QStringList _r = _t->getNicknameList((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setQuitReason((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: { QString _r = _t->getQuitReason((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setPartReason((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: { QString _r = _t->getPartReason((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setKickReason((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: { QString _r = _t->getKickReason((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setRunAwayCommands((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 19: { bool _r = _t->getRunAwayCommands((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setAwayCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 21: { QString _r = _t->getAwayCommand((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setReturnCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: { QString _r = _t->getReturnCommand((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->setAwayNickname((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 25: { QString _r = _t->getAwayNickname((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setAwayMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 27: { QString _r = _t->getAwayMessage((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->listIdentities();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject Konversation::IdentDBus::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__IdentDBus.data,
      qt_meta_data_Konversation__IdentDBus,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::IdentDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::IdentDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__IdentDBus.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::IdentDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
