/****************************************************************************
** Meta object code from reading C++ file 'transferrecv.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transferrecv.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferrecv.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferRecv_t {
    QByteArrayData data[30];
    char stringdata0[398];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferRecv_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferRecv_t qt_meta_stringdata_Konversation__DCC__TransferRecv = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Konversation::DCC::TransferRecv"
QT_MOC_LITERAL(1, 32, 5), // "queue"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 5), // "start"
QT_MOC_LITERAL(4, 45, 5), // "abort"
QT_MOC_LITERAL(5, 51, 11), // "startResume"
QT_MOC_LITERAL(6, 63, 8), // "position"
QT_MOC_LITERAL(7, 72, 18), // "slotLocalCanResume"
QT_MOC_LITERAL(8, 91, 9), // "KIO::Job*"
QT_MOC_LITERAL(9, 101, 3), // "job"
QT_MOC_LITERAL(10, 105, 15), // "KIO::filesize_t"
QT_MOC_LITERAL(11, 121, 4), // "size"
QT_MOC_LITERAL(12, 126, 18), // "slotLocalGotResult"
QT_MOC_LITERAL(13, 145, 5), // "KJob*"
QT_MOC_LITERAL(14, 151, 14), // "slotLocalReady"
QT_MOC_LITERAL(15, 166, 18), // "slotLocalWriteDone"
QT_MOC_LITERAL(16, 185, 22), // "slotLocalGotWriteError"
QT_MOC_LITERAL(17, 208, 11), // "errorString"
QT_MOC_LITERAL(18, 220, 17), // "connectWithSender"
QT_MOC_LITERAL(19, 238, 14), // "startReceiving"
QT_MOC_LITERAL(20, 253, 16), // "connectionFailed"
QT_MOC_LITERAL(21, 270, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(22, 299, 9), // "errorCode"
QT_MOC_LITERAL(23, 309, 8), // "readData"
QT_MOC_LITERAL(24, 318, 7), // "sendAck"
QT_MOC_LITERAL(25, 326, 17), // "connectionTimeout"
QT_MOC_LITERAL(26, 344, 27), // "slotServerSocketReadyAccept"
QT_MOC_LITERAL(27, 372, 14), // "sendReverseAck"
QT_MOC_LITERAL(28, 387, 5), // "error"
QT_MOC_LITERAL(29, 393, 4) // "port"

    },
    "Konversation::DCC::TransferRecv\0queue\0"
    "\0start\0abort\0startResume\0position\0"
    "slotLocalCanResume\0KIO::Job*\0job\0"
    "KIO::filesize_t\0size\0slotLocalGotResult\0"
    "KJob*\0slotLocalReady\0slotLocalWriteDone\0"
    "slotLocalGotWriteError\0errorString\0"
    "connectWithSender\0startReceiving\0"
    "connectionFailed\0QAbstractSocket::SocketError\0"
    "errorCode\0readData\0sendAck\0connectionTimeout\0"
    "slotServerSocketReadyAccept\0sendReverseAck\0"
    "error\0port"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferRecv[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x0a /* Public */,
       3,    0,  100,    2, 0x0a /* Public */,
       4,    0,  101,    2, 0x0a /* Public */,
       5,    1,  102,    2, 0x0a /* Public */,
       7,    2,  105,    2, 0x09 /* Protected */,
      12,    1,  110,    2, 0x09 /* Protected */,
      14,    1,  113,    2, 0x09 /* Protected */,
      15,    0,  116,    2, 0x09 /* Protected */,
      16,    1,  117,    2, 0x09 /* Protected */,
      18,    0,  120,    2, 0x09 /* Protected */,
      19,    0,  121,    2, 0x09 /* Protected */,
      20,    1,  122,    2, 0x09 /* Protected */,
      23,    0,  125,    2, 0x09 /* Protected */,
      24,    0,  126,    2, 0x09 /* Protected */,
      25,    0,  127,    2, 0x09 /* Protected */,
      26,    0,  128,    2, 0x09 /* Protected */,
      27,    2,  129,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::ULongLong,    6,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 10,    9,   11,
    QMetaType::Void, 0x80000000 | 13,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,   28,   29,

       0        // eod
};

void Konversation::DCC::TransferRecv::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferRecv *_t = static_cast<TransferRecv *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->queue();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->start(); break;
        case 2: _t->abort(); break;
        case 3: _t->startResume((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 4: _t->slotLocalCanResume((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< KIO::filesize_t(*)>(_a[2]))); break;
        case 5: _t->slotLocalGotResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 6: _t->slotLocalReady((*reinterpret_cast< KIO::Job*(*)>(_a[1]))); break;
        case 7: _t->slotLocalWriteDone(); break;
        case 8: _t->slotLocalGotWriteError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->connectWithSender(); break;
        case 10: _t->startReceiving(); break;
        case 11: _t->connectionFailed((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 12: _t->readData(); break;
        case 13: _t->sendAck(); break;
        case 14: _t->connectionTimeout(); break;
        case 15: _t->slotServerSocketReadyAccept(); break;
        case 16: _t->sendReverseAck((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    }
}

const QMetaObject Konversation::DCC::TransferRecv::staticMetaObject = {
    { &Transfer::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferRecv.data,
      qt_meta_data_Konversation__DCC__TransferRecv,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferRecv::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferRecv::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferRecv.stringdata0))
        return static_cast<void*>(this);
    return Transfer::qt_metacast(_clname);
}

int Konversation::DCC::TransferRecv::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Transfer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}
struct qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler_t {
    QByteArrayData data[12];
    char stringdata0[142];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler_t qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler = {
    {
QT_MOC_LITERAL(0, 0, 48), // "Konversation::DCC::TransferRe..."
QT_MOC_LITERAL(1, 49, 4), // "done"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 8), // "gotError"
QT_MOC_LITERAL(4, 64, 11), // "errorString"
QT_MOC_LITERAL(5, 76, 14), // "slotKIODataReq"
QT_MOC_LITERAL(6, 91, 9), // "KIO::Job*"
QT_MOC_LITERAL(7, 101, 3), // "job"
QT_MOC_LITERAL(8, 105, 11), // "QByteArray&"
QT_MOC_LITERAL(9, 117, 4), // "data"
QT_MOC_LITERAL(10, 122, 13), // "slotKIOResult"
QT_MOC_LITERAL(11, 136, 5) // "KJob*"

    },
    "Konversation::DCC::TransferRecvWriteCacheHandler\0"
    "done\0\0gotError\0errorString\0slotKIODataReq\0"
    "KIO::Job*\0job\0QByteArray&\0data\0"
    "slotKIOResult\0KJob*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferRecvWriteCacheHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    1,   35,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    2,   38,    2, 0x09 /* Protected */,
      10,    1,   43,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 8,    7,    9,
    QMetaType::Void, 0x80000000 | 11,    7,

       0        // eod
};

void Konversation::DCC::TransferRecvWriteCacheHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferRecvWriteCacheHandler *_t = static_cast<TransferRecvWriteCacheHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->done(); break;
        case 1: _t->gotError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->slotKIODataReq((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< QByteArray(*)>(_a[2]))); break;
        case 3: _t->slotKIOResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TransferRecvWriteCacheHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferRecvWriteCacheHandler::done)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TransferRecvWriteCacheHandler::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferRecvWriteCacheHandler::gotError)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::TransferRecvWriteCacheHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler.data,
      qt_meta_data_Konversation__DCC__TransferRecvWriteCacheHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferRecvWriteCacheHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferRecvWriteCacheHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferRecvWriteCacheHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DCC::TransferRecvWriteCacheHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::TransferRecvWriteCacheHandler::done()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Konversation::DCC::TransferRecvWriteCacheHandler::gotError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
