/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[45];
    char stringdata0[631];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 22), // "showQuickConnectDialog"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 14), // "nicksNowOnline"
QT_MOC_LITERAL(4, 50, 7), // "Server*"
QT_MOC_LITERAL(5, 58, 15), // "endNotification"
QT_MOC_LITERAL(6, 74, 18), // "serverStateChanged"
QT_MOC_LITERAL(7, 93, 6), // "server"
QT_MOC_LITERAL(8, 100, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(9, 130, 5), // "state"
QT_MOC_LITERAL(10, 136, 19), // "triggerRememberLine"
QT_MOC_LITERAL(11, 156, 20), // "triggerRememberLines"
QT_MOC_LITERAL(12, 177, 18), // "cancelRememberLine"
QT_MOC_LITERAL(13, 196, 16), // "insertMarkerLine"
QT_MOC_LITERAL(14, 213, 22), // "activateAndRaiseWindow"
QT_MOC_LITERAL(15, 236, 11), // "quitProgram"
QT_MOC_LITERAL(16, 248, 14), // "updateTrayIcon"
QT_MOC_LITERAL(17, 263, 14), // "openServerList"
QT_MOC_LITERAL(18, 278, 20), // "openIdentitiesDialog"
QT_MOC_LITERAL(19, 299, 12), // "editIdentity"
QT_MOC_LITERAL(20, 312, 11), // "IdentityPtr"
QT_MOC_LITERAL(21, 324, 8), // "identity"
QT_MOC_LITERAL(22, 333, 13), // "setOnlineList"
QT_MOC_LITERAL(23, 347, 12), // "notifyServer"
QT_MOC_LITERAL(24, 360, 4), // "list"
QT_MOC_LITERAL(25, 365, 7), // "changed"
QT_MOC_LITERAL(26, 373, 19), // "settingsChangedSlot"
QT_MOC_LITERAL(27, 393, 21), // "resetHasDirtySettings"
QT_MOC_LITERAL(28, 415, 13), // "toggleMenubar"
QT_MOC_LITERAL(29, 429, 15), // "dontShowWarning"
QT_MOC_LITERAL(30, 445, 15), // "openPrefsDialog"
QT_MOC_LITERAL(31, 461, 15), // "openKeyBindings"
QT_MOC_LITERAL(32, 477, 22), // "openQuickConnectDialog"
QT_MOC_LITERAL(33, 500, 17), // "openNotifications"
QT_MOC_LITERAL(34, 518, 12), // "notifyAction"
QT_MOC_LITERAL(35, 531, 12), // "connectionId"
QT_MOC_LITERAL(36, 544, 4), // "nick"
QT_MOC_LITERAL(37, 549, 16), // "toggleVisibility"
QT_MOC_LITERAL(38, 566, 9), // "showEvent"
QT_MOC_LITERAL(39, 576, 11), // "QShowEvent*"
QT_MOC_LITERAL(40, 588, 1), // "e"
QT_MOC_LITERAL(41, 590, 9), // "hideEvent"
QT_MOC_LITERAL(42, 600, 11), // "QHideEvent*"
QT_MOC_LITERAL(43, 612, 10), // "leaveEvent"
QT_MOC_LITERAL(44, 623, 7) // "QEvent*"

    },
    "MainWindow\0showQuickConnectDialog\0\0"
    "nicksNowOnline\0Server*\0endNotification\0"
    "serverStateChanged\0server\0"
    "Konversation::ConnectionState\0state\0"
    "triggerRememberLine\0triggerRememberLines\0"
    "cancelRememberLine\0insertMarkerLine\0"
    "activateAndRaiseWindow\0quitProgram\0"
    "updateTrayIcon\0openServerList\0"
    "openIdentitiesDialog\0editIdentity\0"
    "IdentityPtr\0identity\0setOnlineList\0"
    "notifyServer\0list\0changed\0settingsChangedSlot\0"
    "resetHasDirtySettings\0toggleMenubar\0"
    "dontShowWarning\0openPrefsDialog\0"
    "openKeyBindings\0openQuickConnectDialog\0"
    "openNotifications\0notifyAction\0"
    "connectionId\0nick\0toggleVisibility\0"
    "showEvent\0QShowEvent*\0e\0hideEvent\0"
    "QHideEvent*\0leaveEvent\0QEvent*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x06 /* Public */,
       3,    1,  155,    2, 0x06 /* Public */,
       5,    0,  158,    2, 0x06 /* Public */,
       6,    2,  159,    2, 0x06 /* Public */,
      10,    0,  164,    2, 0x06 /* Public */,
      11,    1,  165,    2, 0x06 /* Public */,
      12,    0,  168,    2, 0x06 /* Public */,
      13,    0,  169,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  170,    2, 0x0a /* Public */,
      15,    0,  171,    2, 0x0a /* Public */,
      16,    0,  172,    2, 0x0a /* Public */,
      17,    0,  173,    2, 0x0a /* Public */,
      18,    0,  174,    2, 0x0a /* Public */,
      19,    1,  175,    2, 0x0a /* Public */,
      22,    3,  178,    2, 0x0a /* Public */,
      26,    0,  185,    2, 0x09 /* Protected */,
      27,    0,  186,    2, 0x09 /* Protected */,
      28,    1,  187,    2, 0x09 /* Protected */,
      28,    0,  190,    2, 0x29 /* Protected | MethodCloned */,
      30,    0,  191,    2, 0x09 /* Protected */,
      31,    0,  192,    2, 0x09 /* Protected */,
      32,    0,  193,    2, 0x09 /* Protected */,
      33,    0,  194,    2, 0x09 /* Protected */,
      34,    2,  195,    2, 0x09 /* Protected */,
      37,    0,  200,    2, 0x09 /* Protected */,
      38,    1,  201,    2, 0x09 /* Protected */,
      41,    1,  204,    2, 0x09 /* Protected */,
      43,    1,  207,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 8,    7,    9,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 20, 0x80000000 | 20,   21,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QStringList, QMetaType::Bool,   23,   24,   25,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   35,   36,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 42,   40,
    QMetaType::Void, 0x80000000 | 44,   40,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showQuickConnectDialog(); break;
        case 1: _t->nicksNowOnline((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 2: _t->endNotification(); break;
        case 3: _t->serverStateChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 4: _t->triggerRememberLine(); break;
        case 5: _t->triggerRememberLines((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 6: _t->cancelRememberLine(); break;
        case 7: _t->insertMarkerLine(); break;
        case 8: _t->activateAndRaiseWindow(); break;
        case 9: _t->quitProgram(); break;
        case 10: _t->updateTrayIcon(); break;
        case 11: _t->openServerList(); break;
        case 12: _t->openIdentitiesDialog(); break;
        case 13: { IdentityPtr _r = _t->editIdentity((*reinterpret_cast< IdentityPtr(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< IdentityPtr*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->setOnlineList((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 15: _t->settingsChangedSlot(); break;
        case 16: _t->resetHasDirtySettings(); break;
        case 17: _t->toggleMenubar((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->toggleMenubar(); break;
        case 19: _t->openPrefsDialog(); break;
        case 20: _t->openKeyBindings(); break;
        case 21: _t->openQuickConnectDialog(); break;
        case 22: _t->openNotifications(); break;
        case 23: _t->notifyAction((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 24: _t->toggleVisibility(); break;
        case 25: _t->showEvent((*reinterpret_cast< QShowEvent*(*)>(_a[1]))); break;
        case 26: _t->hideEvent((*reinterpret_cast< QHideEvent*(*)>(_a[1]))); break;
        case 27: _t->leaveEvent((*reinterpret_cast< QEvent*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::showQuickConnectDialog)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::nicksNowOnline)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::endNotification)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)(Server * , Konversation::ConnectionState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::serverStateChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::triggerRememberLine)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::triggerRememberLines)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::cancelRememberLine)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::insertMarkerLine)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject MainWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_MainWindow.data,
      qt_meta_data_MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::showQuickConnectDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::nicksNowOnline(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MainWindow::endNotification()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainWindow::serverStateChanged(Server * _t1, Konversation::ConnectionState _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void MainWindow::triggerRememberLine()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MainWindow::triggerRememberLines(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void MainWindow::cancelRememberLine()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MainWindow::insertMarkerLine()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
