/****************************************************************************
** Meta object code from reading C++ file 'transferpanel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transferpanel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferpanel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferPanel_t {
    QByteArrayData data[24];
    char stringdata0[329];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferPanel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferPanel_t qt_meta_stringdata_Konversation__DCC__TransferPanel = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Konversation::DCC::TransferPanel"
QT_MOC_LITERAL(1, 33, 20), // "slotNewTransferAdded"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(4, 84, 8), // "transfer"
QT_MOC_LITERAL(5, 93, 25), // "slotTransferStatusChanged"
QT_MOC_LITERAL(6, 119, 9), // "acceptDcc"
QT_MOC_LITERAL(7, 129, 8), // "abortDcc"
QT_MOC_LITERAL(8, 138, 10), // "resendFile"
QT_MOC_LITERAL(9, 149, 8), // "clearDcc"
QT_MOC_LITERAL(10, 158, 17), // "clearCompletedDcc"
QT_MOC_LITERAL(11, 176, 6), // "runDcc"
QT_MOC_LITERAL(12, 183, 12), // "openLocation"
QT_MOC_LITERAL(13, 196, 9), // "selectAll"
QT_MOC_LITERAL(14, 206, 18), // "selectAllCompleted"
QT_MOC_LITERAL(15, 225, 14), // "popupRequested"
QT_MOC_LITERAL(16, 240, 3), // "pos"
QT_MOC_LITERAL(17, 244, 13), // "doubleClicked"
QT_MOC_LITERAL(18, 258, 5), // "index"
QT_MOC_LITERAL(19, 264, 12), // "updateButton"
QT_MOC_LITERAL(20, 277, 18), // "setDetailPanelItem"
QT_MOC_LITERAL(21, 296, 14), // "QItemSelection"
QT_MOC_LITERAL(22, 311, 8), // "newindex"
QT_MOC_LITERAL(23, 320, 8) // "oldindex"

    },
    "Konversation::DCC::TransferPanel\0"
    "slotNewTransferAdded\0\0"
    "Konversation::DCC::Transfer*\0transfer\0"
    "slotTransferStatusChanged\0acceptDcc\0"
    "abortDcc\0resendFile\0clearDcc\0"
    "clearCompletedDcc\0runDcc\0openLocation\0"
    "selectAll\0selectAllCompleted\0"
    "popupRequested\0pos\0doubleClicked\0index\0"
    "updateButton\0setDetailPanelItem\0"
    "QItemSelection\0newindex\0oldindex"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferPanel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   89,    2, 0x09 /* Protected */,
       5,    0,   92,    2, 0x09 /* Protected */,
       6,    0,   93,    2, 0x09 /* Protected */,
       7,    0,   94,    2, 0x09 /* Protected */,
       8,    0,   95,    2, 0x09 /* Protected */,
       9,    0,   96,    2, 0x09 /* Protected */,
      10,    0,   97,    2, 0x09 /* Protected */,
      11,    0,   98,    2, 0x09 /* Protected */,
      12,    0,   99,    2, 0x09 /* Protected */,
      13,    0,  100,    2, 0x09 /* Protected */,
      14,    0,  101,    2, 0x09 /* Protected */,
      15,    1,  102,    2, 0x09 /* Protected */,
      17,    1,  105,    2, 0x09 /* Protected */,
      19,    0,  108,    2, 0x09 /* Protected */,
      20,    2,  109,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   16,
    QMetaType::Void, QMetaType::QModelIndex,   18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 21,   22,   23,

       0        // eod
};

void Konversation::DCC::TransferPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferPanel *_t = static_cast<TransferPanel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotNewTransferAdded((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 1: _t->slotTransferStatusChanged(); break;
        case 2: _t->acceptDcc(); break;
        case 3: _t->abortDcc(); break;
        case 4: _t->resendFile(); break;
        case 5: _t->clearDcc(); break;
        case 6: _t->clearCompletedDcc(); break;
        case 7: _t->runDcc(); break;
        case 8: _t->openLocation(); break;
        case 9: _t->selectAll(); break;
        case 10: _t->selectAllCompleted(); break;
        case 11: _t->popupRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 12: _t->doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 13: _t->updateButton(); break;
        case 14: _t->setDetailPanelItem((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    }
}

const QMetaObject Konversation::DCC::TransferPanel::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferPanel.data,
      qt_meta_data_Konversation__DCC__TransferPanel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferPanel.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Konversation::DCC::TransferPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
