/****************************************************************************
** Meta object code from reading C++ file 'viewtree.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/viewtree.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewtree.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ViewTreeDelegate_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ViewTreeDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ViewTreeDelegate_t qt_meta_stringdata_ViewTreeDelegate = {
    {
QT_MOC_LITERAL(0, 0, 16) // "ViewTreeDelegate"

    },
    "ViewTreeDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ViewTreeDelegate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ViewTreeDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject ViewTreeDelegate::staticMetaObject = {
    { &QStyledItemDelegate::staticMetaObject, qt_meta_stringdata_ViewTreeDelegate.data,
      qt_meta_data_ViewTreeDelegate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ViewTreeDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewTreeDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ViewTreeDelegate.stringdata0))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int ViewTreeDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_ViewTree_t {
    QByteArrayData data[18];
    char stringdata0[186];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ViewTree_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ViewTree_t qt_meta_stringdata_ViewTree = {
    {
QT_MOC_LITERAL(0, 0, 8), // "ViewTree"
QT_MOC_LITERAL(1, 9, 11), // "sizeChanged"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 8), // "showView"
QT_MOC_LITERAL(4, 31, 11), // "ChatWindow*"
QT_MOC_LITERAL(5, 43, 4), // "view"
QT_MOC_LITERAL(6, 48, 9), // "closeView"
QT_MOC_LITERAL(7, 58, 19), // "showViewContextMenu"
QT_MOC_LITERAL(8, 78, 8), // "QWidget*"
QT_MOC_LITERAL(9, 87, 6), // "widget"
QT_MOC_LITERAL(10, 94, 5), // "point"
QT_MOC_LITERAL(11, 100, 16), // "updateAppearance"
QT_MOC_LITERAL(12, 117, 10), // "selectView"
QT_MOC_LITERAL(13, 128, 5), // "index"
QT_MOC_LITERAL(14, 134, 16), // "selectionChanged"
QT_MOC_LITERAL(15, 151, 14), // "QItemSelection"
QT_MOC_LITERAL(16, 166, 8), // "selected"
QT_MOC_LITERAL(17, 175, 10) // "deselected"

    },
    "ViewTree\0sizeChanged\0\0showView\0"
    "ChatWindow*\0view\0closeView\0"
    "showViewContextMenu\0QWidget*\0widget\0"
    "point\0updateAppearance\0selectView\0"
    "index\0selectionChanged\0QItemSelection\0"
    "selected\0deselected"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ViewTree[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    1,   50,    2, 0x06 /* Public */,
       6,    1,   53,    2, 0x06 /* Public */,
       7,    2,   56,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   61,    2, 0x0a /* Public */,
      12,    1,   62,    2, 0x0a /* Public */,
      14,    2,   65,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 8, QMetaType::QPoint,    9,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,   13,
    QMetaType::Void, 0x80000000 | 15, 0x80000000 | 15,   16,   17,

       0        // eod
};

void ViewTree::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewTree *_t = static_cast<ViewTree *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sizeChanged(); break;
        case 1: _t->showView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 2: _t->closeView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 3: _t->showViewContextMenu((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 4: _t->updateAppearance(); break;
        case 5: _t->selectView((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 6: _t->selectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ViewTree::*_t)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewTree::sizeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ViewTree::*_t)(ChatWindow * ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewTree::showView)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ViewTree::*_t)(ChatWindow * ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewTree::closeView)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ViewTree::*_t)(QWidget * , const QPoint & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewTree::showViewContextMenu)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject ViewTree::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_ViewTree.data,
      qt_meta_data_ViewTree,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ViewTree::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewTree::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ViewTree.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int ViewTree::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ViewTree::sizeChanged()const
{
    QMetaObject::activate(const_cast< ViewTree *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ViewTree::showView(ChatWindow * _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< ViewTree *>(this), &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ViewTree::closeView(ChatWindow * _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(const_cast< ViewTree *>(this), &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ViewTree::showViewContextMenu(QWidget * _t1, const QPoint & _t2)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(const_cast< ViewTree *>(this), &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
