/****************************************************************************
** Meta object code from reading C++ file 'channel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/channel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Channel_t {
    QByteArrayData data[72];
    char stringdata0[943];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Channel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Channel_t qt_meta_stringdata_Channel = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Channel"
QT_MOC_LITERAL(1, 8, 6), // "joined"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 8), // "Channel*"
QT_MOC_LITERAL(4, 25, 7), // "channel"
QT_MOC_LITERAL(5, 33, 12), // "modesChanged"
QT_MOC_LITERAL(6, 46, 8), // "banAdded"
QT_MOC_LITERAL(7, 55, 6), // "newban"
QT_MOC_LITERAL(8, 62, 10), // "banRemoved"
QT_MOC_LITERAL(9, 73, 14), // "banListCleared"
QT_MOC_LITERAL(10, 88, 8), // "sendFile"
QT_MOC_LITERAL(11, 97, 11), // "setNickname"
QT_MOC_LITERAL(12, 109, 11), // "newNickname"
QT_MOC_LITERAL(13, 121, 15), // "scheduleAutoWho"
QT_MOC_LITERAL(14, 137, 4), // "msec"
QT_MOC_LITERAL(15, 142, 15), // "setAutoUserhost"
QT_MOC_LITERAL(16, 158, 5), // "state"
QT_MOC_LITERAL(17, 164, 6), // "rejoin"
QT_MOC_LITERAL(18, 171, 12), // "autoUserhost"
QT_MOC_LITERAL(19, 184, 7), // "autoWho"
QT_MOC_LITERAL(20, 192, 13), // "updateAutoWho"
QT_MOC_LITERAL(21, 206, 12), // "fadeActivity"
QT_MOC_LITERAL(22, 219, 12), // "serverOnline"
QT_MOC_LITERAL(23, 232, 6), // "online"
QT_MOC_LITERAL(24, 239, 19), // "delayedSortNickList"
QT_MOC_LITERAL(25, 259, 10), // "purgeNicks"
QT_MOC_LITERAL(26, 270, 18), // "processQueuedNicks"
QT_MOC_LITERAL(27, 289, 5), // "flush"
QT_MOC_LITERAL(28, 295, 15), // "updateNickInfos"
QT_MOC_LITERAL(29, 311, 18), // "updateChannelNicks"
QT_MOC_LITERAL(30, 330, 16), // "updateAppearance"
QT_MOC_LITERAL(31, 347, 18), // "updateQuickButtons"
QT_MOC_LITERAL(32, 366, 18), // "channelTextEntered"
QT_MOC_LITERAL(33, 385, 25), // "channelPassthroughCommand"
QT_MOC_LITERAL(34, 411, 8), // "sendText"
QT_MOC_LITERAL(35, 420, 4), // "line"
QT_MOC_LITERAL(36, 425, 17), // "showOptionsDialog"
QT_MOC_LITERAL(37, 443, 16), // "showQuickButtons"
QT_MOC_LITERAL(38, 460, 4), // "show"
QT_MOC_LITERAL(39, 465, 15), // "showModeButtons"
QT_MOC_LITERAL(40, 481, 12), // "indicateAway"
QT_MOC_LITERAL(41, 494, 9), // "showTopic"
QT_MOC_LITERAL(42, 504, 15), // "showNicknameBox"
QT_MOC_LITERAL(43, 520, 16), // "showNicknameList"
QT_MOC_LITERAL(44, 537, 11), // "setAutoJoin"
QT_MOC_LITERAL(45, 549, 8), // "autojoin"
QT_MOC_LITERAL(46, 558, 22), // "connectionStateChanged"
QT_MOC_LITERAL(47, 581, 7), // "Server*"
QT_MOC_LITERAL(48, 589, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(49, 619, 12), // "completeNick"
QT_MOC_LITERAL(50, 632, 15), // "endCompleteNick"
QT_MOC_LITERAL(51, 648, 18), // "quickButtonClicked"
QT_MOC_LITERAL(52, 667, 10), // "definition"
QT_MOC_LITERAL(53, 678, 17), // "modeButtonClicked"
QT_MOC_LITERAL(54, 696, 2), // "id"
QT_MOC_LITERAL(55, 699, 2), // "on"
QT_MOC_LITERAL(56, 702, 19), // "channelLimitChanged"
QT_MOC_LITERAL(57, 722, 18), // "doubleClickCommand"
QT_MOC_LITERAL(58, 741, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(59, 758, 4), // "item"
QT_MOC_LITERAL(60, 763, 6), // "column"
QT_MOC_LITERAL(61, 770, 14), // "changeNickname"
QT_MOC_LITERAL(62, 785, 10), // "textPasted"
QT_MOC_LITERAL(63, 796, 4), // "text"
QT_MOC_LITERAL(64, 801, 12), // "sendFileMenu"
QT_MOC_LITERAL(65, 814, 23), // "nicknameComboboxChanged"
QT_MOC_LITERAL(66, 838, 18), // "refreshModeButtons"
QT_MOC_LITERAL(67, 857, 19), // "requestNickListSort"
QT_MOC_LITERAL(68, 877, 12), // "sortNickList"
QT_MOC_LITERAL(69, 890, 7), // "delayed"
QT_MOC_LITERAL(70, 898, 27), // "nicknameListViewTextChanged"
QT_MOC_LITERAL(71, 926, 16) // "textChangedFlags"

    },
    "Channel\0joined\0\0Channel*\0channel\0"
    "modesChanged\0banAdded\0newban\0banRemoved\0"
    "banListCleared\0sendFile\0setNickname\0"
    "newNickname\0scheduleAutoWho\0msec\0"
    "setAutoUserhost\0state\0rejoin\0autoUserhost\0"
    "autoWho\0updateAutoWho\0fadeActivity\0"
    "serverOnline\0online\0delayedSortNickList\0"
    "purgeNicks\0processQueuedNicks\0flush\0"
    "updateNickInfos\0updateChannelNicks\0"
    "updateAppearance\0updateQuickButtons\0"
    "channelTextEntered\0channelPassthroughCommand\0"
    "sendText\0line\0showOptionsDialog\0"
    "showQuickButtons\0show\0showModeButtons\0"
    "indicateAway\0showTopic\0showNicknameBox\0"
    "showNicknameList\0setAutoJoin\0autojoin\0"
    "connectionStateChanged\0Server*\0"
    "Konversation::ConnectionState\0"
    "completeNick\0endCompleteNick\0"
    "quickButtonClicked\0definition\0"
    "modeButtonClicked\0id\0on\0channelLimitChanged\0"
    "doubleClickCommand\0QTreeWidgetItem*\0"
    "item\0column\0changeNickname\0textPasted\0"
    "text\0sendFileMenu\0nicknameComboboxChanged\0"
    "refreshModeButtons\0requestNickListSort\0"
    "sortNickList\0delayed\0nicknameListViewTextChanged\0"
    "textChangedFlags"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Channel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      51,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  269,    2, 0x06 /* Public */,
       5,    0,  272,    2, 0x06 /* Public */,
       6,    1,  273,    2, 0x06 /* Public */,
       8,    1,  276,    2, 0x06 /* Public */,
       9,    0,  279,    2, 0x06 /* Public */,
      10,    0,  280,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,  281,    2, 0x0a /* Public */,
      13,    1,  284,    2, 0x0a /* Public */,
      13,    0,  287,    2, 0x2a /* Public | MethodCloned */,
      15,    1,  288,    2, 0x0a /* Public */,
      17,    0,  291,    2, 0x0a /* Public */,
      18,    0,  292,    2, 0x09 /* Protected */,
      19,    0,  293,    2, 0x09 /* Protected */,
      20,    0,  294,    2, 0x09 /* Protected */,
      21,    0,  295,    2, 0x09 /* Protected */,
      22,    1,  296,    2, 0x09 /* Protected */,
      24,    0,  299,    2, 0x09 /* Protected */,
      25,    0,  300,    2, 0x09 /* Protected */,
      26,    1,  301,    2, 0x09 /* Protected */,
      26,    0,  304,    2, 0x29 /* Protected | MethodCloned */,
      28,    0,  305,    2, 0x09 /* Protected */,
      29,    1,  306,    2, 0x09 /* Protected */,
      30,    0,  309,    2, 0x0a /* Public */,
      31,    0,  310,    2, 0x0a /* Public */,
      32,    0,  311,    2, 0x0a /* Public */,
      33,    0,  312,    2, 0x0a /* Public */,
      34,    1,  313,    2, 0x0a /* Public */,
      36,    0,  316,    2, 0x0a /* Public */,
      37,    1,  317,    2, 0x0a /* Public */,
      39,    1,  320,    2, 0x0a /* Public */,
      40,    1,  323,    2, 0x0a /* Public */,
      41,    1,  326,    2, 0x0a /* Public */,
      42,    1,  329,    2, 0x0a /* Public */,
      43,    1,  332,    2, 0x0a /* Public */,
      44,    1,  335,    2, 0x0a /* Public */,
      46,    2,  338,    2, 0x0a /* Public */,
      49,    0,  343,    2, 0x09 /* Protected */,
      50,    0,  344,    2, 0x09 /* Protected */,
      51,    1,  345,    2, 0x09 /* Protected */,
      53,    2,  348,    2, 0x09 /* Protected */,
      56,    0,  353,    2, 0x09 /* Protected */,
      57,    2,  354,    2, 0x09 /* Protected */,
      61,    1,  359,    2, 0x09 /* Protected */,
      62,    1,  362,    2, 0x09 /* Protected */,
      64,    0,  365,    2, 0x09 /* Protected */,
      65,    0,  366,    2, 0x09 /* Protected */,
      66,    0,  367,    2, 0x09 /* Protected */,
      67,    0,  368,    2, 0x09 /* Protected */,
      68,    1,  369,    2, 0x09 /* Protected */,
      68,    0,  372,    2, 0x29 /* Protected | MethodCloned */,
      70,    1,  373,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   45,
    QMetaType::Void, 0x80000000 | 47, 0x80000000 | 48,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   52,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   54,   55,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 58, QMetaType::Int,   59,   60,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,   63,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   69,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   71,

       0        // eod
};

void Channel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Channel *_t = static_cast<Channel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->joined((*reinterpret_cast< Channel*(*)>(_a[1]))); break;
        case 1: _t->modesChanged(); break;
        case 2: _t->banAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->banRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->banListCleared(); break;
        case 5: _t->sendFile(); break;
        case 6: _t->setNickname((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->scheduleAutoWho((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->scheduleAutoWho(); break;
        case 9: _t->setAutoUserhost((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->rejoin(); break;
        case 11: _t->autoUserhost(); break;
        case 12: _t->autoWho(); break;
        case 13: _t->updateAutoWho(); break;
        case 14: _t->fadeActivity(); break;
        case 15: _t->serverOnline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->delayedSortNickList(); break;
        case 17: _t->purgeNicks(); break;
        case 18: _t->processQueuedNicks((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->processQueuedNicks(); break;
        case 20: _t->updateNickInfos(); break;
        case 21: _t->updateChannelNicks((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->updateAppearance(); break;
        case 23: _t->updateQuickButtons(); break;
        case 24: _t->channelTextEntered(); break;
        case 25: _t->channelPassthroughCommand(); break;
        case 26: _t->sendText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->showOptionsDialog(); break;
        case 28: _t->showQuickButtons((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->showModeButtons((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->indicateAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->showTopic((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->showNicknameBox((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->showNicknameList((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->setAutoJoin((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 35: _t->connectionStateChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 36: _t->completeNick(); break;
        case 37: _t->endCompleteNick(); break;
        case 38: _t->quickButtonClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 39: _t->modeButtonClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 40: _t->channelLimitChanged(); break;
        case 41: _t->doubleClickCommand((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 42: _t->changeNickname((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 43: _t->textPasted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 44: _t->sendFileMenu(); break;
        case 45: _t->nicknameComboboxChanged(); break;
        case 46: _t->refreshModeButtons(); break;
        case 47: _t->requestNickListSort(); break;
        case 48: _t->sortNickList((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 49: _t->sortNickList(); break;
        case 50: _t->nicknameListViewTextChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Channel* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Channel::*_t)(Channel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::joined)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Channel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::modesChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Channel::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::banAdded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Channel::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::banRemoved)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Channel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::banListCleared)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Channel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Channel::sendFile)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject Channel::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_Channel.data,
      qt_meta_data_Channel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Channel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Channel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Channel.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Channel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    return _id;
}

// SIGNAL 0
void Channel::joined(Channel * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Channel::modesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Channel::banAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Channel::banRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Channel::banListCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Channel::sendFile()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
