/****************************************************************************
** Meta object code from reading C++ file 'serverison.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/serverison.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'serverison.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ServerISON_t {
    QByteArrayData data[14];
    char stringdata0[177];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ServerISON_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ServerISON_t qt_meta_stringdata_ServerISON = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ServerISON"
QT_MOC_LITERAL(1, 11, 15), // "nickInfoChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 7), // "Server*"
QT_MOC_LITERAL(4, 36, 6), // "server"
QT_MOC_LITERAL(5, 43, 11), // "NickInfoPtr"
QT_MOC_LITERAL(6, 55, 8), // "nickInfo"
QT_MOC_LITERAL(7, 64, 23), // "slotServerGroupsChanged"
QT_MOC_LITERAL(8, 88, 25), // "slotChannelMembersChanged"
QT_MOC_LITERAL(9, 114, 11), // "channelName"
QT_MOC_LITERAL(10, 126, 6), // "joined"
QT_MOC_LITERAL(11, 133, 6), // "parted"
QT_MOC_LITERAL(12, 140, 8), // "nickname"
QT_MOC_LITERAL(13, 149, 27) // "slotChannelJoinedOrUnjoined"

    },
    "ServerISON\0nickInfoChanged\0\0Server*\0"
    "server\0NickInfoPtr\0nickInfo\0"
    "slotServerGroupsChanged\0"
    "slotChannelMembersChanged\0channelName\0"
    "joined\0parted\0nickname\0"
    "slotChannelJoinedOrUnjoined"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ServerISON[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x08 /* Private */,
       7,    0,   39,    2, 0x08 /* Private */,
       8,    5,   40,    2, 0x08 /* Private */,
      13,    3,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,    4,    9,   10,   11,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::Bool,    4,    9,   10,

       0        // eod
};

void ServerISON::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServerISON *_t = static_cast<ServerISON *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nickInfoChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const NickInfoPtr(*)>(_a[2]))); break;
        case 1: _t->slotServerGroupsChanged(); break;
        case 2: _t->slotChannelMembersChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 3: _t->slotChannelJoinedOrUnjoined((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject ServerISON::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ServerISON.data,
      qt_meta_data_ServerISON,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ServerISON::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ServerISON::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ServerISON.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ServerISON::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
