#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'chatwindowbehaviour_config.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATWINDOWBEHAVIOUR_CONFIG_H
#define UI_CHATWINDOWBEHAVIOUR_CONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ChatwindowBehaviour_Config
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox3;
    QGridLayout *gridLayout_3;
    QCheckBox *kcfg_Beep;
    QCheckBox *kcfg_HideUnimportantEvents;
    QSpacerItem *horizontalSpacer;
    QCheckBox *kcfg_HideUnimportantEventsExcludeActive;
    KComboBox *kcfg_HideUnimportantEventsExcludeActiveThreshold;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *kcfg_DisableExpansion;
    QCheckBox *kcfg_RedirectServerAndAppMsgToStatusPane;
    QCheckBox *kcfg_UseLiteralModes;
    QSpacerItem *spacer1_2;
    QLabel *textLabel1;
    KPluralHandlingSpinBox *kcfg_ScrollbackMax;
    QSpacerItem *spacer1;
    QGroupBox *groupBox3_2;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_AutomaticRememberLine;
    QSpacerItem *spacer9;
    QCheckBox *kcfg_AutomaticRememberLineOnlyOnTextChange;
    QCheckBox *kcfg_MarkerLineInAllViews;
    QGroupBox *kcfg_AutoWhoContinuousEnabled;
    QGridLayout *gridLayout;
    QLabel *textLabel2;
    KPluralHandlingSpinBox *kcfg_AutoWhoNicksLimit;
    QSpacerItem *spacer2;
    QLabel *whoIntervalLbl;
    KPluralHandlingSpinBox *kcfg_AutoWhoContinuousInterval;
    QSpacerItem *spacer3;
    QSpacerItem *spacer6;

    void setupUi(QWidget *ChatwindowBehaviour_Config)
    {
        if (ChatwindowBehaviour_Config->objectName().isEmpty())
            ChatwindowBehaviour_Config->setObjectName(QStringLiteral("ChatwindowBehaviour_Config"));
        ChatwindowBehaviour_Config->resize(489, 534);
        verticalLayout_2 = new QVBoxLayout(ChatwindowBehaviour_Config);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupBox3 = new QGroupBox(ChatwindowBehaviour_Config);
        groupBox3->setObjectName(QStringLiteral("groupBox3"));
        gridLayout_3 = new QGridLayout(groupBox3);
        gridLayout_3->setObjectName(QStringLiteral("gridLayout_3"));
        kcfg_Beep = new QCheckBox(groupBox3);
        kcfg_Beep->setObjectName(QStringLiteral("kcfg_Beep"));

        gridLayout_3->addWidget(kcfg_Beep, 0, 0, 1, 4);

        kcfg_HideUnimportantEvents = new QCheckBox(groupBox3);
        kcfg_HideUnimportantEvents->setObjectName(QStringLiteral("kcfg_HideUnimportantEvents"));

        gridLayout_3->addWidget(kcfg_HideUnimportantEvents, 1, 0, 1, 3);

        horizontalSpacer = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 2, 0, 1, 1);

        kcfg_HideUnimportantEventsExcludeActive = new QCheckBox(groupBox3);
        kcfg_HideUnimportantEventsExcludeActive->setObjectName(QStringLiteral("kcfg_HideUnimportantEventsExcludeActive"));
        kcfg_HideUnimportantEventsExcludeActive->setEnabled(false);

        gridLayout_3->addWidget(kcfg_HideUnimportantEventsExcludeActive, 2, 1, 1, 3);

        kcfg_HideUnimportantEventsExcludeActiveThreshold = new KComboBox(groupBox3);
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setObjectName(QStringLiteral("kcfg_HideUnimportantEventsExcludeActiveThreshold"));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_HideUnimportantEventsExcludeActiveThreshold->sizePolicy().hasHeightForWidth());
        kcfg_HideUnimportantEventsExcludeActiveThreshold->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(kcfg_HideUnimportantEventsExcludeActiveThreshold, 2, 4, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 2, 5, 1, 1);

        kcfg_DisableExpansion = new QCheckBox(groupBox3);
        kcfg_DisableExpansion->setObjectName(QStringLiteral("kcfg_DisableExpansion"));

        gridLayout_3->addWidget(kcfg_DisableExpansion, 3, 0, 1, 4);

        kcfg_RedirectServerAndAppMsgToStatusPane = new QCheckBox(groupBox3);
        kcfg_RedirectServerAndAppMsgToStatusPane->setObjectName(QStringLiteral("kcfg_RedirectServerAndAppMsgToStatusPane"));

        gridLayout_3->addWidget(kcfg_RedirectServerAndAppMsgToStatusPane, 4, 0, 1, 4);

        kcfg_UseLiteralModes = new QCheckBox(groupBox3);
        kcfg_UseLiteralModes->setObjectName(QStringLiteral("kcfg_UseLiteralModes"));

        gridLayout_3->addWidget(kcfg_UseLiteralModes, 5, 0, 1, 5);

        spacer1_2 = new QSpacerItem(410, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(spacer1_2, 6, 0, 1, 5);

        textLabel1 = new QLabel(groupBox3);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        gridLayout_3->addWidget(textLabel1, 7, 0, 1, 2);

        kcfg_ScrollbackMax = new KPluralHandlingSpinBox(groupBox3);
        kcfg_ScrollbackMax->setObjectName(QStringLiteral("kcfg_ScrollbackMax"));
        kcfg_ScrollbackMax->setMinimumSize(QSize(120, 0));
        kcfg_ScrollbackMax->setMaximum(10000);

        gridLayout_3->addWidget(kcfg_ScrollbackMax, 7, 2, 1, 1);

        spacer1 = new QSpacerItem(230, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(spacer1, 7, 3, 1, 2);


        verticalLayout_2->addWidget(groupBox3);

        groupBox3_2 = new QGroupBox(ChatwindowBehaviour_Config);
        groupBox3_2->setObjectName(QStringLiteral("groupBox3_2"));
        gridLayout_2 = new QGridLayout(groupBox3_2);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        kcfg_AutomaticRememberLine = new QCheckBox(groupBox3_2);
        kcfg_AutomaticRememberLine->setObjectName(QStringLiteral("kcfg_AutomaticRememberLine"));

        gridLayout_2->addWidget(kcfg_AutomaticRememberLine, 0, 0, 1, 2);

        spacer9 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_2->addItem(spacer9, 1, 0, 1, 1);

        kcfg_AutomaticRememberLineOnlyOnTextChange = new QCheckBox(groupBox3_2);
        kcfg_AutomaticRememberLineOnlyOnTextChange->setObjectName(QStringLiteral("kcfg_AutomaticRememberLineOnlyOnTextChange"));
        kcfg_AutomaticRememberLineOnlyOnTextChange->setEnabled(false);

        gridLayout_2->addWidget(kcfg_AutomaticRememberLineOnlyOnTextChange, 1, 1, 1, 1);

        kcfg_MarkerLineInAllViews = new QCheckBox(groupBox3_2);
        kcfg_MarkerLineInAllViews->setObjectName(QStringLiteral("kcfg_MarkerLineInAllViews"));

        gridLayout_2->addWidget(kcfg_MarkerLineInAllViews, 2, 0, 1, 2);


        verticalLayout_2->addWidget(groupBox3_2);

        kcfg_AutoWhoContinuousEnabled = new QGroupBox(ChatwindowBehaviour_Config);
        kcfg_AutoWhoContinuousEnabled->setObjectName(QStringLiteral("kcfg_AutoWhoContinuousEnabled"));
        kcfg_AutoWhoContinuousEnabled->setCheckable(true);
        kcfg_AutoWhoContinuousEnabled->setChecked(false);
        gridLayout = new QGridLayout(kcfg_AutoWhoContinuousEnabled);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        textLabel2 = new QLabel(kcfg_AutoWhoContinuousEnabled);
        textLabel2->setObjectName(QStringLiteral("textLabel2"));
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 0, 0, 1, 1);

        kcfg_AutoWhoNicksLimit = new KPluralHandlingSpinBox(kcfg_AutoWhoContinuousEnabled);
        kcfg_AutoWhoNicksLimit->setObjectName(QStringLiteral("kcfg_AutoWhoNicksLimit"));
        kcfg_AutoWhoNicksLimit->setMinimumSize(QSize(140, 0));
        kcfg_AutoWhoNicksLimit->setMinimum(0);
        kcfg_AutoWhoNicksLimit->setMaximum(1000);
        kcfg_AutoWhoNicksLimit->setValue(300);

        gridLayout->addWidget(kcfg_AutoWhoNicksLimit, 0, 1, 1, 1);

        spacer2 = new QSpacerItem(190, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacer2, 0, 2, 1, 1);

        whoIntervalLbl = new QLabel(kcfg_AutoWhoContinuousEnabled);
        whoIntervalLbl->setObjectName(QStringLiteral("whoIntervalLbl"));
        whoIntervalLbl->setWordWrap(false);

        gridLayout->addWidget(whoIntervalLbl, 1, 0, 1, 1);

        kcfg_AutoWhoContinuousInterval = new KPluralHandlingSpinBox(kcfg_AutoWhoContinuousEnabled);
        kcfg_AutoWhoContinuousInterval->setObjectName(QStringLiteral("kcfg_AutoWhoContinuousInterval"));
        kcfg_AutoWhoContinuousInterval->setEnabled(false);
        kcfg_AutoWhoContinuousInterval->setMinimumSize(QSize(140, 0));
        kcfg_AutoWhoContinuousInterval->setMinimum(30);
        kcfg_AutoWhoContinuousInterval->setMaximum(1000);

        gridLayout->addWidget(kcfg_AutoWhoContinuousInterval, 1, 1, 1, 1);

        spacer3 = new QSpacerItem(170, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacer3, 1, 2, 1, 1);


        verticalLayout_2->addWidget(kcfg_AutoWhoContinuousEnabled);

        spacer6 = new QSpacerItem(41, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(spacer6);

#ifndef UI_QT_NO_SHORTCUT
        textLabel1->setBuddy(kcfg_ScrollbackMax);
        textLabel2->setBuddy(kcfg_AutoWhoNicksLimit);
        whoIntervalLbl->setBuddy(kcfg_AutoWhoContinuousInterval);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_Beep, kcfg_HideUnimportantEvents);
        QWidget::setTabOrder(kcfg_HideUnimportantEvents, kcfg_HideUnimportantEventsExcludeActive);
        QWidget::setTabOrder(kcfg_HideUnimportantEventsExcludeActive, kcfg_HideUnimportantEventsExcludeActiveThreshold);
        QWidget::setTabOrder(kcfg_HideUnimportantEventsExcludeActiveThreshold, kcfg_DisableExpansion);
        QWidget::setTabOrder(kcfg_DisableExpansion, kcfg_RedirectServerAndAppMsgToStatusPane);
        QWidget::setTabOrder(kcfg_RedirectServerAndAppMsgToStatusPane, kcfg_UseLiteralModes);
        QWidget::setTabOrder(kcfg_UseLiteralModes, kcfg_ScrollbackMax);
        QWidget::setTabOrder(kcfg_ScrollbackMax, kcfg_AutomaticRememberLine);
        QWidget::setTabOrder(kcfg_AutomaticRememberLine, kcfg_AutomaticRememberLineOnlyOnTextChange);
        QWidget::setTabOrder(kcfg_AutomaticRememberLineOnlyOnTextChange, kcfg_MarkerLineInAllViews);
        QWidget::setTabOrder(kcfg_MarkerLineInAllViews, kcfg_AutoWhoContinuousEnabled);
        QWidget::setTabOrder(kcfg_AutoWhoContinuousEnabled, kcfg_AutoWhoNicksLimit);
        QWidget::setTabOrder(kcfg_AutoWhoNicksLimit, kcfg_AutoWhoContinuousInterval);

        retranslateUi(ChatwindowBehaviour_Config);
        QObject::connect(kcfg_AutoWhoContinuousEnabled, SIGNAL(toggled(bool)), kcfg_AutoWhoContinuousInterval, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_AutomaticRememberLine, SIGNAL(toggled(bool)), kcfg_AutomaticRememberLineOnlyOnTextChange, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_HideUnimportantEvents, SIGNAL(toggled(bool)), kcfg_HideUnimportantEventsExcludeActive, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_HideUnimportantEvents, SIGNAL(toggled(bool)), kcfg_HideUnimportantEventsExcludeActiveThreshold, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ChatwindowBehaviour_Config);
    } // setupUi

    void retranslateUi(QWidget *ChatwindowBehaviour_Config)
    {
        groupBox3->setTitle(tr2i18n("General", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_Beep->setWhatsThis(tr2i18n("Sounds the system bell when you receive an ASCII BEL (0x07) control character", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_Beep->setText(tr2i18n("Enable s&ystem bell on incoming ASCII BEL", Q_NULLPTR));
        kcfg_HideUnimportantEvents->setText(tr2i18n("Hide &Join/Part/Nick events", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_HideUnimportantEventsExcludeActive->setWhatsThis(tr2i18n("If checked, only events concerning active and watched nicks will be displayed.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_HideUnimportantEventsExcludeActive->setText(tr2i18n("Except for watched nicks and nicks active within the", Q_NULLPTR));
        kcfg_HideUnimportantEventsExcludeActiveThreshold->clear();
        kcfg_HideUnimportantEventsExcludeActiveThreshold->insertItems(0, QStringList()
         << tr2i18n("last 10 min", "Is prefaced with: Except for watched nicks and nicks active within the")
         << tr2i18n("last hour", "Is prefaced with: Except for watched nicks and nicks active within the")
         << tr2i18n("last day", "Is prefaced with: Except for watched nicks and nicks active within the")
         << tr2i18n("last week", "Is prefaced with: Except for watched nicks and nicks active within the")
        );
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_DisableExpansion->setWhatsThis(tr2i18n("Do not expand variables when sending text to the server. A variable starts with '%'; for example, %B will expand to the characters needed to make a text bold.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_DisableExpansion->setText(tr2i18n("Disable variable (e.g. %C, %B, %G...) e&xpansion", Q_NULLPTR));
        kcfg_RedirectServerAndAppMsgToStatusPane->setText(tr2i18n("&Redirect status messages to the server status window", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_UseLiteralModes->setWhatsThis(tr2i18n("Keep channel mode string as a combination of characters instead of translating them into human readable words. E.g. '*** Channel modes: no messages from outside' will become '*** Channel modes: n'", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_UseLiteralModes->setText(tr2i18n("Show raw mode characters (e.g. +o) instead of descriptions", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        textLabel1->setWhatsThis(tr2i18n("How many lines to keep in buffers, 0 = unlimited", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        textLabel1->setText(tr2i18n("Scrollbac&k limit:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_ScrollbackMax->setWhatsThis(tr2i18n("How many lines to keep in buffers, 0 = unlimited", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_ScrollbackMax->setSpecialValueText(tr2i18n("Unlimited", Q_NULLPTR));
        groupBox3_2->setTitle(tr2i18n("Marker Lines", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_AutomaticRememberLine->setWhatsThis(tr2i18n("Inserts a remember line into the chat window when you switch to another chat window or minimize the application.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_AutomaticRememberLine->setText(tr2i18n("Mark the last position in a chat window when it is hidden", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        kcfg_AutomaticRememberLine->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        kcfg_AutomaticRememberLineOnlyOnTextChange->setText(tr2i18n("Move the line only when new text is about to be shown", Q_NULLPTR));
        kcfg_MarkerLineInAllViews->setText(tr2i18n("Show manually inserted lines in all chat windows", Q_NULLPTR));
        kcfg_AutoWhoContinuousEnabled->setTitle(tr2i18n("Enable Automatic User Information Look Up (/WHO)", Q_NULLPTR));
        textLabel2->setText(tr2i18n("&Max. number of users in a channel:", Q_NULLPTR));
        whoIntervalLbl->setText(tr2i18n("Update inter&val:", Q_NULLPTR));
        kcfg_AutoWhoContinuousInterval->setPrefix(QString());
        Q_UNUSED(ChatwindowBehaviour_Config);
    } // retranslateUi

};

namespace Ui {
    class ChatwindowBehaviour_Config: public Ui_ChatwindowBehaviour_Config {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHATWINDOWBEHAVIOUR_CONFIG_H

