/****************************************************************************
** Meta object code from reading C++ file 'whiteboardtoolbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/whiteboardtoolbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardtoolbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar_t {
    QByteArrayData data[43];
    char stringdata0[672];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar_t qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar = {
    {
QT_MOC_LITERAL(0, 0, 36), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(1, 37, 11), // "toolChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 52), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(4, 103, 4), // "tool"
QT_MOC_LITERAL(5, 108, 13), // "colorsSwapped"
QT_MOC_LITERAL(6, 122, 18), // "newForegroundColor"
QT_MOC_LITERAL(7, 141, 18), // "newBackgroundColor"
QT_MOC_LITERAL(8, 160, 22), // "foregroundColorChanged"
QT_MOC_LITERAL(9, 183, 5), // "color"
QT_MOC_LITERAL(10, 189, 22), // "backgroundColorChanged"
QT_MOC_LITERAL(11, 212, 11), // "fontChanged"
QT_MOC_LITERAL(12, 224, 4), // "font"
QT_MOC_LITERAL(13, 229, 16), // "lineWidthChanged"
QT_MOC_LITERAL(14, 246, 5), // "width"
QT_MOC_LITERAL(15, 252, 4), // "save"
QT_MOC_LITERAL(16, 257, 8), // "filename"
QT_MOC_LITERAL(17, 266, 5), // "clear"
QT_MOC_LITERAL(18, 272, 10), // "enableTool"
QT_MOC_LITERAL(19, 283, 11), // "disableTool"
QT_MOC_LITERAL(20, 295, 20), // "setSupportedTextType"
QT_MOC_LITERAL(21, 316, 46), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(22, 363, 8), // "textType"
QT_MOC_LITERAL(23, 372, 18), // "setForegroundColor"
QT_MOC_LITERAL(24, 391, 15), // "foregroundColor"
QT_MOC_LITERAL(25, 407, 18), // "setBackgroundColor"
QT_MOC_LITERAL(26, 426, 15), // "backgroundColor"
QT_MOC_LITERAL(27, 442, 12), // "clearClicked"
QT_MOC_LITERAL(28, 455, 11), // "saveClicked"
QT_MOC_LITERAL(29, 467, 13), // "pencilToggled"
QT_MOC_LITERAL(30, 481, 7), // "checked"
QT_MOC_LITERAL(31, 489, 11), // "lineToggled"
QT_MOC_LITERAL(32, 501, 16), // "rectangleToggled"
QT_MOC_LITERAL(33, 518, 14), // "ellipseToggled"
QT_MOC_LITERAL(34, 533, 11), // "textToggled"
QT_MOC_LITERAL(35, 545, 16), // "selectionToggled"
QT_MOC_LITERAL(36, 562, 12), // "eraseToggled"
QT_MOC_LITERAL(37, 575, 11), // "fillToggled"
QT_MOC_LITERAL(38, 587, 12), // "arrowToggled"
QT_MOC_LITERAL(39, 600, 18), // "colorPickerToggled"
QT_MOC_LITERAL(40, 619, 21), // "updateLineWidthPixmap"
QT_MOC_LITERAL(41, 641, 9), // "lineWidth"
QT_MOC_LITERAL(42, 651, 20) // "formSelectionChanged"

    },
    "Konversation::DCC::WhiteBoardToolBar\0"
    "toolChanged\0\0"
    "Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool\0"
    "tool\0colorsSwapped\0newForegroundColor\0"
    "newBackgroundColor\0foregroundColorChanged\0"
    "color\0backgroundColorChanged\0fontChanged\0"
    "font\0lineWidthChanged\0width\0save\0"
    "filename\0clear\0enableTool\0disableTool\0"
    "setSupportedTextType\0"
    "Konversation::DCC::WhiteBoardToolBar::TextType\0"
    "textType\0setForegroundColor\0foregroundColor\0"
    "setBackgroundColor\0backgroundColor\0"
    "clearClicked\0saveClicked\0pencilToggled\0"
    "checked\0lineToggled\0rectangleToggled\0"
    "ellipseToggled\0textToggled\0selectionToggled\0"
    "eraseToggled\0fillToggled\0arrowToggled\0"
    "colorPickerToggled\0updateLineWidthPixmap\0"
    "lineWidth\0formSelectionChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__WhiteBoardToolBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  154,    2, 0x06 /* Public */,
       5,    2,  157,    2, 0x06 /* Public */,
       8,    1,  162,    2, 0x06 /* Public */,
      10,    1,  165,    2, 0x06 /* Public */,
      11,    1,  168,    2, 0x06 /* Public */,
      13,    1,  171,    2, 0x06 /* Public */,
      15,    1,  174,    2, 0x06 /* Public */,
      17,    0,  177,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    1,  178,    2, 0x0a /* Public */,
      19,    1,  181,    2, 0x0a /* Public */,
      20,    1,  184,    2, 0x0a /* Public */,
      22,    0,  187,    2, 0x0a /* Public */,
      23,    1,  188,    2, 0x0a /* Public */,
      25,    1,  191,    2, 0x0a /* Public */,
      27,    0,  194,    2, 0x09 /* Protected */,
      28,    0,  195,    2, 0x09 /* Protected */,
      29,    1,  196,    2, 0x09 /* Protected */,
      31,    1,  199,    2, 0x09 /* Protected */,
      32,    1,  202,    2, 0x09 /* Protected */,
      33,    1,  205,    2, 0x09 /* Protected */,
      34,    1,  208,    2, 0x09 /* Protected */,
      35,    1,  211,    2, 0x09 /* Protected */,
      36,    1,  214,    2, 0x09 /* Protected */,
      37,    1,  217,    2, 0x09 /* Protected */,
      38,    1,  220,    2, 0x09 /* Protected */,
      39,    1,  223,    2, 0x09 /* Protected */,
      40,    1,  226,    2, 0x09 /* Protected */,
      42,    0,  229,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QColor, QMetaType::QColor,    6,    7,
    QMetaType::Void, QMetaType::QColor,    9,
    QMetaType::Void, QMetaType::QColor,    9,
    QMetaType::Void, QMetaType::QFont,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 21,   22,
    0x80000000 | 21,
    QMetaType::Void, QMetaType::QColor,   24,
    QMetaType::Void, QMetaType::QColor,   26,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Int,   41,
    QMetaType::Void,

       0        // eod
};

void Konversation::DCC::WhiteBoardToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhiteBoardToolBar *_t = static_cast<WhiteBoardToolBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->toolChanged((*reinterpret_cast< Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool(*)>(_a[1]))); break;
        case 1: _t->colorsSwapped((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 2: _t->foregroundColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 3: _t->backgroundColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 4: _t->fontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 5: _t->lineWidthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->save((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->clear(); break;
        case 8: _t->enableTool((*reinterpret_cast< Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool(*)>(_a[1]))); break;
        case 9: _t->disableTool((*reinterpret_cast< Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool(*)>(_a[1]))); break;
        case 10: _t->setSupportedTextType((*reinterpret_cast< Konversation::DCC::WhiteBoardToolBar::TextType(*)>(_a[1]))); break;
        case 11: { Konversation::DCC::WhiteBoardToolBar::TextType _r = _t->textType();
            if (_a[0]) *reinterpret_cast< Konversation::DCC::WhiteBoardToolBar::TextType*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 13: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 14: _t->clearClicked(); break;
        case 15: _t->saveClicked(); break;
        case 16: _t->pencilToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->lineToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->rectangleToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->ellipseToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->textToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->selectionToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->eraseToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->fillToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->arrowToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->colorPickerToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->updateLineWidthPixmap((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->formSelectionChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhiteBoardToolBar::*_t)(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::toolChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(const QColor & , const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::colorsSwapped)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::foregroundColorChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::backgroundColorChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::fontChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::lineWidthChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::save)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (WhiteBoardToolBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardToolBar::clear)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::WhiteBoardToolBar::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar.data,
      qt_meta_data_Konversation__DCC__WhiteBoardToolBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::WhiteBoardToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__WhiteBoardToolBar.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WhiteBoardToolBarUi"))
        return static_cast< Ui::WhiteBoardToolBarUi*>(this);
    return QWidget::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardToolBar::toolChanged(Konversation::DCC::WhiteBoardGlobals::WhiteBoardTool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::WhiteBoardToolBar::colorsSwapped(const QColor & _t1, const QColor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::WhiteBoardToolBar::foregroundColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Konversation::DCC::WhiteBoardToolBar::backgroundColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Konversation::DCC::WhiteBoardToolBar::fontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Konversation::DCC::WhiteBoardToolBar::lineWidthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Konversation::DCC::WhiteBoardToolBar::save(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Konversation::DCC::WhiteBoardToolBar::clear()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
