/****************************************************************************
** Meta object code from reading C++ file 'connectionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/connectionmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'connectionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ConnectionManager_t {
    QByteArrayData data[39];
    char stringdata0[543];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ConnectionManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ConnectionManager_t qt_meta_stringdata_ConnectionManager = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ConnectionManager"
QT_MOC_LITERAL(1, 18, 21), // "connectionListChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 22), // "connectionChangedState"
QT_MOC_LITERAL(4, 64, 7), // "Server*"
QT_MOC_LITERAL(5, 72, 6), // "server"
QT_MOC_LITERAL(6, 79, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(7, 109, 5), // "state"
QT_MOC_LITERAL(8, 115, 26), // "connectionChangedAwayState"
QT_MOC_LITERAL(9, 142, 4), // "away"
QT_MOC_LITERAL(10, 147, 16), // "requestReconnect"
QT_MOC_LITERAL(11, 164, 14), // "identityOnline"
QT_MOC_LITERAL(12, 179, 10), // "identityId"
QT_MOC_LITERAL(13, 190, 15), // "identityOffline"
QT_MOC_LITERAL(14, 206, 15), // "closeServerList"
QT_MOC_LITERAL(15, 222, 9), // "connectTo"
QT_MOC_LITERAL(16, 232, 28), // "Konversation::ConnectionFlag"
QT_MOC_LITERAL(17, 261, 4), // "flag"
QT_MOC_LITERAL(18, 266, 6), // "target"
QT_MOC_LITERAL(19, 273, 4), // "port"
QT_MOC_LITERAL(20, 278, 8), // "password"
QT_MOC_LITERAL(21, 287, 4), // "nick"
QT_MOC_LITERAL(22, 292, 7), // "channel"
QT_MOC_LITERAL(23, 300, 6), // "useSSL"
QT_MOC_LITERAL(24, 307, 13), // "serverGroupId"
QT_MOC_LITERAL(25, 321, 11), // "QList<QUrl>"
QT_MOC_LITERAL(26, 333, 4), // "list"
QT_MOC_LITERAL(27, 338, 18), // "ConnectionSettings"
QT_MOC_LITERAL(28, 357, 8), // "settings"
QT_MOC_LITERAL(29, 366, 11), // "quitServers"
QT_MOC_LITERAL(30, 378, 16), // "reconnectServers"
QT_MOC_LITERAL(31, 395, 22), // "involuntaryQuitServers"
QT_MOC_LITERAL(32, 418, 20), // "reconnectInvoluntary"
QT_MOC_LITERAL(33, 439, 16), // "delistConnection"
QT_MOC_LITERAL(34, 456, 12), // "connectionId"
QT_MOC_LITERAL(35, 469, 27), // "handleConnectionStateChange"
QT_MOC_LITERAL(36, 497, 15), // "handleReconnect"
QT_MOC_LITERAL(37, 513, 20), // "onOnlineStateChanged"
QT_MOC_LITERAL(38, 534, 8) // "isOnline"

    },
    "ConnectionManager\0connectionListChanged\0"
    "\0connectionChangedState\0Server*\0server\0"
    "Konversation::ConnectionState\0state\0"
    "connectionChangedAwayState\0away\0"
    "requestReconnect\0identityOnline\0"
    "identityId\0identityOffline\0closeServerList\0"
    "connectTo\0Konversation::ConnectionFlag\0"
    "flag\0target\0port\0password\0nick\0channel\0"
    "useSSL\0serverGroupId\0QList<QUrl>\0list\0"
    "ConnectionSettings\0settings\0quitServers\0"
    "reconnectServers\0involuntaryQuitServers\0"
    "reconnectInvoluntary\0delistConnection\0"
    "connectionId\0handleConnectionStateChange\0"
    "handleReconnect\0onOnlineStateChanged\0"
    "isOnline"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ConnectionManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  134,    2, 0x06 /* Public */,
       3,    2,  135,    2, 0x06 /* Public */,
       8,    1,  140,    2, 0x06 /* Public */,
      10,    1,  143,    2, 0x06 /* Public */,
      11,    1,  146,    2, 0x06 /* Public */,
      13,    1,  149,    2, 0x06 /* Public */,
      14,    0,  152,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    7,  153,    2, 0x0a /* Public */,
      15,    6,  168,    2, 0x2a /* Public | MethodCloned */,
      15,    5,  181,    2, 0x2a /* Public | MethodCloned */,
      15,    4,  192,    2, 0x2a /* Public | MethodCloned */,
      15,    3,  201,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  208,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  213,    2, 0x0a /* Public */,
      15,    2,  218,    2, 0x0a /* Public */,
      15,    2,  223,    2, 0x0a /* Public */,
      29,    0,  228,    2, 0x0a /* Public */,
      30,    0,  229,    2, 0x0a /* Public */,
      31,    0,  230,    2, 0x0a /* Public */,
      32,    0,  231,    2, 0x0a /* Public */,
      33,    1,  232,    2, 0x08 /* Private */,
      35,    2,  235,    2, 0x08 /* Private */,
      36,    1,  240,    2, 0x08 /* Private */,
      37,    1,  243,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 6,    5,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   17,   18,   19,   20,   21,   22,   23,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   17,   18,   19,   20,   21,   22,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   17,   18,   19,   20,   21,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString, QMetaType::QString,   17,   18,   19,   20,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString,   17,   18,   19,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString,   17,   18,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int,   17,   24,
    QMetaType::Void, 0x80000000 | 16, 0x80000000 | 25,   17,   26,
    QMetaType::Void, 0x80000000 | 16, 0x80000000 | 27,   17,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 6,    5,    7,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Bool,   38,

       0        // eod
};

void ConnectionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConnectionManager *_t = static_cast<ConnectionManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connectionListChanged(); break;
        case 1: _t->connectionChangedState((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 2: _t->connectionChangedAwayState((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->requestReconnect((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 4: _t->identityOnline((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->identityOffline((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->closeServerList(); break;
        case 7: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 8: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 9: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 10: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 11: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 12: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 14: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2]))); break;
        case 15: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< ConnectionSettings(*)>(_a[2]))); break;
        case 16: _t->quitServers(); break;
        case 17: _t->reconnectServers(); break;
        case 18: _t->involuntaryQuitServers(); break;
        case 19: _t->reconnectInvoluntary(); break;
        case 20: _t->delistConnection((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->handleConnectionStateChange((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 22: _t->handleReconnect((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 23: _t->onOnlineStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ConnectionManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::connectionListChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)(Server * , Konversation::ConnectionState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::connectionChangedState)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::connectionChangedAwayState)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::requestReconnect)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::identityOnline)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::identityOffline)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ConnectionManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConnectionManager::closeServerList)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject ConnectionManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_ConnectionManager.data,
      qt_meta_data_ConnectionManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ConnectionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConnectionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ConnectionManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ConnectionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void ConnectionManager::connectionListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ConnectionManager::connectionChangedState(Server * _t1, Konversation::ConnectionState _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ConnectionManager::connectionChangedAwayState(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ConnectionManager::requestReconnect(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void ConnectionManager::identityOnline(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void ConnectionManager::identityOffline(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void ConnectionManager::closeServerList()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
