/****************************************************************************
** Meta object code from reading C++ file 'upnprouter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/upnp/upnprouter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'upnprouter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__UPnP__UPnPRouter_t {
    QByteArrayData data[21];
    char stringdata0[223];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__UPnP__UPnPRouter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__UPnP__UPnPRouter_t qt_meta_stringdata_Konversation__UPnP__UPnPRouter = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Konversation::UPnP::UPnPRouter"
QT_MOC_LITERAL(1, 31, 17), // "xmlFileDownloaded"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 11), // "UPnPRouter*"
QT_MOC_LITERAL(4, 62, 1), // "r"
QT_MOC_LITERAL(5, 64, 7), // "success"
QT_MOC_LITERAL(6, 72, 15), // "forwardComplete"
QT_MOC_LITERAL(7, 88, 5), // "error"
QT_MOC_LITERAL(8, 94, 4), // "port"
QT_MOC_LITERAL(9, 99, 17), // "unforwardComplete"
QT_MOC_LITERAL(10, 117, 17), // "onRequestFinished"
QT_MOC_LITERAL(11, 135, 5), // "KJob*"
QT_MOC_LITERAL(12, 141, 5), // "reply"
QT_MOC_LITERAL(13, 147, 16), // "downloadFinished"
QT_MOC_LITERAL(14, 164, 1), // "j"
QT_MOC_LITERAL(15, 166, 12), // "sendSoapData"
QT_MOC_LITERAL(16, 179, 9), // "KIO::Job*"
QT_MOC_LITERAL(17, 189, 3), // "job"
QT_MOC_LITERAL(18, 193, 11), // "QByteArray&"
QT_MOC_LITERAL(19, 205, 4), // "data"
QT_MOC_LITERAL(20, 210, 12) // "recvSoapData"

    },
    "Konversation::UPnP::UPnPRouter\0"
    "xmlFileDownloaded\0\0UPnPRouter*\0r\0"
    "success\0forwardComplete\0error\0port\0"
    "unforwardComplete\0onRequestFinished\0"
    "KJob*\0reply\0downloadFinished\0j\0"
    "sendSoapData\0KIO::Job*\0job\0QByteArray&\0"
    "data\0recvSoapData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__UPnP__UPnPRouter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x06 /* Public */,
       6,    2,   54,    2, 0x06 /* Public */,
       9,    2,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   64,    2, 0x08 /* Private */,
      13,    1,   67,    2, 0x08 /* Private */,
      15,    2,   70,    2, 0x08 /* Private */,
      20,    2,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    5,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,    7,    8,
    QMetaType::Void, QMetaType::Bool, QMetaType::UShort,    7,    8,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 11,   14,
    QMetaType::Void, 0x80000000 | 16, 0x80000000 | 18,   17,   19,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QByteArray,   17,   19,

       0        // eod
};

void Konversation::UPnP::UPnPRouter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UPnPRouter *_t = static_cast<UPnPRouter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->xmlFileDownloaded((*reinterpret_cast< UPnPRouter*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->forwardComplete((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        case 2: _t->unforwardComplete((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< quint16(*)>(_a[2]))); break;
        case 3: _t->onRequestFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 4: _t->downloadFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 5: _t->sendSoapData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< QByteArray(*)>(_a[2]))); break;
        case 6: _t->recvSoapData((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UPnPRouter* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIO::Job* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KIO::Job* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (UPnPRouter::*_t)(UPnPRouter * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UPnPRouter::xmlFileDownloaded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (UPnPRouter::*_t)(bool , quint16 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UPnPRouter::forwardComplete)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (UPnPRouter::*_t)(bool , quint16 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UPnPRouter::unforwardComplete)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Konversation::UPnP::UPnPRouter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__UPnP__UPnPRouter.data,
      qt_meta_data_Konversation__UPnP__UPnPRouter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::UPnP::UPnPRouter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::UPnP::UPnPRouter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__UPnP__UPnPRouter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::UPnP::UPnPRouter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Konversation::UPnP::UPnPRouter::xmlFileDownloaded(UPnPRouter * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::UPnP::UPnPRouter::forwardComplete(bool _t1, quint16 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::UPnP::UPnPRouter::unforwardComplete(bool _t1, quint16 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
