/****************************************************************************
** Meta object code from reading C++ file 'joinchanneldialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/joinchanneldialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'joinchanneldialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__JoinChannelDialog_t {
    QByteArrayData data[10];
    char stringdata0[175];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__JoinChannelDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__JoinChannelDialog_t qt_meta_stringdata_Konversation__JoinChannelDialog = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Konversation::JoinChannelDialog"
QT_MOC_LITERAL(1, 32, 6), // "slotOk"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 19), // "slotNicknameChanged"
QT_MOC_LITERAL(4, 60, 8), // "nickname"
QT_MOC_LITERAL(5, 69, 25), // "slotConnectionListChanged"
QT_MOC_LITERAL(6, 95, 29), // "slotSelectedConnectionChanged"
QT_MOC_LITERAL(7, 125, 18), // "slotChannelChanged"
QT_MOC_LITERAL(8, 144, 4), // "text"
QT_MOC_LITERAL(9, 149, 25) // "slotChannelHistoryCleared"

    },
    "Konversation::JoinChannelDialog\0slotOk\0"
    "\0slotNicknameChanged\0nickname\0"
    "slotConnectionListChanged\0"
    "slotSelectedConnectionChanged\0"
    "slotChannelChanged\0text\0"
    "slotChannelHistoryCleared"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__JoinChannelDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x09 /* Protected */,
       3,    1,   45,    2, 0x09 /* Protected */,
       5,    0,   48,    2, 0x09 /* Protected */,
       6,    1,   49,    2, 0x09 /* Protected */,
       7,    1,   52,    2, 0x09 /* Protected */,
       9,    0,   55,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,

       0        // eod
};

void Konversation::JoinChannelDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JoinChannelDialog *_t = static_cast<JoinChannelDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOk(); break;
        case 1: _t->slotNicknameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->slotConnectionListChanged(); break;
        case 3: _t->slotSelectedConnectionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->slotChannelChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotChannelHistoryCleared(); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::JoinChannelDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__JoinChannelDialog.data,
      qt_meta_data_Konversation__JoinChannelDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::JoinChannelDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::JoinChannelDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__JoinChannelDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::JoinChannelDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
