/****************************************************************************
** Meta object code from reading C++ file 'server.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/server.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'server.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Server_t {
    QByteArrayData data[221];
    char stringdata0[2878];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Server_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Server_t qt_meta_stringdata_Server = {
    {
QT_MOC_LITERAL(0, 0, 6), // "Server"
QT_MOC_LITERAL(1, 7, 9), // "destroyed"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 12), // "connectionId"
QT_MOC_LITERAL(4, 31, 15), // "nicknameChanged"
QT_MOC_LITERAL(5, 47, 9), // "serverLag"
QT_MOC_LITERAL(6, 57, 7), // "Server*"
QT_MOC_LITERAL(7, 65, 6), // "server"
QT_MOC_LITERAL(8, 72, 4), // "msec"
QT_MOC_LITERAL(9, 77, 10), // "tooLongLag"
QT_MOC_LITERAL(10, 88, 8), // "resetLag"
QT_MOC_LITERAL(11, 97, 14), // "nicksNowOnline"
QT_MOC_LITERAL(12, 112, 4), // "list"
QT_MOC_LITERAL(13, 117, 7), // "changed"
QT_MOC_LITERAL(14, 125, 9), // "awayState"
QT_MOC_LITERAL(15, 135, 4), // "away"
QT_MOC_LITERAL(16, 140, 18), // "multiServerCommand"
QT_MOC_LITERAL(17, 159, 7), // "command"
QT_MOC_LITERAL(18, 167, 9), // "parameter"
QT_MOC_LITERAL(19, 177, 12), // "serverOnline"
QT_MOC_LITERAL(20, 190, 5), // "state"
QT_MOC_LITERAL(21, 196, 8), // "sentStat"
QT_MOC_LITERAL(22, 205, 5), // "bytes"
QT_MOC_LITERAL(23, 211, 12), // "encodedBytes"
QT_MOC_LITERAL(24, 224, 9), // "IRCQueue*"
QT_MOC_LITERAL(25, 234, 10), // "whichQueue"
QT_MOC_LITERAL(26, 245, 15), // "nickInfoChanged"
QT_MOC_LITERAL(27, 261, 11), // "NickInfoPtr"
QT_MOC_LITERAL(28, 273, 8), // "nickInfo"
QT_MOC_LITERAL(29, 282, 18), // "channelNickChanged"
QT_MOC_LITERAL(30, 301, 7), // "channel"
QT_MOC_LITERAL(31, 309, 21), // "channelMembersChanged"
QT_MOC_LITERAL(32, 331, 11), // "channelName"
QT_MOC_LITERAL(33, 343, 6), // "joined"
QT_MOC_LITERAL(34, 350, 6), // "parted"
QT_MOC_LITERAL(35, 357, 8), // "nickname"
QT_MOC_LITERAL(36, 366, 23), // "channelJoinedOrUnjoined"
QT_MOC_LITERAL(37, 390, 18), // "watchedNickChanged"
QT_MOC_LITERAL(38, 409, 6), // "online"
QT_MOC_LITERAL(39, 416, 22), // "awayInsertRememberLine"
QT_MOC_LITERAL(40, 439, 14), // "sslInitFailure"
QT_MOC_LITERAL(41, 454, 12), // "sslConnected"
QT_MOC_LITERAL(42, 467, 22), // "connectionStateChanged"
QT_MOC_LITERAL(43, 490, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(44, 520, 8), // "showView"
QT_MOC_LITERAL(45, 529, 11), // "ChatWindow*"
QT_MOC_LITERAL(46, 541, 4), // "view"
QT_MOC_LITERAL(47, 546, 11), // "addDccPanel"
QT_MOC_LITERAL(48, 558, 10), // "addDccChat"
QT_MOC_LITERAL(49, 569, 24), // "Konversation::DCC::Chat*"
QT_MOC_LITERAL(50, 594, 4), // "chat"
QT_MOC_LITERAL(51, 599, 18), // "connectToIRCServer"
QT_MOC_LITERAL(52, 618, 20), // "connectToIRCServerIn"
QT_MOC_LITERAL(53, 639, 5), // "delay"
QT_MOC_LITERAL(54, 645, 5), // "queue"
QT_MOC_LITERAL(55, 651, 4), // "line"
QT_MOC_LITERAL(56, 656, 13), // "QueuePriority"
QT_MOC_LITERAL(57, 670, 8), // "priority"
QT_MOC_LITERAL(58, 679, 9), // "queueList"
QT_MOC_LITERAL(59, 689, 6), // "buffer"
QT_MOC_LITERAL(60, 696, 11), // "setNickname"
QT_MOC_LITERAL(61, 708, 11), // "newNickname"
QT_MOC_LITERAL(62, 720, 8), // "addQuery"
QT_MOC_LITERAL(63, 729, 6), // "Query*"
QT_MOC_LITERAL(64, 736, 11), // "weinitiated"
QT_MOC_LITERAL(65, 748, 10), // "closeQuery"
QT_MOC_LITERAL(66, 759, 4), // "name"
QT_MOC_LITERAL(67, 764, 12), // "closeChannel"
QT_MOC_LITERAL(68, 777, 15), // "reconnectServer"
QT_MOC_LITERAL(69, 793, 11), // "quitMessage"
QT_MOC_LITERAL(70, 805, 16), // "disconnectServer"
QT_MOC_LITERAL(71, 822, 10), // "quitServer"
QT_MOC_LITERAL(72, 833, 11), // "openDccChat"
QT_MOC_LITERAL(73, 845, 13), // "openDccWBoard"
QT_MOC_LITERAL(74, 859, 14), // "requestDccChat"
QT_MOC_LITERAL(75, 874, 11), // "partnerNick"
QT_MOC_LITERAL(76, 886, 9), // "extension"
QT_MOC_LITERAL(77, 896, 14), // "numericalOwnIp"
QT_MOC_LITERAL(78, 911, 7), // "ownPort"
QT_MOC_LITERAL(79, 919, 12), // "acceptDccGet"
QT_MOC_LITERAL(80, 932, 4), // "nick"
QT_MOC_LITERAL(81, 937, 4), // "file"
QT_MOC_LITERAL(82, 942, 10), // "requestBan"
QT_MOC_LITERAL(83, 953, 5), // "users"
QT_MOC_LITERAL(84, 959, 6), // "option"
QT_MOC_LITERAL(85, 966, 12), // "requestUnban"
QT_MOC_LITERAL(86, 979, 4), // "mask"
QT_MOC_LITERAL(87, 984, 10), // "addDccSend"
QT_MOC_LITERAL(88, 995, 9), // "recipient"
QT_MOC_LITERAL(89, 1005, 7), // "fileURL"
QT_MOC_LITERAL(90, 1013, 7), // "passive"
QT_MOC_LITERAL(91, 1021, 11), // "altFileName"
QT_MOC_LITERAL(92, 1033, 8), // "fileSize"
QT_MOC_LITERAL(93, 1042, 11), // "removeQuery"
QT_MOC_LITERAL(94, 1054, 5), // "query"
QT_MOC_LITERAL(95, 1060, 17), // "notifyListStarted"
QT_MOC_LITERAL(96, 1078, 13), // "serverGroupId"
QT_MOC_LITERAL(97, 1092, 16), // "startNotifyTimer"
QT_MOC_LITERAL(98, 1109, 13), // "notifyTimeout"
QT_MOC_LITERAL(99, 1123, 15), // "sendJoinCommand"
QT_MOC_LITERAL(100, 1139, 8), // "password"
QT_MOC_LITERAL(101, 1148, 11), // "requestAway"
QT_MOC_LITERAL(102, 1160, 6), // "reason"
QT_MOC_LITERAL(103, 1167, 13), // "requestUnaway"
QT_MOC_LITERAL(104, 1181, 18), // "requestChannelList"
QT_MOC_LITERAL(105, 1200, 12), // "requestWhois"
QT_MOC_LITERAL(106, 1213, 10), // "requestWho"
QT_MOC_LITERAL(107, 1224, 15), // "requestUserhost"
QT_MOC_LITERAL(108, 1240, 5), // "nicks"
QT_MOC_LITERAL(109, 1246, 12), // "requestTopic"
QT_MOC_LITERAL(110, 1259, 15), // "resolveUserhost"
QT_MOC_LITERAL(111, 1275, 9), // "addRawLog"
QT_MOC_LITERAL(112, 1285, 4), // "show"
QT_MOC_LITERAL(113, 1290, 11), // "closeRawLog"
QT_MOC_LITERAL(114, 1302, 16), // "addToChannelList"
QT_MOC_LITERAL(115, 1319, 5), // "topic"
QT_MOC_LITERAL(116, 1325, 21), // "closeChannelListPanel"
QT_MOC_LITERAL(117, 1347, 22), // "sendMultiServerCommand"
QT_MOC_LITERAL(118, 1370, 25), // "executeMultiServerCommand"
QT_MOC_LITERAL(119, 1396, 13), // "showSSLDialog"
QT_MOC_LITERAL(120, 1410, 17), // "sendToAllChannels"
QT_MOC_LITERAL(121, 1428, 4), // "text"
QT_MOC_LITERAL(122, 1433, 27), // "sendToAllChannelsAndQueries"
QT_MOC_LITERAL(123, 1461, 17), // "enableIdentifyMsg"
QT_MOC_LITERAL(124, 1479, 7), // "enabled"
QT_MOC_LITERAL(125, 1487, 18), // "identifyMsgEnabled"
QT_MOC_LITERAL(126, 1506, 6), // "addBan"
QT_MOC_LITERAL(127, 1513, 3), // "ban"
QT_MOC_LITERAL(128, 1517, 9), // "removeBan"
QT_MOC_LITERAL(129, 1527, 12), // "pongReceived"
QT_MOC_LITERAL(130, 1540, 15), // "initKeyExchange"
QT_MOC_LITERAL(131, 1556, 8), // "receiver"
QT_MOC_LITERAL(132, 1565, 13), // "parseInitKeyX"
QT_MOC_LITERAL(133, 1579, 6), // "sender"
QT_MOC_LITERAL(134, 1586, 6), // "pubKey"
QT_MOC_LITERAL(135, 1593, 15), // "parseFinishKeyX"
QT_MOC_LITERAL(136, 1609, 25), // "startNickInfoChangedTimer"
QT_MOC_LITERAL(137, 1635, 28), // "startChannelNickChangedTimer"
QT_MOC_LITERAL(138, 1664, 15), // "involuntaryQuit"
QT_MOC_LITERAL(139, 1680, 20), // "reconnectInvoluntary"
QT_MOC_LITERAL(140, 1701, 26), // "requestAvailableCapabilies"
QT_MOC_LITERAL(141, 1728, 22), // "capInitiateNegotiation"
QT_MOC_LITERAL(142, 1751, 13), // "availableCaps"
QT_MOC_LITERAL(143, 1765, 8), // "capReply"
QT_MOC_LITERAL(144, 1774, 17), // "capEndNegotiation"
QT_MOC_LITERAL(145, 1792, 15), // "capCheckIgnored"
QT_MOC_LITERAL(146, 1808, 15), // "capAcknowledged"
QT_MOC_LITERAL(147, 1824, 12), // "CapModifiers"
QT_MOC_LITERAL(148, 1837, 9), // "modifiers"
QT_MOC_LITERAL(149, 1847, 9), // "capDenied"
QT_MOC_LITERAL(150, 1857, 16), // "sendAuthenticate"
QT_MOC_LITERAL(151, 1874, 7), // "message"
QT_MOC_LITERAL(152, 1882, 9), // "hostFound"
QT_MOC_LITERAL(153, 1892, 21), // "preShellCommandExited"
QT_MOC_LITERAL(154, 1914, 8), // "exitCode"
QT_MOC_LITERAL(155, 1923, 20), // "QProcess::ExitStatus"
QT_MOC_LITERAL(156, 1944, 10), // "exitStatus"
QT_MOC_LITERAL(157, 1955, 20), // "preShellCommandError"
QT_MOC_LITERAL(158, 1976, 22), // "QProcess::ProcessError"
QT_MOC_LITERAL(159, 1999, 4), // "eror"
QT_MOC_LITERAL(160, 2004, 15), // "socketConnected"
QT_MOC_LITERAL(161, 2020, 14), // "startAwayTimer"
QT_MOC_LITERAL(162, 2035, 8), // "incoming"
QT_MOC_LITERAL(163, 2044, 19), // "processIncomingData"
QT_MOC_LITERAL(164, 2064, 8), // "toServer"
QT_MOC_LITERAL(165, 2073, 8), // "QString&"
QT_MOC_LITERAL(166, 2082, 6), // "closed"
QT_MOC_LITERAL(167, 2089, 6), // "broken"
QT_MOC_LITERAL(168, 2096, 17), // "KTcpSocket::Error"
QT_MOC_LITERAL(169, 2114, 5), // "error"
QT_MOC_LITERAL(170, 2120, 8), // "sslError"
QT_MOC_LITERAL(171, 2129, 16), // "QList<KSslError>"
QT_MOC_LITERAL(172, 2146, 21), // "connectionEstablished"
QT_MOC_LITERAL(173, 2168, 7), // "ownHost"
QT_MOC_LITERAL(174, 2176, 14), // "notifyResponse"
QT_MOC_LITERAL(175, 2191, 11), // "nicksOnline"
QT_MOC_LITERAL(176, 2203, 28), // "slotNewDccTransferItemQueued"
QT_MOC_LITERAL(177, 2232, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(178, 2261, 8), // "transfer"
QT_MOC_LITERAL(179, 2270, 27), // "startReverseDccSendTransfer"
QT_MOC_LITERAL(180, 2298, 10), // "sourceNick"
QT_MOC_LITERAL(181, 2309, 12), // "dccArguments"
QT_MOC_LITERAL(182, 2322, 19), // "startReverseDccChat"
QT_MOC_LITERAL(183, 2342, 11), // "dccArgument"
QT_MOC_LITERAL(184, 2354, 9), // "addDccGet"
QT_MOC_LITERAL(185, 2364, 14), // "requestDccSend"
QT_MOC_LITERAL(186, 2379, 20), // "resumeDccGetTransfer"
QT_MOC_LITERAL(187, 2400, 21), // "resumeDccSendTransfer"
QT_MOC_LITERAL(188, 2422, 21), // "rejectDccSendTransfer"
QT_MOC_LITERAL(189, 2444, 10), // "dccGetDone"
QT_MOC_LITERAL(190, 2455, 4), // "item"
QT_MOC_LITERAL(191, 2460, 11), // "dccSendDone"
QT_MOC_LITERAL(192, 2472, 16), // "dccStatusChanged"
QT_MOC_LITERAL(193, 2489, 9), // "newStatus"
QT_MOC_LITERAL(194, 2499, 9), // "oldStatus"
QT_MOC_LITERAL(195, 2509, 9), // "arguments"
QT_MOC_LITERAL(196, 2519, 13), // "rejectDccChat"
QT_MOC_LITERAL(197, 2533, 14), // "scriptNotFound"
QT_MOC_LITERAL(198, 2548, 20), // "scriptExecutionError"
QT_MOC_LITERAL(199, 2569, 8), // "userhost"
QT_MOC_LITERAL(200, 2578, 8), // "hostmask"
QT_MOC_LITERAL(201, 2587, 5), // "ircOp"
QT_MOC_LITERAL(202, 2593, 14), // "setTopicAuthor"
QT_MOC_LITERAL(203, 2608, 6), // "author"
QT_MOC_LITERAL(204, 2615, 1), // "t"
QT_MOC_LITERAL(205, 2617, 8), // "endOfWho"
QT_MOC_LITERAL(206, 2626, 6), // "target"
QT_MOC_LITERAL(207, 2633, 10), // "endOfNames"
QT_MOC_LITERAL(208, 2644, 10), // "invitation"
QT_MOC_LITERAL(209, 2655, 27), // "gotOwnResolvedHostByWelcome"
QT_MOC_LITERAL(210, 2683, 9), // "QHostInfo"
QT_MOC_LITERAL(211, 2693, 3), // "res"
QT_MOC_LITERAL(212, 2697, 28), // "gotOwnResolvedHostByUserhost"
QT_MOC_LITERAL(213, 2726, 8), // "sendPing"
QT_MOC_LITERAL(214, 2735, 17), // "updateLongPongLag"
QT_MOC_LITERAL(215, 2753, 14), // "updateEncoding"
QT_MOC_LITERAL(216, 2768, 26), // "sendNickInfoChangedSignals"
QT_MOC_LITERAL(217, 2795, 29), // "sendChannelNickChangedSignals"
QT_MOC_LITERAL(218, 2825, 27), // "requestOpenChannelListPanel"
QT_MOC_LITERAL(219, 2853, 6), // "filter"
QT_MOC_LITERAL(220, 2860, 17) // "doPreShellCommand"

    },
    "Server\0destroyed\0\0connectionId\0"
    "nicknameChanged\0serverLag\0Server*\0"
    "server\0msec\0tooLongLag\0resetLag\0"
    "nicksNowOnline\0list\0changed\0awayState\0"
    "away\0multiServerCommand\0command\0"
    "parameter\0serverOnline\0state\0sentStat\0"
    "bytes\0encodedBytes\0IRCQueue*\0whichQueue\0"
    "nickInfoChanged\0NickInfoPtr\0nickInfo\0"
    "channelNickChanged\0channel\0"
    "channelMembersChanged\0channelName\0"
    "joined\0parted\0nickname\0channelJoinedOrUnjoined\0"
    "watchedNickChanged\0online\0"
    "awayInsertRememberLine\0sslInitFailure\0"
    "sslConnected\0connectionStateChanged\0"
    "Konversation::ConnectionState\0showView\0"
    "ChatWindow*\0view\0addDccPanel\0addDccChat\0"
    "Konversation::DCC::Chat*\0chat\0"
    "connectToIRCServer\0connectToIRCServerIn\0"
    "delay\0queue\0line\0QueuePriority\0priority\0"
    "queueList\0buffer\0setNickname\0newNickname\0"
    "addQuery\0Query*\0weinitiated\0closeQuery\0"
    "name\0closeChannel\0reconnectServer\0"
    "quitMessage\0disconnectServer\0quitServer\0"
    "openDccChat\0openDccWBoard\0requestDccChat\0"
    "partnerNick\0extension\0numericalOwnIp\0"
    "ownPort\0acceptDccGet\0nick\0file\0"
    "requestBan\0users\0option\0requestUnban\0"
    "mask\0addDccSend\0recipient\0fileURL\0"
    "passive\0altFileName\0fileSize\0removeQuery\0"
    "query\0notifyListStarted\0serverGroupId\0"
    "startNotifyTimer\0notifyTimeout\0"
    "sendJoinCommand\0password\0requestAway\0"
    "reason\0requestUnaway\0requestChannelList\0"
    "requestWhois\0requestWho\0requestUserhost\0"
    "nicks\0requestTopic\0resolveUserhost\0"
    "addRawLog\0show\0closeRawLog\0addToChannelList\0"
    "topic\0closeChannelListPanel\0"
    "sendMultiServerCommand\0executeMultiServerCommand\0"
    "showSSLDialog\0sendToAllChannels\0text\0"
    "sendToAllChannelsAndQueries\0"
    "enableIdentifyMsg\0enabled\0identifyMsgEnabled\0"
    "addBan\0ban\0removeBan\0pongReceived\0"
    "initKeyExchange\0receiver\0parseInitKeyX\0"
    "sender\0pubKey\0parseFinishKeyX\0"
    "startNickInfoChangedTimer\0"
    "startChannelNickChangedTimer\0"
    "involuntaryQuit\0reconnectInvoluntary\0"
    "requestAvailableCapabilies\0"
    "capInitiateNegotiation\0availableCaps\0"
    "capReply\0capEndNegotiation\0capCheckIgnored\0"
    "capAcknowledged\0CapModifiers\0modifiers\0"
    "capDenied\0sendAuthenticate\0message\0"
    "hostFound\0preShellCommandExited\0"
    "exitCode\0QProcess::ExitStatus\0exitStatus\0"
    "preShellCommandError\0QProcess::ProcessError\0"
    "eror\0socketConnected\0startAwayTimer\0"
    "incoming\0processIncomingData\0toServer\0"
    "QString&\0closed\0broken\0KTcpSocket::Error\0"
    "error\0sslError\0QList<KSslError>\0"
    "connectionEstablished\0ownHost\0"
    "notifyResponse\0nicksOnline\0"
    "slotNewDccTransferItemQueued\0"
    "Konversation::DCC::Transfer*\0transfer\0"
    "startReverseDccSendTransfer\0sourceNick\0"
    "dccArguments\0startReverseDccChat\0"
    "dccArgument\0addDccGet\0requestDccSend\0"
    "resumeDccGetTransfer\0resumeDccSendTransfer\0"
    "rejectDccSendTransfer\0dccGetDone\0item\0"
    "dccSendDone\0dccStatusChanged\0newStatus\0"
    "oldStatus\0arguments\0rejectDccChat\0"
    "scriptNotFound\0scriptExecutionError\0"
    "userhost\0hostmask\0ircOp\0setTopicAuthor\0"
    "author\0t\0endOfWho\0target\0endOfNames\0"
    "invitation\0gotOwnResolvedHostByWelcome\0"
    "QHostInfo\0res\0gotOwnResolvedHostByUserhost\0"
    "sendPing\0updateLongPongLag\0updateEncoding\0"
    "sendNickInfoChangedSignals\0"
    "sendChannelNickChangedSignals\0"
    "requestOpenChannelListPanel\0filter\0"
    "doPreShellCommand"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Server[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
     137,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      23,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  699,    2, 0x06 /* Public */,
       4,    1,  702,    2, 0x06 /* Public */,
       5,    2,  705,    2, 0x06 /* Public */,
       9,    2,  710,    2, 0x06 /* Public */,
      10,    1,  715,    2, 0x06 /* Public */,
      11,    3,  718,    2, 0x06 /* Public */,
      14,    1,  725,    2, 0x06 /* Public */,
      16,    2,  728,    2, 0x06 /* Public */,
      19,    1,  733,    2, 0x06 /* Public */,
      21,    3,  736,    2, 0x06 /* Public */,
      26,    2,  743,    2, 0x06 /* Public */,
      26,    0,  748,    2, 0x06 /* Public */,
      29,    1,  749,    2, 0x06 /* Public */,
      31,    5,  752,    2, 0x06 /* Public */,
      36,    3,  763,    2, 0x06 /* Public */,
      37,    3,  770,    2, 0x06 /* Public */,
      39,    1,  777,    2, 0x06 /* Public */,
      40,    0,  780,    2, 0x06 /* Public */,
      41,    1,  781,    2, 0x06 /* Public */,
      42,    2,  784,    2, 0x06 /* Public */,
      44,    1,  789,    2, 0x06 /* Public */,
      47,    0,  792,    2, 0x06 /* Public */,
      48,    1,  793,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      51,    0,  796,    2, 0x0a /* Public */,
      52,    1,  797,    2, 0x0a /* Public */,
      54,    2,  800,    2, 0x0a /* Public */,
      54,    1,  805,    2, 0x2a /* Public | MethodCloned */,
      58,    2,  808,    2, 0x0a /* Public */,
      58,    1,  813,    2, 0x2a /* Public | MethodCloned */,
      60,    1,  816,    2, 0x0a /* Public */,
      62,    2,  819,    2, 0x0a /* Public */,
      65,    1,  824,    2, 0x0a /* Public */,
      67,    1,  827,    2, 0x0a /* Public */,
      68,    1,  830,    2, 0x0a /* Public */,
      68,    0,  833,    2, 0x2a /* Public | MethodCloned */,
      70,    1,  834,    2, 0x0a /* Public */,
      70,    0,  837,    2, 0x2a /* Public | MethodCloned */,
      71,    1,  838,    2, 0x0a /* Public */,
      71,    0,  841,    2, 0x2a /* Public | MethodCloned */,
      72,    1,  842,    2, 0x0a /* Public */,
      73,    1,  845,    2, 0x0a /* Public */,
      74,    4,  848,    2, 0x0a /* Public */,
      79,    2,  857,    2, 0x0a /* Public */,
      82,    3,  862,    2, 0x0a /* Public */,
      85,    2,  869,    2, 0x0a /* Public */,
      87,    5,  874,    2, 0x0a /* Public */,
      87,    4,  885,    2, 0x2a /* Public | MethodCloned */,
      87,    3,  894,    2, 0x2a /* Public | MethodCloned */,
      87,    2,  901,    2, 0x2a /* Public | MethodCloned */,
      93,    1,  906,    2, 0x0a /* Public */,
      95,    1,  909,    2, 0x0a /* Public */,
      97,    1,  912,    2, 0x0a /* Public */,
      97,    0,  915,    2, 0x2a /* Public | MethodCloned */,
      98,    0,  916,    2, 0x0a /* Public */,
      99,    2,  917,    2, 0x0a /* Public */,
      99,    1,  922,    2, 0x2a /* Public | MethodCloned */,
     101,    1,  925,    2, 0x0a /* Public */,
     101,    0,  928,    2, 0x2a /* Public | MethodCloned */,
     103,    0,  929,    2, 0x0a /* Public */,
     104,    0,  930,    2, 0x0a /* Public */,
     105,    1,  931,    2, 0x0a /* Public */,
     106,    1,  934,    2, 0x0a /* Public */,
     107,    1,  937,    2, 0x0a /* Public */,
     109,    1,  940,    2, 0x0a /* Public */,
     110,    1,  943,    2, 0x0a /* Public */,
     111,    1,  946,    2, 0x0a /* Public */,
     113,    0,  949,    2, 0x0a /* Public */,
     114,    3,  950,    2, 0x0a /* Public */,
     116,    0,  957,    2, 0x0a /* Public */,
     117,    2,  958,    2, 0x0a /* Public */,
     118,    2,  963,    2, 0x0a /* Public */,
     119,    0,  968,    2, 0x0a /* Public */,
     120,    1,  969,    2, 0x0a /* Public */,
     122,    1,  972,    2, 0x0a /* Public */,
     123,    1,  975,    2, 0x0a /* Public */,
     125,    0,  978,    2, 0x0a /* Public */,
     126,    2,  979,    2, 0x0a /* Public */,
     128,    2,  984,    2, 0x0a /* Public */,
     129,    0,  989,    2, 0x0a /* Public */,
     130,    1,  990,    2, 0x0a /* Public */,
     132,    2,  993,    2, 0x0a /* Public */,
     135,    2,  998,    2, 0x0a /* Public */,
     136,    0, 1003,    2, 0x0a /* Public */,
     137,    1, 1004,    2, 0x0a /* Public */,
     138,    0, 1007,    2, 0x0a /* Public */,
     139,    0, 1008,    2, 0x0a /* Public */,
     140,    0, 1009,    2, 0x0a /* Public */,
     141,    1, 1010,    2, 0x0a /* Public */,
     143,    0, 1013,    2, 0x0a /* Public */,
     144,    0, 1014,    2, 0x0a /* Public */,
     145,    0, 1015,    2, 0x0a /* Public */,
     146,    2, 1016,    2, 0x0a /* Public */,
     149,    1, 1021,    2, 0x0a /* Public */,
     150,    1, 1024,    2, 0x0a /* Public */,
     152,    0, 1027,    2, 0x09 /* Protected */,
     153,    2, 1028,    2, 0x09 /* Protected */,
     157,    1, 1033,    2, 0x09 /* Protected */,
     160,    0, 1036,    2, 0x09 /* Protected */,
     161,    0, 1037,    2, 0x09 /* Protected */,
     162,    0, 1038,    2, 0x09 /* Protected */,
     163,    0, 1039,    2, 0x09 /* Protected */,
     164,    2, 1040,    2, 0x09 /* Protected */,
     166,    0, 1045,    2, 0x09 /* Protected */,
     167,    1, 1046,    2, 0x09 /* Protected */,
     170,    1, 1049,    2, 0x09 /* Protected */,
     172,    1, 1052,    2, 0x09 /* Protected */,
     174,    1, 1055,    2, 0x09 /* Protected */,
     176,    1, 1058,    2, 0x09 /* Protected */,
     179,    2, 1061,    2, 0x09 /* Protected */,
     182,    2, 1066,    2, 0x09 /* Protected */,
     184,    2, 1071,    2, 0x09 /* Protected */,
     185,    0, 1076,    2, 0x09 /* Protected */,
     185,    1, 1077,    2, 0x09 /* Protected */,
     186,    2, 1080,    2, 0x09 /* Protected */,
     187,    2, 1085,    2, 0x09 /* Protected */,
     188,    2, 1090,    2, 0x09 /* Protected */,
     189,    1, 1095,    2, 0x09 /* Protected */,
     191,    1, 1098,    2, 0x09 /* Protected */,
     192,    3, 1101,    2, 0x09 /* Protected */,
      48,    2, 1108,    2, 0x09 /* Protected */,
     196,    1, 1113,    2, 0x09 /* Protected */,
     197,    1, 1116,    2, 0x09 /* Protected */,
     198,    1, 1119,    2, 0x09 /* Protected */,
     199,    4, 1122,    2, 0x09 /* Protected */,
     202,    3, 1131,    2, 0x09 /* Protected */,
     205,    1, 1138,    2, 0x09 /* Protected */,
     207,    1, 1141,    2, 0x09 /* Protected */,
     208,    2, 1144,    2, 0x09 /* Protected */,
     209,    1, 1149,    2, 0x09 /* Protected */,
     212,    1, 1152,    2, 0x09 /* Protected */,
     213,    0, 1155,    2, 0x09 /* Protected */,
     214,    0, 1156,    2, 0x09 /* Protected */,
     215,    0, 1157,    2, 0x09 /* Protected */,
     216,    0, 1158,    2, 0x09 /* Protected */,
     217,    0, 1159,    2, 0x09 /* Protected */,
     218,    1, 1160,    2, 0x09 /* Protected */,
     220,    0, 1163,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6, QMetaType::Int,    7,    8,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QStringList, QMetaType::Bool,    7,   12,   13,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   17,   18,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, 0x80000000 | 24,   22,   23,   25,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 27,    7,   28,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,    7,   32,   33,   34,   35,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::Bool,    7,   32,   33,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::Bool,    7,   35,   38,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 43,    7,   20,
    QMetaType::Void, 0x80000000 | 45,   46,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 49,   50,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   53,
    QMetaType::Bool, QMetaType::QString, 0x80000000 | 56,   55,   57,
    QMetaType::Bool, QMetaType::QString,   55,
    QMetaType::Bool, QMetaType::QStringList, 0x80000000 | 56,   59,   57,
    QMetaType::Bool, QMetaType::QStringList,   59,
    QMetaType::Void, QMetaType::QString,   61,
    0x80000000 | 63, 0x80000000 | 27, QMetaType::Bool,   28,   64,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString,   69,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   69,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   69,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::UShort,   75,   76,   77,   78,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   80,   81,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString,   83,   30,   84,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   86,   30,
    QMetaType::Void, QMetaType::QString, QMetaType::QUrl, QMetaType::Bool, QMetaType::QString, QMetaType::ULongLong,   88,   89,   90,   91,   92,
    QMetaType::Void, QMetaType::QString, QMetaType::QUrl, QMetaType::Bool, QMetaType::QString,   88,   89,   90,   91,
    QMetaType::Void, QMetaType::QString, QMetaType::QUrl, QMetaType::Bool,   88,   89,   90,
    QMetaType::Void, QMetaType::QString, QMetaType::QUrl,   88,   89,
    QMetaType::Void, 0x80000000 | 63,   94,
    QMetaType::Void, QMetaType::Int,   96,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   32,  100,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void, QMetaType::QString,  102,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void, QMetaType::QString,  108,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void, QMetaType::QString,   35,
    QMetaType::Void, QMetaType::Bool,  112,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,   30,   83,  115,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   17,   18,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   17,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  121,
    QMetaType::Void, QMetaType::QString,  121,
    QMetaType::Void, QMetaType::Bool,  124,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   30,  127,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   30,  127,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  131,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,  133,  134,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,  133,  134,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  142,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 147,   66,  148,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString,  151,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 155,  154,  156,
    QMetaType::Void, 0x80000000 | 158,  159,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 165, 0x80000000 | 24,    2,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 168,  169,
    QMetaType::Void, 0x80000000 | 171,    2,
    QMetaType::Void, QMetaType::QString,  173,
    QMetaType::Void, QMetaType::QString,  175,
    QMetaType::Void, 0x80000000 | 177,  178,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  181,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  183,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  181,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   88,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  181,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  181,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  181,
    QMetaType::Void, 0x80000000 | 177,  190,
    QMetaType::Void, 0x80000000 | 177,  190,
    QMetaType::Void, 0x80000000 | 177, QMetaType::Int, QMetaType::Int,  190,  193,  194,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,  180,  195,
    QMetaType::Void, QMetaType::QString,  180,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   80,  200,   15,  201,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QDateTime,   30,  203,  204,
    QMetaType::Void, QMetaType::QString,  206,
    QMetaType::Void, QMetaType::QString,  206,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   80,   30,
    QMetaType::Void, 0x80000000 | 210,  211,
    QMetaType::Void, 0x80000000 | 210,  211,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,  219,
    QMetaType::Void,

       0        // eod
};

void Server::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Server *_t = static_cast<Server *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->destroyed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->nicknameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->serverLag((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->tooLongLag((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->resetLag((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 5: _t->nicksNowOnline((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 6: _t->awayState((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->multiServerCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->serverOnline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->sentStat((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< IRCQueue*(*)>(_a[3]))); break;
        case 10: _t->nickInfoChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const NickInfoPtr(*)>(_a[2]))); break;
        case 11: _t->nickInfoChanged(); break;
        case 12: _t->channelNickChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->channelMembersChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 14: _t->channelJoinedOrUnjoined((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 15: _t->watchedNickChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 16: _t->awayInsertRememberLine((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 17: _t->sslInitFailure(); break;
        case 18: _t->sslConnected((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 19: _t->connectionStateChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 20: _t->showView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 21: _t->addDccPanel(); break;
        case 22: _t->addDccChat((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1]))); break;
        case 23: _t->connectToIRCServer(); break;
        case 24: _t->connectToIRCServerIn((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 25: { bool _r = _t->queue((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QueuePriority(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->queue((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->queueList((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< QueuePriority(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->queueList((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setNickname((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 30: { Query* _r = _t->addQuery((*reinterpret_cast< const NickInfoPtr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< Query**>(_a[0]) = std::move(_r); }  break;
        case 31: _t->closeQuery((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 32: _t->closeChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->reconnectServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 34: _t->reconnectServer(); break;
        case 35: _t->disconnectServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 36: _t->disconnectServer(); break;
        case 37: _t->quitServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 38: _t->quitServer(); break;
        case 39: _t->openDccChat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->openDccWBoard((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->requestDccChat((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< quint16(*)>(_a[4]))); break;
        case 42: _t->acceptDccGet((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 43: _t->requestBan((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 44: _t->requestUnban((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 45: _t->addDccSend((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QUrl(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< quint64(*)>(_a[5]))); break;
        case 46: _t->addDccSend((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QUrl(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 47: _t->addDccSend((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QUrl(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 48: _t->addDccSend((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QUrl(*)>(_a[2]))); break;
        case 49: _t->removeQuery((*reinterpret_cast< Query*(*)>(_a[1]))); break;
        case 50: _t->notifyListStarted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 51: _t->startNotifyTimer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 52: _t->startNotifyTimer(); break;
        case 53: _t->notifyTimeout(); break;
        case 54: _t->sendJoinCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 55: _t->sendJoinCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 56: _t->requestAway((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 57: _t->requestAway(); break;
        case 58: _t->requestUnaway(); break;
        case 59: _t->requestChannelList(); break;
        case 60: _t->requestWhois((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 61: _t->requestWho((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 62: _t->requestUserhost((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 63: _t->requestTopic((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 64: _t->resolveUserhost((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 65: _t->addRawLog((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 66: _t->closeRawLog(); break;
        case 67: _t->addToChannelList((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 68: _t->closeChannelListPanel(); break;
        case 69: _t->sendMultiServerCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 70: _t->executeMultiServerCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 71: _t->showSSLDialog(); break;
        case 72: _t->sendToAllChannels((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 73: _t->sendToAllChannelsAndQueries((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 74: _t->enableIdentifyMsg((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 75: { bool _r = _t->identifyMsgEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 76: _t->addBan((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 77: _t->removeBan((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 78: _t->pongReceived(); break;
        case 79: _t->initKeyExchange((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 80: _t->parseInitKeyX((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 81: _t->parseFinishKeyX((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 82: _t->startNickInfoChangedTimer(); break;
        case 83: _t->startChannelNickChangedTimer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 84: _t->involuntaryQuit(); break;
        case 85: _t->reconnectInvoluntary(); break;
        case 86: _t->requestAvailableCapabilies(); break;
        case 87: _t->capInitiateNegotiation((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 88: _t->capReply(); break;
        case 89: _t->capEndNegotiation(); break;
        case 90: _t->capCheckIgnored(); break;
        case 91: _t->capAcknowledged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< CapModifiers(*)>(_a[2]))); break;
        case 92: _t->capDenied((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 93: _t->sendAuthenticate((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 94: _t->hostFound(); break;
        case 95: _t->preShellCommandExited((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QProcess::ExitStatus(*)>(_a[2]))); break;
        case 96: _t->preShellCommandError((*reinterpret_cast< QProcess::ProcessError(*)>(_a[1]))); break;
        case 97: _t->socketConnected(); break;
        case 98: _t->startAwayTimer(); break;
        case 99: _t->incoming(); break;
        case 100: _t->processIncomingData(); break;
        case 101: _t->toServer((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< IRCQueue*(*)>(_a[2]))); break;
        case 102: _t->closed(); break;
        case 103: _t->broken((*reinterpret_cast< KTcpSocket::Error(*)>(_a[1]))); break;
        case 104: _t->sslError((*reinterpret_cast< const QList<KSslError>(*)>(_a[1]))); break;
        case 105: _t->connectionEstablished((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 106: _t->notifyResponse((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 107: _t->slotNewDccTransferItemQueued((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 108: _t->startReverseDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 109: _t->startReverseDccChat((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 110: _t->addDccGet((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 111: _t->requestDccSend(); break;
        case 112: _t->requestDccSend((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 113: _t->resumeDccGetTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 114: _t->resumeDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 115: _t->rejectDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 116: _t->dccGetDone((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 117: _t->dccSendDone((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 118: _t->dccStatusChanged((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 119: _t->addDccChat((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 120: _t->rejectDccChat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 121: _t->scriptNotFound((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 122: _t->scriptExecutionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 123: _t->userhost((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 124: _t->setTopicAuthor((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QDateTime(*)>(_a[3]))); break;
        case 125: _t->endOfWho((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 126: _t->endOfNames((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 127: _t->invitation((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 128: _t->gotOwnResolvedHostByWelcome((*reinterpret_cast< const QHostInfo(*)>(_a[1]))); break;
        case 129: _t->gotOwnResolvedHostByUserhost((*reinterpret_cast< const QHostInfo(*)>(_a[1]))); break;
        case 130: _t->sendPing(); break;
        case 131: _t->updateLongPongLag(); break;
        case 132: _t->updateEncoding(); break;
        case 133: _t->sendNickInfoChangedSignals(); break;
        case 134: _t->sendChannelNickChangedSignals(); break;
        case 135: _t->requestOpenChannelListPanel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 136: _t->doPreShellCommand(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 128:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostInfo >(); break;
            }
            break;
        case 129:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostInfo >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Server::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::destroyed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Server::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::nicknameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::serverLag)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::tooLongLag)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::resetLag)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , const QStringList & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::nicksNowOnline)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Server::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::awayState)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Server::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::multiServerCommand)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Server::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::serverOnline)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Server::*_t)(int , int , IRCQueue * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::sentStat)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , const NickInfoPtr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::nickInfoChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Server::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::nickInfoChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (Server::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::channelNickChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , const QString & , bool , bool , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::channelMembersChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::channelJoinedOrUnjoined)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::watchedNickChanged)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::awayInsertRememberLine)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (Server::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::sslInitFailure)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::sslConnected)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Server * , Konversation::ConnectionState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::connectionStateChanged)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (Server::*_t)(ChatWindow * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::showView)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (Server::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::addDccPanel)) {
                *result = 21;
                return;
            }
        }
        {
            typedef void (Server::*_t)(Konversation::DCC::Chat * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Server::addDccChat)) {
                *result = 22;
                return;
            }
        }
    }
}

const QMetaObject Server::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Server.data,
      qt_meta_data_Server,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Server::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Server::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Server.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Server::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 137)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 137;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 137)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 137;
    }
    return _id;
}

// SIGNAL 0
void Server::destroyed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Server::nicknameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Server::serverLag(Server * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Server::tooLongLag(Server * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Server::resetLag(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Server::nicksNowOnline(Server * _t1, const QStringList & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Server::awayState(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Server::multiServerCommand(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Server::serverOnline(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Server::sentStat(int _t1, int _t2, IRCQueue * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Server::nickInfoChanged(Server * _t1, const NickInfoPtr _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Server::nickInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Server::channelNickChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Server::channelMembersChanged(Server * _t1, const QString & _t2, bool _t3, bool _t4, const QString & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Server::channelJoinedOrUnjoined(Server * _t1, const QString & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Server::watchedNickChanged(Server * _t1, const QString & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Server::awayInsertRememberLine(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Server::sslInitFailure()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Server::sslConnected(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Server::connectionStateChanged(Server * _t1, Konversation::ConnectionState _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Server::showView(ChatWindow * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void Server::addDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Server::addDccChat(Konversation::DCC::Chat * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
