/****************************************************************************
** Meta object code from reading C++ file 'whiteboardfontchooser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/whiteboardfontchooser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardfontchooser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser_t {
    QByteArrayData data[12];
    char stringdata0[168];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser_t qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser = {
    {
QT_MOC_LITERAL(0, 0, 40), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(1, 41, 11), // "fontChanged"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 4), // "font"
QT_MOC_LITERAL(4, 59, 18), // "currentFontChanged"
QT_MOC_LITERAL(5, 78, 16), // "pointSizeChanged"
QT_MOC_LITERAL(6, 95, 4), // "size"
QT_MOC_LITERAL(7, 100, 11), // "boldToggled"
QT_MOC_LITERAL(8, 112, 7), // "checked"
QT_MOC_LITERAL(9, 120, 13), // "italicToggled"
QT_MOC_LITERAL(10, 134, 16), // "underlineToggled"
QT_MOC_LITERAL(11, 151, 16) // "strikeoutToggled"

    },
    "Konversation::DCC::WhiteBoardFontChooser\0"
    "fontChanged\0\0font\0currentFontChanged\0"
    "pointSizeChanged\0size\0boldToggled\0"
    "checked\0italicToggled\0underlineToggled\0"
    "strikeoutToggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__WhiteBoardFontChooser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   52,    2, 0x09 /* Protected */,
       5,    1,   55,    2, 0x09 /* Protected */,
       7,    1,   58,    2, 0x09 /* Protected */,
       9,    1,   61,    2, 0x09 /* Protected */,
      10,    1,   64,    2, 0x09 /* Protected */,
      11,    1,   67,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QFont,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QFont,    3,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,    8,

       0        // eod
};

void Konversation::DCC::WhiteBoardFontChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhiteBoardFontChooser *_t = static_cast<WhiteBoardFontChooser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 1: _t->currentFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 2: _t->pointSizeChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->boldToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->italicToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->underlineToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->strikeoutToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhiteBoardFontChooser::*_t)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardFontChooser::fontChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::WhiteBoardFontChooser::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser.data,
      qt_meta_data_Konversation__DCC__WhiteBoardFontChooser,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::WhiteBoardFontChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardFontChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__WhiteBoardFontChooser.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::WhiteBoardFontChooserUi"))
        return static_cast< Ui::WhiteBoardFontChooserUi*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardFontChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardFontChooser::fontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
