/****************************************************************************
** Meta object code from reading C++ file 'searchbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/searchbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SearchBar_t {
    QByteArrayData data[14];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SearchBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SearchBar_t qt_meta_stringdata_SearchBar = {
    {
QT_MOC_LITERAL(0, 0, 9), // "SearchBar"
QT_MOC_LITERAL(1, 10, 19), // "signalSearchChanged"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 7), // "pattern"
QT_MOC_LITERAL(4, 39, 16), // "signalSearchNext"
QT_MOC_LITERAL(5, 56, 20), // "signalSearchPrevious"
QT_MOC_LITERAL(6, 77, 6), // "hidden"
QT_MOC_LITERAL(7, 84, 15), // "slotTextChanged"
QT_MOC_LITERAL(8, 100, 8), // "slotFind"
QT_MOC_LITERAL(9, 109, 12), // "slotFindNext"
QT_MOC_LITERAL(10, 122, 16), // "slotFindPrevious"
QT_MOC_LITERAL(11, 139, 15), // "toggleMatchCase"
QT_MOC_LITERAL(12, 155, 5), // "value"
QT_MOC_LITERAL(13, 161, 16) // "toggleWholeWords"

    },
    "SearchBar\0signalSearchChanged\0\0pattern\0"
    "signalSearchNext\0signalSearchPrevious\0"
    "hidden\0slotTextChanged\0slotFind\0"
    "slotFindNext\0slotFindPrevious\0"
    "toggleMatchCase\0value\0toggleWholeWords"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SearchBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    0,   67,    2, 0x06 /* Public */,
       5,    0,   68,    2, 0x06 /* Public */,
       6,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   70,    2, 0x08 /* Private */,
       8,    0,   71,    2, 0x08 /* Private */,
       9,    0,   72,    2, 0x08 /* Private */,
      10,    0,   73,    2, 0x08 /* Private */,
      11,    1,   74,    2, 0x08 /* Private */,
      13,    1,   77,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   12,

       0        // eod
};

void SearchBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SearchBar *_t = static_cast<SearchBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalSearchChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->signalSearchNext(); break;
        case 2: _t->signalSearchPrevious(); break;
        case 3: _t->hidden(); break;
        case 4: _t->slotTextChanged(); break;
        case 5: _t->slotFind(); break;
        case 6: _t->slotFindNext(); break;
        case 7: _t->slotFindPrevious(); break;
        case 8: _t->toggleMatchCase((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->toggleWholeWords((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SearchBar::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchBar::signalSearchChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SearchBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchBar::signalSearchNext)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SearchBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchBar::signalSearchPrevious)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (SearchBar::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SearchBar::hidden)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject SearchBar::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_SearchBar.data,
      qt_meta_data_SearchBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SearchBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SearchBar.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int SearchBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SearchBar::signalSearchChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SearchBar::signalSearchNext()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SearchBar::signalSearchPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SearchBar::hidden()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
