/****************************************************************************
** Meta object code from reading C++ file 'chatcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/chatcontainer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__ChatContainer_t {
    QByteArrayData data[17];
    char stringdata0[223];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__ChatContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__ChatContainer_t qt_meta_stringdata_Konversation__DCC__ChatContainer = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Konversation::DCC::ChatContainer"
QT_MOC_LITERAL(1, 33, 14), // "setPartnerNick"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 4), // "nick"
QT_MOC_LITERAL(4, 54, 11), // "textEntered"
QT_MOC_LITERAL(5, 66, 10), // "textPasted"
QT_MOC_LITERAL(6, 77, 4), // "text"
QT_MOC_LITERAL(7, 82, 12), // "receivedLine"
QT_MOC_LITERAL(8, 95, 4), // "line"
QT_MOC_LITERAL(9, 100, 17), // "chatStatusChanged"
QT_MOC_LITERAL(10, 118, 24), // "Konversation::DCC::Chat*"
QT_MOC_LITERAL(11, 143, 4), // "chat"
QT_MOC_LITERAL(12, 148, 31), // "Konversation::DCC::Chat::Status"
QT_MOC_LITERAL(13, 180, 9), // "newstatus"
QT_MOC_LITERAL(14, 190, 9), // "oldstatus"
QT_MOC_LITERAL(15, 200, 9), // "upnpError"
QT_MOC_LITERAL(16, 210, 12) // "errorMessage"

    },
    "Konversation::DCC::ChatContainer\0"
    "setPartnerNick\0\0nick\0textEntered\0"
    "textPasted\0text\0receivedLine\0line\0"
    "chatStatusChanged\0Konversation::DCC::Chat*\0"
    "chat\0Konversation::DCC::Chat::Status\0"
    "newstatus\0oldstatus\0upnpError\0"
    "errorMessage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__ChatContainer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x0a /* Public */,
       4,    0,   47,    2, 0x0a /* Public */,
       5,    1,   48,    2, 0x0a /* Public */,
       7,    1,   51,    2, 0x0a /* Public */,
       9,    3,   54,    2, 0x0a /* Public */,
      15,    1,   61,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 12, 0x80000000 | 12,   11,   13,   14,
    QMetaType::Void, QMetaType::QString,   16,

       0        // eod
};

void Konversation::DCC::ChatContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChatContainer *_t = static_cast<ChatContainer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setPartnerNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->textEntered(); break;
        case 2: _t->textPasted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->receivedLine((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->chatStatusChanged((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1])),(*reinterpret_cast< Konversation::DCC::Chat::Status(*)>(_a[2])),(*reinterpret_cast< Konversation::DCC::Chat::Status(*)>(_a[3]))); break;
        case 5: _t->upnpError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Chat* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Konversation::DCC::ChatContainer::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_Konversation__DCC__ChatContainer.data,
      qt_meta_data_Konversation__DCC__ChatContainer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::ChatContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::ChatContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__ChatContainer.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int Konversation::DCC::ChatContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
