/****************************************************************************
** Meta object code from reading C++ file 'serverlistdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/serverlistdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'serverlistdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__ServerListDialog_t {
    QByteArrayData data[25];
    char stringdata0[376];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__ServerListDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__ServerListDialog_t qt_meta_stringdata_Konversation__ServerListDialog = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Konversation::ServerListDialog"
QT_MOC_LITERAL(1, 31, 9), // "connectTo"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 28), // "Konversation::ConnectionFlag"
QT_MOC_LITERAL(4, 71, 4), // "flag"
QT_MOC_LITERAL(5, 76, 13), // "serverGroupId"
QT_MOC_LITERAL(6, 90, 18), // "ConnectionSettings"
QT_MOC_LITERAL(7, 109, 18), // "connectionSettings"
QT_MOC_LITERAL(8, 128, 19), // "serverGroupsChanged"
QT_MOC_LITERAL(9, 148, 36), // "Konversation::ServerGroupSett..."
QT_MOC_LITERAL(10, 185, 11), // "serverGroup"
QT_MOC_LITERAL(11, 197, 16), // "updateServerList"
QT_MOC_LITERAL(12, 214, 6), // "slotOk"
QT_MOC_LITERAL(13, 221, 7), // "slotAdd"
QT_MOC_LITERAL(14, 229, 8), // "slotEdit"
QT_MOC_LITERAL(15, 238, 10), // "slotDelete"
QT_MOC_LITERAL(16, 249, 20), // "slotSetGroupExpanded"
QT_MOC_LITERAL(17, 270, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(18, 287, 4), // "item"
QT_MOC_LITERAL(19, 292, 21), // "slotSetGroupCollapsed"
QT_MOC_LITERAL(20, 314, 15), // "slotAboutToMove"
QT_MOC_LITERAL(21, 330, 9), // "slotMoved"
QT_MOC_LITERAL(22, 340, 13), // "updateButtons"
QT_MOC_LITERAL(23, 354, 16), // "setShowAtStartup"
QT_MOC_LITERAL(24, 371, 4) // "show"

    },
    "Konversation::ServerListDialog\0connectTo\0"
    "\0Konversation::ConnectionFlag\0flag\0"
    "serverGroupId\0ConnectionSettings\0"
    "connectionSettings\0serverGroupsChanged\0"
    "Konversation::ServerGroupSettingsPtr\0"
    "serverGroup\0updateServerList\0slotOk\0"
    "slotAdd\0slotEdit\0slotDelete\0"
    "slotSetGroupExpanded\0QTreeWidgetItem*\0"
    "item\0slotSetGroupCollapsed\0slotAboutToMove\0"
    "slotMoved\0updateButtons\0setShowAtStartup\0"
    "show"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__ServerListDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x06 /* Public */,
       1,    2,   94,    2, 0x06 /* Public */,
       8,    1,   99,    2, 0x06 /* Public */,
       8,    0,  102,    2, 0x26 /* Public | MethodCloned */,

 // slots: name, argc, parameters, tag, flags
      11,    0,  103,    2, 0x0a /* Public */,
      12,    0,  104,    2, 0x09 /* Protected */,
      13,    0,  105,    2, 0x09 /* Protected */,
      14,    0,  106,    2, 0x09 /* Protected */,
      15,    0,  107,    2, 0x09 /* Protected */,
      16,    1,  108,    2, 0x09 /* Protected */,
      19,    1,  111,    2, 0x09 /* Protected */,
      20,    0,  114,    2, 0x09 /* Protected */,
      21,    0,  115,    2, 0x09 /* Protected */,
      22,    0,  116,    2, 0x09 /* Protected */,
      23,    1,  117,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 6,    4,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   24,

       0        // eod
};

void Konversation::ServerListDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ServerListDialog *_t = static_cast<ServerListDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< ConnectionSettings(*)>(_a[2]))); break;
        case 2: _t->serverGroupsChanged((*reinterpret_cast< const Konversation::ServerGroupSettingsPtr(*)>(_a[1]))); break;
        case 3: _t->serverGroupsChanged(); break;
        case 4: _t->updateServerList(); break;
        case 5: _t->slotOk(); break;
        case 6: _t->slotAdd(); break;
        case 7: _t->slotEdit(); break;
        case 8: _t->slotDelete(); break;
        case 9: _t->slotSetGroupExpanded((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 10: _t->slotSetGroupCollapsed((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->slotAboutToMove(); break;
        case 12: _t->slotMoved(); break;
        case 13: _t->updateButtons(); break;
        case 14: _t->setShowAtStartup((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ServerListDialog::*_t)(Konversation::ConnectionFlag , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServerListDialog::connectTo)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ServerListDialog::*_t)(Konversation::ConnectionFlag , ConnectionSettings );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServerListDialog::connectTo)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ServerListDialog::*_t)(const Konversation::ServerGroupSettingsPtr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ServerListDialog::serverGroupsChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Konversation::ServerListDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Konversation__ServerListDialog.data,
      qt_meta_data_Konversation__ServerListDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::ServerListDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::ServerListDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__ServerListDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Konversation::ServerListDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Konversation::ServerListDialog::connectTo(Konversation::ConnectionFlag _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::ServerListDialog::connectTo(Konversation::ConnectionFlag _t1, ConnectionSettings _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::ServerListDialog::serverGroupsChanged(const Konversation::ServerGroupSettingsPtr _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
