/****************************************************************************
** Meta object code from reading C++ file 'outputfilter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/outputfilter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'outputfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__OutputFilter_t {
    QByteArrayData data[119];
    char stringdata0[1508];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__OutputFilter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__OutputFilter_t qt_meta_stringdata_Konversation__OutputFilter = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Konversation::OutputFilter"
QT_MOC_LITERAL(1, 27, 11), // "openDccSend"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 9), // "recipient"
QT_MOC_LITERAL(4, 50, 3), // "url"
QT_MOC_LITERAL(5, 54, 14), // "requestDccSend"
QT_MOC_LITERAL(6, 69, 11), // "openDccChat"
QT_MOC_LITERAL(7, 81, 4), // "nick"
QT_MOC_LITERAL(8, 86, 13), // "openDccWBoard"
QT_MOC_LITERAL(9, 100, 11), // "addDccPanel"
QT_MOC_LITERAL(10, 112, 13), // "closeDccPanel"
QT_MOC_LITERAL(11, 126, 12), // "acceptDccGet"
QT_MOC_LITERAL(12, 139, 4), // "file"
QT_MOC_LITERAL(13, 144, 10), // "openRawLog"
QT_MOC_LITERAL(14, 155, 4), // "show"
QT_MOC_LITERAL(15, 160, 11), // "closeRawLog"
QT_MOC_LITERAL(16, 172, 16), // "openKonsolePanel"
QT_MOC_LITERAL(17, 189, 15), // "openChannelList"
QT_MOC_LITERAL(18, 205, 9), // "parameter"
QT_MOC_LITERAL(19, 215, 17), // "sendToAllChannels"
QT_MOC_LITERAL(20, 233, 4), // "text"
QT_MOC_LITERAL(21, 238, 12), // "launchScript"
QT_MOC_LITERAL(22, 251, 12), // "connectionId"
QT_MOC_LITERAL(23, 264, 6), // "target"
QT_MOC_LITERAL(24, 271, 8), // "banUsers"
QT_MOC_LITERAL(25, 280, 8), // "userList"
QT_MOC_LITERAL(26, 289, 7), // "channel"
QT_MOC_LITERAL(27, 297, 6), // "option"
QT_MOC_LITERAL(28, 304, 10), // "unbanUsers"
QT_MOC_LITERAL(29, 315, 4), // "mask"
QT_MOC_LITERAL(30, 320, 18), // "multiServerCommand"
QT_MOC_LITERAL(31, 339, 7), // "command"
QT_MOC_LITERAL(32, 347, 15), // "reconnectServer"
QT_MOC_LITERAL(33, 363, 11), // "quitMessage"
QT_MOC_LITERAL(34, 375, 16), // "disconnectServer"
QT_MOC_LITERAL(35, 392, 10), // "quitServer"
QT_MOC_LITERAL(36, 403, 9), // "connectTo"
QT_MOC_LITERAL(37, 413, 28), // "Konversation::ConnectionFlag"
QT_MOC_LITERAL(38, 442, 4), // "flag"
QT_MOC_LITERAL(39, 447, 8), // "hostName"
QT_MOC_LITERAL(40, 456, 4), // "port"
QT_MOC_LITERAL(41, 461, 8), // "password"
QT_MOC_LITERAL(42, 470, 6), // "useSSL"
QT_MOC_LITERAL(43, 477, 8), // "showView"
QT_MOC_LITERAL(44, 486, 11), // "ChatWindow*"
QT_MOC_LITERAL(45, 498, 4), // "view"
QT_MOC_LITERAL(46, 503, 15), // "encodingChanged"
QT_MOC_LITERAL(47, 519, 7), // "execBan"
QT_MOC_LITERAL(48, 527, 18), // "OutputFilterResult"
QT_MOC_LITERAL(49, 546, 8), // "channels"
QT_MOC_LITERAL(50, 555, 9), // "execUnban"
QT_MOC_LITERAL(51, 565, 10), // "command_op"
QT_MOC_LITERAL(52, 576, 17), // "OutputFilterInput"
QT_MOC_LITERAL(53, 594, 5), // "input"
QT_MOC_LITERAL(54, 600, 12), // "command_deop"
QT_MOC_LITERAL(55, 613, 11), // "command_hop"
QT_MOC_LITERAL(56, 625, 13), // "command_dehop"
QT_MOC_LITERAL(57, 639, 13), // "command_voice"
QT_MOC_LITERAL(58, 653, 15), // "command_unvoice"
QT_MOC_LITERAL(59, 669, 15), // "command_devoice"
QT_MOC_LITERAL(60, 685, 12), // "command_join"
QT_MOC_LITERAL(61, 698, 6), // "_input"
QT_MOC_LITERAL(62, 705, 9), // "command_j"
QT_MOC_LITERAL(63, 715, 12), // "command_kick"
QT_MOC_LITERAL(64, 728, 12), // "command_part"
QT_MOC_LITERAL(65, 741, 13), // "command_leave"
QT_MOC_LITERAL(66, 755, 13), // "command_topic"
QT_MOC_LITERAL(67, 769, 12), // "command_away"
QT_MOC_LITERAL(68, 782, 14), // "command_unaway"
QT_MOC_LITERAL(69, 797, 12), // "command_back"
QT_MOC_LITERAL(70, 810, 13), // "command_aaway"
QT_MOC_LITERAL(71, 824, 15), // "command_aunaway"
QT_MOC_LITERAL(72, 840, 13), // "command_aback"
QT_MOC_LITERAL(73, 854, 13), // "command_names"
QT_MOC_LITERAL(74, 868, 13), // "command_close"
QT_MOC_LITERAL(75, 882, 17), // "command_reconnect"
QT_MOC_LITERAL(76, 900, 18), // "command_disconnect"
QT_MOC_LITERAL(77, 919, 12), // "command_quit"
QT_MOC_LITERAL(78, 932, 14), // "command_notice"
QT_MOC_LITERAL(79, 947, 10), // "command_me"
QT_MOC_LITERAL(80, 958, 11), // "command_msg"
QT_MOC_LITERAL(81, 970, 9), // "command_m"
QT_MOC_LITERAL(82, 980, 13), // "command_query"
QT_MOC_LITERAL(83, 994, 12), // "command_smsg"
QT_MOC_LITERAL(84, 1007, 12), // "command_ping"
QT_MOC_LITERAL(85, 1020, 12), // "command_ctcp"
QT_MOC_LITERAL(86, 1033, 11), // "command_ame"
QT_MOC_LITERAL(87, 1045, 12), // "command_amsg"
QT_MOC_LITERAL(88, 1058, 12), // "command_omsg"
QT_MOC_LITERAL(89, 1071, 15), // "command_onotice"
QT_MOC_LITERAL(90, 1087, 13), // "command_quote"
QT_MOC_LITERAL(91, 1101, 11), // "command_say"
QT_MOC_LITERAL(92, 1113, 11), // "command_dcc"
QT_MOC_LITERAL(93, 1125, 14), // "command_invite"
QT_MOC_LITERAL(94, 1140, 12), // "command_exec"
QT_MOC_LITERAL(95, 1153, 11), // "command_raw"
QT_MOC_LITERAL(96, 1165, 14), // "command_notify"
QT_MOC_LITERAL(97, 1180, 12), // "command_oper"
QT_MOC_LITERAL(98, 1193, 11), // "command_ban"
QT_MOC_LITERAL(99, 1205, 15), // "command_kickban"
QT_MOC_LITERAL(100, 1221, 13), // "command_unban"
QT_MOC_LITERAL(101, 1235, 14), // "command_ignore"
QT_MOC_LITERAL(102, 1250, 16), // "command_unignore"
QT_MOC_LITERAL(103, 1267, 14), // "command_server"
QT_MOC_LITERAL(104, 1282, 15), // "command_charset"
QT_MOC_LITERAL(105, 1298, 16), // "command_encoding"
QT_MOC_LITERAL(106, 1315, 14), // "command_setkey"
QT_MOC_LITERAL(107, 1330, 12), // "command_keyx"
QT_MOC_LITERAL(108, 1343, 14), // "command_delkey"
QT_MOC_LITERAL(109, 1358, 15), // "command_showkey"
QT_MOC_LITERAL(110, 1374, 12), // "command_kill"
QT_MOC_LITERAL(111, 1387, 11), // "command_dns"
QT_MOC_LITERAL(112, 1399, 12), // "command_list"
QT_MOC_LITERAL(113, 1412, 15), // "command_konsole"
QT_MOC_LITERAL(114, 1428, 18), // "command_queuetuner"
QT_MOC_LITERAL(115, 1447, 18), // "command_sayversion"
QT_MOC_LITERAL(116, 1466, 13), // "command_cycle"
QT_MOC_LITERAL(117, 1480, 13), // "command_clear"
QT_MOC_LITERAL(118, 1494, 13) // "command_umode"

    },
    "Konversation::OutputFilter\0openDccSend\0"
    "\0recipient\0url\0requestDccSend\0openDccChat\0"
    "nick\0openDccWBoard\0addDccPanel\0"
    "closeDccPanel\0acceptDccGet\0file\0"
    "openRawLog\0show\0closeRawLog\0"
    "openKonsolePanel\0openChannelList\0"
    "parameter\0sendToAllChannels\0text\0"
    "launchScript\0connectionId\0target\0"
    "banUsers\0userList\0channel\0option\0"
    "unbanUsers\0mask\0multiServerCommand\0"
    "command\0reconnectServer\0quitMessage\0"
    "disconnectServer\0quitServer\0connectTo\0"
    "Konversation::ConnectionFlag\0flag\0"
    "hostName\0port\0password\0useSSL\0showView\0"
    "ChatWindow*\0view\0encodingChanged\0"
    "execBan\0OutputFilterResult\0channels\0"
    "execUnban\0command_op\0OutputFilterInput\0"
    "input\0command_deop\0command_hop\0"
    "command_dehop\0command_voice\0command_unvoice\0"
    "command_devoice\0command_join\0_input\0"
    "command_j\0command_kick\0command_part\0"
    "command_leave\0command_topic\0command_away\0"
    "command_unaway\0command_back\0command_aaway\0"
    "command_aunaway\0command_aback\0"
    "command_names\0command_close\0"
    "command_reconnect\0command_disconnect\0"
    "command_quit\0command_notice\0command_me\0"
    "command_msg\0command_m\0command_query\0"
    "command_smsg\0command_ping\0command_ctcp\0"
    "command_ame\0command_amsg\0command_omsg\0"
    "command_onotice\0command_quote\0command_say\0"
    "command_dcc\0command_invite\0command_exec\0"
    "command_raw\0command_notify\0command_oper\0"
    "command_ban\0command_kickban\0command_unban\0"
    "command_ignore\0command_unignore\0"
    "command_server\0command_charset\0"
    "command_encoding\0command_setkey\0"
    "command_keyx\0command_delkey\0command_showkey\0"
    "command_kill\0command_dns\0command_list\0"
    "command_konsole\0command_queuetuner\0"
    "command_sayversion\0command_cycle\0"
    "command_clear\0command_umode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__OutputFilter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      95,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      28,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  489,    2, 0x06 /* Public */,
       5,    0,  494,    2, 0x06 /* Public */,
       5,    1,  495,    2, 0x06 /* Public */,
       6,    1,  498,    2, 0x06 /* Public */,
       8,    1,  501,    2, 0x06 /* Public */,
       9,    0,  504,    2, 0x06 /* Public */,
      10,    0,  505,    2, 0x06 /* Public */,
      11,    2,  506,    2, 0x06 /* Public */,
      13,    1,  511,    2, 0x06 /* Public */,
      15,    0,  514,    2, 0x06 /* Public */,
      16,    0,  515,    2, 0x06 /* Public */,
      17,    1,  516,    2, 0x06 /* Public */,
      19,    1,  519,    2, 0x06 /* Public */,
      21,    3,  522,    2, 0x06 /* Public */,
      24,    3,  529,    2, 0x06 /* Public */,
      28,    2,  536,    2, 0x06 /* Public */,
      30,    2,  541,    2, 0x06 /* Public */,
      32,    1,  546,    2, 0x06 /* Public */,
      34,    1,  549,    2, 0x06 /* Public */,
      35,    1,  552,    2, 0x06 /* Public */,
      36,    7,  555,    2, 0x06 /* Public */,
      36,    6,  570,    2, 0x26 /* Public | MethodCloned */,
      36,    5,  583,    2, 0x26 /* Public | MethodCloned */,
      36,    4,  594,    2, 0x26 /* Public | MethodCloned */,
      36,    3,  603,    2, 0x26 /* Public | MethodCloned */,
      36,    2,  610,    2, 0x26 /* Public | MethodCloned */,
      43,    1,  615,    2, 0x06 /* Public */,
      46,    0,  618,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      47,    2,  619,    2, 0x0a /* Public */,
      50,    2,  624,    2, 0x0a /* Public */,
      51,    1,  629,    2, 0x08 /* Private */,
      54,    1,  632,    2, 0x08 /* Private */,
      55,    1,  635,    2, 0x08 /* Private */,
      56,    1,  638,    2, 0x08 /* Private */,
      57,    1,  641,    2, 0x08 /* Private */,
      58,    1,  644,    2, 0x08 /* Private */,
      59,    1,  647,    2, 0x08 /* Private */,
      60,    1,  650,    2, 0x08 /* Private */,
      62,    1,  653,    2, 0x08 /* Private */,
      63,    1,  656,    2, 0x08 /* Private */,
      64,    1,  659,    2, 0x08 /* Private */,
      65,    1,  662,    2, 0x08 /* Private */,
      66,    1,  665,    2, 0x08 /* Private */,
      67,    1,  668,    2, 0x08 /* Private */,
      68,    1,  671,    2, 0x08 /* Private */,
      69,    1,  674,    2, 0x08 /* Private */,
      70,    1,  677,    2, 0x08 /* Private */,
      71,    1,  680,    2, 0x08 /* Private */,
      72,    1,  683,    2, 0x08 /* Private */,
      73,    1,  686,    2, 0x08 /* Private */,
      74,    1,  689,    2, 0x08 /* Private */,
      75,    1,  692,    2, 0x08 /* Private */,
      76,    1,  695,    2, 0x08 /* Private */,
      77,    1,  698,    2, 0x08 /* Private */,
      78,    1,  701,    2, 0x08 /* Private */,
      79,    1,  704,    2, 0x08 /* Private */,
      80,    1,  707,    2, 0x08 /* Private */,
      81,    1,  710,    2, 0x08 /* Private */,
      82,    1,  713,    2, 0x08 /* Private */,
      83,    1,  716,    2, 0x08 /* Private */,
      84,    1,  719,    2, 0x08 /* Private */,
      85,    1,  722,    2, 0x08 /* Private */,
      86,    1,  725,    2, 0x08 /* Private */,
      87,    1,  728,    2, 0x08 /* Private */,
      88,    1,  731,    2, 0x08 /* Private */,
      89,    1,  734,    2, 0x08 /* Private */,
      90,    1,  737,    2, 0x08 /* Private */,
      91,    1,  740,    2, 0x08 /* Private */,
      92,    1,  743,    2, 0x08 /* Private */,
      93,    1,  746,    2, 0x08 /* Private */,
      94,    1,  749,    2, 0x08 /* Private */,
      95,    1,  752,    2, 0x08 /* Private */,
      96,    1,  755,    2, 0x08 /* Private */,
      97,    1,  758,    2, 0x08 /* Private */,
      98,    1,  761,    2, 0x08 /* Private */,
      99,    1,  764,    2, 0x08 /* Private */,
     100,    1,  767,    2, 0x08 /* Private */,
     101,    1,  770,    2, 0x08 /* Private */,
     102,    1,  773,    2, 0x08 /* Private */,
     103,    1,  776,    2, 0x08 /* Private */,
     104,    1,  779,    2, 0x08 /* Private */,
     105,    1,  782,    2, 0x08 /* Private */,
     106,    1,  785,    2, 0x08 /* Private */,
     107,    1,  788,    2, 0x08 /* Private */,
     108,    1,  791,    2, 0x08 /* Private */,
     109,    1,  794,    2, 0x08 /* Private */,
     110,    1,  797,    2, 0x08 /* Private */,
     111,    1,  800,    2, 0x08 /* Private */,
     112,    1,  803,    2, 0x08 /* Private */,
     113,    1,  806,    2, 0x08 /* Private */,
     114,    1,  809,    2, 0x08 /* Private */,
     115,    1,  812,    2, 0x08 /* Private */,
     116,    1,  815,    2, 0x08 /* Private */,
     117,    1,  818,    2, 0x08 /* Private */,
     118,    1,  821,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QUrl,    3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QString,   22,   23,   18,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString,   25,   26,   27,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   29,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   31,   18,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   38,   39,   40,   41,    7,   26,   42,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   38,   39,   40,   41,    7,   26,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,   38,   39,   40,   41,    7,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString, QMetaType::QString, QMetaType::QString,   38,   39,   40,   41,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString, QMetaType::QString,   38,   39,   40,
    QMetaType::Void, 0x80000000 | 37, QMetaType::QString,   38,   39,
    QMetaType::Void, 0x80000000 | 44,   45,
    QMetaType::Void,

 // slots: parameters
    0x80000000 | 48, QMetaType::QString, QMetaType::QString,   29,   49,
    0x80000000 | 48, QMetaType::QString, QMetaType::QString,   29,   49,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   61,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   61,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   61,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   61,
    0x80000000 | 48, 0x80000000 | 52,   61,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,
    0x80000000 | 48, 0x80000000 | 52,   53,

       0        // eod
};

void Konversation::OutputFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        OutputFilter *_t = static_cast<OutputFilter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openDccSend((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QUrl(*)>(_a[2]))); break;
        case 1: _t->requestDccSend(); break;
        case 2: _t->requestDccSend((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->openDccChat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->openDccWBoard((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->addDccPanel(); break;
        case 6: _t->closeDccPanel(); break;
        case 7: _t->acceptDccGet((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->openRawLog((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->closeRawLog(); break;
        case 10: _t->openKonsolePanel(); break;
        case 11: _t->openChannelList((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->sendToAllChannels((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->launchScript((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 14: _t->banUsers((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 15: _t->unbanUsers((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->multiServerCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->reconnectServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->disconnectServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->quitServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 21: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 22: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 23: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 24: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 25: _t->connectTo((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 26: _t->showView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 27: _t->encodingChanged(); break;
        case 28: { OutputFilterResult _r = _t->execBan((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 29: { OutputFilterResult _r = _t->execUnban((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 30: { OutputFilterResult _r = _t->command_op((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 31: { OutputFilterResult _r = _t->command_deop((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 32: { OutputFilterResult _r = _t->command_hop((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 33: { OutputFilterResult _r = _t->command_dehop((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 34: { OutputFilterResult _r = _t->command_voice((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 35: { OutputFilterResult _r = _t->command_unvoice((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 36: { OutputFilterResult _r = _t->command_devoice((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 37: { OutputFilterResult _r = _t->command_join((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 38: { OutputFilterResult _r = _t->command_j((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 39: { OutputFilterResult _r = _t->command_kick((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 40: { OutputFilterResult _r = _t->command_part((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 41: { OutputFilterResult _r = _t->command_leave((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 42: { OutputFilterResult _r = _t->command_topic((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 43: { OutputFilterResult _r = _t->command_away((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 44: { OutputFilterResult _r = _t->command_unaway((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 45: { OutputFilterResult _r = _t->command_back((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 46: { OutputFilterResult _r = _t->command_aaway((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 47: { OutputFilterResult _r = _t->command_aunaway((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 48: { OutputFilterResult _r = _t->command_aback((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 49: { OutputFilterResult _r = _t->command_names((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 50: { OutputFilterResult _r = _t->command_close((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 51: { OutputFilterResult _r = _t->command_reconnect((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 52: { OutputFilterResult _r = _t->command_disconnect((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 53: { OutputFilterResult _r = _t->command_quit((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 54: { OutputFilterResult _r = _t->command_notice((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 55: { OutputFilterResult _r = _t->command_me((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 56: { OutputFilterResult _r = _t->command_msg((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 57: { OutputFilterResult _r = _t->command_m((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 58: { OutputFilterResult _r = _t->command_query((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 59: { OutputFilterResult _r = _t->command_smsg((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 60: { OutputFilterResult _r = _t->command_ping((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 61: { OutputFilterResult _r = _t->command_ctcp((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 62: { OutputFilterResult _r = _t->command_ame((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 63: { OutputFilterResult _r = _t->command_amsg((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 64: { OutputFilterResult _r = _t->command_omsg((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 65: { OutputFilterResult _r = _t->command_onotice((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 66: { OutputFilterResult _r = _t->command_quote((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 67: { OutputFilterResult _r = _t->command_say((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 68: { OutputFilterResult _r = _t->command_dcc((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 69: { OutputFilterResult _r = _t->command_invite((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 70: { OutputFilterResult _r = _t->command_exec((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 71: { OutputFilterResult _r = _t->command_raw((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 72: { OutputFilterResult _r = _t->command_notify((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 73: { OutputFilterResult _r = _t->command_oper((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 74: { OutputFilterResult _r = _t->command_ban((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 75: { OutputFilterResult _r = _t->command_kickban((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 76: { OutputFilterResult _r = _t->command_unban((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 77: { OutputFilterResult _r = _t->command_ignore((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 78: { OutputFilterResult _r = _t->command_unignore((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 79: { OutputFilterResult _r = _t->command_server((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 80: { OutputFilterResult _r = _t->command_charset((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 81: { OutputFilterResult _r = _t->command_encoding((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 82: { OutputFilterResult _r = _t->command_setkey((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 83: { OutputFilterResult _r = _t->command_keyx((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 84: { OutputFilterResult _r = _t->command_delkey((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 85: { OutputFilterResult _r = _t->command_showkey((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 86: { OutputFilterResult _r = _t->command_kill((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 87: { OutputFilterResult _r = _t->command_dns((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 88: { OutputFilterResult _r = _t->command_list((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 89: { OutputFilterResult _r = _t->command_konsole((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 90: { OutputFilterResult _r = _t->command_queuetuner((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 91: { OutputFilterResult _r = _t->command_sayversion((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 92: { OutputFilterResult _r = _t->command_cycle((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 93: { OutputFilterResult _r = _t->command_clear((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        case 94: { OutputFilterResult _r = _t->command_umode((*reinterpret_cast< const OutputFilterInput(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< OutputFilterResult*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (OutputFilter::*_t)(const QString & , QUrl );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openDccSend)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::requestDccSend)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::requestDccSend)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openDccChat)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openDccWBoard)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::addDccPanel)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::closeDccPanel)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::acceptDccGet)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openRawLog)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::closeRawLog)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openKonsolePanel)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::openChannelList)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::sendToAllChannels)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(int , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::launchScript)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QStringList & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::banUsers)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::unbanUsers)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::multiServerCommand)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::reconnectServer)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::disconnectServer)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::quitServer)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(Konversation::ConnectionFlag , const QString & , const QString & , const QString & , const QString & , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::connectTo)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)(ChatWindow * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::showView)) {
                *result = 26;
                return;
            }
        }
        {
            typedef void (OutputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OutputFilter::encodingChanged)) {
                *result = 27;
                return;
            }
        }
    }
}

const QMetaObject Konversation::OutputFilter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__OutputFilter.data,
      qt_meta_data_Konversation__OutputFilter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::OutputFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::OutputFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__OutputFilter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::OutputFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 95)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 95;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 95)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 95;
    }
    return _id;
}

// SIGNAL 0
void Konversation::OutputFilter::openDccSend(const QString & _t1, QUrl _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::OutputFilter::requestDccSend()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Konversation::OutputFilter::requestDccSend(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Konversation::OutputFilter::openDccChat(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Konversation::OutputFilter::openDccWBoard(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Konversation::OutputFilter::addDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Konversation::OutputFilter::closeDccPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Konversation::OutputFilter::acceptDccGet(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Konversation::OutputFilter::openRawLog(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Konversation::OutputFilter::closeRawLog()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Konversation::OutputFilter::openKonsolePanel()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Konversation::OutputFilter::openChannelList(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Konversation::OutputFilter::sendToAllChannels(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Konversation::OutputFilter::launchScript(int _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Konversation::OutputFilter::banUsers(const QStringList & _t1, const QString & _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Konversation::OutputFilter::unbanUsers(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Konversation::OutputFilter::multiServerCommand(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Konversation::OutputFilter::reconnectServer(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Konversation::OutputFilter::disconnectServer(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Konversation::OutputFilter::quitServer(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Konversation::OutputFilter::connectTo(Konversation::ConnectionFlag _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, bool _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 26
void Konversation::OutputFilter::showView(ChatWindow * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void Konversation::OutputFilter::encodingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
