/****************************************************************************
** Meta object code from reading C++ file 'topichistoryview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/topichistoryview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'topichistoryview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TopicHistorySortfilterProxyModel_t {
    QByteArrayData data[5];
    char stringdata0[72];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopicHistorySortfilterProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopicHistorySortfilterProxyModel_t qt_meta_stringdata_TopicHistorySortfilterProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 32), // "TopicHistorySortfilterProxyModel"
QT_MOC_LITERAL(1, 33, 17), // "sourceDataChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 7), // "topLeft"
QT_MOC_LITERAL(4, 60, 11) // "bottomRight"

    },
    "TopicHistorySortfilterProxyModel\0"
    "sourceDataChanged\0\0topLeft\0bottomRight"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopicHistorySortfilterProxyModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    3,    4,

       0        // eod
};

void TopicHistorySortfilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TopicHistorySortfilterProxyModel *_t = static_cast<TopicHistorySortfilterProxyModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sourceDataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject TopicHistorySortfilterProxyModel::staticMetaObject = {
    { &KCategorizedSortFilterProxyModel::staticMetaObject, qt_meta_stringdata_TopicHistorySortfilterProxyModel.data,
      qt_meta_data_TopicHistorySortfilterProxyModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TopicHistorySortfilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopicHistorySortfilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopicHistorySortfilterProxyModel.stringdata0))
        return static_cast<void*>(this);
    return KCategorizedSortFilterProxyModel::qt_metacast(_clname);
}

int TopicHistorySortfilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCategorizedSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_TopicHistoryLabel_t {
    QByteArrayData data[4];
    char stringdata0[48];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopicHistoryLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopicHistoryLabel_t qt_meta_stringdata_TopicHistoryLabel = {
    {
QT_MOC_LITERAL(0, 0, 17), // "TopicHistoryLabel"
QT_MOC_LITERAL(1, 18, 17), // "setTextSelectable"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 10) // "selectable"

    },
    "TopicHistoryLabel\0setTextSelectable\0"
    "\0selectable"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopicHistoryLabel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,

       0        // eod
};

void TopicHistoryLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TopicHistoryLabel *_t = static_cast<TopicHistoryLabel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setTextSelectable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject TopicHistoryLabel::staticMetaObject = {
    { &KTextEdit::staticMetaObject, qt_meta_stringdata_TopicHistoryLabel.data,
      qt_meta_data_TopicHistoryLabel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TopicHistoryLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopicHistoryLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopicHistoryLabel.stringdata0))
        return static_cast<void*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int TopicHistoryLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_TopicHistoryItemDelegate_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopicHistoryItemDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopicHistoryItemDelegate_t qt_meta_stringdata_TopicHistoryItemDelegate = {
    {
QT_MOC_LITERAL(0, 0, 24) // "TopicHistoryItemDelegate"

    },
    "TopicHistoryItemDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopicHistoryItemDelegate[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void TopicHistoryItemDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject TopicHistoryItemDelegate::staticMetaObject = {
    { &KWidgetItemDelegate::staticMetaObject, qt_meta_stringdata_TopicHistoryItemDelegate.data,
      qt_meta_data_TopicHistoryItemDelegate,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TopicHistoryItemDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopicHistoryItemDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopicHistoryItemDelegate.stringdata0))
        return static_cast<void*>(this);
    return KWidgetItemDelegate::qt_metacast(_clname);
}

int TopicHistoryItemDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KWidgetItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_TopicHistoryView_t {
    QByteArrayData data[5];
    char stringdata0[77];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopicHistoryView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopicHistoryView_t qt_meta_stringdata_TopicHistoryView = {
    {
QT_MOC_LITERAL(0, 0, 16), // "TopicHistoryView"
QT_MOC_LITERAL(1, 17, 21), // "textSelectableChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 10), // "selectable"
QT_MOC_LITERAL(4, 51, 25) // "updateSelectedItemWidgets"

    },
    "TopicHistoryView\0textSelectableChanged\0"
    "\0selectable\0updateSelectedItemWidgets"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopicHistoryView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   27,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void TopicHistoryView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TopicHistoryView *_t = static_cast<TopicHistoryView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->textSelectableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->updateSelectedItemWidgets(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TopicHistoryView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TopicHistoryView::textSelectableChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject TopicHistoryView::staticMetaObject = {
    { &KCategorizedView::staticMetaObject, qt_meta_stringdata_TopicHistoryView.data,
      qt_meta_data_TopicHistoryView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TopicHistoryView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopicHistoryView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopicHistoryView.stringdata0))
        return static_cast<void*>(this);
    return KCategorizedView::qt_metacast(_clname);
}

int TopicHistoryView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCategorizedView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TopicHistoryView::textSelectableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
