/****************************************************************************
** Meta object code from reading C++ file 'quickconnectdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/quickconnectdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickconnectdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QuickConnectDialog_t {
    QByteArrayData data[13];
    char stringdata0[141];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QuickConnectDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QuickConnectDialog_t qt_meta_stringdata_QuickConnectDialog = {
    {
QT_MOC_LITERAL(0, 0, 18), // "QuickConnectDialog"
QT_MOC_LITERAL(1, 19, 14), // "connectClicked"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 28), // "Konversation::ConnectionFlag"
QT_MOC_LITERAL(4, 64, 4), // "flag"
QT_MOC_LITERAL(5, 69, 8), // "hostName"
QT_MOC_LITERAL(6, 78, 4), // "port"
QT_MOC_LITERAL(7, 83, 8), // "password"
QT_MOC_LITERAL(8, 92, 4), // "nick"
QT_MOC_LITERAL(9, 97, 7), // "channel"
QT_MOC_LITERAL(10, 105, 6), // "useSSL"
QT_MOC_LITERAL(11, 112, 6), // "slotOk"
QT_MOC_LITERAL(12, 119, 21) // "slotServerNameChanged"

    },
    "QuickConnectDialog\0connectClicked\0\0"
    "Konversation::ConnectionFlag\0flag\0"
    "hostName\0port\0password\0nick\0channel\0"
    "useSSL\0slotOk\0slotServerNameChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QuickConnectDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    7,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   44,    2, 0x09 /* Protected */,
      12,    1,   45,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    4,    5,    6,    7,    8,    9,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void QuickConnectDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QuickConnectDialog *_t = static_cast<QuickConnectDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connectClicked((*reinterpret_cast< Konversation::ConnectionFlag(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 1: _t->slotOk(); break;
        case 2: _t->slotServerNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QuickConnectDialog::*_t)(Konversation::ConnectionFlag , const QString & , const QString & , const QString & , const QString & , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QuickConnectDialog::connectClicked)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject QuickConnectDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_QuickConnectDialog.data,
      qt_meta_data_QuickConnectDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QuickConnectDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QuickConnectDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QuickConnectDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int QuickConnectDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QuickConnectDialog::connectClicked(Konversation::ConnectionFlag _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, bool _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
