/****************************************************************************
** Meta object code from reading C++ file 'chatwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/chatwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatWindow_t {
    QByteArrayData data[30];
    char stringdata0[370];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatWindow_t qt_meta_stringdata_ChatWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ChatWindow"
QT_MOC_LITERAL(1, 11, 11), // "nameChanged"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 11), // "ChatWindow*"
QT_MOC_LITERAL(4, 36, 4), // "view"
QT_MOC_LITERAL(5, 41, 7), // "newName"
QT_MOC_LITERAL(6, 49, 10), // "updateInfo"
QT_MOC_LITERAL(7, 60, 4), // "info"
QT_MOC_LITERAL(8, 65, 21), // "updateTabNotification"
QT_MOC_LITERAL(9, 87, 7), // "chatWin"
QT_MOC_LITERAL(10, 95, 27), // "Konversation::TabNotifyType"
QT_MOC_LITERAL(11, 123, 4), // "type"
QT_MOC_LITERAL(12, 128, 20), // "setStatusBarTempText"
QT_MOC_LITERAL(13, 149, 22), // "clearStatusBarTempText"
QT_MOC_LITERAL(14, 172, 7), // "closing"
QT_MOC_LITERAL(15, 180, 6), // "myself"
QT_MOC_LITERAL(16, 187, 16), // "updateAppearance"
QT_MOC_LITERAL(17, 204, 7), // "logText"
QT_MOC_LITERAL(18, 212, 4), // "text"
QT_MOC_LITERAL(19, 217, 11), // "adjustFocus"
QT_MOC_LITERAL(20, 229, 15), // "appendInputText"
QT_MOC_LITERAL(21, 245, 10), // "fromCursor"
QT_MOC_LITERAL(22, 256, 12), // "indicateAway"
QT_MOC_LITERAL(23, 269, 4), // "away"
QT_MOC_LITERAL(24, 274, 23), // "setNotificationsEnabled"
QT_MOC_LITERAL(25, 298, 6), // "enable"
QT_MOC_LITERAL(26, 305, 23), // "activateTabNotification"
QT_MOC_LITERAL(27, 329, 20), // "resetTabNotification"
QT_MOC_LITERAL(28, 350, 12), // "serverOnline"
QT_MOC_LITERAL(29, 363, 6) // "online"

    },
    "ChatWindow\0nameChanged\0\0ChatWindow*\0"
    "view\0newName\0updateInfo\0info\0"
    "updateTabNotification\0chatWin\0"
    "Konversation::TabNotifyType\0type\0"
    "setStatusBarTempText\0clearStatusBarTempText\0"
    "closing\0myself\0updateAppearance\0logText\0"
    "text\0adjustFocus\0appendInputText\0"
    "fromCursor\0indicateAway\0away\0"
    "setNotificationsEnabled\0enable\0"
    "activateTabNotification\0resetTabNotification\0"
    "serverOnline\0online"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x06 /* Public */,
       6,    1,   94,    2, 0x06 /* Public */,
       8,    2,   97,    2, 0x06 /* Public */,
      12,    1,  102,    2, 0x06 /* Public */,
      13,    0,  105,    2, 0x06 /* Public */,
      14,    1,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  109,    2, 0x0a /* Public */,
      17,    1,  110,    2, 0x0a /* Public */,
      19,    0,  113,    2, 0x0a /* Public */,
      20,    2,  114,    2, 0x0a /* Public */,
      22,    1,  119,    2, 0x0a /* Public */,
      24,    1,  122,    2, 0x0a /* Public */,
      26,    1,  125,    2, 0x0a /* Public */,
      27,    0,  128,    2, 0x0a /* Public */,
      28,    1,  129,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 10,    9,   11,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   15,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   18,   21,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,

       0        // eod
};

void ChatWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ChatWindow *_t = static_cast<ChatWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nameChanged((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->updateInfo((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->updateTabNotification((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const Konversation::TabNotifyType(*)>(_a[2]))); break;
        case 3: _t->setStatusBarTempText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->clearStatusBarTempText(); break;
        case 5: _t->closing((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 6: _t->updateAppearance(); break;
        case 7: _t->logText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->adjustFocus(); break;
        case 9: _t->appendInputText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->indicateAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setNotificationsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->activateTabNotification((*reinterpret_cast< Konversation::TabNotifyType(*)>(_a[1]))); break;
        case 13: _t->resetTabNotification(); break;
        case 14: _t->serverOnline((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ChatWindow::*_t)(ChatWindow * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::nameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ChatWindow::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::updateInfo)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ChatWindow::*_t)(ChatWindow * , const Konversation::TabNotifyType & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::updateTabNotification)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ChatWindow::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::setStatusBarTempText)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ChatWindow::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::clearStatusBarTempText)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ChatWindow::*_t)(ChatWindow * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatWindow::closing)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject ChatWindow::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ChatWindow.data,
      qt_meta_data_ChatWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ChatWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatWindow.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ChatWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void ChatWindow::nameChanged(ChatWindow * _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ChatWindow::updateInfo(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ChatWindow::updateTabNotification(ChatWindow * _t1, const Konversation::TabNotifyType & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ChatWindow::setStatusBarTempText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void ChatWindow::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ChatWindow::closing(ChatWindow * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
