/****************************************************************************
** Meta object code from reading C++ file 'whiteboardcolorchooser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/whiteboardcolorchooser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'whiteboardcolorchooser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser_t {
    QByteArrayData data[13];
    char stringdata0[211];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser_t qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser = {
    {
QT_MOC_LITERAL(0, 0, 41), // "Konversation::DCC::WhiteBoard..."
QT_MOC_LITERAL(1, 42, 13), // "colorsSwapped"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 18), // "newForegroundColor"
QT_MOC_LITERAL(4, 76, 18), // "newBackgroundColor"
QT_MOC_LITERAL(5, 95, 22), // "foregroundColorChanged"
QT_MOC_LITERAL(6, 118, 5), // "color"
QT_MOC_LITERAL(7, 124, 22), // "backgroundColorChanged"
QT_MOC_LITERAL(8, 147, 8), // "setColor"
QT_MOC_LITERAL(9, 156, 10), // "ColorLayer"
QT_MOC_LITERAL(10, 167, 5), // "layer"
QT_MOC_LITERAL(11, 173, 18), // "setForegroundColor"
QT_MOC_LITERAL(12, 192, 18) // "setBackgroundColor"

    },
    "Konversation::DCC::WhiteBoardColorChooser\0"
    "colorsSwapped\0\0newForegroundColor\0"
    "newBackgroundColor\0foregroundColorChanged\0"
    "color\0backgroundColorChanged\0setColor\0"
    "ColorLayer\0layer\0setForegroundColor\0"
    "setBackgroundColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__WhiteBoardColorChooser[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x06 /* Public */,
       5,    1,   49,    2, 0x06 /* Public */,
       7,    1,   52,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   55,    2, 0x0a /* Public */,
      11,    1,   60,    2, 0x0a /* Public */,
      12,    1,   63,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor, QMetaType::QColor,    3,    4,
    QMetaType::Void, QMetaType::QColor,    6,
    QMetaType::Void, QMetaType::QColor,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9, QMetaType::QColor,   10,    6,
    QMetaType::Void, QMetaType::QColor,    6,
    QMetaType::Void, QMetaType::QColor,    6,

       0        // eod
};

void Konversation::DCC::WhiteBoardColorChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WhiteBoardColorChooser *_t = static_cast<WhiteBoardColorChooser *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->colorsSwapped((*reinterpret_cast< const QColor(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 1: _t->foregroundColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 2: _t->backgroundColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 3: _t->setColor((*reinterpret_cast< ColorLayer(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2]))); break;
        case 4: _t->setForegroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 5: _t->setBackgroundColor((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WhiteBoardColorChooser::*_t)(const QColor & , const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardColorChooser::colorsSwapped)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WhiteBoardColorChooser::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardColorChooser::foregroundColorChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WhiteBoardColorChooser::*_t)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WhiteBoardColorChooser::backgroundColorChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::WhiteBoardColorChooser::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser.data,
      qt_meta_data_Konversation__DCC__WhiteBoardColorChooser,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::WhiteBoardColorChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::WhiteBoardColorChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__WhiteBoardColorChooser.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int Konversation::DCC::WhiteBoardColorChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::WhiteBoardColorChooser::colorsSwapped(const QColor & _t1, const QColor & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::WhiteBoardColorChooser::foregroundColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::WhiteBoardColorChooser::backgroundColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
