/****************************************************************************
** Meta object code from reading C++ file 'statusbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/statusbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__StatusBar_t {
    QByteArrayData data[22];
    char stringdata0[298];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__StatusBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__StatusBar_t qt_meta_stringdata_Konversation__StatusBar = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Konversation::StatusBar"
QT_MOC_LITERAL(1, 24, 16), // "updateAppearance"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 14), // "resetStatusBar"
QT_MOC_LITERAL(4, 57, 16), // "setMainLabelText"
QT_MOC_LITERAL(5, 74, 4), // "text"
QT_MOC_LITERAL(6, 79, 20), // "setMainLabelTempText"
QT_MOC_LITERAL(7, 100, 22), // "clearMainLabelTempText"
QT_MOC_LITERAL(8, 123, 17), // "setInfoLabelShown"
QT_MOC_LITERAL(9, 141, 5), // "shown"
QT_MOC_LITERAL(10, 147, 15), // "updateInfoLabel"
QT_MOC_LITERAL(11, 163, 14), // "clearInfoLabel"
QT_MOC_LITERAL(12, 178, 16), // "setLagLabelShown"
QT_MOC_LITERAL(13, 195, 14), // "updateLagLabel"
QT_MOC_LITERAL(14, 210, 7), // "Server*"
QT_MOC_LITERAL(15, 218, 9), // "lagServer"
QT_MOC_LITERAL(16, 228, 4), // "msec"
QT_MOC_LITERAL(17, 233, 13), // "resetLagLabel"
QT_MOC_LITERAL(18, 247, 13), // "setTooLongLag"
QT_MOC_LITERAL(19, 261, 14), // "updateSSLLabel"
QT_MOC_LITERAL(20, 276, 6), // "server"
QT_MOC_LITERAL(21, 283, 14) // "removeSSLLabel"

    },
    "Konversation::StatusBar\0updateAppearance\0"
    "\0resetStatusBar\0setMainLabelText\0text\0"
    "setMainLabelTempText\0clearMainLabelTempText\0"
    "setInfoLabelShown\0shown\0updateInfoLabel\0"
    "clearInfoLabel\0setLagLabelShown\0"
    "updateLagLabel\0Server*\0lagServer\0msec\0"
    "resetLagLabel\0setTooLongLag\0updateSSLLabel\0"
    "server\0removeSSLLabel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__StatusBar[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x0a /* Public */,
       4,    1,   91,    2, 0x0a /* Public */,
       6,    1,   94,    2, 0x0a /* Public */,
       7,    0,   97,    2, 0x0a /* Public */,
       8,    1,   98,    2, 0x0a /* Public */,
      10,    1,  101,    2, 0x0a /* Public */,
      11,    0,  104,    2, 0x0a /* Public */,
      12,    1,  105,    2, 0x0a /* Public */,
      13,    2,  108,    2, 0x0a /* Public */,
      17,    1,  113,    2, 0x0a /* Public */,
      17,    0,  116,    2, 0x2a /* Public | MethodCloned */,
      18,    2,  117,    2, 0x0a /* Public */,
      19,    1,  122,    2, 0x0a /* Public */,
      21,    0,  125,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, 0x80000000 | 14, QMetaType::Int,   15,   16,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14, QMetaType::Int,   15,   16,
    QMetaType::Void, 0x80000000 | 14,   20,
    QMetaType::Void,

       0        // eod
};

void Konversation::StatusBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StatusBar *_t = static_cast<StatusBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->updateAppearance(); break;
        case 1: _t->resetStatusBar(); break;
        case 2: _t->setMainLabelText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setMainLabelTempText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->clearMainLabelTempText(); break;
        case 5: _t->setInfoLabelShown((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->updateInfoLabel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->clearInfoLabel(); break;
        case 8: _t->setLagLabelShown((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->updateLagLabel((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->resetLagLabel((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 11: _t->resetLagLabel(); break;
        case 12: _t->setTooLongLag((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->updateSSLLabel((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 14: _t->removeSSLLabel(); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::StatusBar::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__StatusBar.data,
      qt_meta_data_Konversation__StatusBar,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::StatusBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::StatusBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__StatusBar.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::StatusBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
