#include <klocalizedstring.h>

/*
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

*/

/********************************************************************************
** Form generated from reading UI file 'generalbehavior_configui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALBEHAVIOR_CONFIGUI_H
#define UI_GENERALBEHAVIOR_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralBehavior_ConfigUI
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *kcfg_ShowTrayIcon;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_TrayNotify;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacer51;
    QCheckBox *kcfg_TrayNotifyOnlyOwnNick;
    QCheckBox *kcfg_HideToTrayOnStartup;
    QGroupBox *middleLabel;
    QGridLayout *gridLayout;
    QLabel *modeLbl;
    KComboBox *kcfg_NickCompletionMode;
    KLineEdit *kcfg_NickCompleteSuffixStart;
    QLabel *startOfLineLabel;
    KLineEdit *kcfg_NickCompleteSuffixMiddle;
    QLabel *textLabel3;
    QCheckBox *kcfg_NickCompletionCaseSensitive;
    QGroupBox *miscGBox;
    QGridLayout *gridLayout1;
    QCheckBox *kcfg_DisableNotifyWhileAway;
    QCheckBox *kcfg_CustomVersionReplyEnabled;
    KLineEdit *kcfg_CustomVersionReply;
    KLineEdit *kcfg_CommandChar;
    QCheckBox *kcfg_UseMultiRowInputBox;
    KLineEdit *kcfg_WebBrowserCmd;
    QLabel *commandCharLabel;
    QCheckBox *kcfg_UseCustomBrowser;
    QSpacerItem *spacer52;

    void setupUi(QWidget *GeneralBehavior_ConfigUI)
    {
        if (GeneralBehavior_ConfigUI->objectName().isEmpty())
            GeneralBehavior_ConfigUI->setObjectName(QStringLiteral("GeneralBehavior_ConfigUI"));
        GeneralBehavior_ConfigUI->resize(508, 477);
        verticalLayout_2 = new QVBoxLayout(GeneralBehavior_ConfigUI);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        kcfg_ShowTrayIcon = new QGroupBox(GeneralBehavior_ConfigUI);
        kcfg_ShowTrayIcon->setObjectName(QStringLiteral("kcfg_ShowTrayIcon"));
        kcfg_ShowTrayIcon->setCheckable(true);
        kcfg_ShowTrayIcon->setChecked(false);
        verticalLayout = new QVBoxLayout(kcfg_ShowTrayIcon);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        kcfg_TrayNotify = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_TrayNotify->setObjectName(QStringLiteral("kcfg_TrayNotify"));

        verticalLayout->addWidget(kcfg_TrayNotify);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        spacer51 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacer51);

        kcfg_TrayNotifyOnlyOwnNick = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_TrayNotifyOnlyOwnNick->setObjectName(QStringLiteral("kcfg_TrayNotifyOnlyOwnNick"));
        kcfg_TrayNotifyOnlyOwnNick->setEnabled(false);

        horizontalLayout->addWidget(kcfg_TrayNotifyOnlyOwnNick);


        verticalLayout->addLayout(horizontalLayout);

        kcfg_HideToTrayOnStartup = new QCheckBox(kcfg_ShowTrayIcon);
        kcfg_HideToTrayOnStartup->setObjectName(QStringLiteral("kcfg_HideToTrayOnStartup"));

        verticalLayout->addWidget(kcfg_HideToTrayOnStartup);


        verticalLayout_2->addWidget(kcfg_ShowTrayIcon);

        middleLabel = new QGroupBox(GeneralBehavior_ConfigUI);
        middleLabel->setObjectName(QStringLiteral("middleLabel"));
        gridLayout = new QGridLayout(middleLabel);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        modeLbl = new QLabel(middleLabel);
        modeLbl->setObjectName(QStringLiteral("modeLbl"));
        modeLbl->setWordWrap(false);

        gridLayout->addWidget(modeLbl, 0, 0, 1, 1);

        kcfg_NickCompletionMode = new KComboBox(middleLabel);
        kcfg_NickCompletionMode->setObjectName(QStringLiteral("kcfg_NickCompletionMode"));

        gridLayout->addWidget(kcfg_NickCompletionMode, 0, 1, 1, 3);

        kcfg_NickCompleteSuffixStart = new KLineEdit(middleLabel);
        kcfg_NickCompleteSuffixStart->setObjectName(QStringLiteral("kcfg_NickCompleteSuffixStart"));

        gridLayout->addWidget(kcfg_NickCompleteSuffixStart, 1, 1, 1, 1);

        startOfLineLabel = new QLabel(middleLabel);
        startOfLineLabel->setObjectName(QStringLiteral("startOfLineLabel"));
        startOfLineLabel->setWordWrap(false);

        gridLayout->addWidget(startOfLineLabel, 1, 0, 1, 1);

        kcfg_NickCompleteSuffixMiddle = new KLineEdit(middleLabel);
        kcfg_NickCompleteSuffixMiddle->setObjectName(QStringLiteral("kcfg_NickCompleteSuffixMiddle"));

        gridLayout->addWidget(kcfg_NickCompleteSuffixMiddle, 1, 3, 1, 1);

        textLabel3 = new QLabel(middleLabel);
        textLabel3->setObjectName(QStringLiteral("textLabel3"));
        textLabel3->setWordWrap(false);

        gridLayout->addWidget(textLabel3, 1, 2, 1, 1);

        kcfg_NickCompletionCaseSensitive = new QCheckBox(middleLabel);
        kcfg_NickCompletionCaseSensitive->setObjectName(QStringLiteral("kcfg_NickCompletionCaseSensitive"));

        gridLayout->addWidget(kcfg_NickCompletionCaseSensitive, 2, 0, 1, 1);


        verticalLayout_2->addWidget(middleLabel);

        miscGBox = new QGroupBox(GeneralBehavior_ConfigUI);
        miscGBox->setObjectName(QStringLiteral("miscGBox"));
        gridLayout1 = new QGridLayout(miscGBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        kcfg_DisableNotifyWhileAway = new QCheckBox(miscGBox);
        kcfg_DisableNotifyWhileAway->setObjectName(QStringLiteral("kcfg_DisableNotifyWhileAway"));

        gridLayout1->addWidget(kcfg_DisableNotifyWhileAway, 0, 0, 1, 2);

        kcfg_CustomVersionReplyEnabled = new QCheckBox(miscGBox);
        kcfg_CustomVersionReplyEnabled->setObjectName(QStringLiteral("kcfg_CustomVersionReplyEnabled"));

        gridLayout1->addWidget(kcfg_CustomVersionReplyEnabled, 5, 0, 1, 1);

        kcfg_CustomVersionReply = new KLineEdit(miscGBox);
        kcfg_CustomVersionReply->setObjectName(QStringLiteral("kcfg_CustomVersionReply"));
        kcfg_CustomVersionReply->setEnabled(false);

        gridLayout1->addWidget(kcfg_CustomVersionReply, 5, 1, 1, 1);

        kcfg_CommandChar = new KLineEdit(miscGBox);
        kcfg_CommandChar->setObjectName(QStringLiteral("kcfg_CommandChar"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_CommandChar->sizePolicy().hasHeightForWidth());
        kcfg_CommandChar->setSizePolicy(sizePolicy);
        kcfg_CommandChar->setMaxLength(1);

        gridLayout1->addWidget(kcfg_CommandChar, 4, 1, 1, 1);

        kcfg_UseMultiRowInputBox = new QCheckBox(miscGBox);
        kcfg_UseMultiRowInputBox->setObjectName(QStringLiteral("kcfg_UseMultiRowInputBox"));

        gridLayout1->addWidget(kcfg_UseMultiRowInputBox, 6, 0, 1, 2);

        kcfg_WebBrowserCmd = new KLineEdit(miscGBox);
        kcfg_WebBrowserCmd->setObjectName(QStringLiteral("kcfg_WebBrowserCmd"));
        kcfg_WebBrowserCmd->setEnabled(false);

        gridLayout1->addWidget(kcfg_WebBrowserCmd, 3, 1, 1, 1);

        commandCharLabel = new QLabel(miscGBox);
        commandCharLabel->setObjectName(QStringLiteral("commandCharLabel"));
        commandCharLabel->setWordWrap(false);

        gridLayout1->addWidget(commandCharLabel, 4, 0, 1, 1);

        kcfg_UseCustomBrowser = new QCheckBox(miscGBox);
        kcfg_UseCustomBrowser->setObjectName(QStringLiteral("kcfg_UseCustomBrowser"));

        gridLayout1->addWidget(kcfg_UseCustomBrowser, 3, 0, 1, 1);


        verticalLayout_2->addWidget(miscGBox);

        spacer52 = new QSpacerItem(20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(spacer52);

#ifndef UI_QT_NO_SHORTCUT
        modeLbl->setBuddy(kcfg_NickCompletionMode);
        startOfLineLabel->setBuddy(kcfg_NickCompleteSuffixStart);
        textLabel3->setBuddy(kcfg_NickCompleteSuffixMiddle);
        commandCharLabel->setBuddy(kcfg_CommandChar);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_ShowTrayIcon, kcfg_TrayNotify);
        QWidget::setTabOrder(kcfg_TrayNotify, kcfg_TrayNotifyOnlyOwnNick);
        QWidget::setTabOrder(kcfg_TrayNotifyOnlyOwnNick, kcfg_HideToTrayOnStartup);
        QWidget::setTabOrder(kcfg_HideToTrayOnStartup, kcfg_NickCompletionMode);
        QWidget::setTabOrder(kcfg_NickCompletionMode, kcfg_NickCompleteSuffixStart);
        QWidget::setTabOrder(kcfg_NickCompleteSuffixStart, kcfg_NickCompleteSuffixMiddle);
        QWidget::setTabOrder(kcfg_NickCompleteSuffixMiddle, kcfg_NickCompletionCaseSensitive);
        QWidget::setTabOrder(kcfg_NickCompletionCaseSensitive, kcfg_DisableNotifyWhileAway);
        QWidget::setTabOrder(kcfg_DisableNotifyWhileAway, kcfg_UseCustomBrowser);
        QWidget::setTabOrder(kcfg_UseCustomBrowser, kcfg_WebBrowserCmd);
        QWidget::setTabOrder(kcfg_WebBrowserCmd, kcfg_CommandChar);
        QWidget::setTabOrder(kcfg_CommandChar, kcfg_CustomVersionReplyEnabled);
        QWidget::setTabOrder(kcfg_CustomVersionReplyEnabled, kcfg_CustomVersionReply);
        QWidget::setTabOrder(kcfg_CustomVersionReply, kcfg_UseMultiRowInputBox);

        retranslateUi(GeneralBehavior_ConfigUI);
        QObject::connect(kcfg_TrayNotify, SIGNAL(toggled(bool)), kcfg_TrayNotifyOnlyOwnNick, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_UseCustomBrowser, SIGNAL(toggled(bool)), kcfg_WebBrowserCmd, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_CustomVersionReplyEnabled, SIGNAL(toggled(bool)), kcfg_CustomVersionReply, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(GeneralBehavior_ConfigUI);
    } // setupUi

    void retranslateUi(QWidget *GeneralBehavior_ConfigUI)
    {
        kcfg_ShowTrayIcon->setTitle(tr2i18n("Enable System Tray", Q_NULLPTR));
        kcfg_TrayNotify->setText(tr2i18n("&Use system tray for new message notification", Q_NULLPTR));
        kcfg_TrayNotifyOnlyOwnNick->setText(tr2i18n("Only &notify when a highlight is triggered or your current nick is used", Q_NULLPTR));
        kcfg_HideToTrayOnStartup->setText(tr2i18n("Hide window on startup", Q_NULLPTR));
        middleLabel->setTitle(tr2i18n("Nickname Completion", Q_NULLPTR));
        modeLbl->setText(tr2i18n("Completion &mode:", Q_NULLPTR));
        kcfg_NickCompletionMode->clear();
        kcfg_NickCompletionMode->insertItems(0, QStringList()
         << tr2i18n("Inline Cycle", Q_NULLPTR)
         << tr2i18n("Shell-Like", Q_NULLPTR)
         << tr2i18n("Shell-Like with Completion Box", Q_NULLPTR)
        );
        startOfLineLabel->setText(tr2i18n("Suffi&x at start of line:", Q_NULLPTR));
        textLabel3->setText(tr2i18n("&Elsewhere:", Q_NULLPTR));
        kcfg_NickCompletionCaseSensitive->setText(tr2i18n("Case sensitive", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        kcfg_NickCompletionCaseSensitive->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        miscGBox->setTitle(tr2i18n("Miscellaneous", Q_NULLPTR));
        kcfg_DisableNotifyWhileAway->setText(tr2i18n("Disable notifications while &away", Q_NULLPTR));
        kcfg_CustomVersionReplyEnabled->setText(tr2i18n("Use custom &version reply:", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_CustomVersionReply->setWhatsThis(tr2i18n("<qt>Here you can set a custom reply for <b>CTCP <i>VERSION</i></b> requests.</qt>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_UseMultiRowInputBox->setText(tr2i18n("Input box expands with text", Q_NULLPTR));
        commandCharLabel->setText(tr2i18n("Comman&d char:", Q_NULLPTR));
        kcfg_UseCustomBrowser->setText(tr2i18n("Use custom web &browser:", Q_NULLPTR));
        Q_UNUSED(GeneralBehavior_ConfigUI);
    } // retranslateUi

};

namespace Ui {
    class GeneralBehavior_ConfigUI: public Ui_GeneralBehavior_ConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALBEHAVIOR_CONFIGUI_H

