/****************************************************************************
** Meta object code from reading C++ file 'upnpmcastsocket.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/upnp/upnpmcastsocket.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'upnpmcastsocket.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket_t {
    QByteArrayData data[14];
    char stringdata0[191];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket_t qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket = {
    {
QT_MOC_LITERAL(0, 0, 35), // "Konversation::UPnP::UPnPMCast..."
QT_MOC_LITERAL(1, 36, 10), // "discovered"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 31), // "Konversation::UPnP::UPnPRouter*"
QT_MOC_LITERAL(4, 80, 6), // "router"
QT_MOC_LITERAL(5, 87, 8), // "discover"
QT_MOC_LITERAL(6, 96, 11), // "onReadyRead"
QT_MOC_LITERAL(7, 108, 7), // "onError"
QT_MOC_LITERAL(8, 116, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(9, 145, 3), // "err"
QT_MOC_LITERAL(10, 149, 19), // "onXmlFileDownloaded"
QT_MOC_LITERAL(11, 169, 11), // "UPnPRouter*"
QT_MOC_LITERAL(12, 181, 1), // "r"
QT_MOC_LITERAL(13, 183, 7) // "success"

    },
    "Konversation::UPnP::UPnPMCastSocket\0"
    "discovered\0\0Konversation::UPnP::UPnPRouter*\0"
    "router\0discover\0onReadyRead\0onError\0"
    "QAbstractSocket::SocketError\0err\0"
    "onXmlFileDownloaded\0UPnPRouter*\0r\0"
    "success"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__UPnP__UPnPMCastSocket[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   42,    2, 0x0a /* Public */,
       6,    0,   43,    2, 0x08 /* Private */,
       7,    1,   44,    2, 0x08 /* Private */,
      10,    2,   47,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Bool,   12,   13,

       0        // eod
};

void Konversation::UPnP::UPnPMCastSocket::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UPnPMCastSocket *_t = static_cast<UPnPMCastSocket *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->discovered((*reinterpret_cast< Konversation::UPnP::UPnPRouter*(*)>(_a[1]))); break;
        case 1: _t->discover(); break;
        case 2: _t->onReadyRead(); break;
        case 3: _t->onError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 4: _t->onXmlFileDownloaded((*reinterpret_cast< UPnPRouter*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::UPnP::UPnPRouter* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UPnPRouter* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (UPnPMCastSocket::*_t)(Konversation::UPnP::UPnPRouter * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UPnPMCastSocket::discovered)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Konversation::UPnP::UPnPMCastSocket::staticMetaObject = {
    { &QUdpSocket::staticMetaObject, qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket.data,
      qt_meta_data_Konversation__UPnP__UPnPMCastSocket,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::UPnP::UPnPMCastSocket::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::UPnP::UPnPMCastSocket::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__UPnP__UPnPMCastSocket.stringdata0))
        return static_cast<void*>(this);
    return QUdpSocket::qt_metacast(_clname);
}

int Konversation::UPnP::UPnPMCastSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QUdpSocket::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Konversation::UPnP::UPnPMCastSocket::discovered(Konversation::UPnP::UPnPRouter * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
