/****************************************************************************
** Meta object code from reading C++ file 'configdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/config/configdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ConfigDialog_t {
    QByteArrayData data[19];
    char stringdata0[248];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ConfigDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ConfigDialog_t qt_meta_stringdata_ConfigDialog = {
    {
QT_MOC_LITERAL(0, 0, 12), // "ConfigDialog"
QT_MOC_LITERAL(1, 13, 14), // "widgetModified"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 15), // "settingsChanged"
QT_MOC_LITERAL(4, 45, 10), // "dialogName"
QT_MOC_LITERAL(5, 56, 14), // "updateSettings"
QT_MOC_LITERAL(6, 71, 13), // "updateWidgets"
QT_MOC_LITERAL(7, 85, 20), // "updateWidgetsDefault"
QT_MOC_LITERAL(8, 106, 13), // "updateButtons"
QT_MOC_LITERAL(9, 120, 19), // "settingsChangedSlot"
QT_MOC_LITERAL(10, 140, 7), // "setHelp"
QT_MOC_LITERAL(11, 148, 6), // "anchor"
QT_MOC_LITERAL(12, 155, 7), // "appname"
QT_MOC_LITERAL(13, 163, 8), // "showHelp"
QT_MOC_LITERAL(14, 172, 13), // "onPageRemoved"
QT_MOC_LITERAL(15, 186, 16), // "KPageWidgetItem*"
QT_MOC_LITERAL(16, 203, 4), // "item"
QT_MOC_LITERAL(17, 208, 16), // "_k_updateButtons"
QT_MOC_LITERAL(18, 225, 22) // "_k_settingsChangedSlot"

    },
    "ConfigDialog\0widgetModified\0\0"
    "settingsChanged\0dialogName\0updateSettings\0"
    "updateWidgets\0updateWidgetsDefault\0"
    "updateButtons\0settingsChangedSlot\0"
    "setHelp\0anchor\0appname\0showHelp\0"
    "onPageRemoved\0KPageWidgetItem*\0item\0"
    "_k_updateButtons\0_k_settingsChangedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ConfigDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    1,   80,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   83,    2, 0x09 /* Protected */,
       6,    0,   84,    2, 0x09 /* Protected */,
       7,    0,   85,    2, 0x09 /* Protected */,
       8,    0,   86,    2, 0x09 /* Protected */,
       9,    0,   87,    2, 0x09 /* Protected */,
      10,    2,   88,    2, 0x09 /* Protected */,
      10,    1,   93,    2, 0x29 /* Protected | MethodCloned */,
      13,    0,   96,    2, 0x09 /* Protected */,
      14,    1,   97,    2, 0x08 /* Private */,
      17,    0,  100,    2, 0x08 /* Private */,
      18,    0,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   11,   12,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConfigDialog *_t = static_cast<ConfigDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->widgetModified(); break;
        case 1: _t->settingsChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->updateSettings(); break;
        case 3: _t->updateWidgets(); break;
        case 4: _t->updateWidgetsDefault(); break;
        case 5: _t->updateButtons(); break;
        case 6: _t->settingsChangedSlot(); break;
        case 7: _t->setHelp((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->setHelp((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->showHelp(); break;
        case 10: _t->onPageRemoved((*reinterpret_cast< KPageWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->d->_k_updateButtons(); break;
        case 12: _t->d->_k_settingsChangedSlot(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPageWidgetItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ConfigDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigDialog::widgetModified)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ConfigDialog::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ConfigDialog::settingsChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject ConfigDialog::staticMetaObject = {
    { &KPageDialog::staticMetaObject, qt_meta_stringdata_ConfigDialog.data,
      qt_meta_data_ConfigDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ConfigDialog.stringdata0))
        return static_cast<void*>(this);
    return KPageDialog::qt_metacast(_clname);
}

int ConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPageDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ConfigDialog::widgetModified()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ConfigDialog::settingsChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
