/****************************************************************************
** Meta object code from reading C++ file 'viewcontainer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/viewcontainer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewcontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TabWidget_t {
    QByteArrayData data[8];
    char stringdata0[69];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TabWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TabWidget_t qt_meta_stringdata_TabWidget = {
    {
QT_MOC_LITERAL(0, 0, 9), // "TabWidget"
QT_MOC_LITERAL(1, 10, 11), // "contextMenu"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "QWidget*"
QT_MOC_LITERAL(4, 32, 6), // "widget"
QT_MOC_LITERAL(5, 39, 3), // "pos"
QT_MOC_LITERAL(6, 43, 19), // "tabBarMiddleClicked"
QT_MOC_LITERAL(7, 63, 5) // "index"

    },
    "TabWidget\0contextMenu\0\0QWidget*\0widget\0"
    "pos\0tabBarMiddleClicked\0index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TabWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x06 /* Public */,
       6,    1,   29,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QPoint,    4,    5,
    QMetaType::Void, QMetaType::Int,    7,

       0        // eod
};

void TabWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabWidget *_t = static_cast<TabWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->contextMenu((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 1: _t->tabBarMiddleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TabWidget::*_t)(QWidget * , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TabWidget::contextMenu)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TabWidget::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TabWidget::tabBarMiddleClicked)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject TabWidget::staticMetaObject = {
    { &QTabWidget::staticMetaObject, qt_meta_stringdata_TabWidget.data,
      qt_meta_data_TabWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TabWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TabWidget.stringdata0))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TabWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TabWidget::contextMenu(QWidget * _t1, const QPoint & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void TabWidget::tabBarMiddleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_ViewContainer_t {
    QByteArrayData data[135];
    char stringdata0[1989];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ViewContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ViewContainer_t qt_meta_stringdata_ViewContainer = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ViewContainer"
QT_MOC_LITERAL(1, 14, 11), // "viewChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 3), // "idx"
QT_MOC_LITERAL(4, 31, 16), // "setWindowCaption"
QT_MOC_LITERAL(5, 48, 7), // "caption"
QT_MOC_LITERAL(6, 56, 23), // "updateChannelAppearance"
QT_MOC_LITERAL(7, 80, 17), // "contextMenuClosed"
QT_MOC_LITERAL(8, 98, 14), // "resetStatusBar"
QT_MOC_LITERAL(9, 113, 20), // "setStatusBarTempText"
QT_MOC_LITERAL(10, 134, 4), // "text"
QT_MOC_LITERAL(11, 139, 22), // "clearStatusBarTempText"
QT_MOC_LITERAL(12, 162, 21), // "setStatusBarInfoLabel"
QT_MOC_LITERAL(13, 184, 23), // "clearStatusBarInfoLabel"
QT_MOC_LITERAL(14, 208, 25), // "setStatusBarLagLabelShown"
QT_MOC_LITERAL(15, 234, 5), // "shown"
QT_MOC_LITERAL(16, 240, 23), // "updateStatusBarLagLabel"
QT_MOC_LITERAL(17, 264, 7), // "Server*"
QT_MOC_LITERAL(18, 272, 6), // "server"
QT_MOC_LITERAL(19, 279, 4), // "msec"
QT_MOC_LITERAL(20, 284, 22), // "resetStatusBarLagLabel"
QT_MOC_LITERAL(21, 307, 30), // "setStatusBarLagLabelTooLongLag"
QT_MOC_LITERAL(22, 338, 23), // "updateStatusBarSSLLabel"
QT_MOC_LITERAL(23, 362, 23), // "removeStatusBarSSLLabel"
QT_MOC_LITERAL(24, 386, 15), // "autoJoinToggled"
QT_MOC_LITERAL(25, 402, 36), // "Konversation::ServerGroupSett..."
QT_MOC_LITERAL(26, 439, 27), // "autoConnectOnStartupToggled"
QT_MOC_LITERAL(27, 467, 19), // "frontServerChanging"
QT_MOC_LITERAL(28, 487, 16), // "updateAppearance"
QT_MOC_LITERAL(29, 504, 17), // "saveSplitterSizes"
QT_MOC_LITERAL(30, 522, 16), // "setViewTreeShown"
QT_MOC_LITERAL(31, 539, 4), // "show"
QT_MOC_LITERAL(32, 544, 11), // "updateViews"
QT_MOC_LITERAL(33, 556, 11), // "serverGroup"
QT_MOC_LITERAL(34, 568, 19), // "setViewNotification"
QT_MOC_LITERAL(35, 588, 11), // "ChatWindow*"
QT_MOC_LITERAL(36, 600, 6), // "widget"
QT_MOC_LITERAL(37, 607, 27), // "Konversation::TabNotifyType"
QT_MOC_LITERAL(38, 635, 4), // "type"
QT_MOC_LITERAL(39, 640, 21), // "unsetViewNotification"
QT_MOC_LITERAL(40, 662, 4), // "view"
QT_MOC_LITERAL(41, 667, 23), // "toggleViewNotifications"
QT_MOC_LITERAL(42, 691, 14), // "toggleAutoJoin"
QT_MOC_LITERAL(43, 706, 22), // "toggleConnectOnStartup"
QT_MOC_LITERAL(44, 729, 8), // "showView"
QT_MOC_LITERAL(45, 738, 8), // "goToView"
QT_MOC_LITERAL(46, 747, 4), // "page"
QT_MOC_LITERAL(47, 752, 12), // "showNextView"
QT_MOC_LITERAL(48, 765, 16), // "showPreviousView"
QT_MOC_LITERAL(49, 782, 18), // "showNextActiveView"
QT_MOC_LITERAL(50, 801, 19), // "showLastFocusedView"
QT_MOC_LITERAL(51, 821, 15), // "canMoveViewLeft"
QT_MOC_LITERAL(52, 837, 16), // "canMoveViewRight"
QT_MOC_LITERAL(53, 854, 12), // "moveViewLeft"
QT_MOC_LITERAL(54, 867, 13), // "moveViewRight"
QT_MOC_LITERAL(55, 881, 9), // "closeView"
QT_MOC_LITERAL(56, 891, 20), // "closeViewMiddleClick"
QT_MOC_LITERAL(57, 912, 16), // "closeCurrentView"
QT_MOC_LITERAL(58, 929, 13), // "renameKonsole"
QT_MOC_LITERAL(59, 943, 17), // "cleanupAfterClose"
QT_MOC_LITERAL(60, 961, 17), // "changeViewCharset"
QT_MOC_LITERAL(61, 979, 5), // "index"
QT_MOC_LITERAL(62, 985, 18), // "updateViewEncoding"
QT_MOC_LITERAL(63, 1004, 19), // "showViewContextMenu"
QT_MOC_LITERAL(64, 1024, 8), // "QWidget*"
QT_MOC_LITERAL(65, 1033, 3), // "tab"
QT_MOC_LITERAL(66, 1037, 3), // "pos"
QT_MOC_LITERAL(67, 1041, 9), // "clearView"
QT_MOC_LITERAL(68, 1051, 13), // "clearAllViews"
QT_MOC_LITERAL(69, 1065, 8), // "findText"
QT_MOC_LITERAL(70, 1074, 12), // "findNextText"
QT_MOC_LITERAL(71, 1087, 12), // "findPrevText"
QT_MOC_LITERAL(72, 1100, 15), // "insertCharacter"
QT_MOC_LITERAL(73, 1116, 10), // "insertChar"
QT_MOC_LITERAL(74, 1127, 3), // "chr"
QT_MOC_LITERAL(75, 1131, 14), // "insertIRCColor"
QT_MOC_LITERAL(76, 1146, 13), // "doAutoReplace"
QT_MOC_LITERAL(77, 1160, 13), // "focusInputBox"
QT_MOC_LITERAL(78, 1174, 14), // "clearViewLines"
QT_MOC_LITERAL(79, 1189, 18), // "insertRememberLine"
QT_MOC_LITERAL(80, 1208, 18), // "cancelRememberLine"
QT_MOC_LITERAL(81, 1227, 16), // "insertMarkerLine"
QT_MOC_LITERAL(82, 1244, 19), // "insertRememberLines"
QT_MOC_LITERAL(83, 1264, 11), // "openLogFile"
QT_MOC_LITERAL(84, 1276, 4), // "file"
QT_MOC_LITERAL(85, 1281, 15), // "addKonsolePanel"
QT_MOC_LITERAL(86, 1297, 6), // "zoomIn"
QT_MOC_LITERAL(87, 1304, 7), // "zoomOut"
QT_MOC_LITERAL(88, 1312, 9), // "resetFont"
QT_MOC_LITERAL(89, 1322, 13), // "addUrlCatcher"
QT_MOC_LITERAL(90, 1336, 15), // "closeUrlCatcher"
QT_MOC_LITERAL(91, 1352, 14), // "toggleDccPanel"
QT_MOC_LITERAL(92, 1367, 11), // "addDccPanel"
QT_MOC_LITERAL(93, 1379, 13), // "closeDccPanel"
QT_MOC_LITERAL(94, 1393, 14), // "deleteDccPanel"
QT_MOC_LITERAL(95, 1408, 11), // "getDccPanel"
QT_MOC_LITERAL(96, 1420, 10), // "addDccChat"
QT_MOC_LITERAL(97, 1431, 24), // "Konversation::DCC::Chat*"
QT_MOC_LITERAL(98, 1456, 6), // "myNick"
QT_MOC_LITERAL(99, 1463, 13), // "addStatusView"
QT_MOC_LITERAL(100, 1477, 12), // "StatusPanel*"
QT_MOC_LITERAL(101, 1490, 9), // "addRawLog"
QT_MOC_LITERAL(102, 1500, 7), // "RawLog*"
QT_MOC_LITERAL(103, 1508, 21), // "disconnectFrontServer"
QT_MOC_LITERAL(104, 1530, 20), // "reconnectFrontServer"
QT_MOC_LITERAL(105, 1551, 21), // "showJoinChannelDialog"
QT_MOC_LITERAL(106, 1573, 22), // "connectionStateChanged"
QT_MOC_LITERAL(107, 1596, 29), // "Konversation::ConnectionState"
QT_MOC_LITERAL(108, 1626, 5), // "state"
QT_MOC_LITERAL(109, 1632, 13), // "channelJoined"
QT_MOC_LITERAL(110, 1646, 8), // "Channel*"
QT_MOC_LITERAL(111, 1655, 7), // "channel"
QT_MOC_LITERAL(112, 1663, 10), // "addChannel"
QT_MOC_LITERAL(113, 1674, 4), // "name"
QT_MOC_LITERAL(114, 1679, 13), // "rejoinChannel"
QT_MOC_LITERAL(115, 1693, 19), // "openChannelSettings"
QT_MOC_LITERAL(116, 1713, 22), // "toggleChannelNicklists"
QT_MOC_LITERAL(117, 1736, 8), // "addQuery"
QT_MOC_LITERAL(118, 1745, 6), // "Query*"
QT_MOC_LITERAL(119, 1752, 11), // "NickInfoPtr"
QT_MOC_LITERAL(120, 1764, 11), // "weinitiated"
QT_MOC_LITERAL(121, 1776, 17), // "updateQueryChrome"
QT_MOC_LITERAL(122, 1794, 12), // "closeQueries"
QT_MOC_LITERAL(123, 1807, 19), // "addChannelListPanel"
QT_MOC_LITERAL(124, 1827, 17), // "ChannelListPanel*"
QT_MOC_LITERAL(125, 1845, 15), // "openChannelList"
QT_MOC_LITERAL(126, 1861, 6), // "filter"
QT_MOC_LITERAL(127, 1868, 7), // "getList"
QT_MOC_LITERAL(128, 1876, 20), // "openNicksOnlinePanel"
QT_MOC_LITERAL(129, 1897, 21), // "closeNicksOnlinePanel"
QT_MOC_LITERAL(130, 1919, 20), // "setupIrcContextMenus"
QT_MOC_LITERAL(131, 1940, 12), // "viewSwitched"
QT_MOC_LITERAL(132, 1953, 8), // "newIndex"
QT_MOC_LITERAL(133, 1962, 19), // "onViewTreeDestroyed"
QT_MOC_LITERAL(134, 1982, 6) // "object"

    },
    "ViewContainer\0viewChanged\0\0idx\0"
    "setWindowCaption\0caption\0"
    "updateChannelAppearance\0contextMenuClosed\0"
    "resetStatusBar\0setStatusBarTempText\0"
    "text\0clearStatusBarTempText\0"
    "setStatusBarInfoLabel\0clearStatusBarInfoLabel\0"
    "setStatusBarLagLabelShown\0shown\0"
    "updateStatusBarLagLabel\0Server*\0server\0"
    "msec\0resetStatusBarLagLabel\0"
    "setStatusBarLagLabelTooLongLag\0"
    "updateStatusBarSSLLabel\0removeStatusBarSSLLabel\0"
    "autoJoinToggled\0Konversation::ServerGroupSettingsPtr\0"
    "autoConnectOnStartupToggled\0"
    "frontServerChanging\0updateAppearance\0"
    "saveSplitterSizes\0setViewTreeShown\0"
    "show\0updateViews\0serverGroup\0"
    "setViewNotification\0ChatWindow*\0widget\0"
    "Konversation::TabNotifyType\0type\0"
    "unsetViewNotification\0view\0"
    "toggleViewNotifications\0toggleAutoJoin\0"
    "toggleConnectOnStartup\0showView\0"
    "goToView\0page\0showNextView\0showPreviousView\0"
    "showNextActiveView\0showLastFocusedView\0"
    "canMoveViewLeft\0canMoveViewRight\0"
    "moveViewLeft\0moveViewRight\0closeView\0"
    "closeViewMiddleClick\0closeCurrentView\0"
    "renameKonsole\0cleanupAfterClose\0"
    "changeViewCharset\0index\0updateViewEncoding\0"
    "showViewContextMenu\0QWidget*\0tab\0pos\0"
    "clearView\0clearAllViews\0findText\0"
    "findNextText\0findPrevText\0insertCharacter\0"
    "insertChar\0chr\0insertIRCColor\0"
    "doAutoReplace\0focusInputBox\0clearViewLines\0"
    "insertRememberLine\0cancelRememberLine\0"
    "insertMarkerLine\0insertRememberLines\0"
    "openLogFile\0file\0addKonsolePanel\0"
    "zoomIn\0zoomOut\0resetFont\0addUrlCatcher\0"
    "closeUrlCatcher\0toggleDccPanel\0"
    "addDccPanel\0closeDccPanel\0deleteDccPanel\0"
    "getDccPanel\0addDccChat\0Konversation::DCC::Chat*\0"
    "myNick\0addStatusView\0StatusPanel*\0"
    "addRawLog\0RawLog*\0disconnectFrontServer\0"
    "reconnectFrontServer\0showJoinChannelDialog\0"
    "connectionStateChanged\0"
    "Konversation::ConnectionState\0state\0"
    "channelJoined\0Channel*\0channel\0"
    "addChannel\0name\0rejoinChannel\0"
    "openChannelSettings\0toggleChannelNicklists\0"
    "addQuery\0Query*\0NickInfoPtr\0weinitiated\0"
    "updateQueryChrome\0closeQueries\0"
    "addChannelListPanel\0ChannelListPanel*\0"
    "openChannelList\0filter\0getList\0"
    "openNicksOnlinePanel\0closeNicksOnlinePanel\0"
    "setupIrcContextMenus\0viewSwitched\0"
    "newIndex\0onViewTreeDestroyed\0object"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ViewContainer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
     102,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  524,    2, 0x06 /* Public */,
       4,    1,  527,    2, 0x06 /* Public */,
       6,    0,  530,    2, 0x06 /* Public */,
       7,    0,  531,    2, 0x06 /* Public */,
       8,    0,  532,    2, 0x06 /* Public */,
       9,    1,  533,    2, 0x06 /* Public */,
      11,    0,  536,    2, 0x06 /* Public */,
      12,    1,  537,    2, 0x06 /* Public */,
      13,    0,  540,    2, 0x06 /* Public */,
      14,    1,  541,    2, 0x06 /* Public */,
      16,    2,  544,    2, 0x06 /* Public */,
      20,    1,  549,    2, 0x06 /* Public */,
      21,    2,  552,    2, 0x06 /* Public */,
      22,    1,  557,    2, 0x06 /* Public */,
      23,    0,  560,    2, 0x06 /* Public */,
      24,    1,  561,    2, 0x06 /* Public */,
      26,    1,  564,    2, 0x06 /* Public */,
      27,    1,  567,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      28,    0,  570,    2, 0x0a /* Public */,
      29,    0,  571,    2, 0x0a /* Public */,
      30,    1,  572,    2, 0x0a /* Public */,
      30,    0,  575,    2, 0x2a /* Public | MethodCloned */,
      32,    1,  576,    2, 0x0a /* Public */,
      32,    0,  579,    2, 0x2a /* Public | MethodCloned */,
      34,    2,  580,    2, 0x0a /* Public */,
      39,    1,  585,    2, 0x0a /* Public */,
      41,    0,  588,    2, 0x0a /* Public */,
      42,    0,  589,    2, 0x0a /* Public */,
      43,    0,  590,    2, 0x0a /* Public */,
      44,    1,  591,    2, 0x0a /* Public */,
      45,    1,  594,    2, 0x0a /* Public */,
      47,    0,  597,    2, 0x0a /* Public */,
      48,    0,  598,    2, 0x0a /* Public */,
      49,    0,  599,    2, 0x0a /* Public */,
      50,    0,  600,    2, 0x0a /* Public */,
      51,    0,  601,    2, 0x0a /* Public */,
      52,    0,  602,    2, 0x0a /* Public */,
      53,    0,  603,    2, 0x0a /* Public */,
      54,    0,  604,    2, 0x0a /* Public */,
      55,    1,  605,    2, 0x0a /* Public */,
      55,    1,  608,    2, 0x0a /* Public */,
      56,    1,  611,    2, 0x0a /* Public */,
      57,    0,  614,    2, 0x0a /* Public */,
      58,    0,  615,    2, 0x0a /* Public */,
      59,    1,  616,    2, 0x0a /* Public */,
      60,    1,  619,    2, 0x0a /* Public */,
      62,    1,  622,    2, 0x0a /* Public */,
      63,    2,  625,    2, 0x0a /* Public */,
      67,    0,  630,    2, 0x0a /* Public */,
      68,    0,  631,    2, 0x0a /* Public */,
      69,    0,  632,    2, 0x0a /* Public */,
      70,    0,  633,    2, 0x0a /* Public */,
      71,    0,  634,    2, 0x0a /* Public */,
      72,    0,  635,    2, 0x0a /* Public */,
      73,    1,  636,    2, 0x0a /* Public */,
      75,    0,  639,    2, 0x0a /* Public */,
      76,    0,  640,    2, 0x0a /* Public */,
      77,    0,  641,    2, 0x0a /* Public */,
      78,    0,  642,    2, 0x0a /* Public */,
      79,    0,  643,    2, 0x0a /* Public */,
      80,    0,  644,    2, 0x0a /* Public */,
      81,    0,  645,    2, 0x0a /* Public */,
      82,    1,  646,    2, 0x0a /* Public */,
      83,    0,  649,    2, 0x0a /* Public */,
      83,    2,  650,    2, 0x0a /* Public */,
      85,    0,  655,    2, 0x0a /* Public */,
      86,    0,  656,    2, 0x0a /* Public */,
      87,    0,  657,    2, 0x0a /* Public */,
      88,    0,  658,    2, 0x0a /* Public */,
      89,    0,  659,    2, 0x0a /* Public */,
      90,    0,  660,    2, 0x0a /* Public */,
      91,    0,  661,    2, 0x0a /* Public */,
      92,    0,  662,    2, 0x0a /* Public */,
      93,    0,  663,    2, 0x0a /* Public */,
      94,    0,  664,    2, 0x0a /* Public */,
      95,    0,  665,    2, 0x0a /* Public */,
      96,    1,  666,    2, 0x0a /* Public */,
      99,    1,  669,    2, 0x0a /* Public */,
     101,    1,  672,    2, 0x0a /* Public */,
     103,    0,  675,    2, 0x0a /* Public */,
     104,    0,  676,    2, 0x0a /* Public */,
     105,    0,  677,    2, 0x0a /* Public */,
     106,    2,  678,    2, 0x0a /* Public */,
     109,    1,  683,    2, 0x0a /* Public */,
     112,    2,  686,    2, 0x0a /* Public */,
     114,    0,  691,    2, 0x0a /* Public */,
     115,    0,  692,    2, 0x0a /* Public */,
     116,    0,  693,    2, 0x0a /* Public */,
     117,    3,  694,    2, 0x0a /* Public */,
     117,    2,  701,    2, 0x2a /* Public | MethodCloned */,
     121,    2,  706,    2, 0x0a /* Public */,
     122,    0,  711,    2, 0x0a /* Public */,
     123,    1,  712,    2, 0x0a /* Public */,
     125,    3,  715,    2, 0x0a /* Public */,
     125,    2,  722,    2, 0x2a /* Public | MethodCloned */,
     125,    1,  727,    2, 0x2a /* Public | MethodCloned */,
     125,    0,  730,    2, 0x2a /* Public | MethodCloned */,
     128,    0,  731,    2, 0x0a /* Public */,
     129,    0,  732,    2, 0x0a /* Public */,
     130,    0,  733,    2, 0x08 /* Private */,
     131,    1,  734,    2, 0x08 /* Private */,
     133,    1,  737,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QModelIndex,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Int,   18,   19,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Int,   18,   19,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 17,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   31,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,   33,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35, 0x80000000 | 37,   36,   38,
    QMetaType::Void, 0x80000000 | 35,   40,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35,   40,
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   40,
    QMetaType::Void, 0x80000000 | 35,   40,
    QMetaType::Void, QMetaType::Int,   40,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35,   40,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, 0x80000000 | 35,   40,
    QMetaType::Void, 0x80000000 | 64, QMetaType::QPoint,   65,   66,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   74,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    5,   84,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 35,
    QMetaType::Void, 0x80000000 | 97,   98,
    0x80000000 | 100, 0x80000000 | 17,   18,
    0x80000000 | 102, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 107,   18,  108,
    QMetaType::Void, 0x80000000 | 110,  111,
    0x80000000 | 110, 0x80000000 | 17, QMetaType::QString,   18,  113,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 118, 0x80000000 | 17, 0x80000000 | 119, QMetaType::Bool,   18,  113,  120,
    0x80000000 | 118, 0x80000000 | 17, 0x80000000 | 119,   18,  113,
    QMetaType::Void, 0x80000000 | 35, QMetaType::QString,   40,  113,
    QMetaType::Void,
    0x80000000 | 124, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17, QMetaType::QString, QMetaType::Bool,   18,  126,  127,
    QMetaType::Void, 0x80000000 | 17, QMetaType::QString,   18,  126,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,  132,
    QMetaType::Void, QMetaType::QObjectStar,  134,

       0        // eod
};

void ViewContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewContainer *_t = static_cast<ViewContainer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->setWindowCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->updateChannelAppearance(); break;
        case 3: _t->contextMenuClosed(); break;
        case 4: _t->resetStatusBar(); break;
        case 5: _t->setStatusBarTempText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->clearStatusBarTempText(); break;
        case 7: _t->setStatusBarInfoLabel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->clearStatusBarInfoLabel(); break;
        case 9: _t->setStatusBarLagLabelShown((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->updateStatusBarLagLabel((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->resetStatusBarLagLabel((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 12: _t->setStatusBarLagLabelTooLongLag((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 13: _t->updateStatusBarSSLLabel((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 14: _t->removeStatusBarSSLLabel(); break;
        case 15: _t->autoJoinToggled((*reinterpret_cast< const Konversation::ServerGroupSettingsPtr(*)>(_a[1]))); break;
        case 16: _t->autoConnectOnStartupToggled((*reinterpret_cast< const Konversation::ServerGroupSettingsPtr(*)>(_a[1]))); break;
        case 17: _t->frontServerChanging((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 18: _t->updateAppearance(); break;
        case 19: _t->saveSplitterSizes(); break;
        case 20: _t->setViewTreeShown((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->setViewTreeShown(); break;
        case 22: _t->updateViews((*reinterpret_cast< const Konversation::ServerGroupSettingsPtr(*)>(_a[1]))); break;
        case 23: _t->updateViews(); break;
        case 24: _t->setViewNotification((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const Konversation::TabNotifyType(*)>(_a[2]))); break;
        case 25: _t->unsetViewNotification((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 26: _t->toggleViewNotifications(); break;
        case 27: _t->toggleAutoJoin(); break;
        case 28: _t->toggleConnectOnStartup(); break;
        case 29: _t->showView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 30: _t->goToView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: _t->showNextView(); break;
        case 32: _t->showPreviousView(); break;
        case 33: _t->showNextActiveView(); break;
        case 34: _t->showLastFocusedView(); break;
        case 35: { bool _r = _t->canMoveViewLeft();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->canMoveViewRight();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->moveViewLeft(); break;
        case 38: _t->moveViewRight(); break;
        case 39: _t->closeView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 40: _t->closeView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 41: _t->closeViewMiddleClick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 42: _t->closeCurrentView(); break;
        case 43: _t->renameKonsole(); break;
        case 44: _t->cleanupAfterClose((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 45: _t->changeViewCharset((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->updateViewEncoding((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 47: _t->showViewContextMenu((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2]))); break;
        case 48: _t->clearView(); break;
        case 49: _t->clearAllViews(); break;
        case 50: _t->findText(); break;
        case 51: _t->findNextText(); break;
        case 52: _t->findPrevText(); break;
        case 53: _t->insertCharacter(); break;
        case 54: _t->insertChar((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 55: _t->insertIRCColor(); break;
        case 56: _t->doAutoReplace(); break;
        case 57: _t->focusInputBox(); break;
        case 58: _t->clearViewLines(); break;
        case 59: _t->insertRememberLine(); break;
        case 60: _t->cancelRememberLine(); break;
        case 61: _t->insertMarkerLine(); break;
        case 62: _t->insertRememberLines((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 63: _t->openLogFile(); break;
        case 64: _t->openLogFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 65: _t->addKonsolePanel(); break;
        case 66: _t->zoomIn(); break;
        case 67: _t->zoomOut(); break;
        case 68: _t->resetFont(); break;
        case 69: _t->addUrlCatcher(); break;
        case 70: _t->closeUrlCatcher(); break;
        case 71: _t->toggleDccPanel(); break;
        case 72: _t->addDccPanel(); break;
        case 73: _t->closeDccPanel(); break;
        case 74: _t->deleteDccPanel(); break;
        case 75: { ChatWindow* _r = _t->getDccPanel();
            if (_a[0]) *reinterpret_cast< ChatWindow**>(_a[0]) = std::move(_r); }  break;
        case 76: _t->addDccChat((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1]))); break;
        case 77: { StatusPanel* _r = _t->addStatusView((*reinterpret_cast< Server*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< StatusPanel**>(_a[0]) = std::move(_r); }  break;
        case 78: { RawLog* _r = _t->addRawLog((*reinterpret_cast< Server*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< RawLog**>(_a[0]) = std::move(_r); }  break;
        case 79: _t->disconnectFrontServer(); break;
        case 80: _t->reconnectFrontServer(); break;
        case 81: _t->showJoinChannelDialog(); break;
        case 82: _t->connectionStateChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< Konversation::ConnectionState(*)>(_a[2]))); break;
        case 83: _t->channelJoined((*reinterpret_cast< Channel*(*)>(_a[1]))); break;
        case 84: { Channel* _r = _t->addChannel((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< Channel**>(_a[0]) = std::move(_r); }  break;
        case 85: _t->rejoinChannel(); break;
        case 86: _t->openChannelSettings(); break;
        case 87: _t->toggleChannelNicklists(); break;
        case 88: { Query* _r = _t->addQuery((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const NickInfoPtr(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< Query**>(_a[0]) = std::move(_r); }  break;
        case 89: { Query* _r = _t->addQuery((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const NickInfoPtr(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< Query**>(_a[0]) = std::move(_r); }  break;
        case 90: _t->updateQueryChrome((*reinterpret_cast< ChatWindow*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 91: _t->closeQueries(); break;
        case 92: { ChannelListPanel* _r = _t->addChannelListPanel((*reinterpret_cast< Server*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< ChannelListPanel**>(_a[0]) = std::move(_r); }  break;
        case 93: _t->openChannelList((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 94: _t->openChannelList((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 95: _t->openChannelList((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 96: _t->openChannelList(); break;
        case 97: _t->openNicksOnlinePanel(); break;
        case 98: _t->closeNicksOnlinePanel(); break;
        case 99: _t->setupIrcContextMenus(); break;
        case 100: _t->viewSwitched((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 101: _t->onViewTreeDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 62:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 77:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 78:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 82:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 88:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 89:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 90:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 93:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 94:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        case 95:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Server* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ViewContainer::*_t)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::viewChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::setWindowCaption)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::updateChannelAppearance)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::contextMenuClosed)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::resetStatusBar)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::setStatusBarTempText)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::clearStatusBarTempText)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::setStatusBarInfoLabel)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::clearStatusBarInfoLabel)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::setStatusBarLagLabelShown)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(Server * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::updateStatusBarLagLabel)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::resetStatusBarLagLabel)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(Server * , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::setStatusBarLagLabelTooLongLag)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::updateStatusBarSSLLabel)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::removeStatusBarSSLLabel)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(const Konversation::ServerGroupSettingsPtr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::autoJoinToggled)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(const Konversation::ServerGroupSettingsPtr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::autoConnectOnStartupToggled)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (ViewContainer::*_t)(Server * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ViewContainer::frontServerChanging)) {
                *result = 17;
                return;
            }
        }
    }
}

const QMetaObject ViewContainer::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_ViewContainer.data,
      qt_meta_data_ViewContainer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ViewContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ViewContainer.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int ViewContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 102)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 102;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 102)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 102;
    }
    return _id;
}

// SIGNAL 0
void ViewContainer::viewChanged(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ViewContainer::setWindowCaption(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ViewContainer::updateChannelAppearance()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ViewContainer::contextMenuClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ViewContainer::resetStatusBar()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ViewContainer::setStatusBarTempText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void ViewContainer::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ViewContainer::setStatusBarInfoLabel(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void ViewContainer::clearStatusBarInfoLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ViewContainer::setStatusBarLagLabelShown(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void ViewContainer::updateStatusBarLagLabel(Server * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void ViewContainer::resetStatusBarLagLabel(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void ViewContainer::setStatusBarLagLabelTooLongLag(Server * _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void ViewContainer::updateStatusBarSSLLabel(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void ViewContainer::removeStatusBarSSLLabel()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ViewContainer::autoJoinToggled(const Konversation::ServerGroupSettingsPtr _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void ViewContainer::autoConnectOnStartupToggled(const Konversation::ServerGroupSettingsPtr _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void ViewContainer::frontServerChanging(Server * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
