#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'channeldialogui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANNELDIALOGUI_H
#define UI_CHANNELDIALOGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ChannelDialogUI
{
public:
    QGridLayout *gridLayout;
    KLineEdit *m_passwordEdit;
    KLineEdit *m_channelEdit;
    QLabel *passwordLbl;
    QLabel *channelLbl;

    void setupUi(QWidget *ChannelDialogUI)
    {
        if (ChannelDialogUI->objectName().isEmpty())
            ChannelDialogUI->setObjectName(QStringLiteral("ChannelDialogUI"));
        ChannelDialogUI->resize(204, 64);
        gridLayout = new QGridLayout(ChannelDialogUI);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        m_passwordEdit = new KLineEdit(ChannelDialogUI);
        m_passwordEdit->setObjectName(QStringLiteral("m_passwordEdit"));
        m_passwordEdit->setPasswordMode(true);

        gridLayout->addWidget(m_passwordEdit, 1, 1, 1, 1);

        m_channelEdit = new KLineEdit(ChannelDialogUI);
        m_channelEdit->setObjectName(QStringLiteral("m_channelEdit"));
        m_channelEdit->setMaxLength(50);

        gridLayout->addWidget(m_channelEdit, 0, 1, 1, 1);

        passwordLbl = new QLabel(ChannelDialogUI);
        passwordLbl->setObjectName(QStringLiteral("passwordLbl"));
        passwordLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(passwordLbl, 1, 0, 1, 1);

        channelLbl = new QLabel(ChannelDialogUI);
        channelLbl->setObjectName(QStringLiteral("channelLbl"));
        channelLbl->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(channelLbl, 0, 0, 1, 1);

        m_passwordEdit->raise();
        m_channelEdit->raise();
        passwordLbl->raise();
        channelLbl->raise();
#ifndef UI_QT_NO_SHORTCUT
        passwordLbl->setBuddy(m_passwordEdit);
        channelLbl->setBuddy(m_channelEdit);
#endif // QT_NO_SHORTCUT

        retranslateUi(ChannelDialogUI);

        QMetaObject::connectSlotsByName(ChannelDialogUI);
    } // setupUi

    void retranslateUi(QWidget *ChannelDialogUI)
    {
        m_passwordEdit->setText(QString());
        passwordLbl->setText(tr2i18n("Pass&word:", Q_NULLPTR));
        channelLbl->setText(tr2i18n("C&hannel:", Q_NULLPTR));
        Q_UNUSED(ChannelDialogUI);
    } // retranslateUi

};

namespace Ui {
    class ChannelDialogUI: public Ui_ChannelDialogUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CHANNELDIALOGUI_H

