/****************************************************************************
** Meta object code from reading C++ file 'ircview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/ircview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IrcViewMarkerLine_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IrcViewMarkerLine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IrcViewMarkerLine_t qt_meta_stringdata_IrcViewMarkerLine = {
    {
QT_MOC_LITERAL(0, 0, 17) // "IrcViewMarkerLine"

    },
    "IrcViewMarkerLine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IrcViewMarkerLine[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void IrcViewMarkerLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject IrcViewMarkerLine::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_IrcViewMarkerLine.data,
      qt_meta_data_IrcViewMarkerLine,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *IrcViewMarkerLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IrcViewMarkerLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IrcViewMarkerLine.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QTextObjectInterface"))
        return static_cast< QTextObjectInterface*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QTextObjectInterface"))
        return static_cast< QTextObjectInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int IrcViewMarkerLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_IRCView_t {
    QByteArrayData data[55];
    char stringdata0[657];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IRCView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IRCView_t qt_meta_stringdata_IRCView = {
    {
QT_MOC_LITERAL(0, 0, 7), // "IRCView"
QT_MOC_LITERAL(1, 8, 8), // "gotFocus"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 9), // "textToLog"
QT_MOC_LITERAL(4, 28, 4), // "text"
QT_MOC_LITERAL(5, 33, 8), // "sendFile"
QT_MOC_LITERAL(6, 42, 8), // "autoText"
QT_MOC_LITERAL(7, 51, 10), // "textPasted"
QT_MOC_LITERAL(8, 62, 12), // "useSelection"
QT_MOC_LITERAL(9, 75, 11), // "urlsDropped"
QT_MOC_LITERAL(10, 87, 11), // "QList<QUrl>"
QT_MOC_LITERAL(11, 99, 4), // "urls"
QT_MOC_LITERAL(12, 104, 8), // "doSearch"
QT_MOC_LITERAL(13, 113, 12), // "doSearchNext"
QT_MOC_LITERAL(14, 126, 16), // "doSearchPrevious"
QT_MOC_LITERAL(15, 143, 20), // "setStatusBarTempText"
QT_MOC_LITERAL(16, 164, 22), // "clearStatusBarTempText"
QT_MOC_LITERAL(17, 187, 16), // "insertMarkerLine"
QT_MOC_LITERAL(18, 204, 18), // "insertRememberLine"
QT_MOC_LITERAL(19, 223, 18), // "cancelRememberLine"
QT_MOC_LITERAL(20, 242, 10), // "clearLines"
QT_MOC_LITERAL(21, 253, 12), // "blockDeleted"
QT_MOC_LITERAL(22, 266, 5), // "Burr*"
QT_MOC_LITERAL(23, 272, 1), // "b"
QT_MOC_LITERAL(24, 274, 14), // "cullMarkedLine"
QT_MOC_LITERAL(25, 289, 6), // "append"
QT_MOC_LITERAL(26, 296, 4), // "nick"
QT_MOC_LITERAL(27, 301, 7), // "message"
QT_MOC_LITERAL(28, 309, 22), // "QHash<QString,QString>"
QT_MOC_LITERAL(29, 332, 11), // "messageTags"
QT_MOC_LITERAL(30, 344, 5), // "label"
QT_MOC_LITERAL(31, 350, 9), // "appendRaw"
QT_MOC_LITERAL(32, 360, 4), // "self"
QT_MOC_LITERAL(33, 365, 9), // "appendLog"
QT_MOC_LITERAL(34, 375, 11), // "appendQuery"
QT_MOC_LITERAL(35, 387, 9), // "inChannel"
QT_MOC_LITERAL(36, 397, 17), // "appendQueryAction"
QT_MOC_LITERAL(37, 415, 19), // "appendChannelAction"
QT_MOC_LITERAL(38, 435, 19), // "appendServerMessage"
QT_MOC_LITERAL(39, 455, 4), // "type"
QT_MOC_LITERAL(40, 460, 8), // "parseURL"
QT_MOC_LITERAL(41, 469, 20), // "appendCommandMessage"
QT_MOC_LITERAL(42, 490, 7), // "command"
QT_MOC_LITERAL(43, 498, 20), // "appendBacklogMessage"
QT_MOC_LITERAL(44, 519, 11), // "firstColumn"
QT_MOC_LITERAL(45, 531, 8), // "findText"
QT_MOC_LITERAL(46, 540, 12), // "findNextText"
QT_MOC_LITERAL(47, 553, 16), // "findPreviousText"
QT_MOC_LITERAL(48, 570, 16), // "increaseFontSize"
QT_MOC_LITERAL(49, 587, 16), // "decreaseFontSize"
QT_MOC_LITERAL(50, 604, 13), // "resetFontSize"
QT_MOC_LITERAL(51, 618, 15), // "highlightedSlot"
QT_MOC_LITERAL(52, 634, 4), // "link"
QT_MOC_LITERAL(53, 639, 13), // "anchorClicked"
QT_MOC_LITERAL(54, 653, 3) // "url"

    },
    "IRCView\0gotFocus\0\0textToLog\0text\0"
    "sendFile\0autoText\0textPasted\0useSelection\0"
    "urlsDropped\0QList<QUrl>\0urls\0doSearch\0"
    "doSearchNext\0doSearchPrevious\0"
    "setStatusBarTempText\0clearStatusBarTempText\0"
    "insertMarkerLine\0insertRememberLine\0"
    "cancelRememberLine\0clearLines\0"
    "blockDeleted\0Burr*\0b\0cullMarkedLine\0"
    "append\0nick\0message\0QHash<QString,QString>\0"
    "messageTags\0label\0appendRaw\0self\0"
    "appendLog\0appendQuery\0inChannel\0"
    "appendQueryAction\0appendChannelAction\0"
    "appendServerMessage\0type\0parseURL\0"
    "appendCommandMessage\0command\0"
    "appendBacklogMessage\0firstColumn\0"
    "findText\0findNextText\0findPreviousText\0"
    "increaseFontSize\0decreaseFontSize\0"
    "resetFontSize\0highlightedSlot\0link\0"
    "anchorClicked\0url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IRCView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      42,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  224,    2, 0x06 /* Public */,
       3,    1,  225,    2, 0x06 /* Public */,
       5,    0,  228,    2, 0x06 /* Public */,
       6,    1,  229,    2, 0x06 /* Public */,
       7,    1,  232,    2, 0x06 /* Public */,
       9,    1,  235,    2, 0x06 /* Public */,
      12,    0,  238,    2, 0x06 /* Public */,
      13,    0,  239,    2, 0x06 /* Public */,
      14,    0,  240,    2, 0x06 /* Public */,
      15,    1,  241,    2, 0x06 /* Public */,
      16,    0,  244,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    0,  245,    2, 0x0a /* Public */,
      18,    0,  246,    2, 0x0a /* Public */,
      19,    0,  247,    2, 0x0a /* Public */,
      20,    0,  248,    2, 0x0a /* Public */,
      21,    1,  249,    2, 0x0a /* Public */,
      24,    3,  252,    2, 0x08 /* Private */,
      25,    4,  259,    2, 0x0a /* Public */,
      25,    3,  268,    2, 0x2a /* Public | MethodCloned */,
      25,    2,  275,    2, 0x2a /* Public | MethodCloned */,
      31,    2,  280,    2, 0x0a /* Public */,
      31,    1,  285,    2, 0x2a /* Public | MethodCloned */,
      33,    1,  288,    2, 0x0a /* Public */,
      34,    4,  291,    2, 0x0a /* Public */,
      34,    3,  300,    2, 0x2a /* Public | MethodCloned */,
      36,    3,  307,    2, 0x0a /* Public */,
      37,    3,  314,    2, 0x0a /* Public */,
      38,    4,  321,    2, 0x0a /* Public */,
      38,    3,  330,    2, 0x2a /* Public | MethodCloned */,
      38,    2,  337,    2, 0x2a /* Public | MethodCloned */,
      41,    5,  342,    2, 0x0a /* Public */,
      41,    4,  353,    2, 0x2a /* Public | MethodCloned */,
      41,    3,  362,    2, 0x2a /* Public | MethodCloned */,
      43,    2,  369,    2, 0x0a /* Public */,
      45,    0,  374,    2, 0x0a /* Public */,
      46,    0,  375,    2, 0x0a /* Public */,
      47,    0,  376,    2, 0x0a /* Public */,
      48,    0,  377,    2, 0x0a /* Public */,
      49,    0,  378,    2, 0x0a /* Public */,
      50,    0,  379,    2, 0x0a /* Public */,
      51,    1,  380,    2, 0x09 /* Protected */,
      53,    1,  383,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::QString,   26,   27,   29,   30,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   26,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   26,   27,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   27,   32,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Bool,   26,   27,   29,   35,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   26,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   26,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   26,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Bool,   39,   27,   29,   40,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   39,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   39,   27,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Bool, QMetaType::Bool,   42,   27,   29,   40,   32,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Bool,   42,   27,   29,   40,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   42,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   44,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   52,
    QMetaType::Void, QMetaType::QUrl,   54,

       0        // eod
};

void IRCView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IRCView *_t = static_cast<IRCView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->gotFocus(); break;
        case 1: _t->textToLog((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->sendFile(); break;
        case 3: _t->autoText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->textPasted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->urlsDropped((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 6: _t->doSearch(); break;
        case 7: _t->doSearchNext(); break;
        case 8: _t->doSearchPrevious(); break;
        case 9: _t->setStatusBarTempText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->clearStatusBarTempText(); break;
        case 11: _t->insertMarkerLine(); break;
        case 12: _t->insertRememberLine(); break;
        case 13: _t->cancelRememberLine(); break;
        case 14: _t->clearLines(); break;
        case 15: _t->blockDeleted((*reinterpret_cast< Burr*(*)>(_a[1]))); break;
        case 16: _t->cullMarkedLine((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 17: _t->append((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 18: _t->append((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 19: _t->append((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 20: _t->appendRaw((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 21: _t->appendRaw((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->appendLog((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->appendQuery((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 24: _t->appendQuery((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 25: _t->appendQueryAction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 26: _t->appendChannelAction((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 27: _t->appendServerMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 28: _t->appendServerMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 29: _t->appendServerMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 30: _t->appendCommandMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 31: _t->appendCommandMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 32: _t->appendCommandMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QHash<QString,QString>(*)>(_a[3]))); break;
        case 33: _t->appendBacklogMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 34: _t->findText(); break;
        case 35: _t->findNextText(); break;
        case 36: _t->findPreviousText(); break;
        case 37: _t->increaseFontSize(); break;
        case 38: _t->decreaseFontSize(); break;
        case 39: _t->resetFontSize(); break;
        case 40: _t->highlightedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->anchorClicked((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::gotFocus)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::textToLog)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::sendFile)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::autoText)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::textPasted)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)(const QList<QUrl> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::urlsDropped)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::doSearch)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::doSearchNext)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::doSearchPrevious)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::setStatusBarTempText)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (IRCView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCView::clearStatusBarTempText)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject IRCView::staticMetaObject = {
    { &QTextBrowser::staticMetaObject, qt_meta_stringdata_IRCView.data,
      qt_meta_data_IRCView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *IRCView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IRCView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IRCView.stringdata0))
        return static_cast<void*>(this);
    return QTextBrowser::qt_metacast(_clname);
}

int IRCView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextBrowser::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void IRCView::gotFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IRCView::textToLog(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void IRCView::sendFile()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IRCView::autoText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void IRCView::textPasted(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void IRCView::urlsDropped(const QList<QUrl> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void IRCView::doSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void IRCView::doSearchNext()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void IRCView::doSearchPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void IRCView::setStatusBarTempText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void IRCView::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
