/****************************************************************************
** Meta object code from reading C++ file 'inputfilter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/inputfilter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_InputFilter_t {
    QByteArrayData data[35];
    char stringdata0[404];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InputFilter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InputFilter_t qt_meta_stringdata_InputFilter = {
    {
QT_MOC_LITERAL(0, 0, 11), // "InputFilter"
QT_MOC_LITERAL(1, 12, 7), // "welcome"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 7), // "ownHost"
QT_MOC_LITERAL(4, 29, 14), // "notifyResponse"
QT_MOC_LITERAL(5, 44, 11), // "nicksOnline"
QT_MOC_LITERAL(6, 56, 27), // "startReverseDccSendTransfer"
QT_MOC_LITERAL(7, 84, 10), // "sourceNick"
QT_MOC_LITERAL(8, 95, 11), // "dccArgument"
QT_MOC_LITERAL(9, 107, 19), // "startReverseDccChat"
QT_MOC_LITERAL(10, 127, 9), // "addDccGet"
QT_MOC_LITERAL(11, 137, 20), // "resumeDccGetTransfer"
QT_MOC_LITERAL(12, 158, 21), // "resumeDccSendTransfer"
QT_MOC_LITERAL(13, 180, 21), // "rejectDccSendTransfer"
QT_MOC_LITERAL(14, 202, 13), // "rejectDccChat"
QT_MOC_LITERAL(15, 216, 8), // "userhost"
QT_MOC_LITERAL(16, 225, 4), // "nick"
QT_MOC_LITERAL(17, 230, 8), // "hostmask"
QT_MOC_LITERAL(18, 239, 4), // "away"
QT_MOC_LITERAL(19, 244, 5), // "ircOp"
QT_MOC_LITERAL(20, 250, 11), // "topicAuthor"
QT_MOC_LITERAL(21, 262, 7), // "channel"
QT_MOC_LITERAL(22, 270, 6), // "author"
QT_MOC_LITERAL(23, 277, 1), // "t"
QT_MOC_LITERAL(24, 279, 8), // "endOfWho"
QT_MOC_LITERAL(25, 288, 6), // "target"
QT_MOC_LITERAL(26, 295, 10), // "endOfNames"
QT_MOC_LITERAL(27, 306, 19), // "addChannelListPanel"
QT_MOC_LITERAL(28, 326, 16), // "addToChannelList"
QT_MOC_LITERAL(29, 343, 5), // "users"
QT_MOC_LITERAL(30, 349, 5), // "topic"
QT_MOC_LITERAL(31, 355, 16), // "endOfChannelList"
QT_MOC_LITERAL(32, 372, 10), // "invitation"
QT_MOC_LITERAL(33, 383, 10), // "addDccChat"
QT_MOC_LITERAL(34, 394, 9) // "arguments"

    },
    "InputFilter\0welcome\0\0ownHost\0"
    "notifyResponse\0nicksOnline\0"
    "startReverseDccSendTransfer\0sourceNick\0"
    "dccArgument\0startReverseDccChat\0"
    "addDccGet\0resumeDccGetTransfer\0"
    "resumeDccSendTransfer\0rejectDccSendTransfer\0"
    "rejectDccChat\0userhost\0nick\0hostmask\0"
    "away\0ircOp\0topicAuthor\0channel\0author\0"
    "t\0endOfWho\0target\0endOfNames\0"
    "addChannelListPanel\0addToChannelList\0"
    "users\0topic\0endOfChannelList\0invitation\0"
    "addDccChat\0arguments"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InputFilter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       4,    1,  107,    2, 0x06 /* Public */,
       6,    2,  110,    2, 0x06 /* Public */,
       9,    2,  115,    2, 0x06 /* Public */,
      10,    2,  120,    2, 0x06 /* Public */,
      11,    2,  125,    2, 0x06 /* Public */,
      12,    2,  130,    2, 0x06 /* Public */,
      13,    2,  135,    2, 0x06 /* Public */,
      14,    1,  140,    2, 0x06 /* Public */,
      15,    4,  143,    2, 0x06 /* Public */,
      20,    3,  152,    2, 0x06 /* Public */,
      24,    1,  159,    2, 0x06 /* Public */,
      26,    1,  162,    2, 0x06 /* Public */,
      27,    0,  165,    2, 0x06 /* Public */,
      28,    3,  166,    2, 0x06 /* Public */,
      31,    0,  173,    2, 0x06 /* Public */,
      32,    2,  174,    2, 0x06 /* Public */,
      33,    2,  179,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    8,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   16,   17,   18,   19,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QDateTime,   21,   22,   23,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,   21,   29,   30,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   16,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,   16,   34,

       0        // eod
};

void InputFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InputFilter *_t = static_cast<InputFilter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->welcome((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->notifyResponse((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->startReverseDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 3: _t->startReverseDccChat((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 4: _t->addDccGet((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 5: _t->resumeDccGetTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 6: _t->resumeDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 7: _t->rejectDccSendTransfer((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 8: _t->rejectDccChat((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->userhost((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 10: _t->topicAuthor((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< QDateTime(*)>(_a[3]))); break;
        case 11: _t->endOfWho((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->endOfNames((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->addChannelListPanel(); break;
        case 14: _t->addToChannelList((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 15: _t->endOfChannelList(); break;
        case 16: _t->invitation((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->addDccChat((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (InputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::welcome)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::notifyResponse)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::startReverseDccSendTransfer)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::startReverseDccChat)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::addDccGet)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::resumeDccGetTransfer)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::resumeDccSendTransfer)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::rejectDccSendTransfer)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::rejectDccChat)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QString & , bool , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::userhost)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QString & , QDateTime );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::topicAuthor)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::endOfWho)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::endOfNames)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::addChannelListPanel)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::addToChannelList)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::endOfChannelList)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::invitation)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (InputFilter::*_t)(const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputFilter::addDccChat)) {
                *result = 17;
                return;
            }
        }
    }
}

const QMetaObject InputFilter::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_InputFilter.data,
      qt_meta_data_InputFilter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *InputFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InputFilter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void InputFilter::welcome(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void InputFilter::notifyResponse(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void InputFilter::startReverseDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void InputFilter::startReverseDccChat(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void InputFilter::addDccGet(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void InputFilter::resumeDccGetTransfer(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void InputFilter::resumeDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void InputFilter::rejectDccSendTransfer(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void InputFilter::rejectDccChat(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void InputFilter::userhost(const QString & _t1, const QString & _t2, bool _t3, bool _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void InputFilter::topicAuthor(const QString & _t1, const QString & _t2, QDateTime _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void InputFilter::endOfWho(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void InputFilter::endOfNames(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void InputFilter::addChannelListPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void InputFilter::addToChannelList(const QString & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void InputFilter::endOfChannelList()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void InputFilter::invitation(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void InputFilter::addDccChat(const QString & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
