/****************************************************************************
** Meta object code from reading C++ file 'trayicon.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/trayicon.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trayicon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__TrayIcon_t {
    QByteArrayData data[9];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__TrayIcon_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__TrayIcon_t qt_meta_stringdata_Konversation__TrayIcon = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Konversation::TrayIcon"
QT_MOC_LITERAL(1, 23, 17), // "startNotification"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 15), // "endNotification"
QT_MOC_LITERAL(4, 58, 22), // "setNotificationEnabled"
QT_MOC_LITERAL(5, 81, 6), // "notify"
QT_MOC_LITERAL(6, 88, 7), // "setAway"
QT_MOC_LITERAL(7, 96, 4), // "away"
QT_MOC_LITERAL(8, 101, 16) // "updateAppearance"

    },
    "Konversation::TrayIcon\0startNotification\0"
    "\0endNotification\0setNotificationEnabled\0"
    "notify\0setAway\0away\0updateAppearance"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__TrayIcon[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x0a /* Public */,
       3,    0,   40,    2, 0x0a /* Public */,
       4,    1,   41,    2, 0x0a /* Public */,
       6,    1,   44,    2, 0x0a /* Public */,
       8,    0,   47,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,

       0        // eod
};

void Konversation::TrayIcon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TrayIcon *_t = static_cast<TrayIcon *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->startNotification(); break;
        case 1: _t->endNotification(); break;
        case 2: _t->setNotificationEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->updateAppearance(); break;
        default: ;
        }
    }
}

const QMetaObject Konversation::TrayIcon::staticMetaObject = {
    { &KStatusNotifierItem::staticMetaObject, qt_meta_stringdata_Konversation__TrayIcon.data,
      qt_meta_data_Konversation__TrayIcon,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::TrayIcon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::TrayIcon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__TrayIcon.stringdata0))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int Konversation::TrayIcon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
