/****************************************************************************
** Meta object code from reading C++ file 'transferview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transferview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferView_t {
    QByteArrayData data[29];
    char stringdata0[492];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferView_t qt_meta_stringdata_Konversation__DCC__TransferView = {
    {
QT_MOC_LITERAL(0, 0, 31), // "Konversation::DCC::TransferView"
QT_MOC_LITERAL(1, 32, 20), // "runSelectedTransfers"
QT_MOC_LITERAL(2, 53, 0), // ""
QT_MOC_LITERAL(3, 54, 5), // "clear"
QT_MOC_LITERAL(4, 60, 32), // "headerCustomContextMenuRequested"
QT_MOC_LITERAL(5, 93, 3), // "pos"
QT_MOC_LITERAL(6, 97, 20), // "toggleFilenameColumn"
QT_MOC_LITERAL(7, 118, 7), // "visible"
QT_MOC_LITERAL(8, 126, 23), // "togglePartnerNickColumn"
QT_MOC_LITERAL(9, 150, 20), // "toggleProgressColumn"
QT_MOC_LITERAL(10, 171, 21), // "toggleStartedAtColumn"
QT_MOC_LITERAL(11, 193, 20), // "togglePositionColumn"
QT_MOC_LITERAL(12, 214, 24), // "toggleCurrentSpeedColumn"
QT_MOC_LITERAL(13, 239, 24), // "toggleSenderAdressColumn"
QT_MOC_LITERAL(14, 264, 18), // "toggleStatusColumn"
QT_MOC_LITERAL(15, 283, 20), // "toggleTimeLeftColumn"
QT_MOC_LITERAL(16, 304, 20), // "toogleTypeIconColumn"
QT_MOC_LITERAL(17, 325, 6), // "update"
QT_MOC_LITERAL(18, 332, 11), // "updateModel"
QT_MOC_LITERAL(19, 344, 21), // "transferStatusChanged"
QT_MOC_LITERAL(20, 366, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(21, 395, 8), // "transfer"
QT_MOC_LITERAL(22, 404, 9), // "newStatus"
QT_MOC_LITERAL(23, 414, 9), // "oldStatus"
QT_MOC_LITERAL(24, 424, 29), // "rowsAboutToBeRemovedFromModel"
QT_MOC_LITERAL(25, 454, 6), // "parent"
QT_MOC_LITERAL(26, 461, 5), // "start"
QT_MOC_LITERAL(27, 467, 3), // "end"
QT_MOC_LITERAL(28, 471, 20) // "rowsRemovedFromModel"

    },
    "Konversation::DCC::TransferView\0"
    "runSelectedTransfers\0\0clear\0"
    "headerCustomContextMenuRequested\0pos\0"
    "toggleFilenameColumn\0visible\0"
    "togglePartnerNickColumn\0toggleProgressColumn\0"
    "toggleStartedAtColumn\0togglePositionColumn\0"
    "toggleCurrentSpeedColumn\0"
    "toggleSenderAdressColumn\0toggleStatusColumn\0"
    "toggleTimeLeftColumn\0toogleTypeIconColumn\0"
    "update\0updateModel\0transferStatusChanged\0"
    "Konversation::DCC::Transfer*\0transfer\0"
    "newStatus\0oldStatus\0rowsAboutToBeRemovedFromModel\0"
    "parent\0start\0end\0rowsRemovedFromModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  104,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  105,    2, 0x0a /* Public */,
       4,    1,  106,    2, 0x0a /* Public */,
       6,    1,  109,    2, 0x0a /* Public */,
       8,    1,  112,    2, 0x0a /* Public */,
       9,    1,  115,    2, 0x0a /* Public */,
      10,    1,  118,    2, 0x0a /* Public */,
      11,    1,  121,    2, 0x0a /* Public */,
      12,    1,  124,    2, 0x0a /* Public */,
      13,    1,  127,    2, 0x0a /* Public */,
      14,    1,  130,    2, 0x0a /* Public */,
      15,    1,  133,    2, 0x0a /* Public */,
      16,    1,  136,    2, 0x0a /* Public */,
      17,    0,  139,    2, 0x0a /* Public */,
      18,    0,  140,    2, 0x0a /* Public */,
      19,    3,  141,    2, 0x0a /* Public */,
      24,    3,  148,    2, 0x09 /* Protected */,
      28,    2,  155,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20, QMetaType::Int, QMetaType::Int,   21,   22,   23,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::Int, QMetaType::Int,   25,   26,   27,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   26,   27,

       0        // eod
};

void Konversation::DCC::TransferView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferView *_t = static_cast<TransferView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->runSelectedTransfers(); break;
        case 1: _t->clear(); break;
        case 2: _t->headerCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 3: _t->toggleFilenameColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->togglePartnerNickColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->toggleProgressColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->toggleStartedAtColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->togglePositionColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->toggleCurrentSpeedColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->toggleSenderAdressColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->toggleStatusColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->toggleTimeLeftColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->toogleTypeIconColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->update(); break;
        case 14: _t->updateModel(); break;
        case 15: _t->transferStatusChanged((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 16: _t->rowsAboutToBeRemovedFromModel((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 17: _t->rowsRemovedFromModel((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Konversation::DCC::Transfer* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TransferView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferView::runSelectedTransfers)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::TransferView::staticMetaObject = {
    { &QTreeView::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferView.data,
      qt_meta_data_Konversation__DCC__TransferView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferView.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int Konversation::DCC::TransferView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::TransferView::runSelectedTransfers()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
