/****************************************************************************
** Meta object code from reading C++ file 'nicksonline.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/irc/nicksonline.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nicksonline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NicksOnline_t {
    QByteArrayData data[28];
    char stringdata0[355];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NicksOnline_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NicksOnline_t qt_meta_stringdata_NicksOnline = {
    {
QT_MOC_LITERAL(0, 0, 11), // "NicksOnline"
QT_MOC_LITERAL(1, 12, 13), // "doubleClicked"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 12), // "connectionId"
QT_MOC_LITERAL(4, 40, 4), // "nick"
QT_MOC_LITERAL(5, 45, 8), // "showView"
QT_MOC_LITERAL(6, 54, 11), // "ChatWindow*"
QT_MOC_LITERAL(7, 66, 4), // "view"
QT_MOC_LITERAL(8, 71, 22), // "updateServerOnlineList"
QT_MOC_LITERAL(9, 94, 7), // "Server*"
QT_MOC_LITERAL(10, 102, 6), // "server"
QT_MOC_LITERAL(11, 109, 18), // "processDoubleClick"
QT_MOC_LITERAL(12, 128, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(13, 145, 4), // "item"
QT_MOC_LITERAL(14, 150, 6), // "column"
QT_MOC_LITERAL(15, 157, 10), // "timerFired"
QT_MOC_LITERAL(16, 168, 33), // "slotNickListView_SelectionCha..."
QT_MOC_LITERAL(17, 202, 30), // "slotCustomContextMenuRequested"
QT_MOC_LITERAL(18, 233, 5), // "point"
QT_MOC_LITERAL(19, 239, 19), // "slotNickInfoChanged"
QT_MOC_LITERAL(20, 259, 11), // "NickInfoPtr"
QT_MOC_LITERAL(21, 271, 8), // "nickInfo"
QT_MOC_LITERAL(22, 280, 23), // "slotPopupMenu_Activated"
QT_MOC_LITERAL(23, 304, 8), // "QAction*"
QT_MOC_LITERAL(24, 313, 2), // "id"
QT_MOC_LITERAL(25, 316, 15), // "slotAddNickname"
QT_MOC_LITERAL(26, 332, 13), // "serverGroupId"
QT_MOC_LITERAL(27, 346, 8) // "nickname"

    },
    "NicksOnline\0doubleClicked\0\0connectionId\0"
    "nick\0showView\0ChatWindow*\0view\0"
    "updateServerOnlineList\0Server*\0server\0"
    "processDoubleClick\0QTreeWidgetItem*\0"
    "item\0column\0timerFired\0"
    "slotNickListView_SelectionChanged\0"
    "slotCustomContextMenuRequested\0point\0"
    "slotNickInfoChanged\0NickInfoPtr\0"
    "nickInfo\0slotPopupMenu_Activated\0"
    "QAction*\0id\0slotAddNickname\0serverGroupId\0"
    "nickname"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NicksOnline[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   64,    2, 0x06 /* Public */,
       5,    1,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   72,    2, 0x0a /* Public */,
      11,    2,   75,    2, 0x09 /* Protected */,
      15,    0,   80,    2, 0x09 /* Protected */,
      16,    0,   81,    2, 0x09 /* Protected */,
      17,    1,   82,    2, 0x09 /* Protected */,
      19,    2,   85,    2, 0x09 /* Protected */,
      22,    1,   90,    2, 0x09 /* Protected */,
      25,    2,   93,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12, QMetaType::Int,   13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   18,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 20,   10,   21,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   26,   27,

       0        // eod
};

void NicksOnline::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NicksOnline *_t = static_cast<NicksOnline *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->doubleClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->showView((*reinterpret_cast< ChatWindow*(*)>(_a[1]))); break;
        case 2: _t->updateServerOnlineList((*reinterpret_cast< Server*(*)>(_a[1]))); break;
        case 3: _t->processDoubleClick((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->timerFired(); break;
        case 5: _t->slotNickListView_SelectionChanged(); break;
        case 6: _t->slotCustomContextMenuRequested((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 7: _t->slotNickInfoChanged((*reinterpret_cast< Server*(*)>(_a[1])),(*reinterpret_cast< const NickInfoPtr(*)>(_a[2]))); break;
        case 8: _t->slotPopupMenu_Activated((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 9: _t->slotAddNickname((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChatWindow* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NicksOnline::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NicksOnline::doubleClicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (NicksOnline::*_t)(ChatWindow * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NicksOnline::showView)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject NicksOnline::staticMetaObject = {
    { &ChatWindow::staticMetaObject, qt_meta_stringdata_NicksOnline.data,
      qt_meta_data_NicksOnline,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *NicksOnline::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NicksOnline::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NicksOnline.stringdata0))
        return static_cast<void*>(this);
    return ChatWindow::qt_metacast(_clname);
}

int NicksOnline::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChatWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void NicksOnline::doubleClicked(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void NicksOnline::showView(ChatWindow * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
