/****************************************************************************
** Meta object code from reading C++ file 'transfermanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/dcc/transfermanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__DCC__TransferManager_t {
    QByteArrayData data[21];
    char stringdata0[366];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__DCC__TransferManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__DCC__TransferManager_t qt_meta_stringdata_Konversation__DCC__TransferManager = {
    {
QT_MOC_LITERAL(0, 0, 34), // "Konversation::DCC::TransferMa..."
QT_MOC_LITERAL(1, 35, 16), // "newTransferAdded"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 28), // "Konversation::DCC::Transfer*"
QT_MOC_LITERAL(4, 82, 8), // "transfer"
QT_MOC_LITERAL(5, 91, 20), // "newDccTransferQueued"
QT_MOC_LITERAL(6, 112, 14), // "fileURLChanged"
QT_MOC_LITERAL(7, 127, 32), // "Konversation::DCC::TransferRecv*"
QT_MOC_LITERAL(8, 160, 25), // "slotTransferStatusChanged"
QT_MOC_LITERAL(9, 186, 4), // "item"
QT_MOC_LITERAL(10, 191, 9), // "newStatus"
QT_MOC_LITERAL(11, 201, 9), // "oldStatus"
QT_MOC_LITERAL(12, 211, 14), // "removeSendItem"
QT_MOC_LITERAL(13, 226, 14), // "removeRecvItem"
QT_MOC_LITERAL(14, 241, 14), // "removeChatItem"
QT_MOC_LITERAL(15, 256, 24), // "Konversation::DCC::Chat*"
QT_MOC_LITERAL(16, 281, 4), // "chat"
QT_MOC_LITERAL(17, 286, 19), // "slotSettingsChanged"
QT_MOC_LITERAL(18, 306, 20), // "upnpRouterDiscovered"
QT_MOC_LITERAL(19, 327, 31), // "Konversation::UPnP::UPnPRouter*"
QT_MOC_LITERAL(20, 359, 6) // "router"

    },
    "Konversation::DCC::TransferManager\0"
    "newTransferAdded\0\0Konversation::DCC::Transfer*\0"
    "transfer\0newDccTransferQueued\0"
    "fileURLChanged\0Konversation::DCC::TransferRecv*\0"
    "slotTransferStatusChanged\0item\0newStatus\0"
    "oldStatus\0removeSendItem\0removeRecvItem\0"
    "removeChatItem\0Konversation::DCC::Chat*\0"
    "chat\0slotSettingsChanged\0upnpRouterDiscovered\0"
    "Konversation::UPnP::UPnPRouter*\0router"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__DCC__TransferManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       5,    1,   62,    2, 0x06 /* Public */,
       6,    1,   65,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    3,   68,    2, 0x08 /* Private */,
      12,    1,   75,    2, 0x08 /* Private */,
      13,    1,   78,    2, 0x08 /* Private */,
      14,    1,   81,    2, 0x08 /* Private */,
      17,    0,   84,    2, 0x08 /* Private */,
      18,    1,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 7,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,    9,   10,   11,
    QMetaType::Void, 0x80000000 | 3,    9,
    QMetaType::Void, 0x80000000 | 3,    9,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,

       0        // eod
};

void Konversation::DCC::TransferManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TransferManager *_t = static_cast<TransferManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newTransferAdded((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 1: _t->newDccTransferQueued((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 2: _t->fileURLChanged((*reinterpret_cast< Konversation::DCC::TransferRecv*(*)>(_a[1]))); break;
        case 3: _t->slotTransferStatusChanged((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->removeSendItem((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 5: _t->removeRecvItem((*reinterpret_cast< Konversation::DCC::Transfer*(*)>(_a[1]))); break;
        case 6: _t->removeChatItem((*reinterpret_cast< Konversation::DCC::Chat*(*)>(_a[1]))); break;
        case 7: _t->slotSettingsChanged(); break;
        case 8: _t->upnpRouterDiscovered((*reinterpret_cast< Konversation::UPnP::UPnPRouter*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TransferManager::*_t)(Konversation::DCC::Transfer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferManager::newTransferAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TransferManager::*_t)(Konversation::DCC::Transfer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferManager::newDccTransferQueued)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TransferManager::*_t)(Konversation::DCC::TransferRecv * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TransferManager::fileURLChanged)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Konversation::DCC::TransferManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Konversation__DCC__TransferManager.data,
      qt_meta_data_Konversation__DCC__TransferManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::DCC::TransferManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::DCC::TransferManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__DCC__TransferManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Konversation::DCC::TransferManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Konversation::DCC::TransferManager::newTransferAdded(Konversation::DCC::Transfer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::DCC::TransferManager::newDccTransferQueued(Konversation::DCC::Transfer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Konversation::DCC::TransferManager::fileURLChanged(Konversation::DCC::TransferRecv * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
