/****************************************************************************
** Meta object code from reading C++ file 'topiclabel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/topiclabel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'topiclabel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Konversation__TopicLabel_t {
    QByteArrayData data[9];
    char stringdata0[113];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Konversation__TopicLabel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Konversation__TopicLabel_t qt_meta_stringdata_Konversation__TopicLabel = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Konversation::TopicLabel"
QT_MOC_LITERAL(1, 25, 20), // "setStatusBarTempText"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 22), // "clearStatusBarTempText"
QT_MOC_LITERAL(4, 70, 8), // "openLink"
QT_MOC_LITERAL(5, 79, 4), // "link"
QT_MOC_LITERAL(6, 84, 7), // "setText"
QT_MOC_LITERAL(7, 92, 4), // "text"
QT_MOC_LITERAL(8, 97, 15) // "highlightedSlot"

    },
    "Konversation::TopicLabel\0setStatusBarTempText\0"
    "\0clearStatusBarTempText\0openLink\0link\0"
    "setText\0text\0highlightedSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Konversation__TopicLabel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       3,    0,   42,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   43,    2, 0x0a /* Public */,
       6,    1,   46,    2, 0x0a /* Public */,
       8,    1,   49,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void Konversation::TopicLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TopicLabel *_t = static_cast<TopicLabel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setStatusBarTempText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->clearStatusBarTempText(); break;
        case 2: _t->openLink((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->highlightedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TopicLabel::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TopicLabel::setStatusBarTempText)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TopicLabel::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TopicLabel::clearStatusBarTempText)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Konversation::TopicLabel::staticMetaObject = {
    { &QLabel::staticMetaObject, qt_meta_stringdata_Konversation__TopicLabel.data,
      qt_meta_data_Konversation__TopicLabel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Konversation::TopicLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konversation::TopicLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Konversation__TopicLabel.stringdata0))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int Konversation::TopicLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Konversation::TopicLabel::setStatusBarTempText(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Konversation::TopicLabel::clearStatusBarTempText()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
