/****************************************************************************
** Meta object code from reading C++ file 'ircinput.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/konversation-1.7.4/src/viewer/ircinput.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircinput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IRCInput_t {
    QByteArrayData data[26];
    char stringdata0[300];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IRCInput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IRCInput_t qt_meta_stringdata_IRCInput = {
    {
QT_MOC_LITERAL(0, 0, 8), // "IRCInput"
QT_MOC_LITERAL(1, 9, 14), // "nickCompletion"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 13), // "endCompletion"
QT_MOC_LITERAL(4, 39, 10), // "textPasted"
QT_MOC_LITERAL(5, 50, 4), // "text"
QT_MOC_LITERAL(6, 55, 6), // "submit"
QT_MOC_LITERAL(7, 62, 15), // "envelopeCommand"
QT_MOC_LITERAL(8, 78, 5), // "paste"
QT_MOC_LITERAL(9, 84, 12), // "useSelection"
QT_MOC_LITERAL(10, 97, 18), // "showCompletionList"
QT_MOC_LITERAL(11, 116, 5), // "nicks"
QT_MOC_LITERAL(12, 122, 7), // "setText"
QT_MOC_LITERAL(13, 130, 16), // "preserveContents"
QT_MOC_LITERAL(14, 147, 17), // "setLastCompletion"
QT_MOC_LITERAL(15, 165, 10), // "completion"
QT_MOC_LITERAL(16, 176, 16), // "setOverwriteMode"
QT_MOC_LITERAL(17, 193, 16), // "updateAppearance"
QT_MOC_LITERAL(18, 210, 10), // "getHistory"
QT_MOC_LITERAL(19, 221, 2), // "up"
QT_MOC_LITERAL(20, 224, 16), // "insertCompletion"
QT_MOC_LITERAL(21, 241, 4), // "nick"
QT_MOC_LITERAL(22, 246, 20), // "disableSpellChecking"
QT_MOC_LITERAL(23, 267, 16), // "setSpellChecking"
QT_MOC_LITERAL(24, 284, 3), // "set"
QT_MOC_LITERAL(25, 288, 11) // "maybeResize"

    },
    "IRCInput\0nickCompletion\0\0endCompletion\0"
    "textPasted\0text\0submit\0envelopeCommand\0"
    "paste\0useSelection\0showCompletionList\0"
    "nicks\0setText\0preserveContents\0"
    "setLastCompletion\0completion\0"
    "setOverwriteMode\0updateAppearance\0"
    "getHistory\0up\0insertCompletion\0nick\0"
    "disableSpellChecking\0setSpellChecking\0"
    "set\0maybeResize"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IRCInput[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,
       3,    0,  100,    2, 0x06 /* Public */,
       4,    1,  101,    2, 0x06 /* Public */,
       6,    0,  104,    2, 0x06 /* Public */,
       7,    0,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,  106,    2, 0x0a /* Public */,
      10,    1,  109,    2, 0x0a /* Public */,
      12,    2,  112,    2, 0x0a /* Public */,
      12,    1,  117,    2, 0x2a /* Public | MethodCloned */,
      14,    1,  120,    2, 0x0a /* Public */,
      16,    1,  123,    2, 0x0a /* Public */,
      17,    0,  126,    2, 0x0a /* Public */,
      18,    1,  127,    2, 0x09 /* Protected */,
      20,    1,  130,    2, 0x09 /* Protected */,
      22,    0,  133,    2, 0x09 /* Protected */,
      23,    1,  134,    2, 0x09 /* Protected */,
      25,    0,  137,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void, QMetaType::QStringList,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    5,   13,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void,

       0        // eod
};

void IRCInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        IRCInput *_t = static_cast<IRCInput *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nickCompletion(); break;
        case 1: _t->endCompletion(); break;
        case 2: _t->textPasted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->submit(); break;
        case 4: _t->envelopeCommand(); break;
        case 5: _t->paste((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->showCompletionList((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 7: _t->setText((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->setText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->setLastCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setOverwriteMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->updateAppearance(); break;
        case 12: _t->getHistory((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->insertCompletion((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->disableSpellChecking(); break;
        case 15: _t->setSpellChecking((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->maybeResize(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (IRCInput::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCInput::nickCompletion)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (IRCInput::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCInput::endCompletion)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (IRCInput::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCInput::textPasted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (IRCInput::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCInput::submit)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (IRCInput::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IRCInput::envelopeCommand)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject IRCInput::staticMetaObject = {
    { &KTextEdit::staticMetaObject, qt_meta_stringdata_IRCInput.data,
      qt_meta_data_IRCInput,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *IRCInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IRCInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IRCInput.stringdata0))
        return static_cast<void*>(this);
    return KTextEdit::qt_metacast(_clname);
}

int IRCInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void IRCInput::nickCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IRCInput::endCompletion()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IRCInput::textPasted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void IRCInput::submit()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IRCInput::envelopeCommand()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
